# -*- coding: binary -*-
require 'rex/post/meterpreter/extensions/stdapi/railgun/win_const_manager'
require 'thread'

module Rex
module Post
module Meterpreter
module Extensions
module Stdapi
module Railgun

#
# A container holding useful Windows API Constants.
#
class ApiConstants

	# This will be lazily loaded in self.manager
	@@manager = nil

	# Mutex to ensure we don't add constants more than once via thread races.
	@@manager_semaphore = Mutex.new

	#
	# Provides a frozen constant manager for the constants defined in
	# self.add_constants
	#
	def self.manager

		# The first check for nil is to potentially skip the need to synchronize
		if @@manager.nil?
			# Looks like we MAY need to load manager
			@@manager_semaphore.synchronize do
				# We check once more. Now our options are synchronized
				if @@manager.nil?
					@@manager = WinConstManager.new

					self.add_constants(@@manager)

					@@manager.freeze
				end
			end
		end

		return @@manager
	end

	#
	# Slurp in a giant list of known constants.
	#
	def self.add_constants(win_const_mgr)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_TINT',0x00004003)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_PROCESS',0x00000001)
		win_const_mgr.add_const('TF_LBI_TOOLTIP',0x00000004)
		win_const_mgr.add_const('CM_DRP_CLASSGUID',0x00000009)
		win_const_mgr.add_const('SYMMETRICWRAPKEYBLOB',0x0000000B)
		win_const_mgr.add_const('FKF_AVAILABLE',0x00000002)
		win_const_mgr.add_const('LINE_AGENTSTATUSEX',0x0000001D)
		win_const_mgr.add_const('REGDF_GENFORCEDCONFIG',0x00000020)
		win_const_mgr.add_const('ERROR_INSTALL_PACKAGE_REJECTED',0x00000659)
		win_const_mgr.add_const('AM_DVD_SECTOR_PROTECTED',0x00000020)
		win_const_mgr.add_const('BTH_ERROR_PAIRING_NOT_ALLOWED',0x00000018)
		win_const_mgr.add_const('CMSG_HASH_DATA_PARAM',0x00000015)
		win_const_mgr.add_const('DNS_ERROR_INCONSISTENT_ROOT_HINTS',0x0000255D)
		win_const_mgr.add_const('HSE_VECTOR_ELEMENT_TYPE_MEMORY_BUFFER',0x00000000)
		win_const_mgr.add_const('TASK_LAST_WEEK',0x00000005)
		win_const_mgr.add_const('DISPID_COLLECTION_RESERVED_MAX',0x000007FF)
		win_const_mgr.add_const('MSIM_DISPID_ONSESSIONMEMBERLEAVE',0x00000E0D)
		win_const_mgr.add_const('WPWIZ_ERROR_PROV_QI',0xC0042002)
		win_const_mgr.add_const('FLICK_WM_HANDLED_MASK',0x00000001)
		win_const_mgr.add_const('NS_NISPLUS',0x0000002A)
		win_const_mgr.add_const('WM_SYSCHAR',0x00000106)
		win_const_mgr.add_const('NDR_MAJOR_VERSION',0x00000005)
		win_const_mgr.add_const('SPPSR_ENUM_ADV_DEVICE_PROPERTIES',0x00000003)
		win_const_mgr.add_const('ICC_PAGESCROLLER_CLASS',0x00001000)
		win_const_mgr.add_const('SUBLANG_CORSICAN_FRANCE',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_IA64_PCREL60X',0x00000015)
		win_const_mgr.add_const('MD_WARNING_SAVE_FAILED',0x000CC809)
		win_const_mgr.add_const('GIL_CHECKSHIELD',0x00000200)
		win_const_mgr.add_const('DDE_FDEFERUPD',0x00004000)
		win_const_mgr.add_const('OS_NT4ORGREATER',0x00000003)
		win_const_mgr.add_const('DISK_LOGGING_DUMP',0x00000002)
		win_const_mgr.add_const('IMAGE_SIZEOF_SYMBOL',0x00000012)
		win_const_mgr.add_const('LVS_EX_HIDELABELS',0x00020000)
		win_const_mgr.add_const('DBT_VOLLOCKUNLOCKFAILED',0x00008046)
		win_const_mgr.add_const('WM_GETICON',0x0000007F)
		win_const_mgr.add_const('SEC_WINNT_AUTH_IDENTITY_VERSION',0x00000200)
		win_const_mgr.add_const('USER_MARSHAL_FC_USMALL',0x00000004)
		win_const_mgr.add_const('INTERNET_OPTION_HANDLE_TYPE',0x00000009)
		win_const_mgr.add_const('MCGIP_CALENDARBODY',0x00000006)
		win_const_mgr.add_const('EVENT_SYSTEM_DIALOGEND',0x00000011)
		win_const_mgr.add_const('MFOUTPUTATTRIBUTE_SOFTWARE',0x00000010)
		win_const_mgr.add_const('IMAGEHLP_GET_TYPE_INFO_CHILDREN',0x00000002)
		win_const_mgr.add_const('MCI_CD_OFFSET',0x00000440)
		win_const_mgr.add_const('CRED_MAX_DOMAIN_TARGET_NAME_LENGTH',0x00000100)
		win_const_mgr.add_const('ERROR_DS_SIZELIMIT_EXCEEDED',0x00002023)
		win_const_mgr.add_const('ACPI_PPM_SOFTWARE_ANY',0x000000FD)
		win_const_mgr.add_const('DM_PELSHEIGHT',0x00100000)
		win_const_mgr.add_const('EVENT_TRACE_CONTROL_STOP',0x00000001)
		win_const_mgr.add_const('BTH_ERROR_QOS_IS_NOT_SUPPORTED',0x00000027)
		win_const_mgr.add_const('DISPID_IWBSCRIPTCONTROL_VERSION',0x00000008)
		win_const_mgr.add_const('CLONE_FLAG_ENTITY',0x00000004)
		win_const_mgr.add_const('IP_UNICAST_IF',0x0000001F)
		win_const_mgr.add_const('LDAP_OPT_VERSION',0x00000011)
		win_const_mgr.add_const('CLUSAPI_CHANGE_ACCESS',0x00000002)
		win_const_mgr.add_const('SND_NOSTOP',0x00000010)
		win_const_mgr.add_const('L2_NOTIFICATION_SOURCE_ALL',0x00000000)
		win_const_mgr.add_const('IDM_SIZETOCONTROLHEIGHT',0x00000024)
		win_const_mgr.add_const('CTRY_CANADA',0x00000002)
		win_const_mgr.add_const('FWPM_ACTRL_CLASSIFY',0x00000010)
		win_const_mgr.add_const('SERVICE_STOP_REASON_FLAG_CUSTOM',0x20000000)
		win_const_mgr.add_const('DN_MOVED',0x00001000)
		win_const_mgr.add_const('RPC_S_ENTRY_TYPE_MISMATCH',0x00000782)
		win_const_mgr.add_const('DMBIN_LARGECAPACITY',0x0000000B)
		win_const_mgr.add_const('SOUND_SYSTEM_BEEP',0x00000003)
		win_const_mgr.add_const('SQL_FD_FETCH_ABSOLUTE',0x00000010)
		win_const_mgr.add_const('COLOR_HIGHLIGHTTEXT',0x0000000E)
		win_const_mgr.add_const('CTRY_SAUDI_ARABIA',0x000003C6)
		win_const_mgr.add_const('DEBUG_FILTER_GO_HANDLED',0x00000000)
		win_const_mgr.add_const('CR_FLG_RENEWAL',0x00000002)
		win_const_mgr.add_const('DDOVERZ_INSERTINBACKOF',0x00000005)
		win_const_mgr.add_const('PARITY_MARK',0x00000800)
		win_const_mgr.add_const('SUBLANG_BOSNIAN_BOSNIA_HERZEGOVINA_CYRILLIC',0x00000008)
		win_const_mgr.add_const('MSSIP_FLAGS_USE_CATALOG',0x00020000)
		win_const_mgr.add_const('PSINJECT_SHOWPAGE',0x00000069)
		win_const_mgr.add_const('TMT_GLYPHINDEX',0x00000972)
		win_const_mgr.add_const('OID_FDDI_MAC_FRAME_ERROR_FLAG',0x0303024C)
		win_const_mgr.add_const('PAN_SERIF_OBTUSE_SQUARE_COVE',0x00000005)
		win_const_mgr.add_const('JOYCAPS_HASPOV',0x00000010)
		win_const_mgr.add_const('WAVE_FORMAT_96S16',0x00080000)
		win_const_mgr.add_const('LVS_ALIGNTOP',0x00000000)
		win_const_mgr.add_const('SUBLANG_ALSATIAN_FRANCE',0x00000001)
		win_const_mgr.add_const('SQL_DL_SQL92_TIME',0x00000002)
		win_const_mgr.add_const('LANG_FAEROESE',0x00000038)
		win_const_mgr.add_const('SQL_QUALIFIER_NAME_SEPARATOR',0x00000029)
		win_const_mgr.add_const('DNS_TYPE_SINK',0x00000028)
		win_const_mgr.add_const('FD_QOS',0x00000001)
		win_const_mgr.add_const('EXCEPTION_MAXIMUM_PARAMETERS',0x0000000F)
		win_const_mgr.add_const('ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE',0x000036C2)
		win_const_mgr.add_const('SUBLANG_PORTUGUESE',0x00000002)
		win_const_mgr.add_const('POST_CHECK_CACHE_ENTRY',0x20000000)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_EXCEPTION',0x00000005)
		win_const_mgr.add_const('AUDIT_ENUMERATE_USERS',0x00000010)
		win_const_mgr.add_const('ALT4KB_BASE',0x6FC00000000)
		win_const_mgr.add_const('DIRID_COMMON_TEMPLATES',0x0000402D)
		win_const_mgr.add_const('MCI_DGV_INFO_TEXT',0x00010000)
		win_const_mgr.add_const('OPTION_REBIND_TIME',0x0000003B)
		win_const_mgr.add_const('WM_COMPAREITEM',0x00000039)
		win_const_mgr.add_const('TAPE_DRIVE_SET_REPORT_SMKS',0x80000800)
		win_const_mgr.add_const('RPC_X_SS_HANDLES_MISMATCH',0x000006F2)
		win_const_mgr.add_const('CRYPT_OCSP_ONLY_RETRIEVAL',0x01000000)
		win_const_mgr.add_const('PRINT_PROP_FORCE_NAME',0x00000001)
		win_const_mgr.add_const('DISPID_LISTITEM',0x00000000)
		win_const_mgr.add_const('DEVICE_STATE_DISABLED',0x00000002)
		win_const_mgr.add_const('NAP_BIT_OFFSET',0x00000008)
		win_const_mgr.add_const('SERVICE_CTRL_PAUSE',0x00000001)
		win_const_mgr.add_const('SECURITY_WORLD_RID',0x00000000)
		win_const_mgr.add_const('PPP_LCP_ACFC',0x00000004)
		win_const_mgr.add_const('DRMHSESSION_INVALID',0x00000000)
		win_const_mgr.add_const('FEI_MODEM_POWERED_OFF',0x00000012)
		win_const_mgr.add_const('VK_TAB',0x00000009)
		win_const_mgr.add_const('DNS_RTYPE_AXFR',0x00000000)
		win_const_mgr.add_const('IDD_UPDATELINKS',0x000003EF)
		win_const_mgr.add_const('SNMP_ERROR_READONLY',0x00000004)
		win_const_mgr.add_const('CMSG_KEY_TRANS_RECIPIENT',0x00000001)
		win_const_mgr.add_const('UISF_HIDEACCEL',0x00000002)
		win_const_mgr.add_const('WTPF_OFFLINEOK_COM',0x00000800)
		win_const_mgr.add_const('WPF_NO_VERIFY_POST',0x00000080)
		win_const_mgr.add_const('CERT_STORE_PROV_CONTROL_FUNC',0x0000000D)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_CONNECT_GOPHER',0x00000003)
		win_const_mgr.add_const('CB_GETEDITSEL',0x00000140)
		win_const_mgr.add_const('SFGAO_NONENUMERATED',0x00100000)
		win_const_mgr.add_const('XP1_SUPPORT_BROADCAST',0x00000200)
		win_const_mgr.add_const('STI_HW_CONFIG_SCSI',0x00000002)
		win_const_mgr.add_const('CSS_ENABLETEMPLATE',0x00000020)
		win_const_mgr.add_const('SEMAPHORE_MODIFY_STATE',0x00000002)
		win_const_mgr.add_const('OLEUI_CANCEL',0x00000002)
		win_const_mgr.add_const('RIM_TYPEHID',0x00000002)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_HAS_CLOCK',0x00004003)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MAGFGAUSSIANQUAD',0x10000000)
		win_const_mgr.add_const('SORT_JAPANESE_RADICALSTROKE',0x00000004)
		win_const_mgr.add_const('RSC_FLAG_QUIET',0x00000004)
		win_const_mgr.add_const('ERROR_CLIPPING_NOT_SUPPORTED',0x000007D5)
		win_const_mgr.add_const('XINPUT_GAMEPAD_BACK',0x00000020)
		win_const_mgr.add_const('CERT_DECIPHER_ONLY_KEY_USAGE',0x00000080)
		win_const_mgr.add_const('ERROR_TRANSACTION_REQUEST_NOT_VALID',0x00001A2E)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_DEFAULT_FLUSH',0x00000000)
		win_const_mgr.add_const('CRYPTDLG_REVOCATION_ONLINE',0x80000000)
		win_const_mgr.add_const('APPCOMMAND_BROWSER_STOP',0x00000004)
		win_const_mgr.add_const('DIF_ADDPROPERTYPAGE_ADVANCED',0x00000023)
		win_const_mgr.add_const('SV_ENFORCEKERBEROSREAUTHENTICATION_PARMNUM',0x00000257)
		win_const_mgr.add_const('TLMENUF_FORE',0x00000020)
		win_const_mgr.add_const('UIS_SET',0x00000001)
		win_const_mgr.add_const('FEI_BUSY',0x00000005)
		win_const_mgr.add_const('DMI_MASK',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_TYPE',0x00000001)
		win_const_mgr.add_const('DISPID_IWEBBRIDGE_SCROLLBAR',0x00000002)
		win_const_mgr.add_const('DN_HAS_MARK',0x00000200)
		win_const_mgr.add_const('IN_CLASSD_NET',0x00000000)
		win_const_mgr.add_const('ERROR_REDIRECTOR_HAS_OPEN_HANDLES',0x00000702)
		win_const_mgr.add_const('FP_MD_ID_BEGIN_RESERVED',0x00008000)
		win_const_mgr.add_const('IDD_DYNAWIZ_INSTALLDETECTEDDEVS_PAGE',0x0000271B)
		win_const_mgr.add_const('DISPID_IMULTISESSION_STARTSECTOROFPREVIOUSSESSION',0x00000201)
		win_const_mgr.add_const('TRUSTEE_ACCESS_READ',0x00000002)
		win_const_mgr.add_const('LNH_16_CPU',0x00000031)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_EJECTMEDIA',0x00000100)
		win_const_mgr.add_const('NS_DNS',0x0000000C)
		win_const_mgr.add_const('SE_ADT_PARAMETERS_SEND_TO_LSA',0x00000002)
		win_const_mgr.add_const('CFM_SMALLCAPS',0x00000040)
		win_const_mgr.add_const('DISPID_COMMANDSTATECHANGE',0x00000069)
		win_const_mgr.add_const('TBS_BOTH',0x00000008)
		win_const_mgr.add_const('IF_TYPE_IPFORWARD',0x0000008E)
		win_const_mgr.add_const('PIPE_CLIENT_END',0x00000000)
		win_const_mgr.add_const('ERROR_SXS_UNTRANSLATABLE_HRESULT',0x000036FD)
		win_const_mgr.add_const('DS_REPADD_SELECT_SECRETS',0x00001000)
		win_const_mgr.add_const('DICS_FLAG_CONFIGSPECIFIC',0x00000002)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_WANT_PROVIDER_LDAP',0x00000004)
		win_const_mgr.add_const('ISOLATIONAWARE_MANIFEST_RESOURCE_ID',0x00000002)
		win_const_mgr.add_const('WINHTTP_OPTION_RESOLVE_TIMEOUT',0x00000002)
		win_const_mgr.add_const('NS_DHCP',0x00000006)
		win_const_mgr.add_const('CMSG_VERSION_PARAM',0x0000001E)
		win_const_mgr.add_const('ERROR_INVALID_AT_INTERRUPT_TIME',0x00000068)
		win_const_mgr.add_const('ICDRAW_UPDATE',0x40000000)
		win_const_mgr.add_const('X3_TMPLT_INST_WORD_X',0x00000000)
		win_const_mgr.add_const('PST_KEY_CURRENT_USER',0x00000000)
		win_const_mgr.add_const('FLAG_ASSUME_COMP_WQLFILTER_TRUE',0x02000000)
		win_const_mgr.add_const('CMSG_MAIL_LIST_ENCRYPT_FREE_OBJID_FLAG',0x00000002)
		win_const_mgr.add_const('CM_PROB_MOVED',0x00000019)
		win_const_mgr.add_const('APD_STRICT_UPGRADE',0x00000001)
		win_const_mgr.add_const('KAGPROPVAL_CONCUR_LOCK',0x00000004)
		win_const_mgr.add_const('TRBN_LAST',0x00000000)
		win_const_mgr.add_const('DXVA_BITSTREAM_CONCEALMENT_NEED_LIKELY',0x00000002)
		win_const_mgr.add_const('MDM_MASK_PROTOCOLDATA',0x00000000)
		win_const_mgr.add_const('VPDF_FORCEAPM10MODE',0x00000002)
		win_const_mgr.add_const('DDCKEYCAPS_DESTOVERLAYONEACTIVE',0x00000080)
		win_const_mgr.add_const('IDM_ALIGNBOTTOM',0x00000001)
		win_const_mgr.add_const('PDCAP_WAKE_FROM_S1_SUPPORTED',0x00200000)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_NDSCONTAINER',0x0000000B)
		win_const_mgr.add_const('MAX_NOTIFICATION_DATA',0x00000040)
		win_const_mgr.add_const('MDM_SHIFT_HDLCPPP_SPEED',0x00000000)
		win_const_mgr.add_const('SQL_COLUMN_LENGTH',0x00000003)
		win_const_mgr.add_const('IMAGE_REL_SH3_TOKEN',0x00000012)
		win_const_mgr.add_const('LINECALLSTATE_UNKNOWN',0x00008000)
		win_const_mgr.add_const('SKF_LCTLLOCKED',0x00040000)
		win_const_mgr.add_const('DOT11_STATUS_ENCRYPTION_FAILED',0x00000200)
		win_const_mgr.add_const('IDC_GP_OBJECTSIZE',0x000003F3)
		win_const_mgr.add_const('COMMON_LVB_LEADING_BYTE',0x00000100)
		win_const_mgr.add_const('GAA_FLAG_SKIP_DNS_SERVER',0x00000008)
		win_const_mgr.add_const('DNF_UNUSED_28',0x10000000)
		win_const_mgr.add_const('DNF_UNUSED_27',0x08000000)
		win_const_mgr.add_const('DNF_UNUSED_26',0x04000000)
		win_const_mgr.add_const('SCARD_E_NO_SUCH_CERTIFICATE',0x8010002C)
		win_const_mgr.add_const('DNF_UNUSED_24',0x01000000)
		win_const_mgr.add_const('DNF_UNUSED_23',0x00800000)
		win_const_mgr.add_const('DNF_UNUSED_22',0x00400000)
		win_const_mgr.add_const('DNF_UNUSED_21',0x00200000)
		win_const_mgr.add_const('URLACTION_FEATURE_ZONE_ELEVATION',0x00002101)
		win_const_mgr.add_const('ISDB_ITT_TID',0x000000D2)
		win_const_mgr.add_const('GESTURE_BRACE_LEFT',0x00000000)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_COLLATIONS',0x00000003)
		win_const_mgr.add_const('CR_NO_SUCH_DEVICE_INTERFACE',0x00000037)
		win_const_mgr.add_const('MCI_DGV_STATUS_VOLUME',0x00004019)
		win_const_mgr.add_const('JIFMK_RST0',0x0000FFD0)
		win_const_mgr.add_const('DDCKEYCAPS_SRCBLTCLRSPACE',0x00000400)
		win_const_mgr.add_const('JIFMK_RST2',0x0000FFD2)
		win_const_mgr.add_const('JIFMK_RST5',0x0000FFD5)
		win_const_mgr.add_const('JIFMK_RST4',0x0000FFD4)
		win_const_mgr.add_const('JIFMK_RST7',0x0000FFD7)
		win_const_mgr.add_const('JIFMK_RST6',0x0000FFD6)
		win_const_mgr.add_const('LVCDRF_NOGROUPFRAME',0x00020000)
		win_const_mgr.add_const('LOCALE_SNATIVELANGNAME',0x00000004)
		win_const_mgr.add_const('LINEERR_INVALCONSULTCALLHANDLE',0x80000021)
		win_const_mgr.add_const('DDBLT_ZBUFFERDESTCONSTOVERRIDE',0x00100000)
		win_const_mgr.add_const('RF_SHOW_EVENTS',0x00800000)
		win_const_mgr.add_const('WM_MDIMAXIMIZE',0x00000225)
		win_const_mgr.add_const('RAS_EAP_FLAG_FIRST_LINK',0x00000010)
		win_const_mgr.add_const('NCBNAMSZ',0x00000010)
		win_const_mgr.add_const('CRR_ACTIVATION_LIMIT',0xFFFFFFFE)
		win_const_mgr.add_const('DB_PROT_LEVEL_CONNECT',0x00000001)
		win_const_mgr.add_const('INTERNET_CACHE_FLAG_ALLOW_COLLISIONS',0x00000100)
		win_const_mgr.add_const('DSA_NEWOBJ_CTX_PRECOMMIT',0x00000001)
		win_const_mgr.add_const('VER_SUITE_BACKOFFICE',0x00000004)
		win_const_mgr.add_const('WHITEBALANCE_ONEPUSH_AUTO',0x00000003)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_STRUCT',0x00000008)
		win_const_mgr.add_const('LINEMEDIAMODE_AUTOMATEDVOICE',0x00000008)
		win_const_mgr.add_const('SFC_DISABLE_ONCE',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_SH3_PCREL12_WORD',0x0000000B)
		win_const_mgr.add_const('PTE_ACCESS',0x00000005)
		win_const_mgr.add_const('SQL_SQL92_NUMERIC_VALUE_FUNCTIONS',0x0000009F)
		win_const_mgr.add_const('WIA_IPC_THUMBNAIL',0x00001402)
		win_const_mgr.add_const('D3D10_EFFECT_VARIABLE_ANNOTATION',0x00000001)
		win_const_mgr.add_const('OBM_OLD_CLOSE',0x00007FFF)
		win_const_mgr.add_const('IPP_E_FILENOTDIRTY',0xC0048004)
		win_const_mgr.add_const('IF_TYPE_HSSI',0x0000002E)
		win_const_mgr.add_const('SQL_MAX_PROCEDURE_NAME_LEN',0x00000021)
		win_const_mgr.add_const('ERROR_SXS_SETTING_NOT_REGISTERED',0x0000371A)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_ERROR',0x000035F8)
		win_const_mgr.add_const('ACM_FORMATENUMF_NCHANNELS',0x00020000)
		win_const_mgr.add_const('CCS_ADJUSTABLE',0x00000020)
		win_const_mgr.add_const('ZERO_PADDING',0x00000003)
		win_const_mgr.add_const('ASC_REQ_IDENTIFY',0x00080000)
		win_const_mgr.add_const('D3DDEVCAPS_TEXTURENONLOCALVIDMEM',0x00001000)
		win_const_mgr.add_const('MAXD3DDECLLENGTH',0x00000040)
		win_const_mgr.add_const('MAXD3DDECLUSAGEINDEX',0x0000000F)
		win_const_mgr.add_const('META_SETPOLYFILLMODE',0x00000106)
		win_const_mgr.add_const('SKF_CONFIRMHOTKEY',0x00000008)
		win_const_mgr.add_const('DTR_KIPCR2_INDEX',0x00000004)
		win_const_mgr.add_const('DIF_MOVEDEVICE',0x0000000E)
		win_const_mgr.add_const('RESERVED',0x80000000)
		win_const_mgr.add_const('ERROR_INVALID_OPERATION_ON_QUORUM',0x000013CC)
		win_const_mgr.add_const('RI_MOUSE_WHEEL',0x00000400)
		win_const_mgr.add_const('TMT_EDGESHADOWCOLOR',0x00000EDE)
		win_const_mgr.add_const('SYMFLAG_THUNK',0x00002000)
		win_const_mgr.add_const('BITS_MC_STATE_FILE_CORRUPT',0x80194007)
		win_const_mgr.add_const('PSR_MBZ1_V',0x00000001)
		win_const_mgr.add_const('PAN_PROP_MODERN',0x00000003)
		win_const_mgr.add_const('SMC_AUTOEXPANDCHANGE',0x00000042)
		win_const_mgr.add_const('WSB_PROP_CXHSCROLL',0x00000002)
		win_const_mgr.add_const('JRO_VERSION',0x00000002)
		win_const_mgr.add_const('SPSVCINST_TAGTOFRONT',0x00000001)
		win_const_mgr.add_const('IDTB_TOC_PREV',0x000000E0)
		win_const_mgr.add_const('IDC_VP_ASICON',0x000003EB)
		win_const_mgr.add_const('CM_DISABLE_BITS',0x00000007)
		win_const_mgr.add_const('SORTED_CTL_EXT_FLAGS_OFFSET',0x00000000)
		win_const_mgr.add_const('IPP_E_FIRST',0x40048000)
		win_const_mgr.add_const('SQL_MORE_INFO_YES',0x00000001)
		win_const_mgr.add_const('IASSEMBLYCACHE_UNINSTALL_DISPOSITION_REFERENCE_NOT_FOUND',0x00000006)
		win_const_mgr.add_const('WLX_OPTION_IGNORE_AUTO_LOGON',0x00000008)
		win_const_mgr.add_const('SCRIPTPROP_HOSTSTACKREQUIRED',0x00001003)
		win_const_mgr.add_const('HC_SKIP',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_KEEP_CONNECTION',0x00000016)
		win_const_mgr.add_const('HHWIN_BUTTON_FORWARD',0x00000001)
		win_const_mgr.add_const('DFM_INVOKECOMMAND',0x00000002)
		win_const_mgr.add_const('CB_SETHORIZONTALEXTENT',0x00000015)
		win_const_mgr.add_const('ERROR_MEDIA_NOT_AVAILABLE',0x000010DE)
		win_const_mgr.add_const('ERROR_IPSEC_MM_FILTER_PENDING_DELETION',0x000032DA)
		win_const_mgr.add_const('UF_PARTIAL_SECRETS_ACCOUNT',0x04000000)
		win_const_mgr.add_const('EXPOSUREMETERING_CENTERSPOT',0x00000004)
		win_const_mgr.add_const('DISPID_SETVIEWTYPE',0x00000017)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_DEF_FLOW_DURATION',0x00000009)
		win_const_mgr.add_const('SV_SRVHEURISTICS_PARMNUM',0x000001AF)
		win_const_mgr.add_const('INCLUDED_TYPES_FCI_FDI',0x00000001)
		win_const_mgr.add_const('WM_NEXTDLGCTL',0x00000028)
		win_const_mgr.add_const('OID_TCP_OFFLOAD_PARAMETERS',0xFC01020C)
		win_const_mgr.add_const('L2CAP_DEFAULT_MTU',0x000002A0)
		win_const_mgr.add_const('SM_CXICON',0x0000000B)
		win_const_mgr.add_const('WMS_STREAM_AVG_BITRATE',0x00000003)
		win_const_mgr.add_const('ALLOCATE_RESPONSE',0x00000002)
		win_const_mgr.add_const('MD_ACCESS_EXECUTE',0x00000004)
		win_const_mgr.add_const('TMT_HEIGHT',0x00000971)
		win_const_mgr.add_const('CERT_IE30_RESERVED_PROP_ID',0x00000007)
		win_const_mgr.add_const('DNS_QUERY_STANDARD',0x00000000)
		win_const_mgr.add_const('SERVICE_QUALITATIVE',0x80200000)
		win_const_mgr.add_const('OID_802_3_MULTICAST_LIST',0x01010103)
		win_const_mgr.add_const('TRUSTEE_ACCESS_ALL',0xFFFFFFFF)
		win_const_mgr.add_const('IMAGE_SCN_NO_DEFER_SPEC_EXC',0x00004000)
		win_const_mgr.add_const('BG_E_TOO_LARGE',0x80200020)
		win_const_mgr.add_const('DISPID_FOCUSCHANGED',0x000000D0)
		win_const_mgr.add_const('DBCOMPUTEMODE_DYNAMIC',0x00000002)
		win_const_mgr.add_const('DNS_TYPE_ADDRS',0x00000000)
		win_const_mgr.add_const('STM_SETICON',0x00000170)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_GRP_FLOW_DURATION',0x0000000E)
		win_const_mgr.add_const('PRINTER_CHANGE_WRITE_JOB',0x00000800)
		win_const_mgr.add_const('INTERNET_OPTION_DATA_RECEIVE_TIMEOUT',0x00000008)
		win_const_mgr.add_const('KSALLOCATOR_REQUIREMENTF_FRAME_INTEGRITY',0x00000004)
		win_const_mgr.add_const('CSIDL_CDBURN_AREA',0x00000003)
		win_const_mgr.add_const('CMSG_CMS_RECIPIENT_INFO_PARAM',0x00000024)
		win_const_mgr.add_const('NDW_INSTALLFLAG_NODETECTEDDEVS',0x00001000)
		win_const_mgr.add_const('MDM_PROTOCOLID_AUTO',0x00000006)
		win_const_mgr.add_const('SQL_CVT_LONGVARBINARY',0x00040000)
		win_const_mgr.add_const('WM_RESTORE_INDIVIDUALIZE',0x00000002)
		win_const_mgr.add_const('ARRAY_SEP_CHAR',0x00000009)
		win_const_mgr.add_const('SC_MANAGER_CREATE_SERVICE',0x00000002)
		win_const_mgr.add_const('ERROR_NO_SAVEPOINT_WITH_OPEN_FILES',0x00001ABA)
		win_const_mgr.add_const('OID_FDDI_SMT_STATION_ACTION',0x03030277)
		win_const_mgr.add_const('OID_PNP_ADD_WAKE_UP_PATTERN',0xFD010103)
		win_const_mgr.add_const('ERROR_NO_USER_KEYS',0x00001776)
		win_const_mgr.add_const('ERROR_ILLEGAL_FLOAT_CONTEXT',0x00000243)
		win_const_mgr.add_const('ISR_TPA',0x00000000)
		win_const_mgr.add_const('DEVPROP_TYPE_INT32',0x00000006)
		win_const_mgr.add_const('SIO_ASSOCIATE_PVC',0x90160003)
		win_const_mgr.add_const('LANG_KAZAK',0x00000003)
		win_const_mgr.add_const('FS_THAI',0x00010000)
		win_const_mgr.add_const('DDOSD_GUID',0x00000001)
		win_const_mgr.add_const('ARW_BOTTOMRIGHT',0x00000001)
		win_const_mgr.add_const('IPSEC_POLICY_FLAG_CLEAR_DF_ON_TUNNEL',0x00000008)
		win_const_mgr.add_const('AE_UAS_MODALS',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_GETSPIFAIL',0x00003621)
		win_const_mgr.add_const('ERROR_DS_DRA_SCHEMA_INFO_SHIP',0x0000215E)
		win_const_mgr.add_const('SE_ADT_PARAMETER_GENERIC_AUDIT',0x00000008)
		win_const_mgr.add_const('MD_EXTLOG_CLIENT_IP',0x00000004)
		win_const_mgr.add_const('MIB_IF_ADMIN_STATUS_DOWN',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_NP_ABOUTTODO',0x00000002)
		win_const_mgr.add_const('OPTION_NON_LOCAL_SOURCE_ROUTING',0x00000014)
		win_const_mgr.add_const('PROP_UPDATE',0x00000002)
		win_const_mgr.add_const('SQL_DATABASE_NAME',0x00000010)
		win_const_mgr.add_const('LINEDIGITMODE_DTMFEND',0x00000004)
		win_const_mgr.add_const('DNS_TYPE_NAPTR',0x00000023)
		win_const_mgr.add_const('LINE_LEN',0x00000100)
		win_const_mgr.add_const('TF_CONVERSIONMODE_FIXED',0x00000800)
		win_const_mgr.add_const('EDITF_ATTRIBUTESUBJECTALTNAME2',0x00040000)
		win_const_mgr.add_const('SES_USEAIMM',0x00000040)
		win_const_mgr.add_const('ERROR_INSTALL_PACKAGE_INVALID',0x00000654)
		win_const_mgr.add_const('SQL_TXN_SERIALIZABLE',0x00000008)
		win_const_mgr.add_const('CRYPT_OID_INFO_SIGN_KEY',0x00000004)
		win_const_mgr.add_const('CAPATHLENGTH_INFINITE',0x00000000)
		win_const_mgr.add_const('SUBLANG_ENGLISH_NZ',0x00000005)
		win_const_mgr.add_const('SHGFI_SMALLICON',0x00000001)
		win_const_mgr.add_const('BTH_ERROR_UNSPECIFIED_ERROR',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_NONCE',0x0000360F)
		win_const_mgr.add_const('ISFB_MASK_BKCOLOR',0x00000002)
		win_const_mgr.add_const('EVENT_TRACE_FILE_MODE_NEWFILE',0x00000008)
		win_const_mgr.add_const('MCI_DGV_PUT_SOURCE',0x00020000)
		win_const_mgr.add_const('SEE_MASK_CLASSNAME',0x00000001)
		win_const_mgr.add_const('SQL_CONCURRENCY',0x00000007)
		win_const_mgr.add_const('CCHCCTEXT',0x00000100)
		win_const_mgr.add_const('XINPUT_GAMEPAD_DPAD_DOWN',0x00000002)
		win_const_mgr.add_const('DS_REPL_NBR_RETURN_OBJECT_PARENTS',0x00000800)
		win_const_mgr.add_const('DBPROPVAL_PT_PGUID_NAME',0x00000020)
		win_const_mgr.add_const('OBM_CHECK',0x00007FF8)
		win_const_mgr.add_const('ICW_FULL_SMARTSTART',0x00000800)
		win_const_mgr.add_const('SPDSL_DISALLOW_NEGATIVE_ADJUST',0x00000002)
		win_const_mgr.add_const('LINEERR_NODEVICE',0x80000042)
		win_const_mgr.add_const('ERRCLASS_ALREADY',0x0000000C)
		win_const_mgr.add_const('META_OFFSETWINDOWORG',0x0000020F)
		win_const_mgr.add_const('PICTYPE_BITMAP',0x00000001)
		win_const_mgr.add_const('MCI_VCR_STATUS_COUNTER_RESOLUTION',0x00004011)
		win_const_mgr.add_const('FS_BAD_ADDRESS',0x20000100)
		win_const_mgr.add_const('DXVA_DEBLOCKING_CONTROL_BUFFER',0x00000004)
		win_const_mgr.add_const('WINHTTP_FLAG_NULL_CODEPAGE',0x00000008)
		win_const_mgr.add_const('ACMFORMATCHOOSE_STYLEF_SHOWHELP',0x00000004)
		win_const_mgr.add_const('CHANGER_PREDISMOUNT_ALIGN_TO_SLOT',0x80000001)
		win_const_mgr.add_const('DDOSD_COMPRESSION_RATIO',0x00000002)
		win_const_mgr.add_const('MD_CPU_ENABLE_KERNEL_TIME',0x00000008)
		win_const_mgr.add_const('CERT_KEY_SPEC_PROP_ID',0x00000006)
		win_const_mgr.add_const('NETE_TOOMANYCONN',0x00000005)
		win_const_mgr.add_const('OBM_ZOOMD',0x00007FE9)
		win_const_mgr.add_const('OLEUI_QUERY_LINKBROKEN',0x0000FF01)
		win_const_mgr.add_const('OID_802_11_PMKID',0x0D010123)
		win_const_mgr.add_const('DEVPROP_TYPE_SBYTE',0x00000002)
		win_const_mgr.add_const('PORT_FINGER',0x0000004F)
		win_const_mgr.add_const('SB_ENDSCROLL',0x00000008)
		win_const_mgr.add_const('FILE_DEVICE_8042_PORT',0x00000027)
		win_const_mgr.add_const('MPEG2_PROGRAM_ELEMENTARY_STREAM',0x00000001)
		win_const_mgr.add_const('ERROR_NO_VOLUME_ID',0x00000495)
		win_const_mgr.add_const('SECURITY_FLAG_IGNORE_REVOCATION',0x00000080)
		win_const_mgr.add_const('RECOFLAG_COERCE',0x00000002)
		win_const_mgr.add_const('PIDSI_GENRE',0x0000000B)
		win_const_mgr.add_const('MDPROPVAL_NME_MEASURESONLY',0x00000001)
		win_const_mgr.add_const('DDCKEYCAPS_DESTBLTCLRSPACEYUV',0x00000004)
		win_const_mgr.add_const('AE_NETLOGOFF',0x0000000F)
		win_const_mgr.add_const('ATSC_PIT_TID',0x000000D0)
		win_const_mgr.add_const('EXTENSION_CRITICAL_FLAG',0x00000001)
		win_const_mgr.add_const('ERROR_INVALID_ACCOUNT_NAME',0x00000523)
		win_const_mgr.add_const('INITIAL_MXCSR',0x00000001)
		win_const_mgr.add_const('SECURITY_PROXY_RID',0x00000008)
		win_const_mgr.add_const('CRYPT_LDAP_SIGN_RETRIEVAL',0x00010000)
		win_const_mgr.add_const('GBF_DIRECT',0x00000001)
		win_const_mgr.add_const('DISPID_EVENTHOOK_INSENSITIVE_BASE',0x0044AA20)
		win_const_mgr.add_const('DBPROPVAL_NC_START',0x00000008)
		win_const_mgr.add_const('FILE_ENCRYPTABLE',0x00000000)
		win_const_mgr.add_const('NTMS_PRODUCTNAME_LENGTH',0x00000080)
		win_const_mgr.add_const('SQL_FD_FETCH_BOOKMARK',0x00000080)
		win_const_mgr.add_const('PDH_UNABLE_READ_LOG_HEADER',0xC0000BD0)
		win_const_mgr.add_const('META_SETVIEWPORTEXT',0x0000020E)
		win_const_mgr.add_const('CPL_INQUIRE',0x00000003)
		win_const_mgr.add_const('MAX_CLASS_NAME_LEN',0x00000020)
		win_const_mgr.add_const('WIN32',0x00000064)
		win_const_mgr.add_const('TABLET_DISABLE_FLICKFALLBACKKEYS',0x00100000)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_CRYPTO_OPERATORS',0x00000239)
		win_const_mgr.add_const('D3DDEVCAPS_HWRASTERIZATION',0x00080000)
		win_const_mgr.add_const('SQL_FN_TSI_SECOND',0x00000002)
		win_const_mgr.add_const('URLPOLICY_CREDENTIALS_MUST_PROMPT_USER',0x00010000)
		win_const_mgr.add_const('D3DPCMPCAPS_NEVER',0x00000001)
		win_const_mgr.add_const('DTBG_CLIPRECT',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_RCODE_NXRRSET',0x00002330)
		win_const_mgr.add_const('ERROR_DS_RIDMGR_INIT_ERROR',0x00002013)
		win_const_mgr.add_const('WIA_DPC_COMPRESSION_SETTING',0x00000817)
		win_const_mgr.add_const('EXPOSUREMODE_APERTURE_PRIORITY',0x00000003)
		win_const_mgr.add_const('COD_AUDIO_MINOR_VIDEO_MONITOR',0x0000000E)
		win_const_mgr.add_const('WM_MDIACTIVATE',0x00000222)
		win_const_mgr.add_const('DMPAPER_PENV_2_ROTATED',0x0000006E)
		win_const_mgr.add_const('MCI_VCR_CUE_INPUT',0x00010000)
		win_const_mgr.add_const('DDCKEY_SRCBLT',0x00000008)
		win_const_mgr.add_const('SWP_NOCOPYBITS',0x00000100)
		win_const_mgr.add_const('HTTP_STATUS_MOVED',0x0000012D)
		win_const_mgr.add_const('FPF_SEND',0x00000002)
		win_const_mgr.add_const('ERROR_FAIL_RESTART',0x00000160)
		win_const_mgr.add_const('CRYPT_OID_INFO_NAME_KEY',0x00000002)
		win_const_mgr.add_const('SM_CXMENUSIZE',0x00000036)
		win_const_mgr.add_const('DTN_LAST2',0x00000000)
		win_const_mgr.add_const('CRED_ENUMERATE_ALL_CREDENTIALS',0x00000001)
		win_const_mgr.add_const('MCI_DGV_INFO_VIDEO_ALG',0x00004006)
		win_const_mgr.add_const('DEBUG_REGSRC_DEBUGGEE',0x00000000)
		win_const_mgr.add_const('EMR_STROKEPATH',0x00000040)
		win_const_mgr.add_const('SW_SHOWMINIMIZED',0x00000002)
		win_const_mgr.add_const('GQOS_ERRORCODE_UNKNOWN',0xFFFFFFFF)
		win_const_mgr.add_const('AUDIT_QUERY_SYSTEM_POLICY',0x00000002)
		win_const_mgr.add_const('LINEERR_INVALFEATURE',0x80000055)
		win_const_mgr.add_const('RPC_S_UNKNOWN_MGR_TYPE',0x000006B4)
		win_const_mgr.add_const('TCI_SRCCODEPAGE',0x00000002)
		win_const_mgr.add_const('TB_USER_MASK',0x00000180)
		win_const_mgr.add_const('SQL_ATTR_APP_PARAM_DESC',0x0000271B)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_BROADCAST_FRAMES_XMIT',0x00000100)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_NON_TRANSITIVE',0x00000001)
		win_const_mgr.add_const('OID_FDDI_MAC_FRAME_ERROR_RATIO',0x03030246)
		win_const_mgr.add_const('WLX_DLG_SAS',0x00000065)
		win_const_mgr.add_const('MCI_DGV_STATUS_VIDEO_STREAM',0x00000402)
		win_const_mgr.add_const('DSGIF_ISDISABLED',0x00000002)
		win_const_mgr.add_const('WMDM_SP_REVOKED',0x00000004)
		win_const_mgr.add_const('HSE_EXEC_URL_SSI_CMD',0x00000040)
		win_const_mgr.add_const('DSBI_ENTIREDIRECTORY',0x00090000)
		win_const_mgr.add_const('IME_CAND_STROKE',0x00000005)
		win_const_mgr.add_const('TVIF_INTEGRAL',0x00000080)
		win_const_mgr.add_const('SCARD_CLASS_PERF',0x00000007)
		win_const_mgr.add_const('INDEX_GUID_DESCENDER',0x00000008)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_CALLHUB',0x00000400)
		win_const_mgr.add_const('D3DMIN30SHADERINSTRUCTIONS',0x00000200)
		win_const_mgr.add_const('PORT_NFS',0x00000801)
		win_const_mgr.add_const('RECO_CUT',0x00000003)
		win_const_mgr.add_const('FR_PROP_NONE',0x00000000)
		win_const_mgr.add_const('MCI_VCR_STATUS_AUDIO_MONITOR',0x0000400A)
		win_const_mgr.add_const('NETSH_VERSION_50',0x00005000)
		win_const_mgr.add_const('AGP_FLAG_SPECIAL_RESERVE',0x000F8000)
		win_const_mgr.add_const('FAX_CONFIG_SET',0x00000008)
		win_const_mgr.add_const('FILE_DEVICE_DISK',0x00000007)
		win_const_mgr.add_const('CERT_ISSUER_PUBLIC_KEY_MD5_HASH_PROP_ID',0x00000018)
		win_const_mgr.add_const('LIF_URL',0x00000008)
		win_const_mgr.add_const('WLAN_CONNECTION_ADHOC_JOIN_ONLY',0x00000002)
		win_const_mgr.add_const('ERROR_INVALID_ACCESS',0x0000000C)
		win_const_mgr.add_const('LINEPROXYREQUEST_SETAGENTMEASUREMENTPERIOD',0x0000000A)
		win_const_mgr.add_const('DWFAF_HIDDEN',0x00000001)
		win_const_mgr.add_const('EMR_CREATEPEN',0x00000026)
		win_const_mgr.add_const('TCP_CONGESTION_ALGORITHM',0x0000000C)
		win_const_mgr.add_const('LINEERR_DIALDIALTONE',0x80000009)
		win_const_mgr.add_const('COMPRESSION_FORMAT_DEFAULT',0x00000001)
		win_const_mgr.add_const('SVAUD_BADNETLOGON',0x00000180)
		win_const_mgr.add_const('ETW_REVERSED_COUNTED_STRING_TYPE_VALUE',0x0000006E)
		win_const_mgr.add_const('HSHELL_APPCOMMAND',0x0000000C)
		win_const_mgr.add_const('DLGC_WANTCHARS',0x00000080)
		win_const_mgr.add_const('DIF_NEWDEVICEWIZARD_FINISHINSTALL',0x0000001E)
		win_const_mgr.add_const('DNS_ERROR_ZONE_ALREADY_EXISTS',0x00002589)
		win_const_mgr.add_const('IDM_PASTEINSERT',0x00000848)
		win_const_mgr.add_const('IMGCHG_SIZE',0x00000001)
		win_const_mgr.add_const('TF_NAVIGATE',0x7FAEABAC)
		win_const_mgr.add_const('ASYNCH',0x00000080)
		win_const_mgr.add_const('CBR_19200',0x00004B00)
		win_const_mgr.add_const('X3_I_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('ERROR_INVALID_LDT_SIZE',0x00000231)
		win_const_mgr.add_const('EXCHIVERB_REPLYTOSENDER',0x00000066)
		win_const_mgr.add_const('LC_POLYMARKER',0x00000008)
		win_const_mgr.add_const('RI_MOUSE_MIDDLE_BUTTON_DOWN',0x00000010)
		win_const_mgr.add_const('VK_LBUTTON',0x00000001)
		win_const_mgr.add_const('INT32_MAX',0x7FFFFFFF)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_UNAUTH_USER_SUM_FLOW_RATE',0x00000024)
		win_const_mgr.add_const('CREATE_WAITABLE_TIMER_MANUAL_RESET',0x00000001)
		win_const_mgr.add_const('SQL_TXN_READ_COMMITTED',0x00000002)
		win_const_mgr.add_const('MCI_VD_PLAY_SLOW',0x00100000)
		win_const_mgr.add_const('PFM_DONOTHYPHEN',0x00400000)
		win_const_mgr.add_const('AIF_REPLACEONLY',0x00000400)
		win_const_mgr.add_const('FD_WRITE_BIT',0x00000001)
		win_const_mgr.add_const('ULONG_MAX',0x00000000)
		win_const_mgr.add_const('ERROR_USER_PROFILE_LOAD',0x000001F4)
		win_const_mgr.add_const('FILE_IS_ENCRYPTED',0x00000001)
		win_const_mgr.add_const('MOD_WAVETABLE',0x00000006)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_FLAG_SECURITY_CHANNEL_ERROR',0x80000000)
		win_const_mgr.add_const('WEBPOST_ERROR_POST_FILES',0xC004210F)
		win_const_mgr.add_const('EMR_POLYLINETO',0x00000006)
		win_const_mgr.add_const('CM_DRP_EXCLUSIVE',0x0000001B)
		win_const_mgr.add_const('EAP_FLAG_CONFG_READONLY',0x00080000)
		win_const_mgr.add_const('IP_DEFAULT_MULTICAST_LOOP',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_BRIGHTNESS',0x00004000)
		win_const_mgr.add_const('X3_TMPLT_SIGN_VAL_POS_X',0x00000000)
		win_const_mgr.add_const('RPC_S_INVALID_STRING_BINDING',0x000006A4)
		win_const_mgr.add_const('QUOTA_LIMITS_HARDWS_MAX_ENABLE',0x00000004)
		win_const_mgr.add_const('DXVA_SCAN_METHOD_ZIG_ZAG',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_MEMORY_HARD_FAULTS',0x00002000)
		win_const_mgr.add_const('MILCORE_TS_QUERYVER_RESULT_FALSE',0x00000000)
		win_const_mgr.add_const('USER_SCRIPT_PATH_PARMNUM',0x00000009)
		win_const_mgr.add_const('LR_VGACOLOR',0x00000080)
		win_const_mgr.add_const('RSC_LOADRS_LEN',0x0000000E)
		win_const_mgr.add_const('BITS_MC_JOB_TAKE_OWNERSHIP',0x80194004)
		win_const_mgr.add_const('BYTE_ERROR',0x00000000)
		win_const_mgr.add_const('WSA_QOS_EFLOWCOUNT',0x00002B0F)
		win_const_mgr.add_const('GPT_BASIC_DATA_ATTRIBUTE_HIDDEN',0x4000000000000000)
		win_const_mgr.add_const('WIA_PAGE_USLEGAL',0x00000003)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_DISABLEDVDCOMPATIBILITYMODE',0x0000010E)
		win_const_mgr.add_const('NET_SITEID_MAXSYSTEM',0x00000000)
		win_const_mgr.add_const('DLG_FLAGS_SEC_CERT_CN_INVALID',0x02000000)
		win_const_mgr.add_const('MCI_AVI_SETVIDEO_PALETTE_COLOR',0x00008100)
		win_const_mgr.add_const('ERROR_DS_UNWILLING_TO_PERFORM',0x00002035)
		win_const_mgr.add_const('PRF_NONCLIENT',0x00000002)
		win_const_mgr.add_const('DEX_IDS_ILLEGAL_PROPERTY_VAL',0x00000588)
		win_const_mgr.add_const('DEBUG_GETMOD_DEFAULT',0x00000000)
		win_const_mgr.add_const('CRED_PERSIST_LOCAL_MACHINE',0x00000002)
		win_const_mgr.add_const('PIPE_READMODE_MESSAGE',0x00000002)
		win_const_mgr.add_const('DNS_QUERY_NO_HOSTS_FILE',0x00000040)
		win_const_mgr.add_const('ODA_DRAWENTIRE',0x00000001)
		win_const_mgr.add_const('CLUSTER_VERSION_UNKNOWN',0xFFFFFFFF)
		win_const_mgr.add_const('BL_36M',0x02400000)
		win_const_mgr.add_const('DOMAIN_NO_LM_OWF_CHANGE',0x00000040)
		win_const_mgr.add_const('ERROR_MAPPED_ALIGNMENT',0x0000046C)
		win_const_mgr.add_const('HTTP_LOGGING_FLAG_LOCAL_TIME_ROLLOVER',0x00000001)
		win_const_mgr.add_const('CRLF_IGNORE_UNKNOWN_CMC_ATTRIBUTES',0x00000080)
		win_const_mgr.add_const('BTH_MAJORVERSION',0x00000002)
		win_const_mgr.add_const('ELEMENT_STATUS_PRODUCT_DATA',0x00000040)
		win_const_mgr.add_const('APPCOMMAND_BROWSER_REFRESH',0x00000003)
		win_const_mgr.add_const('CI_STATE_DELETION_MERGE',0x00008000)
		win_const_mgr.add_const('IR_CLOSECONVERT',0x00000122)
		win_const_mgr.add_const('SQL_API_SQLBINDCOL',0x00000004)
		win_const_mgr.add_const('SES_MAPCPS',0x00000008)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_FREESECTORS',0x00000109)
		win_const_mgr.add_const('RESTART_NO_PATCH',0x00000004)
		win_const_mgr.add_const('CS_HREDRAW',0x00000002)
		win_const_mgr.add_const('RSA1024BIT_KEY',0x04000000)
		win_const_mgr.add_const('RPC_C_OPT_BINDING_NONCAUSAL',0x00000009)
		win_const_mgr.add_const('PSP_USEHICON',0x00000002)
		win_const_mgr.add_const('SWP_NOZORDER',0x00000004)
		win_const_mgr.add_const('PHONESTATE_RESUME',0x00080000)
		win_const_mgr.add_const('MD_LOGON_INTERACTIVE',0x00000000)
		win_const_mgr.add_const('MQ_LOOKUP_PEEK_CURRENT',0x40000010)
		win_const_mgr.add_const('MDPROPVAL_MSF_LASTPERIODS',0x00000020)
		win_const_mgr.add_const('D3DSI_COMMENTSIZE_MASK',0x7FFF0000)
		win_const_mgr.add_const('HTTP_RESPONSE_INFO_FLAGS_PRESERVE_ORDER',0x00000001)
		win_const_mgr.add_const('WNODE_FLAG_SINGLE_ITEM',0x00000004)
		win_const_mgr.add_const('MSV1_0_SUBAUTH_WORKSTATIONS',0x00000004)
		win_const_mgr.add_const('SCOPE_FLAG_INCLUDE',0x00000001)
		win_const_mgr.add_const('ERROR_TM_VOLATILE',0x00001AAC)
		win_const_mgr.add_const('STATE_SYSTEM_PROTECTED',0x20000000)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_PROVIDER_CHIMNEY_OFFLOAD_GENERIC_CHARACTERISTICS',0x0000008F)
		win_const_mgr.add_const('ERROR_DEBUGGER_INACTIVE',0x00000504)
		win_const_mgr.add_const('DEBUG_VALUE_FLOAT128',0x00000009)
		win_const_mgr.add_const('TKF_HOTKEYSOUND',0x00000010)
		win_const_mgr.add_const('WAVECAPS_PLAYBACKRATE',0x00000002)
		win_const_mgr.add_const('CLIP_CHARACTER_PRECIS',0x00000001)
		win_const_mgr.add_const('SPI_SETHANDHELD',0x0000004E)
		win_const_mgr.add_const('IDM_VERTSPACEINCREASE',0x00000030)
		win_const_mgr.add_const('MB_YESNO',0x00000004)
		win_const_mgr.add_const('ALINF_ROLLBACK',0x00000040)
		win_const_mgr.add_const('SI_NO_ADDITIONAL_PERMISSION',0x00200000)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_ALG',0x00020000)
		win_const_mgr.add_const('STM_GETICON',0x00000171)
		win_const_mgr.add_const('INTERNET_FLAG_SECURE',0x00800000)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_RESERVED4',0x00010000)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_SETS',0x00000005)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_TRUST_TESTROOT_FLAG',0x00004000)
		win_const_mgr.add_const('AF_BTH',0x00000020)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_SUPPORTEDWRITESPEEDS',0x0000010F)
		win_const_mgr.add_const('CR_WRONG_TYPE',0x00000026)
		win_const_mgr.add_const('DS_SCHEMA_GUID_NOT_FOUND',0x00000000)
		win_const_mgr.add_const('ERROR_DS_PARAM_ERROR',0x0000203F)
		win_const_mgr.add_const('TXFS_RM_FLAG_LOG_GROWTH_INCREMENT_PERCENT',0x00000020)
		win_const_mgr.add_const('DBPROPVAL_IN_ALLOWNULL',0x00000000)
		win_const_mgr.add_const('RF_LINED_INPUT',0x00000008)
		win_const_mgr.add_const('ADN_DONT_DEL_DIR',0x00000004)
		win_const_mgr.add_const('CBR_115200',0x0001C200)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_CODE_SEGMENTS',0x00001000)
		win_const_mgr.add_const('D3DUSAGE_QUERY_WRAPANDMIP',0x00200000)
		win_const_mgr.add_const('CONFIGMG_VERSION',0x00000400)
		win_const_mgr.add_const('TPM_HORPOSANIMATION',0x00000400)
		win_const_mgr.add_const('MQ_LOOKUP_RECEIVE_NEXT',0x40000021)
		win_const_mgr.add_const('IFS_IFM_LEN',0x00000026)
		win_const_mgr.add_const('WIA_IPA_FORMAT',0x0000100A)
		win_const_mgr.add_const('BS_OWNERDRAW',0x0000000B)
		win_const_mgr.add_const('DSBI_NOROOT',0x00010000)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_POSIX_CUI',0x00000007)
		win_const_mgr.add_const('MAX_CREATINGDC_LENGTH',0x00000100)
		win_const_mgr.add_const('PSH_WIZARDHASFINISH',0x00000010)
		win_const_mgr.add_const('OID_802_5_CURRENT_GROUP',0x02010104)
		win_const_mgr.add_const('SECURITY_FLAG_PCT',0x00000008)
		win_const_mgr.add_const('SQL_CODE_MINUTE_TO_SECOND',0x0000000D)
		win_const_mgr.add_const('CM_DRP_BUSNUMBER',0x00000016)
		win_const_mgr.add_const('NORMAL_PRIORITY_CLASS',0x00000020)
		win_const_mgr.add_const('ERROR_FAIL_SHUTDOWN',0x0000015F)
		win_const_mgr.add_const('TIMED_SEND_CAPABLE',0x00000010)
		win_const_mgr.add_const('CDDS_POSTPAINT',0x00000002)
		win_const_mgr.add_const('PSWIZB_RESTORE',0x00000001)
		win_const_mgr.add_const('ERROR_INVALID_TRANSFORM',0x000007E4)
		win_const_mgr.add_const('WINHTTP_OPTION_MAX_HTTP_STATUS_CONTINUE',0x0000005A)
		win_const_mgr.add_const('LINEGATHERTERM_TERMDIGIT',0x00000002)
		win_const_mgr.add_const('TRACE_LEVEL_ERROR',0x00000002)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_READ_COMPLETE',0x00080000)
		win_const_mgr.add_const('TXFS_ROLLFORWARD_REDO_FLAG_USE_LAST_REDO_LSN',0x00000001)
		win_const_mgr.add_const('HTOBJECT',0x00000013)
		win_const_mgr.add_const('MDSP_READ',0x00000001)
		win_const_mgr.add_const('OPATH_TOK_BACKSLASH',0x0000006E)
		win_const_mgr.add_const('MK_LBUTTON',0x00000001)
		win_const_mgr.add_const('FACILITY_UMI',0x00000016)
		win_const_mgr.add_const('CR_PROP_NONE',0x00000000)
		win_const_mgr.add_const('DEBUG_DATA_SPACE_VIRTUAL',0x00000000)
		win_const_mgr.add_const('ACM_FILTERTAGDETAILSF_FILTERTAG',0x00000001)
		win_const_mgr.add_const('ERROR_NO_LOGON_SERVERS',0x0000051F)
		win_const_mgr.add_const('CMSG_RECIPIENT_COUNT_PARAM',0x00000011)
		win_const_mgr.add_const('READABLE_LOCAL_CLOCK',0x00000001)
		win_const_mgr.add_const('PROGDLG_MODAL',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_AUTO_SYNC',0x00000001)
		win_const_mgr.add_const('EMR_OFFSETCLIPRGN',0x0000001A)
		win_const_mgr.add_const('PC_WINDPOLYGON',0x00000004)
		win_const_mgr.add_const('MDMEASURE_AGGR_STD',0x00000007)
		win_const_mgr.add_const('ODBC_ERROR_LOAD_LIB_FAILED',0x0000000D)
		win_const_mgr.add_const('IME_ESC_SET_EUDC_DICTIONARY',0x00001004)
		win_const_mgr.add_const('TASK_MARCH',0x00000004)
		win_const_mgr.add_const('NCBRECVANY',0x00000016)
		win_const_mgr.add_const('ERROR_DS_CANT_CREATE_UNDER_SCHEMA',0x0000213E)
		win_const_mgr.add_const('LINEERR_UNINITIALIZED',0x80000050)
		win_const_mgr.add_const('MND_ENDMENU',0x00000001)
		win_const_mgr.add_const('DRV_FREE',0x00000006)
		win_const_mgr.add_const('ADS_JOB_PRINTED',0x00000080)
		win_const_mgr.add_const('HSHELL_ENDTASK',0x0000000A)
		win_const_mgr.add_const('NORM_IGNOREWIDTH',0x00020000)
		win_const_mgr.add_const('USER_DCR_INITIAL',0x00000007)
		win_const_mgr.add_const('LVM_FIRST',0x00001000)
		win_const_mgr.add_const('DS_REPSYNC_FORCE',0x00000100)
		win_const_mgr.add_const('CSC_CACHE_NONE',0x00000030)
		win_const_mgr.add_const('ILD_ROP',0x00000040)
		win_const_mgr.add_const('OID_FDDI_PORT_LER_ESTIMATE',0x0303026D)
		win_const_mgr.add_const('KF_REPEAT',0x00004000)
		win_const_mgr.add_const('MD_ERROR_SUB403_CERT_BAD',0x00000010)
		win_const_mgr.add_const('DS_DNS_CONTROLLER_FLAG',0x20000000)
		win_const_mgr.add_const('ERROR_INCOMPATIBLE_SERVICE_SID_TYPE',0x0000050A)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_ENABLE_DEVQ',0x00000080)
		win_const_mgr.add_const('RBS_TOOLTIPS',0x00000100)
		win_const_mgr.add_const('OID_TAPI_GET_ADDRESS_STATUS',0x0703010C)
		win_const_mgr.add_const('PRJOB_DESTPAUSED',0x00000040)
		win_const_mgr.add_const('PXE_TRACE_INFO',0x00020000)
		win_const_mgr.add_const('VIEW_NETDISCONNECT',0x0000000A)
		win_const_mgr.add_const('ERROR_DS_NOT_INSTALLED',0x00002008)
		win_const_mgr.add_const('FACILITY_INTERNET',0x0000000C)
		win_const_mgr.add_const('SMART_SHORT_SELFTEST_OFFLINE',0x00000001)
		win_const_mgr.add_const('DCBA_FACEUPLEFT',0x00000002)
		win_const_mgr.add_const('SECPKG_OPTIONS_TYPE_LSA',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_TR_COMMIT',0x00000002)
		win_const_mgr.add_const('SECPKG_ATTR_LOCAL_CERT_INFO',0x00000063)
		win_const_mgr.add_const('SW_NORMAL',0x00000001)
		win_const_mgr.add_const('BI_RGB',0x00000000)
		win_const_mgr.add_const('SSRVOPT_FAVOR_COMPRESSED',0x00200000)
		win_const_mgr.add_const('SQL_ATTR_ENLIST_IN_XA',0x000004B8)
		win_const_mgr.add_const('CMSG_CONTENTS_OCTETS_FLAG',0x00000010)
		win_const_mgr.add_const('ERROR_INVALID_SPI_VALUE',0x0000059F)
		win_const_mgr.add_const('WINHTTP_OPTION_USE_GLOBAL_SERVER_CREDENTIALS',0x00000065)
		win_const_mgr.add_const('CRL_V1',0x00000000)
		win_const_mgr.add_const('COD_SERVICE_RENDERING',0x00000020)
		win_const_mgr.add_const('ALG_SID_ANY',0x00000000)
		win_const_mgr.add_const('SUOI_FORCEDELETE',0x00000001)
		win_const_mgr.add_const('AVIF_MUSTUSEINDEX',0x00000020)
		win_const_mgr.add_const('IDM_TABLEPROPERTIES',0x000008A2)
		win_const_mgr.add_const('DTR_KTBASE_INDEX',0x00000002)
		win_const_mgr.add_const('CTFMODEBIAS_HANGUL',0x00000009)
		win_const_mgr.add_const('MAPI_RECEIPT_REQUESTED',0x00000002)
		win_const_mgr.add_const('ES_CENTER',0x00000001)
		win_const_mgr.add_const('CERT_INFO_NOT_AFTER_FLAG',0x00000006)
		win_const_mgr.add_const('WSP_PROTOCOL_UUID16',0x0000000E)
		win_const_mgr.add_const('IMAGE_REL_IA64_ADDEND',0x0000001F)
		win_const_mgr.add_const('DCX_NORESETATTRS',0x00000004)
		win_const_mgr.add_const('LOGON32_LOGON_SERVICE',0x00000005)
		win_const_mgr.add_const('DS_DNS_FOREST_FLAG',0x80000000)
		win_const_mgr.add_const('WIA_IPS_PHOTOMETRIC_INTERP',0x00001809)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_SPEAKERON',0x00000015)
		win_const_mgr.add_const('LANG_YORUBA',0x00000006)
		win_const_mgr.add_const('FWPM_FILTER_FLAG_HAS_PROVIDER_CONTEXT',0x00000004)
		win_const_mgr.add_const('DISPID_PICT_HANDLE',0x00000000)
		win_const_mgr.add_const('IPSEC_AUTH_CONFIG_HMAC_MD5_96',0x00000000)
		win_const_mgr.add_const('PRIMARY_CACHE_INVALID',0x00000000)
		win_const_mgr.add_const('VK_DBE_ENTERDLGCONVERSIONMODE',0x00000000)
		win_const_mgr.add_const('MAX_CACHE_ENTRY_INFO_SIZE',0x00001000)
		win_const_mgr.add_const('PFS_EC_SHIFT',0x00000034)
		win_const_mgr.add_const('SUBLANG_POLISH_POLAND',0x00000001)
		win_const_mgr.add_const('DDFLIP_STEREO',0x00000010)
		win_const_mgr.add_const('METADATA_MASTER_ROOT_HANDLE',0x00000000)
		win_const_mgr.add_const('WS_EX_NOINHERITLAYOUT',0x00100000)
		win_const_mgr.add_const('LVA_ALIGNTOP',0x00000002)
		win_const_mgr.add_const('CTFMODEBIAS_HALFWIDTHALPHANUMERIC',0x0000000C)
		win_const_mgr.add_const('SECURITY_SERVICE_ID_RID_COUNT',0x00000006)
		win_const_mgr.add_const('IMAGE_FILE_BYTES_REVERSED_HI',0x00008000)
		win_const_mgr.add_const('SDP_ATTRIB_CORDLESS_EXTERNAL_NETWORK',0x00000301)
		win_const_mgr.add_const('MD_APPPOOL_COMMAND_STOP',0x00000002)
		win_const_mgr.add_const('APPCOMMAND_BASS_BOOST',0x00000014)
		win_const_mgr.add_const('SFVM_GETHELPTOPIC',0x0000003F)
		win_const_mgr.add_const('NIIF_FILTER_INTERFACE',0x00000002)
		win_const_mgr.add_const('CI_PROVIDER_INDEXING_SERVICE',0x00000002)
		win_const_mgr.add_const('SI_ACCESS_CONTAINER',0x00040000)
		win_const_mgr.add_const('MM_TEXT',0x00000001)
		win_const_mgr.add_const('CSTR_LESS_THAN',0x00000001)
		win_const_mgr.add_const('DXGI_MWA_NO_WINDOW_CHANGES',0x00000001)
		win_const_mgr.add_const('DFCS_SCROLLSIZEGRIP',0x00000008)
		win_const_mgr.add_const('SM_CXEDGE',0x0000002D)
		win_const_mgr.add_const('CRYPT_ACQUIRE_SILENT_FLAG',0x00000040)
		win_const_mgr.add_const('CERT_COMPARE_ISSUER_OF',0x0000000C)
		win_const_mgr.add_const('DDPF_ALPHA',0x00000002)
		win_const_mgr.add_const('SQL_ADD',0x00000004)
		win_const_mgr.add_const('WINHTTP_OPTION_PASSPORT_COBRANDING_TEXT',0x00000051)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM9D_SIZE_X',0x00000009)
		win_const_mgr.add_const('DS_REPMOD_ASYNCHRONOUS_OPERATION',0x00000001)
		win_const_mgr.add_const('THAI_CHARSET',0x000000DE)
		win_const_mgr.add_const('MB_MODEMASK',0x00003000)
		win_const_mgr.add_const('ALG_SID_TLS1PRF',0x0000000A)
		win_const_mgr.add_const('AA_AUDIT_ALL',0x00000001)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_FIXUP',0x00000006)
		win_const_mgr.add_const('PHONEFEATURE_SETGAINSPEAKER',0x00040000)
		win_const_mgr.add_const('OIC_WINLOGO',0x00007F05)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_SERVICES',0x0000000F)
		win_const_mgr.add_const('IDS_CAP_ERRORDIBSAVE',0x00000196)
		win_const_mgr.add_const('EMR_ALPHABLEND',0x00000072)
		win_const_mgr.add_const('GL_ID_UNKNOWN',0x00000000)
		win_const_mgr.add_const('CFU_UNDERLINETHICKDASH',0x0000000E)
		win_const_mgr.add_const('SNMPAPI_TL_PDU_TOO_BIG',0x0000006D)
		win_const_mgr.add_const('TXTLOG_SETUP',0x08000000)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_QUEUECALL',0x0000002D)
		win_const_mgr.add_const('DEFAULT_CONTEXT_PRIORITY',0x00000064)
		win_const_mgr.add_const('NT32_PTR_SIZE',0x00000004)
		win_const_mgr.add_const('SCESTATUS_SUCCESS',0x00000000)
		win_const_mgr.add_const('PHONEFEATURE_SETHOOKSWITCHHANDSET',0x00100000)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_31',0x0000001F)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_MSGINDICATOR',0x00000026)
		win_const_mgr.add_const('OID_FDDI_PATH_T_MAX_LOWER_BOUND',0x0303025A)
		win_const_mgr.add_const('USER_PARMS_PARMNUM',0x0000000D)
		win_const_mgr.add_const('DISPID_SUBMIT',0x00000003)
		win_const_mgr.add_const('LINEMEDIACONTROL_RESET',0x00000004)
		win_const_mgr.add_const('PP_SMARTCARD_GUID',0x0000002D)
		win_const_mgr.add_const('DDOVER_ARGBSCALEFACTORS',0x02000000)
		win_const_mgr.add_const('IMAGE_COMPRESSION_UNCOMPRESSED',0x00000001)
		win_const_mgr.add_const('MB_TASKMODAL',0x00002000)
		win_const_mgr.add_const('OID_GEN_MULTICAST_FRAMES_XMIT',0x00020204)
		win_const_mgr.add_const('SUBLANG_QUECHUA_ECUADOR',0x00000002)
		win_const_mgr.add_const('CRYPT_MM',0x00000003)
		win_const_mgr.add_const('CFU_UNDERLINETHICK',0x00000009)
		win_const_mgr.add_const('ERROR_SXS_MANIFEST_FORMAT_ERROR',0x000036B4)
		win_const_mgr.add_const('SFVM_SIZE',0x00000039)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_ANONYMOUS',0x80000040)
		win_const_mgr.add_const('SV_THREADCOUNTADD_PARMNUM',0x0000020E)
		win_const_mgr.add_const('PORT_SEND',0x000000A9)
		win_const_mgr.add_const('SQL_FN_NUM_ATAN',0x00000008)
		win_const_mgr.add_const('CTL_FIND_SAME_USAGE_FLAG',0x00000001)
		win_const_mgr.add_const('VER_ERR_METHOD_SIG',0x01000000)
		win_const_mgr.add_const('DBPROPVAL_TI_BROWSE',0x00000100)
		win_const_mgr.add_const('DXGI_CPU_ACCESS_NONE',0x00000000)
		win_const_mgr.add_const('VR_INSTANT_BAD',0x00000002)
		win_const_mgr.add_const('ES_SUNKEN',0x00004000)
		win_const_mgr.add_const('SPREG_GETPROCADDR',0x00000002)
		win_const_mgr.add_const('MQ_MOVE_ACCESS',0x00000004)
		win_const_mgr.add_const('MDM_MASK_BEARERMODE',0x00000000)
		win_const_mgr.add_const('DISPID_MODE',0x00000012)
		win_const_mgr.add_const('RAS_FLAGS_PPP_CONNECTION',0x00000001)
		win_const_mgr.add_const('ERROR_MEMBER_IN_ALIAS',0x00000562)
		win_const_mgr.add_const('NETLOGON_CONTROL_BACKUP_CHANGE_LOG',0x0000FFFC)
		win_const_mgr.add_const('LVBKIF_TYPE_WATERMARK',0x10000000)
		win_const_mgr.add_const('IDM_TRIED_ITALIC',0x0000002B)
		win_const_mgr.add_const('NCRYPT_ALLOW_PLAINTEXT_ARCHIVING_FLAG',0x00000008)
		win_const_mgr.add_const('NETLOGON_REDO_NEEDED',0x00000008)
		win_const_mgr.add_const('CE_PTO',0x00000200)
		win_const_mgr.add_const('JOB_OBJECT_EXTENDED_LIMIT_VALID_FLAGS',0x00000003)
		win_const_mgr.add_const('MIXERLINE_LINEF_SOURCE',0x80000000)
		win_const_mgr.add_const('MD_ACCESS_NO_PHYSICAL_DIR',0x00008000)
		win_const_mgr.add_const('ERROR_UNKNOWN_PRINT_MONITOR',0x00000BB8)
		win_const_mgr.add_const('ROLLBACK_BITS',0x00000001)
		win_const_mgr.add_const('MQMSG_ACKNOWLEDGMENT_POS_ARRIVAL',0x00000001)
		win_const_mgr.add_const('PF_NX_ENABLED',0x0000000C)
		win_const_mgr.add_const('POLICY_GET_PRIVATE_INFORMATION',0x00000004)
		win_const_mgr.add_const('DEBUG_REGISTER_SUB_REGISTER',0x00000001)
		win_const_mgr.add_const('FD_ADDRESS_LIST_CHANGE_BIT',0x00000009)
		win_const_mgr.add_const('IDM_VERTSPACEDECREASE',0x0000002F)
		win_const_mgr.add_const('UM_SELTYPE_LOCALGROUP',0x00000004)
		win_const_mgr.add_const('SQL_SRJO_CROSS_JOIN',0x00000002)
		win_const_mgr.add_const('FWPM_FILTER_FLAG_PERSISTENT',0x00000001)
		win_const_mgr.add_const('ERROR_TRANSACTION_NOT_ROOT',0x00001A41)
		win_const_mgr.add_const('OID_GEN_NDIS_RESERVED_5',0x0001020C)
		win_const_mgr.add_const('D3DVTXPCAPS_NO_TEXGEN_NONLOCALVIEWER',0x00000200)
		win_const_mgr.add_const('OID_GEN_NDIS_RESERVED_6',0x00010212)
		win_const_mgr.add_const('OID_GEN_NDIS_RESERVED_1',0x00020217)
		win_const_mgr.add_const('MARK_HANDLE_NOT_TXF_SYSTEM_LOG',0x00000008)
		win_const_mgr.add_const('OID_GEN_NDIS_RESERVED_3',0x0001020A)
		win_const_mgr.add_const('OID_GEN_NDIS_RESERVED_2',0x00020218)
		win_const_mgr.add_const('ERROR_INVALID_MENU_HANDLE',0x00000579)
		win_const_mgr.add_const('TXFS_RM_FLAG_LOGGING_MODE',0x00000001)
		win_const_mgr.add_const('ERROR_UNKNOWN_PRINTPROCESSOR',0x00000706)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NEG_STATUS_BEGIN',0x000035E8)
		win_const_mgr.add_const('CS_OWNDC',0x00000020)
		win_const_mgr.add_const('DIRID_ABSOLUTE_16BIT',0x00000000)
		win_const_mgr.add_const('LINECALLFEATURE_REDIRECT',0x00020000)
		win_const_mgr.add_const('ERROR_BUFFER_ALL_ZEROS',0x000002F2)
		win_const_mgr.add_const('RESOURCE_MANAGER_VOLATILE',0x00000001)
		win_const_mgr.add_const('SO_PAUSE_ACCEPT',0x00003003)
		win_const_mgr.add_const('MDPROPVAL_MNF_DRILLUPLEVEL',0x00020000)
		win_const_mgr.add_const('DBPROP_IGNORENOISEONLYCLAUSES',0x00000005)
		win_const_mgr.add_const('GPO_INFO_FLAG_LOGRSOP_TRANSITION',0x00000200)
		win_const_mgr.add_const('LANG_IRISH',0x00000003)
		win_const_mgr.add_const('ERROR_DS_GENERIC_ERROR',0x00002095)
		win_const_mgr.add_const('CTRY_UKRAINE',0x0000017C)
		win_const_mgr.add_const('WMIREG_FLAG_INSTANCE_LIST',0x00000004)
		win_const_mgr.add_const('POLICY_AUDIT_EVENT_SUCCESS',0x00000001)
		win_const_mgr.add_const('PAGEMASK_64KB',0x00000000)
		win_const_mgr.add_const('FWPM_ACTRL_READ',0x00000080)
		win_const_mgr.add_const('RQ_UPDATE_REQUEST_CACHE',0x00000200)
		win_const_mgr.add_const('LINEADDRFEATURE_PICKUPWAITING',0x00000800)
		win_const_mgr.add_const('RF_DOWN_AND_LEFT',0x00000100)
		win_const_mgr.add_const('MCI_VCR_SETAUDIO_NUMBER',0x00400000)
		win_const_mgr.add_const('ERROR_LOG_PINNED_RESERVATION',0x000019F8)
		win_const_mgr.add_const('RPC_S_INVALID_NAF_ID',0x000006E3)
		win_const_mgr.add_const('LANG_BENGALI',0x00000045)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_RESERVED3',0x00008000)
		win_const_mgr.add_const('TLMENUF_BACK',0x00000010)
		win_const_mgr.add_const('NDIS_LINK_STATE_REVISION_1',0x00000001)
		win_const_mgr.add_const('TXFS_RM_FLAG_GROW_LOG',0x00000400)
		win_const_mgr.add_const('LINETERMDEV_PHONE',0x00000001)
		win_const_mgr.add_const('MPEG_TSDT_TID',0x00000003)
		win_const_mgr.add_const('RASLCPAD_CHAP_MD5',0x00000005)
		win_const_mgr.add_const('D3DSTENCILCAPS_INVERT',0x00000020)
		win_const_mgr.add_const('INT_MAX',0x7FFFFFFF)
		win_const_mgr.add_const('NI_FINALIZECONVERSIONRESULT',0x00000014)
		win_const_mgr.add_const('CREATE_MUTEX_INITIAL_OWNER',0x00000001)
		win_const_mgr.add_const('VOLUME_NAME_DOS',0x00000000)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_HAS_STILL',0x00004005)
		win_const_mgr.add_const('PRIVACY_TEMPLATE_MEDIUM_LOW',0x00000004)
		win_const_mgr.add_const('DATE_YEARMONTH',0x00000008)
		win_const_mgr.add_const('CPIOD_FORCE_PROMPT',0x80000000)
		win_const_mgr.add_const('SERVICETYPE_CONTROLLEDLOAD',0x00000002)
		win_const_mgr.add_const('LINE_REPLY',0x0000000C)
		win_const_mgr.add_const('BG_COPY_FILE_GROUP',0x00000002)
		win_const_mgr.add_const('DNOBJECT_EVR',0x0000001A)
		win_const_mgr.add_const('MD_LOGCUSTOM_DATATYPE_UINT',0x00000001)
		win_const_mgr.add_const('COD_LAN_ACCESS_0_USED',0x00000000)
		win_const_mgr.add_const('PRINTER_ENUM_ICONMASK',0x00000000)
		win_const_mgr.add_const('SECBUFFER_VERSION',0x00000000)
		win_const_mgr.add_const('ENM_CHANGE',0x00000001)
		win_const_mgr.add_const('URL_WININET_COMPATIBILITY',0x80000000)
		win_const_mgr.add_const('RPC_X_SS_CHAR_TRANS_SHORT_FILE',0x000006EE)
		win_const_mgr.add_const('MMIO_WRITE',0x00000001)
		win_const_mgr.add_const('PROPID_M_BASE',0x00000000)
		win_const_mgr.add_const('RTCTR_TCP',0x00000002)
		win_const_mgr.add_const('WSAHOST_NOT_FOUND',0x00002AF9)
		win_const_mgr.add_const('MDM_ANALOG_RLP_OFF',0x00000001)
		win_const_mgr.add_const('ACCESS_SUCCESS_MASK',0x000000F0)
		win_const_mgr.add_const('WINEVENT_OPCODE_SEND',0x00000009)
		win_const_mgr.add_const('MDM_BLIND_DIAL',0x00000200)
		win_const_mgr.add_const('VARIANT_USE_NLS',0x00000080)
		win_const_mgr.add_const('D3DVS_W_W',0x00000003)
		win_const_mgr.add_const('ERROR_SXS_FILE_HASH_MISMATCH',0x000036CC)
		win_const_mgr.add_const('REG_LATEST_FORMAT',0x00000002)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_SCHEMA_ADMINS',0x00000206)
		win_const_mgr.add_const('REG_WHOLE_HIVE_VOLATILE',0x00000001)
		win_const_mgr.add_const('VK_PROCESSKEY',0x000000E5)
		win_const_mgr.add_const('ERROR_INVALID_EXE_SIGNATURE',0x000000BF)
		win_const_mgr.add_const('WINHTTP_QUERY_WARNING',0x00000043)
		win_const_mgr.add_const('SORT_GEORGIAN_TRADITIONAL',0x00000000)
		win_const_mgr.add_const('D3DVS_W_Z',0x00000002)
		win_const_mgr.add_const('D3DVS_W_X',0x00000000)
		win_const_mgr.add_const('D3DVS_W_Y',0x00000001)
		win_const_mgr.add_const('JIFMK_JPG13',0x0000FFFD)
		win_const_mgr.add_const('JIFMK_JPG12',0x0000FFFC)
		win_const_mgr.add_const('HTTP_LOGGING_FLAG_LOG_ERRORS_ONLY',0x00000004)
		win_const_mgr.add_const('JIFMK_JPG10',0x0000FFFA)
		win_const_mgr.add_const('EVENTLOG_AUDIT_SUCCESS',0x00000008)
		win_const_mgr.add_const('LINECALLCOMPLCOND_NOANSWER',0x00000002)
		win_const_mgr.add_const('TBS_ENABLESELRANGE',0x00000020)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_CERT_ADMINS',0x00000205)
		win_const_mgr.add_const('HTTP_ADDREQ_FLAG_COALESCE_WITH_SEMICOLON',0x01000000)
		win_const_mgr.add_const('DISPID_SETCONTEXTMENU',0x00000005)
		win_const_mgr.add_const('DDFLIP_WAIT',0x00000001)
		win_const_mgr.add_const('PCF_RLSD',0x00000004)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_BYTE',0x0000000C)
		win_const_mgr.add_const('ERROR_PRINTER_HAS_JOBS_QUEUED',0x00000BC1)
		win_const_mgr.add_const('SPREG_UNKNOWN',0xFFFFFFFF)
		win_const_mgr.add_const('DDSCAPS2_CUBEMAP_NEGATIVEZ',0x00008000)
		win_const_mgr.add_const('ERROR_NOT_QUORUM_CAPABLE',0x0000139D)
		win_const_mgr.add_const('WM_MDIRESTORE',0x00000223)
		win_const_mgr.add_const('WHEEL_DELTA',0x00000078)
		win_const_mgr.add_const('CRSWPP_BIND_FAILED',0xC004220A)
		win_const_mgr.add_const('FAX_ERR_MESSAGE_NOT_FOUND',0x00001B61)
		win_const_mgr.add_const('SUBLANG_CHINESE_SIMPLIFIED',0x00000002)
		win_const_mgr.add_const('IF_TYPE_AAL5',0x00000031)
		win_const_mgr.add_const('DB_DISP_REVOKED',0x00000015)
		win_const_mgr.add_const('DEBUG_SYMINFO_GET_MODULE_SYMBOL_NAMES_AND_OFFSETS',0x00000003)
		win_const_mgr.add_const('CF_WYSIWYG',0x00008000)
		win_const_mgr.add_const('MDMVOLFLAG_LOW',0x00000001)
		win_const_mgr.add_const('BAUD_075',0x00000001)
		win_const_mgr.add_const('ED_BASE',0x00001000)
		win_const_mgr.add_const('CAUSE_PROTOCOL_ERROR',0x0000006F)
		win_const_mgr.add_const('CHANNEL_OPTION_SHOW_PROTOCOL',0x00200000)
		win_const_mgr.add_const('CDB2GVF_NOINCLUDEITEM',0x00000010)
		win_const_mgr.add_const('BIF_RETURNFSANCESTORS',0x00000008)
		win_const_mgr.add_const('CM_VIEWFLAGS_MASK',0x00000000)
		win_const_mgr.add_const('FMEVENT_TOOLBARLOAD',0x00000069)
		win_const_mgr.add_const('DSBI_NOBUTTONS',0x00000001)
		win_const_mgr.add_const('ERROR_TRANSACTION_PROPAGATION_FAILED',0x00001A37)
		win_const_mgr.add_const('DIIRFLAG_INF_ALREADY_COPIED',0x00000001)
		win_const_mgr.add_const('RASIPO_VJ',0x00000001)
		win_const_mgr.add_const('SUBLANG_SAMI_NORTHERN_NORWAY',0x00000001)
		win_const_mgr.add_const('EMR_SETCOLORSPACE',0x00000064)
		win_const_mgr.add_const('FLG_PROFITEM_DELETE',0x00000002)
		win_const_mgr.add_const('ERROR_CONNECTION_ACTIVE',0x000004CE)
		win_const_mgr.add_const('VPF_DISABLESCALE',0x00000004)
		win_const_mgr.add_const('MD_DIRBROW_SHOW_TIME',0x00000004)
		win_const_mgr.add_const('OID_GEN_RCV_NO_BUFFER',0x00020105)
		win_const_mgr.add_const('FWPM_PROVIDER_CONTEXT_FLAG_PERSISTENT',0x00000001)
		win_const_mgr.add_const('MCHT_TODAYLINK',0x00030000)
		win_const_mgr.add_const('DS_REPDEL_LOCAL_ONLY',0x00000010)
		win_const_mgr.add_const('TCS_FLATBUTTONS',0x00000008)
		win_const_mgr.add_const('DE_E_FILTER_SCRIPTLABEL',0x80100010)
		win_const_mgr.add_const('OID_CO_TAPI_CM_CAPS',0xFE001001)
		win_const_mgr.add_const('CSTORAGEPROPERTY',0x00000017)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_PALETTES',0x00004006)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_STRUCT_TAG',0x0000000A)
		win_const_mgr.add_const('SFC_SCAN_ONCE',0x00000002)
		win_const_mgr.add_const('PGF_SCROLLLEFT',0x00000004)
		win_const_mgr.add_const('ERROR_COULD_NOT_RESIZE_LOG',0x000019E5)
		win_const_mgr.add_const('IDM_TRIED_INSERTCOL',0x0000000F)
		win_const_mgr.add_const('SEE_MASK_ASYNCOK',0x00100000)
		win_const_mgr.add_const('WINHTTP_OPTION_REJECT_USERPWD_IN_URL',0x00000064)
		win_const_mgr.add_const('DBT_DEVICEQUERYREMOVE',0x00008001)
		win_const_mgr.add_const('KSEVENT_TYPE_ONESHOT',0x00000002)
		win_const_mgr.add_const('DTR_KIPCR_INDEX',0x00000000)
		win_const_mgr.add_const('SQL_CVT_LONGVARCHAR',0x00000200)
		win_const_mgr.add_const('KSSTREAM_SYNCHRONOUS',0x00001000)
		win_const_mgr.add_const('CI_STATE_ANNEALING_MERGE',0x00000008)
		win_const_mgr.add_const('SSRVOPT_OVERWRITE',0x00004000)
		win_const_mgr.add_const('DB_BINDFLAGS_DELAYFETCHCOLUMNS',0x00000001)
		win_const_mgr.add_const('SPI_GETSCREENSAVETIMEOUT',0x0000000E)
		win_const_mgr.add_const('SEE_MASK_NOASYNC',0x00000100)
		win_const_mgr.add_const('LDAP_OPT_SERVER_ERROR',0x00000033)
		win_const_mgr.add_const('PHONEFEATURE_SETGAINHANDSET',0x00020000)
		win_const_mgr.add_const('PWLEN',0x00000100)
		win_const_mgr.add_const('MDM_PIAFS_INCOMING',0x00000000)
		win_const_mgr.add_const('LINEPROXYREQUEST_SETAGENTSTATE',0x00000002)
		win_const_mgr.add_const('AD_APPLY_BUFFERED_REFRESH',0x00000010)
		win_const_mgr.add_const('EAP_E_USER_FIRST',0x80420100)
		win_const_mgr.add_const('SPI_GETACCESSTIMEOUT',0x0000003C)
		win_const_mgr.add_const('IPPROTO_GGP',0x00000003)
		win_const_mgr.add_const('SYMFLAG_METADATA',0x00020000)
		win_const_mgr.add_const('SNMP_ERROR_NOSUCHNAME',0x00000002)
		win_const_mgr.add_const('ACMSTREAMHEADER_STATUSF_PREPARED',0x00020000)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_QUARTERS',0x00000044)
		win_const_mgr.add_const('SBSP_ALLOW_AUTONAVIGATE',0x00010000)
		win_const_mgr.add_const('SQL_NB_OFF',0x00000000)
		win_const_mgr.add_const('IO_REPARSE_TAG_RESERVED_ZERO',0x00000000)
		win_const_mgr.add_const('DRIVE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('CC_MAX_HW_DECODE_LINES',0x0000000C)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_UNAUTH_USER_PEAK_RATE',0x0000001C)
		win_const_mgr.add_const('FR_HIDEUPDOWN',0x00004000)
		win_const_mgr.add_const('JIFMK_SOF11',0x0000FFCB)
		win_const_mgr.add_const('WPCPROV_KEYWORD_WPC',0x00000010)
		win_const_mgr.add_const('PID_INTSITE_DESCRIPTION',0x00000007)
		win_const_mgr.add_const('IMAGE_REL_ARM_SECTION',0x0000000E)
		win_const_mgr.add_const('SMC_OPEN',0x00000045)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_NATIVE',0x00000001)
		win_const_mgr.add_const('EVT_VARIANT_TYPE_ARRAY',0x00000080)
		win_const_mgr.add_const('SPDRP_CLASSGUID',0x00000008)
		win_const_mgr.add_const('HHT_ONOVERFLOW',0x00004000)
		win_const_mgr.add_const('URLACTION_JAVA_CURR_MAX',0x00001C00)
		win_const_mgr.add_const('MFBYTESTREAM_HAS_SLOW_SEEK',0x00000100)
		win_const_mgr.add_const('CERT_CLOSE_STORE_FORCE_FLAG',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_FORCEOVERWRITE',0x00000117)
		win_const_mgr.add_const('DBC_SHOWOBSCURE',0x00000002)
		win_const_mgr.add_const('EMBDHLP_INPROC_SERVER',0x00000001)
		win_const_mgr.add_const('HTMAXBUTTON',0x00000009)
		win_const_mgr.add_const('SIMPLEREGION',0x00000002)
		win_const_mgr.add_const('KSPROPERTY_VIDEOPROCAMP_FLAGS_MANUAL',0x00000000)
		win_const_mgr.add_const('DEBUG_DATA_SPACE_IO',0x00000003)
		win_const_mgr.add_const('LVS_OWNERDATA',0x00001000)
		win_const_mgr.add_const('SHCNE_INTERRUPT',0x80000000)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_STATUS',0x0000000A)
		win_const_mgr.add_const('POLICY_ERRV_NO_MORE_INFO',0x00000001)
		win_const_mgr.add_const('SF_NOTIFY_SEND_RAW_DATA',0x00000400)
		win_const_mgr.add_const('ERROR_DS_SRC_GUID_MISMATCH',0x00002128)
		win_const_mgr.add_const('TMT_HBITMAP',0x000000D4)
		win_const_mgr.add_const('NEWFILEOPENV3ORD',0x00000611)
		win_const_mgr.add_const('IMAGE_SIZEOF_FILE_HEADER',0x00000014)
		win_const_mgr.add_const('RBHT_GRABBER',0x00000004)
		win_const_mgr.add_const('WM_QUERYUISTATE',0x00000129)
		win_const_mgr.add_const('ERROR_DS_CANT_CACHE_ATT',0x000020D1)
		win_const_mgr.add_const('ERROR_LOG_FILE_FULL',0x000005DE)
		win_const_mgr.add_const('SQL_FN_NUM_ACOS',0x00000002)
		win_const_mgr.add_const('DI_NOMIRROR',0x00000010)
		win_const_mgr.add_const('LB_SELITEMRANGEEX',0x00000183)
		win_const_mgr.add_const('STI_ONLINESTATE_ERROR',0x00000004)
		win_const_mgr.add_const('SCARD_READER_TYPE_IDE',0x00000010)
		win_const_mgr.add_const('SHCNE_NETSHARE',0x00000200)
		win_const_mgr.add_const('CRYPTDLG_POLICY_MASK',0x0000FFFF)
		win_const_mgr.add_const('SV_MAXNONPAGEDMEMORYUSAGE_PARMNUM',0x00000200)
		win_const_mgr.add_const('DNS_ERROR_RCODE_NOTAUTH',0x00002331)
		win_const_mgr.add_const('FWPM_SESSION_FLAG_DYNAMIC',0x00000001)
		win_const_mgr.add_const('DBPROP_MSREMOTE_HANDLER',0x00000004)
		win_const_mgr.add_const('ERROR_CTX_INVALID_WD',0x00001B89)
		win_const_mgr.add_const('PXE_CALLBACK_SHUTDOWN',0x00000001)
		win_const_mgr.add_const('SQL_NNC_NULL',0x00000000)
		win_const_mgr.add_const('SECURITY_FLAG_STRENGTH_STRONG',0x20000000)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_READCLIPBOARD',0x00000002)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_HEADERS_AVAILABLE',0x00020000)
		win_const_mgr.add_const('OID_802_11_RTS_THRESHOLD',0x0D01020A)
		win_const_mgr.add_const('RUNDLGORD',0x00000609)
		win_const_mgr.add_const('SQL_CVT_DECIMAL',0x00000004)
		win_const_mgr.add_const('PARTITION_FAT_12',0x00000001)
		win_const_mgr.add_const('FLAG_NO_CSE_INVOKE',0x40000000)
		win_const_mgr.add_const('PARTITION_FAT_16',0x00000004)
		win_const_mgr.add_const('OLEMISC_ACTSLIKELABEL',0x00002000)
		win_const_mgr.add_const('MCI_VCR_SEEK_MARK',0x00020000)
		win_const_mgr.add_const('WSAESOCKTNOSUPPORT',0x0000273C)
		win_const_mgr.add_const('LM20_SERVICE_PAUSE_PENDING',0x00000008)
		win_const_mgr.add_const('MDM_MASK_AUTO_SPEED',0x00000007)
		win_const_mgr.add_const('CRYPT_MODE_CBCOFMI',0x0000000A)
		win_const_mgr.add_const('CE_TXFULL',0x00000100)
		win_const_mgr.add_const('IDS_IMPORTANCE',0x00011009)
		win_const_mgr.add_const('PROCESSOR_HITACHI_SH3E',0x00002714)
		win_const_mgr.add_const('PORT_AT3',0x000000CB)
		win_const_mgr.add_const('LUP_DUAL_ADDR',0x00200000)
		win_const_mgr.add_const('PORT_AT5',0x000000CD)
		win_const_mgr.add_const('EV_RING',0x00000100)
		win_const_mgr.add_const('PORT_AT7',0x000000CF)
		win_const_mgr.add_const('DI_MASK',0x00000001)
		win_const_mgr.add_const('DPNHADDRESSTYPE_SHAREDPORTS',0x00000004)
		win_const_mgr.add_const('DDBLT_ALPHADEST',0x00000001)
		win_const_mgr.add_const('MCI_DGV_STATUS_CONTRAST',0x00004007)
		win_const_mgr.add_const('DISPID_IHTMLOPSPROFILE_COMMITCHANGES',0x00000006)
		win_const_mgr.add_const('IMAGE_REL_CEE_ADDR32NB',0x00000003)
		win_const_mgr.add_const('_WIN32_IE_IE20',0x00000200)
		win_const_mgr.add_const('TBS_LEFT',0x00000004)
		win_const_mgr.add_const('NS_NIS',0x00000029)
		win_const_mgr.add_const('HTTP_LOG_FIELD_SERVER_IP',0x00000040)
		win_const_mgr.add_const('ITIR_KEY',0x00000008)
		win_const_mgr.add_const('NDR64_FC_BIND_PRIMITIVE',0x00000002)
		win_const_mgr.add_const('DCI_1632_ACCESS',0x00000040)
		win_const_mgr.add_const('STGM_CREATE',0x00001000)
		win_const_mgr.add_const('DBT_CUSTOMEVENT',0x00008006)
		win_const_mgr.add_const('PHONEERR_INVALPHONESTATE',0x90000014)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME11',0x0000004E)
		win_const_mgr.add_const('DDPF_PALETTEINDEXEDTO8',0x00000010)
		win_const_mgr.add_const('OPTION_MTU',0x0000001A)
		win_const_mgr.add_const('SFF_KEEPDOCINFO',0x00001000)
		win_const_mgr.add_const('ACL_REVISION1',0x00000001)
		win_const_mgr.add_const('SDP_ATTRIB_HID_REMOTE_WAKE',0x0000020A)
		win_const_mgr.add_const('PHONESTATE_DEVSPECIFIC',0x00100000)
		win_const_mgr.add_const('LINEAGENTSTATE_LOGGEDOFF',0x00000001)
		win_const_mgr.add_const('SM_CYSCREEN',0x00000001)
		win_const_mgr.add_const('ERROR_POSSIBLE_DEADLOCK',0x0000046B)
		win_const_mgr.add_const('CBR_128000',0x0001F400)
		win_const_mgr.add_const('UNDNAME_NO_MEMBER_TYPE',0x00000200)
		win_const_mgr.add_const('INVALID_FRAGMENT_ID',0x00000000)
		win_const_mgr.add_const('TVHT_ONITEMBUTTON',0x00000010)
		win_const_mgr.add_const('ISCSI_SECURITY_FLAG_AGGRESSIVE_MODE_ENABLED',0x00000008)
		win_const_mgr.add_const('SCARD_E_WRITE_TOO_MANY',0x80100028)
		win_const_mgr.add_const('INTERNET_CUSTOMDIAL_SAFE_FOR_UNATTENDED',0x00000001)
		win_const_mgr.add_const('LINEMEDIACONTROL_VOLUMEDOWN',0x00000200)
		win_const_mgr.add_const('TXTBIT_DISABLEDRAG',0x00001000)
		win_const_mgr.add_const('CP_RECTANGLE',0x00000001)
		win_const_mgr.add_const('BS_DIBPATTERNPT',0x00000006)
		win_const_mgr.add_const('SCTE_EAS_OOB_PID',0x00001FFC)
		win_const_mgr.add_const('ERROR_DS_EPOCH_MISMATCH',0x00002123)
		win_const_mgr.add_const('VK_DBE_ENTERWORDREGISTERMODE',0x00000000)
		win_const_mgr.add_const('WINHTTP_QUERY_IF_MATCH',0x00000038)
		win_const_mgr.add_const('OID_FDDI_MAC_NOT_COPIED_RATIO',0x03030248)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_SUCCESS',0x00000000)
		win_const_mgr.add_const('HTTP_LOG_FIELD_URI_QUERY',0x00000200)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_MULTIPLEADDR',0x00000010)
		win_const_mgr.add_const('ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE',0x00001B66)
		win_const_mgr.add_const('SQL_DATETIME_LITERALS',0x00000077)
		win_const_mgr.add_const('DBPROPVAL_UP_DELETE',0x00000002)
		win_const_mgr.add_const('KAGPROP_SYSTEMFUNCTIONS',0x00000015)
		win_const_mgr.add_const('IMAGE_REL_IA64_SREL32',0x00000013)
		win_const_mgr.add_const('SERVICE_DEREGISTER',0x00000002)
		win_const_mgr.add_const('CERT_CHAIN_REVOCATION_CHECK_END_CERT',0x10000000)
		win_const_mgr.add_const('LINECALLSTATE_CONFERENCED',0x00000800)
		win_const_mgr.add_const('SQL_SR_GRANT_OPTION_FOR',0x00000010)
		win_const_mgr.add_const('VDMDBG_BREAK_DOSTASK',0x00000001)
		win_const_mgr.add_const('SYSTEM_MANDATORY_LABEL_NO_EXECUTE_UP',0x00000004)
		win_const_mgr.add_const('MF_256_BYTE_ALIGNMENT',0x00000000)
		win_const_mgr.add_const('IP6_ADDRESS_STRING_LENGTH',0x00000041)
		win_const_mgr.add_const('VK_VOLUME_DOWN',0x000000AE)
		win_const_mgr.add_const('ISCSI_LOGIN_OPTIONS_MAXIMUM_CONNECTIONS',0x00000004)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_DC_PROMOTION',0x00000021)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_REQUEST_EX',0x00000096)
		win_const_mgr.add_const('SQL_BP_SCROLL',0x00000040)
		win_const_mgr.add_const('EC_EXTDEVICE_MODE_CHANGE',0x00000031)
		win_const_mgr.add_const('ACL_REVISION',0x00000002)
		win_const_mgr.add_const('CMSG_KEY_AGREE_RECIPIENT',0x00000002)
		win_const_mgr.add_const('VK_DIVIDE',0x0000006F)
		win_const_mgr.add_const('DNS_RTYPE_ATMA',0x00002200)
		win_const_mgr.add_const('HTTP_QUERY_RETRY_AFTER',0x00000024)
		win_const_mgr.add_const('WM_NOTIFY',0x0000004E)
		win_const_mgr.add_const('ERROR_DS_NAME_ERROR_NO_MAPPING',0x00002118)
		win_const_mgr.add_const('IPPORT_RJE',0x0000004D)
		win_const_mgr.add_const('SHFMT_CANCEL',0xFFFFFFFE)
		win_const_mgr.add_const('ERROR_DS_ATT_NOT_DEF_IN_SCHEMA',0x0000206F)
		win_const_mgr.add_const('IPSEC_POLICY_FLAG_DONT_NEGOTIATE_SECOND_LIFETIME',0x00000040)
		win_const_mgr.add_const('HTCLIENT',0x00000001)
		win_const_mgr.add_const('CHANNEL_EVENT_INITIALIZED',0x00000000)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_EXCLUDE_BUILTIN_GROUPS',0x80008000)
		win_const_mgr.add_const('PSH_WIZARD97',0x01000000)
		win_const_mgr.add_const('WIA_IPS_DESKEW_Y',0x00001813)
		win_const_mgr.add_const('WIA_IPS_DESKEW_X',0x00001812)
		win_const_mgr.add_const('SFF_SELECTION',0x00008000)
		win_const_mgr.add_const('SFGAO_NEWCONTENT',0x00200000)
		win_const_mgr.add_const('LINEGENERATETERM_DONE',0x00000001)
		win_const_mgr.add_const('DCTT_DOWNLOAD',0x00000002)
		win_const_mgr.add_const('IDC_LP_AUTOMATIC',0x000003F8)
		win_const_mgr.add_const('IPXADDRESSLEN',0x00000016)
		win_const_mgr.add_const('OID_ATM_CALL_PROCEEDING',0x0801020B)
		win_const_mgr.add_const('TRANSACTIONMANAGER_SET_INFORMATION',0x00000002)
		win_const_mgr.add_const('RATING_THREE_STARS_MAX',0x0000003E)
		win_const_mgr.add_const('CSIDL_INTERNET_CACHE',0x00000020)
		win_const_mgr.add_const('WIA_DIP_DRIVER_VERSION',0x0000000F)
		win_const_mgr.add_const('SCERR_NOCARDNAME',0x00004000)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_PREPARE_COMPLETE',0x00000020)
		win_const_mgr.add_const('SQL_INTERVAL_DAY_TO_SECOND',0x00000064)
		win_const_mgr.add_const('SMC_EXITMENU',0x00000003)
		win_const_mgr.add_const('ACM_FORMATDETAILSF_QUERYMASK',0x0000000F)
		win_const_mgr.add_const('INTERNET_OPTION_ASYNC_ID',0x0000000F)
		win_const_mgr.add_const('PROP_LG_CYDLG',0x000000DA)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_DEF_FLOW_RATE',0x00000011)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2_ENDINGSECTORSPERSECOND',0x00000103)
		win_const_mgr.add_const('CBN_DROPDOWN',0x00000007)
		win_const_mgr.add_const('DVASPECT_SHORTNAME',0x00000002)
		win_const_mgr.add_const('WSAEISCONN',0x00002748)
		win_const_mgr.add_const('RDW_ERASENOW',0x00000200)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_CAN_MONITOR_SOURCES',0x00004009)
		win_const_mgr.add_const('CM_PROB_REGISTRY',0x00000013)
		win_const_mgr.add_const('ERROR_CLUSTER_NETWORK_NOT_INTERNAL',0x000013C4)
		win_const_mgr.add_const('META_FLOODFILL',0x00000419)
		win_const_mgr.add_const('PE_ATTRIB_TYPE_CREDENTIAL',0x00000002)
		win_const_mgr.add_const('TXFS_RM_FLAG_LOG_CONTAINER_COUNT_MIN',0x00000008)
		win_const_mgr.add_const('IOF_CHECKLINK',0x00000008)
		win_const_mgr.add_const('TVIS_USERMASK',0x0000F000)
		win_const_mgr.add_const('SPI_SETMOUSECLICKLOCKTIME',0x00002009)
		win_const_mgr.add_const('CR_APM_VETOED',0x00000018)
		win_const_mgr.add_const('LVGA_FOOTER_LEFT',0x00000008)
		win_const_mgr.add_const('TTI_INFO_LARGE',0x00000004)
		win_const_mgr.add_const('RTCEF_BUDDY',0x00000100)
		win_const_mgr.add_const('LPM_RESULT_READY',0x00000000)
		win_const_mgr.add_const('TR_PL',0x00000007)
		win_const_mgr.add_const('DS_GOOD_TIMESERV_FLAG',0x00000200)
		win_const_mgr.add_const('IPP_E_STATUS_CANNOTCOMPLETE',0xC0048101)
		win_const_mgr.add_const('RP_DSN_NOTIFY_MASK',0x0F000000)
		win_const_mgr.add_const('PHOTOACQ_DISABLE_AUTO_ROTATE',0x00000002)
		win_const_mgr.add_const('JOB_STATUS_SPOOLING',0x00000008)
		win_const_mgr.add_const('EDS_RAWMODE',0x00000002)
		win_const_mgr.add_const('KDF_SECRET_HANDLE',0x00000006)
		win_const_mgr.add_const('FS_HANDLED',0x20000010)
		win_const_mgr.add_const('TVNRET_SKIPNEW',0x00000002)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_DATA_AVAILABLE',0x00040000)
		win_const_mgr.add_const('ACCESS_MAX_MS_V4_ACE_TYPE',0x00000008)
		win_const_mgr.add_const('ERROR_MAX_THRDS_REACHED',0x000000A4)
		win_const_mgr.add_const('ELEMENT_STATUS_AVOLTAG',0x20000000)
		win_const_mgr.add_const('CM_PROB_VXDLDR',0x00000014)
		win_const_mgr.add_const('WIA_DIP_VEND_DESC',0x00000003)
		win_const_mgr.add_const('DNF_UNUSED_29',0x20000000)
		win_const_mgr.add_const('SHTDN_REASON_MAJOR_APPLICATION',0x00040000)
		win_const_mgr.add_const('SQL_IDENTIFIER_CASE',0x0000001C)
		win_const_mgr.add_const('LANG_AFRIKAANS',0x00000036)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_NUMBER',0x00080000)
		win_const_mgr.add_const('KAGPROP_MARSHALLABLE',0x00000003)
		win_const_mgr.add_const('SMINV_REFRESH',0x00000001)
		win_const_mgr.add_const('TC_NORMAL',0x00000000)
		win_const_mgr.add_const('MK_E_LAST',0x800401EF)
		win_const_mgr.add_const('LANG_ROMANIAN',0x00000018)
		win_const_mgr.add_const('HTMLDLG_VERIFY',0x00000100)
		win_const_mgr.add_const('DNF_AUTHENTICODE_SIGNED',0x00020000)
		win_const_mgr.add_const('ABN_POSCHANGED',0x00000001)
		win_const_mgr.add_const('DNF_UNUSED_25',0x02000000)
		win_const_mgr.add_const('CACHE_HEADER_DATA_NOTIFICATION_FILTER',0x00000015)
		win_const_mgr.add_const('AE_LIM_UNKNOWN',0x00000000)
		win_const_mgr.add_const('SPI_SETKEYBOARDDELAY',0x00000017)
		win_const_mgr.add_const('SQL_NUM_FUNCTIONS',0x00000017)
		win_const_mgr.add_const('IRLMP_PARAMETERS',0x00000018)
		win_const_mgr.add_const('STD_DELETE',0x00000005)
		win_const_mgr.add_const('ICU_ENCODE_PERCENT',0x00001000)
		win_const_mgr.add_const('EXITEVENT_INVALID',0x00000000)
		win_const_mgr.add_const('MAXWORD',0x00000000)
		win_const_mgr.add_const('MAX_SUBSTREAMS',0x0000000F)
		win_const_mgr.add_const('ARCONTENT_PHASE_MASK',0x70000000)
		win_const_mgr.add_const('MCI_VCR_SET_CLOCK',0x04000000)
		win_const_mgr.add_const('TMT_SCROLLBAR',0x00000641)
		win_const_mgr.add_const('TYPE_ENUMFONTS',0x00000001)
		win_const_mgr.add_const('BOM_NEUTRALOVERRIDE',0x00000004)
		win_const_mgr.add_const('MP_STATUS_ABANDON_DELIVERY',0x00000006)
		win_const_mgr.add_const('ERROR_EVENT_PENDING',0x000002C7)
		win_const_mgr.add_const('BNEP_PROTOCOL_UUID16',0x0000000F)
		win_const_mgr.add_const('KS_VIDEO_FLAG_FIELD2',0x00000002)
		win_const_mgr.add_const('MM_MIM_LONGERROR',0x000003C6)
		win_const_mgr.add_const('REO_SELECTED',0x08000000)
		win_const_mgr.add_const('KS_VIDEO_FLAG_FIELD1',0x00000001)
		win_const_mgr.add_const('PHONEBUTTONMODE_CALL',0x00000002)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_USER',0x00000000)
		win_const_mgr.add_const('ERROR_CTX_CLIENT_QUERY_TIMEOUT',0x00001B80)
		win_const_mgr.add_const('SQL_NO_ACTION',0x00000003)
		win_const_mgr.add_const('SC_ARRANGE',0x0000F110)
		win_const_mgr.add_const('RDW_VALIDATE',0x00000008)
		win_const_mgr.add_const('BS_HATCHED',0x00000002)
		win_const_mgr.add_const('CERT_TRUST_IS_OFFLINE_REVOCATION',0x01000000)
		win_const_mgr.add_const('INDEX_GUID_LINE',0x00000008)
		win_const_mgr.add_const('MQMSG_PRIV_LEVEL_NONE',0x00000000)
		win_const_mgr.add_const('OPAQUEKEYBLOB',0x00000009)
		win_const_mgr.add_const('LINECALLFEATURE2_TRANSFERNORM',0x00000040)
		win_const_mgr.add_const('PROP_SD',0x00000200)
		win_const_mgr.add_const('ETO_RTLREADING',0x00000080)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_DEF_FLOW_DURATION',0x0000000D)
		win_const_mgr.add_const('WINHTTP_OPTION_CALLBACK',0x00000001)
		win_const_mgr.add_const('N_BTSHFT',0x00000004)
		win_const_mgr.add_const('DI_AUTOASSIGNRES',0x00000040)
		win_const_mgr.add_const('IAS_MAX_CLASSNAME',0x00000040)
		win_const_mgr.add_const('ERROR_DS_CODE_INCONSISTENCY',0x000020D8)
		win_const_mgr.add_const('CF_FORCEFONTEXIST',0x00010000)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_ALG',0x00040000)
		win_const_mgr.add_const('CLUS_NO_MODIFY',0x00000000)
		win_const_mgr.add_const('CLIENTSITE_E_FIRST',0x80040190)
		win_const_mgr.add_const('EN_UPDATE',0x00000400)
		win_const_mgr.add_const('PRINTTICKET_ISTREAM_APIS',0x00000001)
		win_const_mgr.add_const('CHANNEL_RC_NOT_CONNECTED',0x00000004)
		win_const_mgr.add_const('JIFMK_RST1',0x0000FFD1)
		win_const_mgr.add_const('SECURITY_LOCAL_SYSTEM_RID',0x00000012)
		win_const_mgr.add_const('DOT11_STATUS_RETRY_LIMIT_EXCEEDED',0x00000002)
		win_const_mgr.add_const('HCBT_DESTROYWND',0x00000004)
		win_const_mgr.add_const('ERROR_NOT_SUBSTED',0x00000089)
		win_const_mgr.add_const('SQL_CD_FALSE',0x00000000)
		win_const_mgr.add_const('JIFMK_RST3',0x0000FFD3)
		win_const_mgr.add_const('SFGAO_REMOVABLE',0x02000000)
		win_const_mgr.add_const('NETE_NOMEMORY',0x00000001)
		win_const_mgr.add_const('EC_COMPLETE',0x00000001)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2_CANCELWRITE',0x00000201)
		win_const_mgr.add_const('SERVICE_FLAG_HARD',0x00000002)
		win_const_mgr.add_const('WMDM_DEVICECAP_CANSTREAMRECORD',0x00000008)
		win_const_mgr.add_const('WPF_ENABLE_LOCAL_BASE_DIR',0x00100000)
		win_const_mgr.add_const('ALG_SID_SHA1',0x00000004)
		win_const_mgr.add_const('WS_TABSTOP',0x00010000)
		win_const_mgr.add_const('WSA_E_CANCELLED',0x0000277F)
		win_const_mgr.add_const('SUBLANG_ENGLISH_JAMAICA',0x00000008)
		win_const_mgr.add_const('OPTION_BOOTFILE_NAME',0x00000043)
		win_const_mgr.add_const('ERROR_TOO_MANY_SECRETS',0x00000565)
		win_const_mgr.add_const('X3_OPCODE_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('DISPID_BEFORENAVIGATE2',0x000000FA)
		win_const_mgr.add_const('TMT_INFOTEXT',0x00000658)
		win_const_mgr.add_const('LINEQOSSERVICELEVEL_IFAVAILABLE',0x00000002)
		win_const_mgr.add_const('MQ_MIN_PRIORITY',0x00000000)
		win_const_mgr.add_const('SDP_ATTRIB_CLASS_ID_LIST',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_SECLOADFAIL',0x0000361C)
		win_const_mgr.add_const('AVIFILECAPS_ALLKEYFRAMES',0x00000010)
		win_const_mgr.add_const('WIA_IPA_DATATYPE',0x00001007)
		win_const_mgr.add_const('LB_GETTOPINDEX',0x0000018E)
		win_const_mgr.add_const('DISPID_MOUSEOUT',0x0000000C)
		win_const_mgr.add_const('LDAP_MSG_ALL',0x00000001)
		win_const_mgr.add_const('RTS_CONTROL_TOGGLE',0x00000003)
		win_const_mgr.add_const('EVENT_TRACE_FILE_MODE_APPEND',0x00000004)
		win_const_mgr.add_const('CERT_FILTER_VALID_TIME_RANGE',0x00000002)
		win_const_mgr.add_const('DMSTATEFLAG_APPLYTOALL',0x00000001)
		win_const_mgr.add_const('BCRYPT_DH_PUBLIC_MAGIC',0x42504844)
		win_const_mgr.add_const('EAP_FLAG_NON_INTERACTIVE',0x00000002)
		win_const_mgr.add_const('LISTEN_OUTSTANDING',0x00000001)
		win_const_mgr.add_const('COMP_ELEM_POS_LEFT',0x00000010)
		win_const_mgr.add_const('ATSC_MGT_PID',0x00001FFB)
		win_const_mgr.add_const('URLACTION_SCRIPT_RUN',0x00001400)
		win_const_mgr.add_const('TMT_CUSTOMSPLITRECT',0x0000138C)
		win_const_mgr.add_const('GPC_BLOCK_POLICY',0x00000001)
		win_const_mgr.add_const('CS_VREDRAW',0x00000001)
		win_const_mgr.add_const('PDH_LOG_SAMPLE_TOO_SMALL',0xC0000BF8)
		win_const_mgr.add_const('D3DTEXOPCAPS_BLENDFACTORALPHA',0x00002000)
		win_const_mgr.add_const('IDS_CAP_STAT_CAP_FINI',0x000001F7)
		win_const_mgr.add_const('SUBLANG_SPANISH',0x00000001)
		win_const_mgr.add_const('VER_SUITE_STORAGE_SERVER',0x00002000)
		win_const_mgr.add_const('DOMAIN_USER_RID_KRBTGT',0x000001F6)
		win_const_mgr.add_const('RESTART_MAX_CMD_LINE',0x00000800)
		win_const_mgr.add_const('DC_DUPLEX',0x00000007)
		win_const_mgr.add_const('FAX_ERR_RULE_NOT_FOUND',0x00001B5D)
		win_const_mgr.add_const('VARCMP_GT',0x00000002)
		win_const_mgr.add_const('TXTBIT_SAVESELECTION',0x00000040)
		win_const_mgr.add_const('NOTE_COLOR_GREEN',0x00000001)
		win_const_mgr.add_const('ICDRAW_QUERY',0x00000001)
		win_const_mgr.add_const('IP_ADAPTER_DDNS_ENABLED',0x00000001)
		win_const_mgr.add_const('ERROR_DS_SERVER_DOWN',0x0000203A)
		win_const_mgr.add_const('DDFXCAPS_BLTROTATION',0x00000100)
		win_const_mgr.add_const('PAN_ANY',0x00000000)
		win_const_mgr.add_const('CMSG_VERIFY_SIGNER_CERT',0x00000002)
		win_const_mgr.add_const('CS_E_LAST',0x8004016F)
		win_const_mgr.add_const('BG_E_TOO_MANY_RANGES_IN_FILE',0x80200052)
		win_const_mgr.add_const('TASK_FLAG_START_ONLY_IF_IDLE',0x00000010)
		win_const_mgr.add_const('WLAN_PROFILE_GROUP_POLICY',0x00000001)
		win_const_mgr.add_const('USER_USR_COMMENT_PARMNUM',0x0000000C)
		win_const_mgr.add_const('SM_CYMENU',0x0000000F)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_BYTES_PRINTED',0x00000017)
		win_const_mgr.add_const('IMAGE_REL_BASED_IA64_PCREL21',0x0000000B)
		win_const_mgr.add_const('PFM_KEEP',0x00020000)
		win_const_mgr.add_const('LINEDIGITMODE_DTMF',0x00000002)
		win_const_mgr.add_const('PSR_DI',0x00000016)
		win_const_mgr.add_const('ERROR_DS_DRS_EXTENSIONS_CHANGED',0x00002192)
		win_const_mgr.add_const('CF_NOSIZESEL',0x00200000)
		win_const_mgr.add_const('LVS_SORTASCENDING',0x00000010)
		win_const_mgr.add_const('CERT_TRUST_IS_COMPLEX_CHAIN',0x00010000)
		win_const_mgr.add_const('PSR_DA',0x00000026)
		win_const_mgr.add_const('PSR_DB',0x00000018)
		win_const_mgr.add_const('ERROR_SXS_XML_E_MULTIPLE_COLONS',0x000036DE)
		win_const_mgr.add_const('ERROR_INVALID_SUB_AUTHORITY',0x00000537)
		win_const_mgr.add_const('IDM_ARRANGEBOTTOM',0x00000008)
		win_const_mgr.add_const('META_ARC',0x00000817)
		win_const_mgr.add_const('LOAD_WITH_ALTERED_SEARCH_PATH',0x00000008)
		win_const_mgr.add_const('PSR_DT',0x00000011)
		win_const_mgr.add_const('MD_ERROR_SUB404_QUERY_STRING_TOO_LONG',0x0000000F)
		win_const_mgr.add_const('WMDM_E_INVALIDTYPE',0x80045002)
		win_const_mgr.add_const('FACILITY_NDIS_ERROR_CODE',0x00000023)
		win_const_mgr.add_const('DEBUG_DUMP_FILE_PAGE_FILE_DUMP',0x00000000)
		win_const_mgr.add_const('TYPE_VALUE',0x00000000)
		win_const_mgr.add_const('CDEF_DEVMON_FILTER',0x00000080)
		win_const_mgr.add_const('DISPID_HTMLDLG',0x000061A8)
		win_const_mgr.add_const('TVC_BYMOUSE',0x00000001)
		win_const_mgr.add_const('PIDDSI_LINKSDIRTY',0x00000010)
		win_const_mgr.add_const('PROTO_IP_DIFFSERV',0x00002718)
		win_const_mgr.add_const('D3DTA_SELECTMASK',0x00000000)
		win_const_mgr.add_const('FWPM_ACTRL_ENUM',0x00000020)
		win_const_mgr.add_const('ERROR_DRIVER_FAILED_PRIOR_UNLOAD',0x0000028E)
		win_const_mgr.add_const('IPV6_IFLIST',0x0000001C)
		win_const_mgr.add_const('FILE_DEVICE_VMBUS',0x0000003E)
		win_const_mgr.add_const('SQL_COPT_SS_BASE',0x000004B0)
		win_const_mgr.add_const('ERROR_WX86_WARNING',0x0000021B)
		win_const_mgr.add_const('MAX_MCAST_TTL',0x000000FF)
		win_const_mgr.add_const('ERROR_IPSEC_MM_FILTER_NOT_FOUND',0x000032CF)
		win_const_mgr.add_const('RTL_CRITICAL_SECTION_FLAG_STATIC_INIT',0x04000000)
		win_const_mgr.add_const('RI_MOUSE_BUTTON_4_UP',0x00000080)
		win_const_mgr.add_const('SQL_AT_CONSTRAINT_NAME_DEFINITION',0x00008000)
		win_const_mgr.add_const('CERT_STORE_CREATE_NEW_FLAG',0x00002000)
		win_const_mgr.add_const('STATURL_QUERYFLAG_ISCACHED',0x00010000)
		win_const_mgr.add_const('WAVE_FORMAT_2M16',0x00000040)
		win_const_mgr.add_const('RECIPIENTPOLICYV1',0x00000001)
		win_const_mgr.add_const('WMDRM_KEYTYPE_COCKTAIL',0x00000001)
		win_const_mgr.add_const('GIL_PERCLASS',0x00000004)
		win_const_mgr.add_const('WINEVENT_CHANNEL_GLOBAL_SECURITY',0x00000000)
		win_const_mgr.add_const('DDFXCAPS_BLTALPHA',0x00000001)
		win_const_mgr.add_const('CM_GAMMA_RAMP',0x00000002)
		win_const_mgr.add_const('DEBUG_FILTER_GO_NOT_HANDLED',0x00000001)
		win_const_mgr.add_const('GCP_REORDER',0x00000002)
		win_const_mgr.add_const('WIA_DPS_PAGE_HEIGHT',0x00000C1B)
		win_const_mgr.add_const('_WIN32_WINNT_LONGHORN',0x00000600)
		win_const_mgr.add_const('IMAGE_REL_BASED_HIGHADJ',0x00000004)
		win_const_mgr.add_const('IDM_TRIED_DELETECELLS',0x00000015)
		win_const_mgr.add_const('CRYPT_OID_INFO_ALGID_KEY',0x00000003)
		win_const_mgr.add_const('LVGS_SELECTED',0x00000020)
		win_const_mgr.add_const('DNS_ERROR_NO_PACKET',0x0000251F)
		win_const_mgr.add_const('JOY_POVRIGHT',0x00002328)
		win_const_mgr.add_const('UIS_INITIALIZE',0x00000003)
		win_const_mgr.add_const('LANG_ARABIC',0x00000001)
		win_const_mgr.add_const('D3DSP_SWIZZLE_SHIFT',0x00000010)
		win_const_mgr.add_const('KSALLOCATOR_REQUIREMENTF_PREFERENCES_ONLY',0x80000000)
		win_const_mgr.add_const('LINEBUSYMODE_TRUNK',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_NP_OKTODO',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_RESOURCE_TYPE_BUSY',0x00001715)
		win_const_mgr.add_const('CHECKSUM_OPEN_FAILURE',0x00000001)
		win_const_mgr.add_const('DE_E_NO_VALID_MEDIA',0x800C000A)
		win_const_mgr.add_const('PORT_SNMP',0x000000A1)
		win_const_mgr.add_const('DNS_TYPE_NS',0x00000002)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_PHY_DISABLED',0x00000004)
		win_const_mgr.add_const('PORT_DCP',0x0000005D)
		win_const_mgr.add_const('INTERNET_COOKIE_PROMPT_REQUIRED',0x00000020)
		win_const_mgr.add_const('TM_JOIN',0x00000002)
		win_const_mgr.add_const('WPP_POST_POSTING_URL_ERROR',0xC0042381)
		win_const_mgr.add_const('STATUS_SEVERITY_ERROR',0x00000003)
		win_const_mgr.add_const('WH_SYSMSGFILTER',0x00000006)
		win_const_mgr.add_const('IF_TYPE_ISO88025_TOKENRING',0x00000009)
		win_const_mgr.add_const('FILE_FLAG_SEQUENTIAL_SCAN',0x08000000)
		win_const_mgr.add_const('RPC_C_HTTP_AUTHN_SCHEME_BASIC',0x00000001)
		win_const_mgr.add_const('VPDF_SKIPINTELSLCHECK',0x00000004)
		win_const_mgr.add_const('PTE_WRITE_MASK',0x00000400)
		win_const_mgr.add_const('PAN_PROP_VERY_CONDENSED',0x00000008)
		win_const_mgr.add_const('MQMSG_AUTHENTICATED_SIGXML',0x00000009)
		win_const_mgr.add_const('INTERNET_STATUS_P3P_POLICYREF',0x00000146)
		win_const_mgr.add_const('SHARE_NETNAME_PARMNUM',0x00000001)
		win_const_mgr.add_const('NDR64_FC_BIND_GENERIC',0x00000001)
		win_const_mgr.add_const('CERT_TRUST_HAS_NOT_SUPPORTED_CRITICAL_EXT',0x08000000)
		win_const_mgr.add_const('ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT',0x0000170F)
		win_const_mgr.add_const('EVENT_SYSTEM_CONTEXTHELPSTART',0x0000000C)
		win_const_mgr.add_const('SV_TIMESOURCE_PARMNUM',0x00000204)
		win_const_mgr.add_const('EAP_E_SERVER_CERT_INVALID',0x80420201)
		win_const_mgr.add_const('MSIM_LIST_CONTACT',0x00000001)
		win_const_mgr.add_const('CMC_FAIL_BAD_IDENTITY',0x00000007)
		win_const_mgr.add_const('FIND_ENDSWITH',0x00200000)
		win_const_mgr.add_const('ODBC_ERROR_REMOVE_DSN_FAILED',0x00000014)
		win_const_mgr.add_const('DISPID_CANADVANCEERROR',0x0000000C)
		win_const_mgr.add_const('IP_RECEIVE_BROADCAST',0x00000016)
		win_const_mgr.add_const('WINHTTP_AUTH_SCHEME_BASIC',0x00000001)
		win_const_mgr.add_const('SIMULATED_FONTTYPE',0x00008000)
		win_const_mgr.add_const('VER_ERR_OPERAND',0x00000004)
		win_const_mgr.add_const('WIA_DPC_POWER_MODE',0x00000810)
		win_const_mgr.add_const('PDH_PLA_COLLECTION_NOT_FOUND',0xC0000BEB)
		win_const_mgr.add_const('COMP_ELEM_RESTORED_CSI',0x00002000)
		win_const_mgr.add_const('FIND_ACTCTX_SECTION_KEY_RETURN_FLAGS',0x00000002)
		win_const_mgr.add_const('HTTP_STATUS_CONFLICT',0x00000199)
		win_const_mgr.add_const('ETDT_USEAEROWIZARDTABTEXTURE',0x00000008)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_BLOCKALIGN',0x00004007)
		win_const_mgr.add_const('GPO_INFO_FLAG_SAFEMODE_BOOT',0x00000800)
		win_const_mgr.add_const('DBPROPVAL_TR_DONTCARE',0x00000040)
		win_const_mgr.add_const('CERT_STORE_SAVE_AS_PKCS12',0x00000003)
		win_const_mgr.add_const('NETLOGON_REPLICATION_IN_PROGRESS',0x00000002)
		win_const_mgr.add_const('SQL_BIND_TYPE',0x00000005)
		win_const_mgr.add_const('DCI_CAN_STRETCHXN',0x00004000)
		win_const_mgr.add_const('ENM_CORRECTTEXT',0x00400000)
		win_const_mgr.add_const('PHONEFEATURE_GETVOLUMEHANDSET',0x00000800)
		win_const_mgr.add_const('D3DFVF_TEXTUREFORMAT4',0x00000002)
		win_const_mgr.add_const('DEBUG_OUTSYM_DEFAULT',0x00000000)
		win_const_mgr.add_const('SPI_SETCLEARTYPE',0x00001049)
		win_const_mgr.add_const('EVENT_HEADER_EXT_TYPE_SID',0x00000002)
		win_const_mgr.add_const('SF_MAX_USERNAME',0x00000100)
		win_const_mgr.add_const('BL_4M',0x00400000)
		win_const_mgr.add_const('SM_FOCUS_TYPE_WFW_SERVER',0x00000006)
		win_const_mgr.add_const('PFM_NUMBERINGTAB',0x00004000)
		win_const_mgr.add_const('SFC_SCAN_IMMEDIATE',0x00000003)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_LOCAL_GROUPS',0x80000002)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_NOT_MEMBER',0x000013BC)
		win_const_mgr.add_const('META_DIBCREATEPATTERNBRUSH',0x00000142)
		win_const_mgr.add_const('CRYPT_HTTP_POST_RETRIEVAL',0x00100000)
		win_const_mgr.add_const('C2_RIGHTTOLEFT',0x00000002)
		win_const_mgr.add_const('BTH_MFG_TTPCOM',0x0000001A)
		win_const_mgr.add_const('MNGO_NOERROR',0x00000001)
		win_const_mgr.add_const('DS_REPSYNC_REQUEUE',0x00040000)
		win_const_mgr.add_const('WMDM_DEVICECAP_CANSEEK',0x00000080)
		win_const_mgr.add_const('NCRYPTBUFFER_DATA',0x00000001)
		win_const_mgr.add_const('UF_PASSWORD_EXPIRED',0x00800000)
		win_const_mgr.add_const('ERROR_BAD_CLUSTERS',0x00001AC1)
		win_const_mgr.add_const('SF_TEXTIZED',0x00000004)
		win_const_mgr.add_const('ETO_OPAQUE',0x00000002)
		win_const_mgr.add_const('LINEPROXYSTATUS_CLOSE',0x00000002)
		win_const_mgr.add_const('NTMS_BARCODE_LENGTH',0x00000040)
		win_const_mgr.add_const('HTTP_STATUS_SWITCH_PROTOCOLS',0x00000065)
		win_const_mgr.add_const('ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME',0x0000370B)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_CURRENT_USER_ID',0x00000001)
		win_const_mgr.add_const('KSDATARANGE_ATTRIBUTES',0x00000001)
		win_const_mgr.add_const('PAN_PROP_EXPANDED',0x00000005)
		win_const_mgr.add_const('WIA_PROP_NONE',0x00000008)
		win_const_mgr.add_const('ENABLE_EXTENDED_FLAGS',0x00000080)
		win_const_mgr.add_const('HELP_INDEX',0x00000003)
		win_const_mgr.add_const('WSAELOOP',0x0000274E)
		win_const_mgr.add_const('SV_BALANCECOUNT_PARMNUM',0x00000241)
		win_const_mgr.add_const('ERROR_PRINTER_DRIVER_ALREADY_INSTALLED',0x00000703)
		win_const_mgr.add_const('BS_ICON',0x00000040)
		win_const_mgr.add_const('EWX_REBOOT',0x00000002)
		win_const_mgr.add_const('HHWIN_BUTTON_STOP',0x00000001)
		win_const_mgr.add_const('DI_FLAGSEX_DRIVERLIST_FROM_URL',0x00200000)
		win_const_mgr.add_const('CTL_FIND_MD5_HASH',0x00000002)
		win_const_mgr.add_const('VK_DBE_KATAKANA',0x00000000)
		win_const_mgr.add_const('DCR_PP',0x00000000)
		win_const_mgr.add_const('WIA_PAGE_ISO_A8',0x0000000E)
		win_const_mgr.add_const('WIA_PAGE_ISO_A9',0x0000000F)
		win_const_mgr.add_const('WIA_PAGE_ISO_A6',0x0000000C)
		win_const_mgr.add_const('WIA_PAGE_ISO_A7',0x0000000D)
		win_const_mgr.add_const('MCI_WAVE_SET_ANYINPUT',0x04000000)
		win_const_mgr.add_const('DISPLAYDIB_NOFLIP',0x00000800)
		win_const_mgr.add_const('WIA_PAGE_ISO_A2',0x00000009)
		win_const_mgr.add_const('DN_HAS_PROBLEM',0x00000400)
		win_const_mgr.add_const('WIA_PAGE_ISO_A0',0x00000007)
		win_const_mgr.add_const('IMAGE_COMPRESSION_JPEG',0x00000006)
		win_const_mgr.add_const('LINEDIGITMODE_PULSE',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_ALREADY_UP',0x000013C5)
		win_const_mgr.add_const('SM_CXPADDEDBORDER',0x0000005C)
		win_const_mgr.add_const('TV_FIRST',0x00001100)
		win_const_mgr.add_const('CM_REMOVAL_POLICY_EXPECT_SURPRISE_REMOVAL',0x00000003)
		win_const_mgr.add_const('AMCONTROL_USED',0x00000001)
		win_const_mgr.add_const('STATE_SYSTEM_SELFVOICING',0x00080000)
		win_const_mgr.add_const('DEBUG_PROC_DESC_NO_MTS_PACKAGES',0x00000004)
		win_const_mgr.add_const('FAX_ERR_GROUP_NOT_FOUND',0x00001B5A)
		win_const_mgr.add_const('SQL_CVT_FLOAT',0x00000020)
		win_const_mgr.add_const('SQL_FN_NUM_TAN',0x00008000)
		win_const_mgr.add_const('MAPI_PW_FIRST_PROFILE',0x00000001)
		win_const_mgr.add_const('WS_GROUP',0x00020000)
		win_const_mgr.add_const('COLOR_SAMPLES',0x000002CD)
		win_const_mgr.add_const('ERROR_SCREEN_ALREADY_LOCKED',0x000005A0)
		win_const_mgr.add_const('CSRESTORE_TYPE_ONLINE',0x00000002)
		win_const_mgr.add_const('BG_E_TOO_MANY_JOBS_PER_MACHINE',0x80200050)
		win_const_mgr.add_const('TRUSTERROR_STEP_MSG_SIGNERCERT',0x0000000E)
		win_const_mgr.add_const('SI_ADVANCED',0x00000010)
		win_const_mgr.add_const('MCI_VCR_STATUS_VIDEO_SOURCE_NUMBER',0x00004009)
		win_const_mgr.add_const('WIA_DPS_SHOW_PREVIEW_CONTROL',0x00000C1F)
		win_const_mgr.add_const('DDFXCAPS_BLTSHRINKY',0x00001000)
		win_const_mgr.add_const('SPFILENOTIFY_STARTCOPY',0x00000000)
		win_const_mgr.add_const('HDF_JUSTIFYMASK',0x00000003)
		win_const_mgr.add_const('OID_GEN_VENDOR_ID',0x0001010C)
		win_const_mgr.add_const('DIF_NEWDEVICEWIZARD_PRESELECT',0x0000001A)
		win_const_mgr.add_const('PORT_UUCPD',0x0000021C)
		win_const_mgr.add_const('ILGOS_ALWAYS',0x00000000)
		win_const_mgr.add_const('C2_COMMONSEPARATOR',0x00000007)
		win_const_mgr.add_const('IDM_SIZETOCONTROL',0x00000023)
		win_const_mgr.add_const('SPQ_FLAG_BACKUP_AWARE',0x00000001)
		win_const_mgr.add_const('DEBUG_PHYSICAL_WRITE_COMBINED',0x00000003)
		win_const_mgr.add_const('ALG_TYPE_STREAM',0x00000004)
		win_const_mgr.add_const('ISSCERT_FILEURL_OLD',0x00000008)
		win_const_mgr.add_const('CMS_BACKWARD',0x00000001)
		win_const_mgr.add_const('EXCHIVERB_RESERVED_DELIVERY',0x0000006B)
		win_const_mgr.add_const('BTH_ERROR_UKNOWN_LMP_PDU',0x00000019)
		win_const_mgr.add_const('CFS_FORCE_POSITION',0x00000020)
		win_const_mgr.add_const('DEX_IDS_INSTALL_PROBLEM',0x0000057C)
		win_const_mgr.add_const('TCHT_ONITEMICON',0x00000002)
		win_const_mgr.add_const('WSAEDQUOT',0x00002755)
		win_const_mgr.add_const('IDM_DYNSRCSTOP',0x000008E0)
		win_const_mgr.add_const('CERT_PROT_ROOT_DISABLE_NT_AUTH_REQUIRED_FLAG',0x00000010)
		win_const_mgr.add_const('IDS_CC',0x00011005)
		win_const_mgr.add_const('DEBUG_SYMENT_IS_DATA',0x00000002)
		win_const_mgr.add_const('DS_REPSYNC_CRITICAL',0x00200000)
		win_const_mgr.add_const('DIF_INSTALLWIZARD',0x00000010)
		win_const_mgr.add_const('DOT11_STATUS_PACKET_REASSEMBLED',0x00001000)
		win_const_mgr.add_const('DMPAPER_A4_EXTRA',0x00000035)
		win_const_mgr.add_const('IMAGE_REL_IA64_SECREL32',0x0000000E)
		win_const_mgr.add_const('CERT_TRUST_DO_FULL_TRUST',0x00000005)
		win_const_mgr.add_const('IME_ESC_RESERVED_FIRST',0x00000004)
		win_const_mgr.add_const('SECPKG_FLAG_PRIVACY',0x00000002)
		win_const_mgr.add_const('MCI_INFO_NAME',0x00001000)
		win_const_mgr.add_const('CPF_CASTORE_ERROR',0x00000010)
		win_const_mgr.add_const('PAN_FAMILY_DECORATIVE',0x00000004)
		win_const_mgr.add_const('SQL_AD_CONSTRAINT_NAME_DEFINITION',0x00000001)
		win_const_mgr.add_const('FS_CALL_DELAYED',0x20002000)
		win_const_mgr.add_const('DB_IMP_LEVEL_ANONYMOUS',0x00000000)
		win_const_mgr.add_const('WNODE_FLAG_TOO_SMALL',0x00000020)
		win_const_mgr.add_const('SI_RESET_SACL',0x00080000)
		win_const_mgr.add_const('ICW_LAUNCHEDMANUAL',0x00000200)
		win_const_mgr.add_const('PICTYPE_METAFILE',0x00000002)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_TRICORE',0x00000520)
		win_const_mgr.add_const('DNS_RCLASS_HESIOD',0x00000400)
		win_const_mgr.add_const('DEBUG_CLASS_UNINITIALIZED',0x00000000)
		win_const_mgr.add_const('CALENDAR_SHOWTIMEAS_FREE',0x00000000)
		win_const_mgr.add_const('VER_SUITENAME',0x00000040)
		win_const_mgr.add_const('OID_FDDI_PORT_NEIGHBOR_TYPE',0x0303025D)
		win_const_mgr.add_const('MCI_DGV_FILE_MODE_LOADING',0x00000002)
		win_const_mgr.add_const('IMPORTANCE_HIGH_MIN',0x00000005)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_CO_PROTOCOL_CHARACTERISTICS',0x00000090)
		win_const_mgr.add_const('EAP_E_EAPHOST_METHOD_INVALID_PACKET',0x80420017)
		win_const_mgr.add_const('HIGH_SURROGATE_END',0x00000000)
		win_const_mgr.add_const('SP_PROT_NONE',0x00000000)
		win_const_mgr.add_const('ERROR_ACCOUNT_DISABLED',0x00000533)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_REASON_CODE_MASK',0x00000000)
		win_const_mgr.add_const('LB_SETANCHORINDEX',0x0000019C)
		win_const_mgr.add_const('KRAF_DISABLEUSEDEFAULTPROVIDER',0x00000008)
		win_const_mgr.add_const('BCRYPT_SECRET_AGREEMENT_OPERATION',0x00000008)
		win_const_mgr.add_const('METHOD_TYPE_ALL_METHODS',0xFFFFFFFF)
		win_const_mgr.add_const('DPNHCAPSFLAG_PUBLICADDRESSAVAILABLE',0x00000008)
		win_const_mgr.add_const('CM_DRP_REMOVAL_POLICY_HW_DEFAULT',0x00000021)
		win_const_mgr.add_const('ISR_ED',0x0000002B)
		win_const_mgr.add_const('FR_HIDEMATCHCASE',0x00008000)
		win_const_mgr.add_const('PERF_AGGREGATE_MAX',0x00000004)
		win_const_mgr.add_const('SQL_SCCO_READ_ONLY',0x00000001)
		win_const_mgr.add_const('RATING_FOUR_STARS_MAX',0x00000057)
		win_const_mgr.add_const('CTRY_AZERBAIJAN',0x000003E2)
		win_const_mgr.add_const('ISR_EI',0x00000029)
		win_const_mgr.add_const('WINEVENT_OPCODE_RECEIVE',0x00000000)
		win_const_mgr.add_const('ERROR_GROUP_NOT_FOUND',0x00001395)
		win_const_mgr.add_const('DC_COLLATE',0x00000016)
		win_const_mgr.add_const('D3DFVF_XYZ',0x00000002)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_OTHER',0x00000001)
		win_const_mgr.add_const('NETBIOS_TYPE_QUICK_UNIQUE',0x00000002)
		win_const_mgr.add_const('WINEVENT_OPCODE_DC_STOP',0x00000004)
		win_const_mgr.add_const('ERROR_CTX_CLOSE_PENDING',0x00001B5F)
		win_const_mgr.add_const('OT_STATIC',0x00000003)
		win_const_mgr.add_const('TAPE_FIXED_PARTITIONS',0x00000000)
		win_const_mgr.add_const('KSALLOCATOR_OPTIONF_VALID',0x00000003)
		win_const_mgr.add_const('USER_MARSHAL_FC_SHORT',0x00000006)
		win_const_mgr.add_const('CRLF_PRESERVE_EXPIRED_CA_CERTS',0x00040000)
		win_const_mgr.add_const('SHUTDOWN_TYPE_LEN',0x00000020)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_FILE_IO_INIT',0x04000000)
		win_const_mgr.add_const('LBS_MULTICOLUMN',0x00000200)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_SERVICEPACK_UNINSTALL',0x00000013)
		win_const_mgr.add_const('DDOVERFX_ARITHSTRETCHY',0x00000001)
		win_const_mgr.add_const('CAL_SABBREVDAYNAME2',0x00000000)
		win_const_mgr.add_const('CAL_SABBREVDAYNAME3',0x00000010)
		win_const_mgr.add_const('CAL_SABBREVDAYNAME4',0x00000011)
		win_const_mgr.add_const('TRANSPARENT',0x00000001)
		win_const_mgr.add_const('CAL_SABBREVDAYNAME6',0x00000013)
		win_const_mgr.add_const('SQL_DATE',0x00000009)
		win_const_mgr.add_const('CF_TIFF',0x00000006)
		win_const_mgr.add_const('SO_DONTROUTE',0x00000010)
		win_const_mgr.add_const('MEM_4MB_PAGES',0x80000000)
		win_const_mgr.add_const('STI_DEVSTATUS_EVENTS_STATE',0x00000002)
		win_const_mgr.add_const('D3DPMISCCAPS_POSTBLENDSRGBCONVERT',0x00200000)
		win_const_mgr.add_const('ILGT_NORMAL',0x00000000)
		win_const_mgr.add_const('ISDB_ERT_PID',0x00000021)
		win_const_mgr.add_const('SM_YVIRTUALSCREEN',0x0000004D)
		win_const_mgr.add_const('CERT_NAME_STR_NO_QUOTING_FLAG',0x10000000)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_MEMBERS',0x0000000C)
		win_const_mgr.add_const('DNS_ERROR_INVALID_NAME_CHAR',0x00002558)
		win_const_mgr.add_const('MAX_IDD_DYNAWIZ_RESOURCE_ID',0x00002AF8)
		win_const_mgr.add_const('LINECALLINFOSTATE_MEDIAMODE',0x00000010)
		win_const_mgr.add_const('MD_EXTLOG_SITE_NAME',0x00000010)
		win_const_mgr.add_const('SQL_DIAG_DROP_COLLATION',0x0000001A)
		win_const_mgr.add_const('SM_FOCUS_TYPE_LM_DOMAIN',0x00000002)
		win_const_mgr.add_const('CRYPT_DELETE_KEYSET',0x00000001)
		win_const_mgr.add_const('AA_A_WRITE',0x00002000)
		win_const_mgr.add_const('MAX_THEMESIZE',0x00000040)
		win_const_mgr.add_const('DEBUG_FORMAT_DEFAULT',0x00000000)
		win_const_mgr.add_const('STATUS_SEVERITY_RTC_ERROR',0x00000002)
		win_const_mgr.add_const('SCARD_W_SECURITY_VIOLATION',0x8010006A)
		win_const_mgr.add_const('MSIMWND_DISPID_ONSHOW',0x000000E3)
		win_const_mgr.add_const('BSSF_UNDELETEABLE',0x00001000)
		win_const_mgr.add_const('__SPECSTRINGS_STRICT_LEVEL',0x00000001)
		win_const_mgr.add_const('OID_GEN_LAST_CHANGE',0x00010281)
		win_const_mgr.add_const('IDS_CAP_STAT_CAP_INIT',0x000001F6)
		win_const_mgr.add_const('ERROR_DS_CANT_ON_NON_LEAF',0x00002015)
		win_const_mgr.add_const('SB_THUMBPOSITION',0x00000004)
		win_const_mgr.add_const('CERT_REQUEST_ORIGINATOR_PROP_ID',0x00000047)
		win_const_mgr.add_const('USER_HOME_DIR_PARMNUM',0x00000006)
		win_const_mgr.add_const('SCESTATUS_NO_MAPPING',0x00000012)
		win_const_mgr.add_const('FWPM_SUBSCRIPTION_FLAG_NOTIFY_ON_DELETE',0x00000002)
		win_const_mgr.add_const('DDPCAPS_8BIT',0x00000004)
		win_const_mgr.add_const('LC_INTERIORS',0x00000080)
		win_const_mgr.add_const('ERROR_INVALID_LB_MESSAGE',0x00000598)
		win_const_mgr.add_const('ERROR_BAD_ACCESSOR_FLAGS',0x00000305)
		win_const_mgr.add_const('WKSTA_UTILIZENTCACHING_PARMNUM',0x00000035)
		win_const_mgr.add_const('DNS_RCODE_SERVFAIL',0x00000002)
		win_const_mgr.add_const('D3DCAPS2_CANSHARERESOURCE',0x80000000)
		win_const_mgr.add_const('KSPROPERTY_TYPE_SERIALIZESIZE',0x00008000)
		win_const_mgr.add_const('LM20_UNLEN',0x00000014)
		win_const_mgr.add_const('BASE_PROTOCOL',0x00000001)
		win_const_mgr.add_const('KTM_MARSHAL_BLOB_VERSION_MINOR',0x00000001)
		win_const_mgr.add_const('MUTZ_REQUIRESAVEDFILECHECK',0x00000400)
		win_const_mgr.add_const('MS_PROFILE_GROUP_POLICY',0x00000001)
		win_const_mgr.add_const('PAN_FAMILYTYPE_INDEX',0x00000000)
		win_const_mgr.add_const('WM_HANDHELDFIRST',0x00000358)
		win_const_mgr.add_const('MCI_DEVTYPE_VCR',0x00000201)
		win_const_mgr.add_const('SCARD_NEGOTIABLE',0x00000005)
		win_const_mgr.add_const('CM_OPEN_CLASS_KEY_INTERFACE',0x00000001)
		win_const_mgr.add_const('HDI_FORMAT',0x00000004)
		win_const_mgr.add_const('ERROR_LOG_POLICY_INVALID',0x000019DD)
		win_const_mgr.add_const('IDM_HTMLAREA',0x00000882)
		win_const_mgr.add_const('MUI_MACHINE_LANGUAGE_SETTINGS',0x00000400)
		win_const_mgr.add_const('CBS_AUTOHSCROLL',0x00000040)
		win_const_mgr.add_const('FILEOP_DELETE',0x00000002)
		win_const_mgr.add_const('DISPID_ONFULLSCREEN',0x00000102)
		win_const_mgr.add_const('RASLCPAP_SPAP',0x0000C027)
		win_const_mgr.add_const('SCARD_COLD_RESET',0x00000001)
		win_const_mgr.add_const('TF_CLUIE_SELECTION',0x00000004)
		win_const_mgr.add_const('OID_802_11_NON_BCAST_SSID_LIST',0x0D010124)
		win_const_mgr.add_const('DI_FLAGSEX_PROPCHANGE_PENDING',0x00000400)
		win_const_mgr.add_const('SQL_API_SQLGETDESCFIELD',0x000003F0)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_IO_FLUSH',0x0000000E)
		win_const_mgr.add_const('ERROR_NO_RECOVERY_POLICY',0x00001773)
		win_const_mgr.add_const('WARNING_IPSEC_QM_POLICY_PRUNED',0x000032E1)
		win_const_mgr.add_const('D3DPBLENDCAPS_INVSRCALPHA',0x00000020)
		win_const_mgr.add_const('NI_DGRAM',0x00000010)
		win_const_mgr.add_const('LINE_QUEUESTATUS',0x0000001C)
		win_const_mgr.add_const('OPTION_NETWORK_INFO_SERVICE_DOM',0x00000028)
		win_const_mgr.add_const('PST_RS422',0x00000003)
		win_const_mgr.add_const('RPC_IF_ALLOW_LOCAL_ONLY',0x00000020)
		win_const_mgr.add_const('ERROR_INVALID_PRIMARY_GROUP',0x0000051C)
		win_const_mgr.add_const('PP_ENUMALGS',0x00000001)
		win_const_mgr.add_const('DSF_ALL_DEVICES',0x0000FFFF)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_FLOAT',0x00000006)
		win_const_mgr.add_const('CM_DRP_DEVICEDESC',0x00000001)
		win_const_mgr.add_const('WM_MDISETMENU',0x00000230)
		win_const_mgr.add_const('BTH_MFG_SYMBOL_TECHNOLOGIES',0x0000002A)
		win_const_mgr.add_const('IP_SUCCESS',0x00000000)
		win_const_mgr.add_const('CRYPTUI_CERT_MGR_PUBLISHER_TAB',0x00000004)
		win_const_mgr.add_const('GLEX_RETURN',0x00000020)
		win_const_mgr.add_const('DEBUG_ATTACH_EXDI_DRIVER',0x00000002)
		win_const_mgr.add_const('CDERR_NOTEMPLATE',0x00000003)
		win_const_mgr.add_const('RC_OP_DX_OUTPUT',0x00004000)
		win_const_mgr.add_const('FW_SEMIBOLD',0x00000258)
		win_const_mgr.add_const('MAX_DATE_TIME_LENGTH',0x00000038)
		win_const_mgr.add_const('MSIM_LIST_BLOCK',0x00000004)
		win_const_mgr.add_const('PRIVACY_TYPE_FIRST_PARTY',0x00000000)
		win_const_mgr.add_const('WEBPOST_ERROR_FIRST',0x40042100)
		win_const_mgr.add_const('PAN_LETT_NORMAL_FLATTENED',0x00000005)
		win_const_mgr.add_const('AMDDS_YUVOVR',0x00000008)
		win_const_mgr.add_const('NCRYPT_SCHANNEL_INTERFACE',0x00010002)
		win_const_mgr.add_const('GDICOMMENT_UNICODE_END',0x00000080)
		win_const_mgr.add_const('DOT11_FLAGS_80211G_USE_PROTECTION',0x00000020)
		win_const_mgr.add_const('SPI_SETKEYBOARDCUES',0x0000100B)
		win_const_mgr.add_const('LINEDEVSTATE_BATTERY',0x00008000)
		win_const_mgr.add_const('SQL_ATTR_ENLIST_IN_DTC',0x000004B7)
		win_const_mgr.add_const('KS_VIDEO_FLAG_B_FRAME',0x00000020)
		win_const_mgr.add_const('FTP_TRANSFER_TYPE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('UF_MNS_LOGON_ACCOUNT',0x00020000)
		win_const_mgr.add_const('WINSTA_ENUMERATE',0x00000100)
		win_const_mgr.add_const('MDSP_WRITE',0x00000002)
		win_const_mgr.add_const('SV_QUEUESAMPLESECS_PARMNUM',0x00000240)
		win_const_mgr.add_const('CRYPT_ACQUIRE_COMPARE_KEY_FLAG',0x00000004)
		win_const_mgr.add_const('RR_INDEX_LEN',0x00000003)
		win_const_mgr.add_const('CRYPT_DONT_VERIFY_SIGNATURE',0x00000100)
		win_const_mgr.add_const('WMS_NUM_STREAMHEADER_ATTRIBUTES',0x0000000B)
		win_const_mgr.add_const('DNS_RTYPE_WINS',0x00000001)
		win_const_mgr.add_const('COLOR_HUEACCEL',0x000002D3)
		win_const_mgr.add_const('DEBUG_EXECUTE_NO_REPEAT',0x00000004)
		win_const_mgr.add_const('DNS_ERROR_INVALID_DATAFILE_NAME',0x000025B4)
		win_const_mgr.add_const('DMPAPER_ENV_B5',0x00000022)
		win_const_mgr.add_const('DMPAPER_ENV_B6',0x00000023)
		win_const_mgr.add_const('_FACDXGI',0x00000087)
		win_const_mgr.add_const('CM_REMOVE_BITS',0x00000003)
		win_const_mgr.add_const('SCARD_CLASS_ICC_STATE',0x00000009)
		win_const_mgr.add_const('MODALS_MIN_PASSWD_LEN_PARMNUM',0x00000001)
		win_const_mgr.add_const('WHITEBALANCE_DAYLIGHT',0x00000004)
		win_const_mgr.add_const('FRS_ERR_PARENT_INSUFFICIENT_PRIV',0x00001F49)
		win_const_mgr.add_const('OID_FDDI_PORT_CONNNECT_STATE',0x03030272)
		win_const_mgr.add_const('RPC_X_SS_CONTEXT_DAMAGED',0x000006F1)
		win_const_mgr.add_const('IIS_MD_ADSI_METAID_BEGIN',0x0001FBD0)
		win_const_mgr.add_const('WSB_PROP_HSTYLE',0x00000200)
		win_const_mgr.add_const('PTE_PFN_SHIFT',0x00000008)
		win_const_mgr.add_const('LPD_SWAP_COPY',0x00000400)
		win_const_mgr.add_const('SPDRP_SECURITY',0x00000017)
		win_const_mgr.add_const('IDM_RAISED',0x0000003D)
		win_const_mgr.add_const('MCI_VCR_STATUS_TUNER_CHANNEL',0x00004014)
		win_const_mgr.add_const('MAPI_DIALOG',0x00000008)
		win_const_mgr.add_const('OID_ATM_RCV_INVALID_VPI_VCI',0x08020201)
		win_const_mgr.add_const('EVENT_HEADER_FLAG_TRACE_MESSAGE',0x00000008)
		win_const_mgr.add_const('BEST_MODE',0x00000003)
		win_const_mgr.add_const('CRL_FIND_ISSUED_BY_AKI_FLAG',0x00000001)
		win_const_mgr.add_const('PROCESSOR_ARM_7TDMI',0x00011171)
		win_const_mgr.add_const('WLAN_AVAILABLE_NETWORK_INCLUDE_ALL_ADHOC_PROFILES',0x00000001)
		win_const_mgr.add_const('CB_GETLBTEXT',0x00000148)
		win_const_mgr.add_const('MILCORE_TS_QUERYVER_RESULT_TRUE',0x7FFFFFFF)
		win_const_mgr.add_const('WKSTA_COMPUTERNAME_PARMNUM',0x00000001)
		win_const_mgr.add_const('SV_NETIOALERT_PARMNUM',0x0000002A)
		win_const_mgr.add_const('PORT_NICNAME',0x0000002B)
		win_const_mgr.add_const('NDW_INSTALLFLAG_NEEDSHUTDOWN',0x00000200)
		win_const_mgr.add_const('DT_LEFT',0x00000000)
		win_const_mgr.add_const('PID_MISC_ACCESSCOUNT',0x00000003)
		win_const_mgr.add_const('MINIDUMP_MISC1_PROCESS_ID',0x00000001)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_STATUS',0x00000012)
		win_const_mgr.add_const('D3DWRAPCOORD_3',0x00000008)
		win_const_mgr.add_const('D3DWRAPCOORD_2',0x00000004)
		win_const_mgr.add_const('D3DWRAPCOORD_1',0x00000002)
		win_const_mgr.add_const('D3DWRAPCOORD_0',0x00000001)
		win_const_mgr.add_const('IF_TYPE_DS0_BUNDLE',0x00000052)
		win_const_mgr.add_const('MXDCOP_SET_S0PAGE',0x0000001C)
		win_const_mgr.add_const('JOY_POVBACKWARD',0x00004650)
		win_const_mgr.add_const('DDOVER_ALPHASRCNEG',0x00000080)
		win_const_mgr.add_const('ED_CENTER',0x00000200)
		win_const_mgr.add_const('PRODUCT_STORAGE_STANDARD_SERVER',0x00000015)
		win_const_mgr.add_const('MD_SERVER_SIZE_MEDIUM',0x00000001)
		win_const_mgr.add_const('OID_802_3_XMIT_TIMES_CRS_LOST',0x01020206)
		win_const_mgr.add_const('SUBLANG_KINYARWANDA_RWANDA',0x00000001)
		win_const_mgr.add_const('LINEDEVSTATE_LOCK',0x00080000)
		win_const_mgr.add_const('SHGVSPB_INHERIT',0x00000010)
		win_const_mgr.add_const('COLOR_INACTIVECAPTIONTEXT',0x00000013)
		win_const_mgr.add_const('X3_D_WH_SIGN_VAL_POS_X',0x00000000)
		win_const_mgr.add_const('LINEAGENTSTATUSEX_STATE',0x00000002)
		win_const_mgr.add_const('MM_MIM_ERROR',0x000003C5)
		win_const_mgr.add_const('ERROR_LOG_INCONSISTENT_SECURITY',0x000019F6)
		win_const_mgr.add_const('SNMP_GENERICTRAP_EGPNEIGHLOSS',0x00000005)
		win_const_mgr.add_const('INTERNET_OPTION_SECURITY_CERTIFICATE',0x00000023)
		win_const_mgr.add_const('ERROR_LOG_START_OF_LOG',0x000019DA)
		win_const_mgr.add_const('OID_IRDA_MAX_UNICAST_LIST_SIZE',0x0A010203)
		win_const_mgr.add_const('SQL_CONVERT_BIT',0x00000037)
		win_const_mgr.add_const('ES_AWAYMODE_REQUIRED',0x00000040)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGKCBRUNDOWNEND',0x00000019)
		win_const_mgr.add_const('OPATH_TOK_INT',0x00000066)
		win_const_mgr.add_const('RP_SYNC',0x00000002)
		win_const_mgr.add_const('URLACTION_HTML_MIN',0x00001600)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_UNAUTH_USER_FLOW_COUNT',0x00000008)
		win_const_mgr.add_const('ERROR_EVT_VERSION_TOO_NEW',0x00003ABB)
		win_const_mgr.add_const('CERT_KEY_ENCIPHERMENT_KEY_USAGE',0x00000020)
		win_const_mgr.add_const('TF_MOD_LCONTROL',0x00000080)
		win_const_mgr.add_const('ENCODE_IS_USED',0x00000010)
		win_const_mgr.add_const('WINHTTP_QUERY_ALLOW',0x00000007)
		win_const_mgr.add_const('SCH_CRED_RESTRICTED_ROOTS',0x00002000)
		win_const_mgr.add_const('META_SELECTPALETTE',0x00000234)
		win_const_mgr.add_const('PIDDSI_CATEGORY',0x00000002)
		win_const_mgr.add_const('EC_DEVICE_LOST',0x00000001)
		win_const_mgr.add_const('CACHE_CONFIG_DISK_CACHE_PATHS_FC',0x00000040)
		win_const_mgr.add_const('ERROR_CONNECTION_UNAVAIL',0x000004B1)
		win_const_mgr.add_const('GPO_BROWSE_OPENBUTTON',0x00000008)
		win_const_mgr.add_const('ERROR_WRONG_EFS',0x00001775)
		win_const_mgr.add_const('SPINST_COPYINF',0x00000200)
		win_const_mgr.add_const('KSDSOUND_BUFFER_CTRL_PAN',0x00000004)
		win_const_mgr.add_const('IDS_CAP_STAT_VIDEOAUDIO',0x000001FF)
		win_const_mgr.add_const('ERROR_INDIGENOUS_TYPE',0x000010F2)
		win_const_mgr.add_const('GT_INTERNAL',0x00000008)
		win_const_mgr.add_const('AA_S_DELETE',0x00000040)
		win_const_mgr.add_const('E_SURFACE_NOTMYPOINTER',0x8000C002)
		win_const_mgr.add_const('PRNSETUPDLGORD',0x00000603)
		win_const_mgr.add_const('RPC_C_AUTHN_LEVEL_CALL',0x00000003)
		win_const_mgr.add_const('PHONEFEATURE_SETHOOKSWITCHHEADSET',0x00400000)
		win_const_mgr.add_const('POLICY_SHOWREASONUI_ALWAYS',0x00000001)
		win_const_mgr.add_const('ERROR_GEN_FAILURE',0x0000001F)
		win_const_mgr.add_const('SYNCH_DATA_STORE_NOTES',0x00000005)
		win_const_mgr.add_const('DEBUG_REGISTERS_INT32',0x00000001)
		win_const_mgr.add_const('SES_DRAFTMODE',0x00008000)
		win_const_mgr.add_const('DPNHGETCAPS_UPDATESERVERSTATUS',0x00000001)
		win_const_mgr.add_const('IME_ESC_SYNC_HOTKEY',0x00001007)
		win_const_mgr.add_const('CRYPT_VERIFY_CERT_SIGN_ISSUER_NULL',0x00000004)
		win_const_mgr.add_const('ERROR_UNSUPPORTED_COMPRESSION',0x0000026A)
		win_const_mgr.add_const('TTI_WARNING',0x00000002)
		win_const_mgr.add_const('DOT11_STATUS_AUTH_NOT_VERIFIED',0x00008000)
		win_const_mgr.add_const('BLLI_L2_HDLC_NRM',0x0000000A)
		win_const_mgr.add_const('IMAGE_REL_MIPS_SECRELLO',0x0000000C)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_QM_EXPIRED',0x00003647)
		win_const_mgr.add_const('MM_DONTREMOVESEPS',0x00000004)
		win_const_mgr.add_const('CERT_TRUST_HAS_VALID_NAME_CONSTRAINTS',0x00000400)
		win_const_mgr.add_const('ERROR_DS_CLASS_MUST_BE_CONCRETE',0x000020A7)
		win_const_mgr.add_const('IF_TYPE_FASTETHER',0x0000003E)
		win_const_mgr.add_const('WM_TCARD',0x00000052)
		win_const_mgr.add_const('PFM_OFFSET',0x00000004)
		win_const_mgr.add_const('IMGBITS_NONE',0x02000000)
		win_const_mgr.add_const('IDRETRY',0x00000004)
		win_const_mgr.add_const('CRL_DIST_POINT_ISSUER_RDN_NAME',0x00000002)
		win_const_mgr.add_const('STOPBITS_15',0x00000002)
		win_const_mgr.add_const('LMEM_VALID_FLAGS',0x00000F72)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_SINGLE_PHASE_COMMIT',0x00000200)
		win_const_mgr.add_const('WIA_DPC_TILT_POSITION',0x0000080D)
		win_const_mgr.add_const('HTTP_QUERY_MAX_FORWARDS',0x0000003C)
		win_const_mgr.add_const('MSV1_0_NTLM3_OWF_LENGTH',0x00000010)
		win_const_mgr.add_const('SV_CONNECTIONLESSAUTODISC_PARMNUM',0x00000232)
		win_const_mgr.add_const('ERROR_DS_DST_DOMAIN_NOT_NATIVE',0x00002130)
		win_const_mgr.add_const('MD_ERROR_SUB403_ADDR_REJECT',0x00000006)
		win_const_mgr.add_const('WMDM_FILE_ATTR_MUSIC',0x00080000)
		win_const_mgr.add_const('CDB2N_CONTEXTMENU_START',0x00000002)
		win_const_mgr.add_const('ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER',0x00002145)
		win_const_mgr.add_const('WINEVENT_KEYWORD_RESERVED_62',0x4000000000000000)
		win_const_mgr.add_const('WINEVENT_KEYWORD_RESERVED_63',0x8000000000000000)
		win_const_mgr.add_const('TTFMFP_SUBSET',0x00000000)
		win_const_mgr.add_const('SPI_GETTOOLTIPFADE',0x00001018)
		win_const_mgr.add_const('COD_AUDIO_MINOR_GAMING_TOY',0x00000012)
		win_const_mgr.add_const('CM_DEVCAP_NONDYNAMIC',0x00000200)
		win_const_mgr.add_const('LOCALE_IMEASURE',0x0000000D)
		win_const_mgr.add_const('NRC_CMDTMO',0x00000005)
		win_const_mgr.add_const('FILTER_TEMP_DUPLICATE_ACCOUNT',0x00000001)
		win_const_mgr.add_const('TLS1_ALERT_EXPORT_RESTRICTION',0x0000003C)
		win_const_mgr.add_const('HTTP_QUERY_ECHO_REPLY',0x00000048)
		win_const_mgr.add_const('DEBUG_SYMINFO_IMAGEHLP_MODULEW64',0x00000001)
		win_const_mgr.add_const('MSIM_LIST_SYSTEM',0x00000080)
		win_const_mgr.add_const('IDD_OUTOFMEMORY',0x00000400)
		win_const_mgr.add_const('SP_COPY_FORCE_NEWER',0x00002000)
		win_const_mgr.add_const('PROV_REPLACE_OWF',0x00000017)
		win_const_mgr.add_const('METADATA_DONT_EXPAND',0x00000200)
		win_const_mgr.add_const('CB_OKAY',0x00000000)
		win_const_mgr.add_const('MCIWNDF_NOTIFYSIZE',0x00000400)
		win_const_mgr.add_const('BTH_MFG_NOKIA',0x00000001)
		win_const_mgr.add_const('LDAP_VENDOR_VERSION',0x000001FE)
		win_const_mgr.add_const('IF_TYPE_REGULAR_1822',0x00000002)
		win_const_mgr.add_const('DBFLAGS_CREATEIFNEEDED',0x00000002)
		win_const_mgr.add_const('SCARD_W_CHV_BLOCKED',0x8010006C)
		win_const_mgr.add_const('CACHE_CONFIG_USER_MODE_FC',0x00001000)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_WANT_PROVIDER_GC',0x00000008)
		win_const_mgr.add_const('NETE_CONNBROKEN',0x00000004)
		win_const_mgr.add_const('RBBIM_CHEVRONLOCATION',0x00001000)
		win_const_mgr.add_const('TIMEANIMATIONELEMENT_OFFSET',0x00000300)
		win_const_mgr.add_const('SM_CYSIZE',0x0000001F)
		win_const_mgr.add_const('XIDDATASIZE',0x00000080)
		win_const_mgr.add_const('SNMP_TRAP_LINKUP',0x00000003)
		win_const_mgr.add_const('AUTH_REQ_TRANSITIVE_TRUST',0x00000400)
		win_const_mgr.add_const('D3DISSUE_BEGIN',0x00000001)
		win_const_mgr.add_const('ERROR_FLOPPY_UNKNOWN_ERROR',0x00000464)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_VOLUMEUP',0x00000013)
		win_const_mgr.add_const('HTTP_QUERY_LINK',0x00000010)
		win_const_mgr.add_const('IDC_EL_CANCELLINK',0x000000D1)
		win_const_mgr.add_const('LUP_RETURN_BLOB',0x00000200)
		win_const_mgr.add_const('CP_SUPPORTED',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NEG_STATUS_END',0x00003649)
		win_const_mgr.add_const('CTRY_CARIBBEAN',0x00000001)
		win_const_mgr.add_const('DISPID_IWBSCRIPTCONTROL_SETCONTEXTMENU',0x00000003)
		win_const_mgr.add_const('MAPIFORM_SELECT_ALL_REGISTRIES',0x00000000)
		win_const_mgr.add_const('OFASI_EDIT',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_LANGUAGE',0x00000006)
		win_const_mgr.add_const('SHACF_AUTOAPPEND_FORCE_OFF',0x80000000)
		win_const_mgr.add_const('FEI_LINE_UNAVAILABLE',0x00000019)
		win_const_mgr.add_const('DRM_PLAYLIST_DATA_V2_VALID',0x00000001)
		win_const_mgr.add_const('D3D10_DEFAULT_BLEND_FACTOR_ALPHA',0x00000001)
		win_const_mgr.add_const('ACTRL_AUDIT_FAILURE',0x00000008)
		win_const_mgr.add_const('RP_ERROR_CONTEXT_CAT',0x00200000)
		win_const_mgr.add_const('ERROR_DRIVER_DATABASE_ERROR',0x0000028C)
		win_const_mgr.add_const('DEBUG_CES_EFFECTIVE_PROCESSOR',0x00000002)
		win_const_mgr.add_const('MDM_SHIFT_BEARERMODE',0x0000000C)
		win_const_mgr.add_const('RPC_C_HTTP_AUTHN_SCHEME_NEGOTIATE',0x00000010)
		win_const_mgr.add_const('CTL_FIND_EXISTING',0x00000005)
		win_const_mgr.add_const('SQL_API_SQLGETSTMTATTR',0x000003F6)
		win_const_mgr.add_const('PIDVSI_FRAME_COUNT',0x00000005)
		win_const_mgr.add_const('DCOMSCM_PING_DISALLOW_UNSECURE_CALL',0x00000020)
		win_const_mgr.add_const('DDPCAPS_8BITENTRIES',0x00000002)
		win_const_mgr.add_const('D3DPRESENT_BACK_BUFFERS_MAX',0x00000003)
		win_const_mgr.add_const('DEBUG_ENGOPT_FAIL_INCOMPLETE_INFORMATION',0x00000200)
		win_const_mgr.add_const('FCT_ADDTOEND',0x00000004)
		win_const_mgr.add_const('CAL_TAIWAN',0x00000004)
		win_const_mgr.add_const('FACILITY_USERMODE_FILTER_MANAGER',0x0000001F)
		win_const_mgr.add_const('DEX_IDS_STREAM_NUMBER',0x0000057F)
		win_const_mgr.add_const('DBPROP_DEFERNONINDEXEDTRIMMING',0x00000003)
		win_const_mgr.add_const('NTDDI_WIN2KSP4',0x05000400)
		win_const_mgr.add_const('AM_AC3_ALTERNATE_AUDIO_1',0x00000001)
		win_const_mgr.add_const('NTDDI_WIN2KSP3',0x05000300)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_GOPHER_FILE',0x0000000B)
		win_const_mgr.add_const('AM_AC3_ALTERNATE_AUDIO_2',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_XML_E_EXPECTINGTAGEND',0x000036D6)
		win_const_mgr.add_const('SMART_OFFLINE_ROUTINE_OFFLINE',0x00000000)
		win_const_mgr.add_const('IPX_IN_TRAFFIC_FILTER_INFO_TYPE',0x00000006)
		win_const_mgr.add_const('WAVE_FORMAT_48M16',0x00004000)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_NETWORK',0x00000006)
		win_const_mgr.add_const('GT_RESOURCE',0x00000005)
		win_const_mgr.add_const('TTFCFP_SUBSET1',0x00000001)
		win_const_mgr.add_const('CRYPT_STRING_BINARY',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_CEE_ADDR64',0x00000002)
		win_const_mgr.add_const('LOGFLAGS_FORWARD',0x00000000)
		win_const_mgr.add_const('SQL_CO_OFF',0x00000000)
		win_const_mgr.add_const('DN_STARTED',0x00000008)
		win_const_mgr.add_const('OID_GEN_PCI_DEVICE_CUSTOM_PROPERTIES',0x00010211)
		win_const_mgr.add_const('DNS_CLASS_CSNET',0x00000002)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_WINDOWS_CE_GUI',0x00000009)
		win_const_mgr.add_const('AUTH_FLAG_DISABLE_BASIC_CLEARCHANNEL',0x00000004)
		win_const_mgr.add_const('DSBF_ICONLOCATION',0x00000002)
		win_const_mgr.add_const('ERROR_SOURCE_ELEMENT_EMPTY',0x00000488)
		win_const_mgr.add_const('EAP_E_EAPHOST_THIRDPARTY_METHOD_HOST_RESET',0x80420012)
		win_const_mgr.add_const('MDLEVEL_TYPE_CALCULATED',0x00000002)
		win_const_mgr.add_const('PBTF_APMRESUMEFROMFAILURE',0x00000001)
		win_const_mgr.add_const('LINEADDRESSTYPE_DOMAINNAME',0x00000008)
		win_const_mgr.add_const('SUBLANG_SINDHI_AFGHANISTAN',0x00000002)
		win_const_mgr.add_const('IDF_NOREMOVABLEMEDIAPROMPT',0x00001000)
		win_const_mgr.add_const('DMCOLOR_COLOR',0x00000002)
		win_const_mgr.add_const('LDAP_RES_COMPARE',0x00000006)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_PREW2KCOMPACCESS',0x0000022A)
		win_const_mgr.add_const('CDO_E_INVALID_POST_OPTION',0x80040221)
		win_const_mgr.add_const('CAUSE_REASON_IE_MISSING',0x00000004)
		win_const_mgr.add_const('IDM_OPTIONS',0x00000857)
		win_const_mgr.add_const('DNF_DUPDRIVERVER',0x00008000)
		win_const_mgr.add_const('ERROR_TRANSPORT_FULL',0x000010E8)
		win_const_mgr.add_const('KERBEROS_VERSION',0x00000005)
		win_const_mgr.add_const('SUBLANG_ENGLISH_PHILIPPINES',0x00000000)
		win_const_mgr.add_const('SDP_PROTOCOL_UUID16',0x00000001)
		win_const_mgr.add_const('IDM_TRIED_FIND',0x00000022)
		win_const_mgr.add_const('SPI_SETSOUNDSENTRY',0x00000041)
		win_const_mgr.add_const('DI_VENDOR_ID_SOURCE_USB_IF',0x00000002)
		win_const_mgr.add_const('RIDI_PREPARSEDDATA',0x20000005)
		win_const_mgr.add_const('STDPROP_INDEX_TERM_RAW_LENGTH',0x000000D3)
		win_const_mgr.add_const('MHDR_DONE',0x00000001)
		win_const_mgr.add_const('ERROR_TRANSFORM_NOT_SUPPORTED',0x000007D4)
		win_const_mgr.add_const('ERROR_MULTIPLE_FAULT_VIOLATION',0x00000280)
		win_const_mgr.add_const('CMC_TAGGED_CERT_REQUEST_CHOICE',0x00000001)
		win_const_mgr.add_const('PRJOB_QS_SPOOLING',0x00000002)
		win_const_mgr.add_const('EM_GETPASSWORDCHAR',0x000000D2)
		win_const_mgr.add_const('MDPROPVAL_MNF_DRILLDOWNLEVELBOTTOM',0x00008000)
		win_const_mgr.add_const('WAVE_FILTER_DEVELOPMENT',0x0000FFFF)
		win_const_mgr.add_const('NDIS_WMI_ENUM_ADAPTER_REVISION_1',0x00000001)
		win_const_mgr.add_const('CACHEGROUP_ATTRIBUTE_BASIC',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_RECORDER',0x00000100)
		win_const_mgr.add_const('SQL_ATTR_WRITE',0x00000001)
		win_const_mgr.add_const('CPLPAGE_MOUSE_WHEEL',0x00000003)
		win_const_mgr.add_const('EC_END_OF_SEGMENT',0x0000001C)
		win_const_mgr.add_const('DISPID_DDISCFORMAT2RAWCDEVENTS_UPDATE',0x00000200)
		win_const_mgr.add_const('PDH_LOG_OPT_USER_STRING',0x01000000)
		win_const_mgr.add_const('RP_ERROR_CONTEXT_STORE',0x00100000)
		win_const_mgr.add_const('MD_SERVER_CONFIG_ALLOW_ENCRYPT',0x00000004)
		win_const_mgr.add_const('PER_USER_AUDIT_FAILURE_EXCLUDE',0x00000008)
		win_const_mgr.add_const('OID_TAPI_PROVIDER_SHUTDOWN',0x07030119)
		win_const_mgr.add_const('LINECALLPARAMFLAGS_PREDICTIVEDIAL',0x00000040)
		win_const_mgr.add_const('IDI_DISABLED_OVL',0x000001F5)
		win_const_mgr.add_const('LOCALE_IDEFAULTEBCDICCODEPAGE',0x00001012)
		win_const_mgr.add_const('WINHTTP_OPTION_MAX_CONNS_PER_SERVER',0x00000049)
		win_const_mgr.add_const('MCI_DGV_LIST_NUMBER',0x00040000)
		win_const_mgr.add_const('BG_E_VALIDATION_FAILED',0x80200053)
		win_const_mgr.add_const('CRYPTPROTECT_PROMPT_REQUIRE_STRONG',0x00000010)
		win_const_mgr.add_const('OID_TAPI_CONDITIONAL_MEDIA_DETECTION',0x07030105)
		win_const_mgr.add_const('UIA_E_ELEMENTNOTENABLED',0x80040200)
		win_const_mgr.add_const('PID_IS_SHOWCMD',0x00000007)
		win_const_mgr.add_const('FAX_CONFIG_QUERY',0x00000004)
		win_const_mgr.add_const('MD_LOG_TYPE_ENABLED',0x00000001)
		win_const_mgr.add_const('DNS_RTYPE_WKS',0x00000000)
		win_const_mgr.add_const('SQL_DESC_LITERAL_PREFIX',0x0000001B)
		win_const_mgr.add_const('ARCONTENT_UNKNOWNCONTENT',0x00000040)
		win_const_mgr.add_const('MDLEVEL_TYPE_REGULAR',0x00000000)
		win_const_mgr.add_const('CPL_EXIT',0x00000007)
		win_const_mgr.add_const('DDOVER_REFRESHDIRTYRECTS',0x00010000)
		win_const_mgr.add_const('IAS_ATTRIB_INT',0x00000001)
		win_const_mgr.add_const('SECPKG_FLAG_STREAM',0x00000400)
		win_const_mgr.add_const('WIA_COMPRESSION_BI_RLE4',0x00000001)
		win_const_mgr.add_const('DEBUG_STATUS_INSIDE_WAIT',0x100000000)
		win_const_mgr.add_const('CHANNEL_OPTION_ENCRYPT_RDP',0x40000000)
		win_const_mgr.add_const('TMT_EDGEHIGHLIGHTCOLOR',0x00000EDD)
		win_const_mgr.add_const('TBS_COMMAND_LOCALITY_ONE',0x00000001)
		win_const_mgr.add_const('ISCSI_LOGIN_OPTIONS_DEFAULT_TIME_2_WAIT',0x00000008)
		win_const_mgr.add_const('ERROR_DS_ROOT_MUST_BE_NC',0x0000206D)
		win_const_mgr.add_const('PID_INTSITE_WHATSNEW',0x00000002)
		win_const_mgr.add_const('ACM_FORMATSUGGESTF_TYPEMASK',0x00FF0000)
		win_const_mgr.add_const('MCI_DGV_OPEN_WS',0x00010000)
		win_const_mgr.add_const('WAVE_FORMAT_44M16',0x00000400)
		win_const_mgr.add_const('CERT_STORE_UPDATE_KEYID_FLAG',0x00000400)
		win_const_mgr.add_const('COD_PERIPHERAL_MINOR_REMOTE_CONTROL',0x00000003)
		win_const_mgr.add_const('SV_MINKEEPSEARCH_PARMNUM',0x0000020A)
		win_const_mgr.add_const('ISCSI_LOGIN_FLAG_REQUIRE_IPSEC',0x00000001)
		win_const_mgr.add_const('D3D9_RESOURCE_PRIORITY_LOW',0x50000000)
		win_const_mgr.add_const('LINECALLFEATURE_SETCALLDATA',0x80000000)
		win_const_mgr.add_const('D3DPRASTERCAPS_DITHER',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_I386_DIR16',0x00000001)
		win_const_mgr.add_const('AUDIOCLOCK_CHARACTERISTIC_FIXED_FREQ',0x00000001)
		win_const_mgr.add_const('PID_AUTHOR',0x00000004)
		win_const_mgr.add_const('IDB_HIST_LARGE_COLOR',0x00000009)
		win_const_mgr.add_const('ERROR_HANDLE_EOF',0x00000026)
		win_const_mgr.add_const('XINPUT_GAMEPAD_START',0x00000010)
		win_const_mgr.add_const('RPC_C_AUTHN_NONE',0x00000000)
		win_const_mgr.add_const('RATING_FIVE_STARS_SET',0x00000063)
		win_const_mgr.add_const('ERROR_CANT_TERMINATE_SELF',0x0000022B)
		win_const_mgr.add_const('PTE_OFFSET_LEN',0x0000000A)
		win_const_mgr.add_const('PFM_TABSTOPS',0x00000010)
		win_const_mgr.add_const('EM_LINELENGTH',0x000000C1)
		win_const_mgr.add_const('STARTF_USEPOSITION',0x00000004)
		win_const_mgr.add_const('UNDNAME_NO_ALLOCATION_LANGUAGE',0x00000010)
		win_const_mgr.add_const('CWF_CREATE_ONLY',0x00000001)
		win_const_mgr.add_const('PROCESSOR_MIPS_R4000',0x00000FA0)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_INCONSISTENTVALUE',0x0000000C)
		win_const_mgr.add_const('CERT_CHAIN_MAX_AIA_URL_COUNT_IN_CERT_DEFAULT',0x00000005)
		win_const_mgr.add_const('CERT_KEYGEN_REQUEST_V1',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_PPC_ADDR16',0x00000004)
		win_const_mgr.add_const('CAP_SMART_CMD',0x00000004)
		win_const_mgr.add_const('GUI_16BITTASK',0x00000020)
		win_const_mgr.add_const('IF_TYPE_DCN',0x0000008D)
		win_const_mgr.add_const('CSRESTORE_TYPE_CATCHUP',0x00000004)
		win_const_mgr.add_const('DDCAPS_ALIGNBOUNDARYDEST',0x00000002)
		win_const_mgr.add_const('CTRY_ITALY',0x00000027)
		win_const_mgr.add_const('IMAGE_REL_PPC_ADDR14',0x00000005)
		win_const_mgr.add_const('DEBUG_GSEL_NEAREST_ONLY',0x00000008)
		win_const_mgr.add_const('MRINFO_LEAF_FLAG',0x00000080)
		win_const_mgr.add_const('INTERNET_FLAG_RESYNCHRONIZE',0x00000800)
		win_const_mgr.add_const('SSA_PIDX',0x10000000)
		win_const_mgr.add_const('FACILITY_P2P',0x00000063)
		win_const_mgr.add_const('PRIORITY_PROP_NORMAL',0x00000001)
		win_const_mgr.add_const('IDC_IO_OBJECTTYPETEXT',0x0000083F)
		win_const_mgr.add_const('KP_PERMISSIONS',0x00000006)
		win_const_mgr.add_const('CMSG_DETACHED_FLAG',0x00000004)
		win_const_mgr.add_const('C1_DEFINED',0x00000200)
		win_const_mgr.add_const('AM_VIDEO_FLAG_FIELD_MASK',0x00000003)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_UPGRADE',0x00000004)
		win_const_mgr.add_const('DMPAPER_ENV_ITALY',0x00000024)
		win_const_mgr.add_const('HTTP_STATUS_USE_PROXY',0x00000131)
		win_const_mgr.add_const('DRM_EL_GROUPIDENTITY',0x00000002)
		win_const_mgr.add_const('BG_E_CONNECTION_CLOSED',0x8020002E)
		win_const_mgr.add_const('ACMFILTERCHOOSE_STYLEF_ENABLETEMPLATEHANDLE',0x00000020)
		win_const_mgr.add_const('WMDM_STORAGECONTROL_INSERTAFTER',0x00000400)
		win_const_mgr.add_const('VK_OEM_PA1',0x000000EB)
		win_const_mgr.add_const('SV_OTHERQUEUEAFFINITY_PARMNUM',0x0000023F)
		win_const_mgr.add_const('DEBUG_REQUEST_READ_USER_MINIDUMP_STREAM',0x00000007)
		win_const_mgr.add_const('METADATA_PERMISSION_READ',0x00000001)
		win_const_mgr.add_const('FILE_SKIP_SET_EVENT_ON_HANDLE',0x00000002)
		win_const_mgr.add_const('OID_ATM_MAX_AAL34_PACKET_SIZE',0x0801010A)
		win_const_mgr.add_const('HHWIN_BUTTON_SYNC',0x00000001)
		win_const_mgr.add_const('VK_OEM_PA3',0x000000ED)
		win_const_mgr.add_const('TVIF_EXPANDEDIMAGE',0x00000200)
		win_const_mgr.add_const('CM_PROB_UNKNOWN_RESOURCE',0x00000011)
		win_const_mgr.add_const('VK_OEM_PA2',0x000000EC)
		win_const_mgr.add_const('LINECALLSTATE_DIALTONE',0x00000008)
		win_const_mgr.add_const('INTERNET_OPTION_IGNORE_CERT_ERROR_FLAGS',0x00000063)
		win_const_mgr.add_const('PRINTER_STATUS_POWER_SAVE',0x01000000)
		win_const_mgr.add_const('USER_CALL_IS_ASYNC',0x00000100)
		win_const_mgr.add_const('RPC_QUERY_SERVER_PRINCIPAL_NAME',0x00000002)
		win_const_mgr.add_const('TF_LBI_BITMAP',0x00000008)
		win_const_mgr.add_const('FLASHMODE_REDEYE_AUTO',0x00000004)
		win_const_mgr.add_const('IDM_PROTECTMETATAGS',0x00001BBD)
		win_const_mgr.add_const('PIDMSI_SEQUENCE_NO',0x00000005)
		win_const_mgr.add_const('WEBPOST_ERROR_NO_POSTINFO',0x40042119)
		win_const_mgr.add_const('IDC_CI_BROWSE',0x00000082)
		win_const_mgr.add_const('MAPIFORM_CPU_MIP',0x00000002)
		win_const_mgr.add_const('VK_MEDIA_STOP',0x000000B2)
		win_const_mgr.add_const('WCT_OBJNAME_LENGTH',0x00000080)
		win_const_mgr.add_const('PDH_LOG_TYPE_CSV',0x00000001)
		win_const_mgr.add_const('DEF_MAX_PWHIST',0x00000008)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_MARTIAN',0x00000001)
		win_const_mgr.add_const('ERROR_USER_MAPPED_FILE',0x000004C8)
		win_const_mgr.add_const('CDIS_FOCUS',0x00000010)
		win_const_mgr.add_const('SERVICE_UI_ALWAYS',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_PARENT_HANDLE',0x00000015)
		win_const_mgr.add_const('PARTITION_UNIX',0x00000063)
		win_const_mgr.add_const('CB_MAX_CABINET_NAME',0x00000100)
		win_const_mgr.add_const('PAGEMASK_1MB',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_ZONE_DOES_NOT_EXIST',0x00002581)
		win_const_mgr.add_const('WINEVENT_OPCODE_INFO',0x00000000)
		win_const_mgr.add_const('CF_SELECTSCRIPT',0x00400000)
		win_const_mgr.add_const('PRODUCT_ENTERPRISE_SERVER',0x0000000A)
		win_const_mgr.add_const('WAVEIN_MAPPER_STATUS_DEVICE',0x00000000)
		win_const_mgr.add_const('CERT_NAME_STR_NO_PLUS_FLAG',0x20000000)
		win_const_mgr.add_const('DDCKEYCAPS_SRCOVERLAY',0x00002000)
		win_const_mgr.add_const('PORT_OCBINDER',0x000000B7)
		win_const_mgr.add_const('URLACTION_ACTIVEX_NO_WEBOC_SCRIPT',0x00001206)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_SENDREQUEST_COMPLETE',0x00400000)
		win_const_mgr.add_const('BACKUP_TYPE_INCREMENTAL',0x00000004)
		win_const_mgr.add_const('RTCEF_SESSION_STATE_CHANGE',0x00000004)
		win_const_mgr.add_const('ERROR_DS_DRA_INCONSISTENT_DIT',0x000020FB)
		win_const_mgr.add_const('DNS_UPDATE_SECURITY_ONLY',0x00000100)
		win_const_mgr.add_const('AM_GBF_NODDSURFACELOCK',0x00000008)
		win_const_mgr.add_const('COOKIEACTION_REJECT',0x00000002)
		win_const_mgr.add_const('MQCERT_REGISTER_ALWAYS',0x00000001)
		win_const_mgr.add_const('DNS_TKEY_MODE_DIFFIE_HELLMAN',0x00000002)
		win_const_mgr.add_const('LINECALLFEATURE_DROP',0x00000080)
		win_const_mgr.add_const('IMAGE_REL_PPC_ADDR64',0x00000001)
		win_const_mgr.add_const('WVR_ALIGNTOP',0x00000010)
		win_const_mgr.add_const('IDM_JUSTIFYGENERAL',0x0000003A)
		win_const_mgr.add_const('WIA_PRIVATE_ITEMPROP',0x00011802)
		win_const_mgr.add_const('NETLOGON_CONTROL_QUERY_DNS_REG',0x0000000C)
		win_const_mgr.add_const('CR_NOT_SYSTEM_VM',0x00000016)
		win_const_mgr.add_const('WKSTA_BUFFILESWITHDENYWRITE_PARMNUM',0x0000003A)
		win_const_mgr.add_const('DEBUG_FIND_SOURCE_DEFAULT',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_PPC_REL24',0x00000006)
		win_const_mgr.add_const('SES_UPPERCASE',0x00000200)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYMIRRORLEFTRIGHT',0x08000000)
		win_const_mgr.add_const('OID_802_11_AUTHENTICATION_MODE',0x0D010118)
		win_const_mgr.add_const('TF_SPEECHUI_SHOWN',0x00000010)
		win_const_mgr.add_const('CAL_SMONTHNAME6',0x00000001)
		win_const_mgr.add_const('BG_E_SESSION_NOT_FOUND',0x8020001F)
		win_const_mgr.add_const('MQSEC_GET_QUEUE_PROPERTIES',0x00000020)
		win_const_mgr.add_const('EAP_E_USER_ROOT_CERT_NOT_FOUND',0x80420300)
		win_const_mgr.add_const('D3DCREATE_HARDWARE_VERTEXPROCESSING',0x00000040)
		win_const_mgr.add_const('CERT_OID_NAME_STR',0x00000002)
		win_const_mgr.add_const('MONITORINFOF_PRIMARY',0x00000001)
		win_const_mgr.add_const('ERROR_EVT_INVALID_CHANNEL_PATH',0x00003A98)
		win_const_mgr.add_const('SYNCMGRHANDLERFLAG_MASK',0x00000000)
		win_const_mgr.add_const('SCARD_E_UNSUPPORTED_FEATURE',0x80100022)
		win_const_mgr.add_const('HH_GET_WIN_TYPE',0x00000005)
		win_const_mgr.add_const('SPI_SETSCREENSAVETIMEOUT',0x0000000F)
		win_const_mgr.add_const('EVENT_OBJECT_FOCUS',0x00008005)
		win_const_mgr.add_const('_A_EXEC',0x00000040)
		win_const_mgr.add_const('DISPID_SEARCHGUIDEURL',0x0000001D)
		win_const_mgr.add_const('MCI_DGV_STATUS_AUDIO',0x00004014)
		win_const_mgr.add_const('ERROR_BAD_ARGUMENTS',0x000000A0)
		win_const_mgr.add_const('CAL_SMONTHNAME7',0x00000001)
		win_const_mgr.add_const('SP_BACKUP_BACKUPPASS',0x00000001)
		win_const_mgr.add_const('CSF_ONLYGETSOURCE',0x00000004)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_ROOT_REV_UNKNOWN_FLAG',0x00000800)
		win_const_mgr.add_const('VIEW_PRIORITY_SHELLEXT',0x00000040)
		win_const_mgr.add_const('CACHE_S_FIRST',0x00040170)
		win_const_mgr.add_const('SMINV_ID',0x00000008)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_SOURCE_ROUTING',0x00000010)
		win_const_mgr.add_const('LINEADDRFEATURE_FORWARDFWD',0x00001000)
		win_const_mgr.add_const('CR_PROP_DNSNAME',0x00000016)
		win_const_mgr.add_const('MDM_V120_ML_2',0x00000002)
		win_const_mgr.add_const('IMR_CANDIDATEWINDOW',0x00000002)
		win_const_mgr.add_const('ERROR_DS_SHUTTING_DOWN',0x000020AC)
		win_const_mgr.add_const('DB_ALL_EXCEPT_LIKE',0x00000003)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_AUTOMATIC',0x00000001)
		win_const_mgr.add_const('ERRCLASS_APPERR',0x00000007)
		win_const_mgr.add_const('LINEADDRFEATURE_PICKUPDIRECT',0x00000400)
		win_const_mgr.add_const('HHWIN_PROP_TAB_CUSTOM8',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_TAB_CUSTOM9',0x00000001)
		win_const_mgr.add_const('PST_X25',0x00000103)
		win_const_mgr.add_const('COD_LAN_ACCESS_83_USED',0x00000005)
		win_const_mgr.add_const('CMSG_KEY_AGREE_ENCRYPT_FREE_PARA_FLAG',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_TAB_CUSTOM2',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_TAB_CUSTOM3',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_TAB_CUSTOM1',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_TAB_CUSTOM6',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_TAB_CUSTOM7',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_TAB_CUSTOM4',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_TAB_CUSTOM5',0x00000001)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_DIAGONAL',0x0000000E)
		win_const_mgr.add_const('RES_FIND_MULTIPLE',0x00000002)
		win_const_mgr.add_const('GESTURE_DOUBLE_TAP',0x00000000)
		win_const_mgr.add_const('SQL_SO_KEYSET_DRIVEN',0x00000002)
		win_const_mgr.add_const('FILE_FLAG_DELETE_ON_CLOSE',0x04000000)
		win_const_mgr.add_const('PHONEFEATURE_GETVOLUMEHEADSET',0x00002000)
		win_const_mgr.add_const('STARTF_USEHOTKEY',0x00000200)
		win_const_mgr.add_const('KAGPROP_POSITIONONNEWROW',0x00000004)
		win_const_mgr.add_const('METHOD_BGP4_PA_ORIGIN',0x00000004)
		win_const_mgr.add_const('HHT_ONFILTER',0x00000010)
		win_const_mgr.add_const('USE_USERNAME_PARMNUM',0x00000005)
		win_const_mgr.add_const('ETDT_USETABTEXTURE',0x00000004)
		win_const_mgr.add_const('DOT11_STATUS_ICV_VERIFIED',0x00000800)
		win_const_mgr.add_const('LINECALLFEATURE_HOLD',0x00000800)
		win_const_mgr.add_const('LANG_SINHALESE',0x00000005)
		win_const_mgr.add_const('PORT_MDQS',0x0000029A)
		win_const_mgr.add_const('HTTP_STATUS_VERSION_NOT_SUP',0x000001F9)
		win_const_mgr.add_const('INPUT_KEYBOARD',0x00000001)
		win_const_mgr.add_const('DWORD_PTR_ERROR',0x00000000)
		win_const_mgr.add_const('EMR_SCALEWINDOWEXTEX',0x00000020)
		win_const_mgr.add_const('PERF_ATTRIB_BY_REFERENCE',0x00000001)
		win_const_mgr.add_const('IPX_STATIC_SERVICE_INFO_TYPE',0x00000003)
		win_const_mgr.add_const('OID_LTALK_OUT_NO_HANDLERS',0x05020201)
		win_const_mgr.add_const('BG_E_DESTINATION_LOCKED',0x8020000D)
		win_const_mgr.add_const('OBJ_ENHMETAFILE',0x0000000D)
		win_const_mgr.add_const('AA_S_CREATE',0x00000020)
		win_const_mgr.add_const('CM_CDFLAGS_DRIVER',0x00000001)
		win_const_mgr.add_const('SQL_UNSEARCHABLE',0x00000000)
		win_const_mgr.add_const('OUT_CHARACTER_PRECIS',0x00000002)
		win_const_mgr.add_const('PHONEERR_NOMEM',0x9000001A)
		win_const_mgr.add_const('CAL_SMONTHNAME2',0x00000016)
		win_const_mgr.add_const('IPX_IN_TRAFFIC_FILTER_GLOBAL_INFO_TYPE',0x0000000B)
		win_const_mgr.add_const('REPL_UNLOCK_FORCE',0x00000001)
		win_const_mgr.add_const('NTDSCONN_OPT_RODC_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('IDS_CAP_STAT_L_FRAMES',0x000001FB)
		win_const_mgr.add_const('ISC_REQ_MUTUAL_AUTH',0x00000002)
		win_const_mgr.add_const('IMF_UIFONTS',0x00000020)
		win_const_mgr.add_const('DBIMF_TOPALIGN',0x00000400)
		win_const_mgr.add_const('MCI_DGV_COPY_VIDEO_STREAM',0x00040000)
		win_const_mgr.add_const('CREATE_NEW_CONSOLE',0x00000010)
		win_const_mgr.add_const('LOCALE_ITIME',0x00000023)
		win_const_mgr.add_const('CB_FINDSTRINGEXACT',0x00000158)
		win_const_mgr.add_const('SUBLANG_SPANISH_PERU',0x00000000)
		win_const_mgr.add_const('RP_DSN_SENT_DELAYED',0x00004000)
		win_const_mgr.add_const('DISPLAY_DEVICE_MULTI_DRIVER',0x00000002)
		win_const_mgr.add_const('PCMCIA_DEF_MEMLEN',0x00001000)
		win_const_mgr.add_const('CM_PROB_IRQ_TRANSLATION_FAILED',0x00000024)
		win_const_mgr.add_const('LINEFORWARDMODE_BUSYNAINTERNAL',0x00002000)
		win_const_mgr.add_const('MDPROPVAL_NL_NUMBEREDLEVELS',0x00000002)
		win_const_mgr.add_const('HELP_SETCONTENTS',0x00000005)
		win_const_mgr.add_const('TRUSTERROR_STEP_FINAL_OBJPROV',0x00000020)
		win_const_mgr.add_const('BS_CHECKBOX',0x00000002)
		win_const_mgr.add_const('VNSPROTO_RELIABLE_IPC',0x00000002)
		win_const_mgr.add_const('DISPID_SELECT',0x00000007)
		win_const_mgr.add_const('HHWIN_PARAM_CUR_TAB',0x00000001)
		win_const_mgr.add_const('DS_REPUPD_DELETE_REFERENCE',0x00000008)
		win_const_mgr.add_const('STAT_BUSY',0x00000000)
		win_const_mgr.add_const('LDAP_SCOPE_BASE',0x00000000)
		win_const_mgr.add_const('RUNCMDS_NOWAIT',0x00000002)
		win_const_mgr.add_const('CAL_JAPAN',0x00000003)
		win_const_mgr.add_const('IMAGE_REL_CEF_TOKEN',0x00000006)
		win_const_mgr.add_const('ADAPTER_FLOW_MODE_STANDARD',0x00000002)
		win_const_mgr.add_const('SQL_CT_CONSTRAINT_NON_DEFERRABLE',0x00000100)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_PVK_PROV',0x00000002)
		win_const_mgr.add_const('PERF_SIZE_VARIABLE_LEN',0x00000300)
		win_const_mgr.add_const('DS_REPMOD_UPDATE_RESULT',0x00000008)
		win_const_mgr.add_const('SV_TYPE_LOCAL_LIST_ONLY',0x40000000)
		win_const_mgr.add_const('LINEERR_DIALBILLING',0x80000008)
		win_const_mgr.add_const('CF_DIF',0x00000005)
		win_const_mgr.add_const('CCHILDREN_TITLEBAR',0x00000005)
		win_const_mgr.add_const('TAPIMEDIATYPE_DATAMODEM',0x00000010)
		win_const_mgr.add_const('MD_NOTIFY_READ_RAW_DATA',0x00008000)
		win_const_mgr.add_const('RBAB_AUTOSIZE',0x00000001)
		win_const_mgr.add_const('BTH_ERROR_LMP_TRANSACTION_COLLISION',0x00000023)
		win_const_mgr.add_const('DDFXCAPS_BLTARITHSTRETCHYN',0x00000010)
		win_const_mgr.add_const('WT_EXECUTEINLONGTHREAD',0x00000010)
		win_const_mgr.add_const('SERVICE_CONTROL_PAUSE',0x00000002)
		win_const_mgr.add_const('IMFT_RADIOCHECK',0x00000001)
		win_const_mgr.add_const('SETRTS',0x00000003)
		win_const_mgr.add_const('LUP_RETURN_ADDR',0x00000100)
		win_const_mgr.add_const('TF_MOD_ALT',0x00000001)
		win_const_mgr.add_const('HHWIN_PARAM_EXPANSION',0x00000001)
		win_const_mgr.add_const('SM_CYEDGE',0x0000002E)
		win_const_mgr.add_const('SIZEPALETTE',0x00000068)
		win_const_mgr.add_const('ERROR_EVT_NON_VALIDATING_MSXML',0x00003AA5)
		win_const_mgr.add_const('VCSTATUS_READONLY',0x00000010)
		win_const_mgr.add_const('FLG_PROFITEM_GROUP',0x00000004)
		win_const_mgr.add_const('D3DCURSORCAPS_COLOR',0x00000001)
		win_const_mgr.add_const('WTPF_IGNOREREVOCATIONONTS',0x00020000)
		win_const_mgr.add_const('MK_MBUTTON',0x00000010)
		win_const_mgr.add_const('GCP_LIGATE',0x00000020)
		win_const_mgr.add_const('DISABLE_DET_STALL_FIX',0x00000003)
		win_const_mgr.add_const('DISPID_RUNONCEREQUIREDSETTINGSCOMPLETE',0x0000001B)
		win_const_mgr.add_const('WMDM_E_LICENSE_NOTEXIST',0x8004500F)
		win_const_mgr.add_const('V86FLAGS_IOPL',0x00003000)
		win_const_mgr.add_const('ERR_DISK_OPEN_ERROR',0xE0000003)
		win_const_mgr.add_const('IMC_GETCOMPOSITIONFONT',0x00000009)
		win_const_mgr.add_const('EMR_SETMITERLIMIT',0x0000003A)
		win_const_mgr.add_const('SYSPAL_STATIC',0x00000001)
		win_const_mgr.add_const('CERT_STORE_UNSAFE_PHYSICAL_FLAG',0x00000020)
		win_const_mgr.add_const('VDMDBG_BREAK_EXCEPTIONS',0x00000008)
		win_const_mgr.add_const('CREATE_NEW_PROCESS_GROUP',0x00000200)
		win_const_mgr.add_const('OID_GEN_FRIENDLY_NAME',0x00020216)
		win_const_mgr.add_const('MCIERR_BASE',0x00000100)
		win_const_mgr.add_const('HHN_FIRST',0x00000000)
		win_const_mgr.add_const('TRUSTERROR_STEP_VERIFY_MSGINDIRECTDATA',0x00000013)
		win_const_mgr.add_const('SQL_API_SQLCOLATTRIBUTE',0x00000006)
		win_const_mgr.add_const('LUP_DEEP',0x00000001)
		win_const_mgr.add_const('GAA_FLAG_SKIP_UNICAST',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLFREEENV',0x0000000F)
		win_const_mgr.add_const('CPS_REVERT',0x00000003)
		win_const_mgr.add_const('RBBIM_ID',0x00000100)
		win_const_mgr.add_const('RP_UNRESOLVED',0x00001030)
		win_const_mgr.add_const('UF_DONT_REQUIRE_PREAUTH',0x00400000)
		win_const_mgr.add_const('SECURITY_LOGON_IDS_RID',0x00000005)
		win_const_mgr.add_const('AM_DVD_SECTOR_NOT_PROTECTED',0x00000000)
		win_const_mgr.add_const('NUM_BASIC_COLORS',0x00000030)
		win_const_mgr.add_const('INTERNET_CONNECTION_CONFIGURED',0x00000040)
		win_const_mgr.add_const('DMPAPER_LETTER_TRANSVERSE',0x00000036)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_DIRECT',0x00000002)
		win_const_mgr.add_const('LINEADDRESSSHARING_PRIVATE',0x00000001)
		win_const_mgr.add_const('SQL_COMMIT',0x00000000)
		win_const_mgr.add_const('IDC_GP_OBJECTTYPE',0x000003F2)
		win_const_mgr.add_const('DISPID_AUTOCOMPLETESAVEFORM',0x0000000A)
		win_const_mgr.add_const('PRINTER_ENUM_ICON4',0x00080000)
		win_const_mgr.add_const('TMT_HEADING1FONT',0x00000327)
		win_const_mgr.add_const('SYNC_HANDLERTYPE_OTHER',0x00000000)
		win_const_mgr.add_const('COOKIE_STATE_LB',0x00000000)
		win_const_mgr.add_const('IDM_TELETYPE',0x000008B8)
		win_const_mgr.add_const('IDM_TRIED_HYPERLINK',0x00000028)
		win_const_mgr.add_const('DISPID_ONKEYDOWN',0x0000000C)
		win_const_mgr.add_const('BCRYPT_CIPHER_INTERFACE',0x00000001)
		win_const_mgr.add_const('TCPIP_OWNING_MODULE_SIZE',0x00000010)
		win_const_mgr.add_const('DFCS_PUSHED',0x00000200)
		win_const_mgr.add_const('BCRYPT_ECDH_PRIVATE_P521_MAGIC',0x364B4345)
		win_const_mgr.add_const('RTM_VIEW_MASK_UCAST',0x00000001)
		win_const_mgr.add_const('CERT_ALT_NAME_VALUE_ERR_INDEX_MASK',0x0000FFFF)
		win_const_mgr.add_const('ERROR_NO_SUCH_GROUP',0x00000527)
		win_const_mgr.add_const('GENERIC_ALL',0x10000000)
		win_const_mgr.add_const('LINEINITIALIZEEXOPTION_USECOMPLETIONPORT',0x00000003)
		win_const_mgr.add_const('AVIIF_TWOCC',0x00000002)
		win_const_mgr.add_const('TBTS_LEFT',0x00000001)
		win_const_mgr.add_const('PDH_LOGSVC_QUERY_NOT_FOUND',0xC0000BD8)
		win_const_mgr.add_const('PRINTER_CONTROL_PAUSE',0x00000001)
		win_const_mgr.add_const('RPC_C_IMP_LEVEL_ANONYMOUS',0x00000001)
		win_const_mgr.add_const('DIF_DETECTVERIFY',0x00000014)
		win_const_mgr.add_const('HCF_AVAILABLE',0x00000002)
		win_const_mgr.add_const('PT_BEZIERTO',0x00000004)
		win_const_mgr.add_const('BG_E_PROXY_LIST_TOO_LARGE',0x80200018)
		win_const_mgr.add_const('SW_HIDE',0x00000000)
		win_const_mgr.add_const('ACM_FORMATENUMF_CONVERT',0x00100000)
		win_const_mgr.add_const('CERT_VALIDITY_AFTER_END',0x00000002)
		win_const_mgr.add_const('RPC_C_STATS_PKTS_IN',0x00000002)
		win_const_mgr.add_const('DXVA_QUERYORREPLYFUNCFLAG_ACCEL_PROBE_FALSE_PLUS',0x00FFFFFB)
		win_const_mgr.add_const('WM_CUT',0x00000300)
		win_const_mgr.add_const('SP_PROT_SSL3_CLIENT',0x00000020)
		win_const_mgr.add_const('SS_WHITEFRAME',0x00000009)
		win_const_mgr.add_const('IMAGE_REL_AMD64_SECREL',0x0000000B)
		win_const_mgr.add_const('OPATH_TOK_DOT',0x00000069)
		win_const_mgr.add_const('INTERNET_STATUS_USER_INPUT_REQUIRED',0x0000008C)
		win_const_mgr.add_const('PSD_NOWARNING',0x00000080)
		win_const_mgr.add_const('WINHTTP_QUERY_WWW_AUTHENTICATE',0x00000028)
		win_const_mgr.add_const('PATCH_OPTION_NO_TIMESTAMP',0x00800000)
		win_const_mgr.add_const('ERROR_WMI_SERVER_UNAVAILABLE',0x00001070)
		win_const_mgr.add_const('SQL_API_SQLEXECDIRECT',0x0000000B)
		win_const_mgr.add_const('TMT_SIZES',0x00000192)
		win_const_mgr.add_const('SQL_DESC_UNNAMED',0x000003F4)
		win_const_mgr.add_const('SMART_ERROR_NO_MEM',0x00000007)
		win_const_mgr.add_const('APPCOMMAND_DWM_FLIP3D',0x00000036)
		win_const_mgr.add_const('FILE_SUPPORTS_REPARSE_POINTS',0x00000080)
		win_const_mgr.add_const('IN_CLASSD_HOST',0x00000000)
		win_const_mgr.add_const('WINHTTP_OPTION_REQUEST_PRIORITY',0x0000003A)
		win_const_mgr.add_const('TRBN_FIRST',0x00000000)
		win_const_mgr.add_const('PORT_HOSTS2NS',0x00000051)
		win_const_mgr.add_const('DNSSEC_PROTOCOL_TLS',0x00000001)
		win_const_mgr.add_const('HH_PRETRANSLATEMESSAGE',0x00000000)
		win_const_mgr.add_const('OPTION_ARP_CACHE_TIMEOUT',0x00000023)
		win_const_mgr.add_const('SV_SCAVTIMEOUT_PARMNUM',0x00000210)
		win_const_mgr.add_const('DBPROP_MSDAORA_DETERMINEKEYCOLUMNS',0x00000001)
		win_const_mgr.add_const('LINEDIALTONEMODE_NORMAL',0x00000001)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_ASSOCIATION_RESPONSE',0x00030000)
		win_const_mgr.add_const('DI_COMPAT_FROM_CLASS',0x00080000)
		win_const_mgr.add_const('MPEG2_PROGRAM_DIRECTORY_PES_PACKET',0x00000002)
		win_const_mgr.add_const('MF_UNHILITE',0x00000000)
		win_const_mgr.add_const('CAUSE_COND_TRANSIENT',0x00000002)
		win_const_mgr.add_const('CMSG_CRL_COUNT_PARAM',0x0000000D)
		win_const_mgr.add_const('DNS_RTYPE_X25',0x00001300)
		win_const_mgr.add_const('MEDIA_WRITE_PROTECTED',0x00000100)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_DATAON',0x00000018)
		win_const_mgr.add_const('SQL_FN_STR_ASCII',0x00002000)
		win_const_mgr.add_const('ACTRL_PERM_6',0x00000020)
		win_const_mgr.add_const('ACTRL_PERM_7',0x00000040)
		win_const_mgr.add_const('ACTRL_PERM_4',0x00000008)
		win_const_mgr.add_const('ACTRL_PERM_5',0x00000010)
		win_const_mgr.add_const('ACTRL_PERM_2',0x00000002)
		win_const_mgr.add_const('ACTRL_PERM_3',0x00000004)
		win_const_mgr.add_const('ACTRL_PERM_1',0x00000001)
		win_const_mgr.add_const('PHONEFEATURE_SETHOOKSWITCHSPEAKER',0x00200000)
		win_const_mgr.add_const('PERF_TIMER_100NS',0x00100000)
		win_const_mgr.add_const('IDTB_EXPAND',0x000000C8)
		win_const_mgr.add_const('ACTRL_PERM_8',0x00000080)
		win_const_mgr.add_const('IKEEXT_CERT_CREDENTIAL_FLAG_NAP_CERT',0x00000001)
		win_const_mgr.add_const('PFNS_PAREN',0x00000000)
		win_const_mgr.add_const('EMR_SETARCDIRECTION',0x00000039)
		win_const_mgr.add_const('SV_LOCKVIOLATIONRETRIES_PARMNUM',0x00000237)
		win_const_mgr.add_const('MAXBQUALSIZE',0x00000040)
		win_const_mgr.add_const('SPI_SETFOREGROUNDFLASHCOUNT',0x00002005)
		win_const_mgr.add_const('MF_USER_MODE_COMPONENT_LOAD',0x00000001)
		win_const_mgr.add_const('D3DTA_DIFFUSE',0x00000000)
		win_const_mgr.add_const('CM_DEVCAP_LOCKSUPPORTED',0x00000001)
		win_const_mgr.add_const('PRINTER_CHANGE_TIMEOUT',0x80000000)
		win_const_mgr.add_const('CREDP_FLAGS_IN_PROCESS',0x00000001)
		win_const_mgr.add_const('LDAP_OPT_ERROR_STRING',0x00000032)
		win_const_mgr.add_const('IMR_COMPOSITIONWINDOW',0x00000001)
		win_const_mgr.add_const('C3_SYMBOL',0x00000008)
		win_const_mgr.add_const('KERB_RETRIEVE_TICKET_WITH_SEC_CRED',0x00000010)
		win_const_mgr.add_const('DDCAPS2_CANMANAGETEXTURE',0x00800000)
		win_const_mgr.add_const('FAILED_ACCESS_ACE_FLAG',0x00000080)
		win_const_mgr.add_const('CTRY_HUNGARY',0x00000024)
		win_const_mgr.add_const('TBMF_BUTTONSPACING',0x00000004)
		win_const_mgr.add_const('CERT_VALIDITY_OTHER_EXTENSION_FAILURE',0x00000200)
		win_const_mgr.add_const('SUBLANG_ITALIAN_SWISS',0x00000002)
		win_const_mgr.add_const('CM_DETECT_BITS',0x80000007)
		win_const_mgr.add_const('WS_THICKFRAME',0x00040000)
		win_const_mgr.add_const('LANG_OCCITAN',0x00000082)
		win_const_mgr.add_const('SQL_OPT_TRACE_OFF',0x00000000)
		win_const_mgr.add_const('PHONESTATE_REINIT',0x00200000)
		win_const_mgr.add_const('IIS_MD_SSL_BASE',0x0000157C)
		win_const_mgr.add_const('ES_LEFT',0x00000000)
		win_const_mgr.add_const('CREDSSP_SERVER_AUTH_NEGOTIATE',0x00000001)
		win_const_mgr.add_const('JOB_OBJECT_MSG_END_OF_PROCESS_TIME',0x00000002)
		win_const_mgr.add_const('CRYPT_EXPORT',0x00000004)
		win_const_mgr.add_const('WIA_IPS_MAX_HORIZONTAL_SIZE',0x00001815)
		win_const_mgr.add_const('DISPID_GETERRORCODE',0x00000010)
		win_const_mgr.add_const('CERT_FILTER_ISSUER_CERTS_ONLY',0x00000010)
		win_const_mgr.add_const('MF_8_BYTE_ALIGNMENT',0x00000007)
		win_const_mgr.add_const('OID_GEN_VLAN_ID',0x0001021C)
		win_const_mgr.add_const('_WIN32_IE_IE60',0x00000600)
		win_const_mgr.add_const('SV_TYPE_CLUSTER_VS_NT',0x04000000)
		win_const_mgr.add_const('SN_INFLAG_INSTALL',0x00000002)
		win_const_mgr.add_const('ACCESS_ALLOWED_CALLBACK_ACE_TYPE',0x00000009)
		win_const_mgr.add_const('IOCTL_WMP_DEVICE_CAN_SYNC',0x00032504)
		win_const_mgr.add_const('NDIS_RING_COUNTER_OVERFLOW',0x00000100)
		win_const_mgr.add_const('ETW_ASCIICHAR_TYPE_VALUE',0x00000066)
		win_const_mgr.add_const('DTBG_OMITBORDER',0x00000004)
		win_const_mgr.add_const('CLUSCTL_OBJECT_SHIFT',0x00000018)
		win_const_mgr.add_const('ADOMD_MINOR',0x00000000)
		win_const_mgr.add_const('ERROR_DS_NO_REQUESTED_ATTS_FOUND',0x00002074)
		win_const_mgr.add_const('RTM_ENUM_NEXT',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_SQL_ANSI92_FULL',0x00000080)
		win_const_mgr.add_const('SQL_AT_CONSTRAINT_INITIALLY_DEFERRED',0x00010000)
		win_const_mgr.add_const('KSPIN_FLAG_PROCESS_IN_RUN_STATE_ONLY',0x00010000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_SUPPORTEDWRITESPEEDS',0x00000115)
		win_const_mgr.add_const('IDM_ORDERLIST',0x00000888)
		win_const_mgr.add_const('FACILITY_AUDCLNT',0x00000889)
		win_const_mgr.add_const('ERROR_DS_POLICY_NOT_KNOWN',0x000021AA)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETAGENTGROUPLIST',0x00000008)
		win_const_mgr.add_const('PHONE_CREATE',0x00000014)
		win_const_mgr.add_const('SQL_DD_DROP_DOMAIN',0x00000001)
		win_const_mgr.add_const('FOF_ALLOWUNDO',0x00000040)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_EXCLUDE_PAGE_HASHES',0x00000002)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_CYCLE',0x00000400)
		win_const_mgr.add_const('DNS_ATMA_FORMAT_AESA',0x00000002)
		win_const_mgr.add_const('PRINTER_STATUS_WARMING_UP',0x00010000)
		win_const_mgr.add_const('SNMPAPI_TL_TIMEOUT',0x0000006C)
		win_const_mgr.add_const('GPO_INFO_FLAG_ASYNC_FOREGROUND',0x00001000)
		win_const_mgr.add_const('ENM_DRAGDROPDONE',0x00000010)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_MUTLISESSIONINTERFACES',0x00000118)
		win_const_mgr.add_const('IN_CLASSB_NET',0x00000000)
		win_const_mgr.add_const('MD_AUTH_BASIC',0x00000002)
		win_const_mgr.add_const('PDH_NOEXPANDINSTANCES',0x00000002)
		win_const_mgr.add_const('PHOTO_SHARPNESS_NORMAL',0x00000000)
		win_const_mgr.add_const('SPDRP_PHYSICAL_DEVICE_OBJECT_NAME',0x0000000E)
		win_const_mgr.add_const('VECTOR_RANK_MAX',0x00000001)
		win_const_mgr.add_const('MAX_INTLIST_COUNT',0x0000000A)
		win_const_mgr.add_const('RPC_S_NOT_RPC_ERROR',0x0000071F)
		win_const_mgr.add_const('WIN_CERT_REVISION_1_0',0x00000100)
		win_const_mgr.add_const('IP_RTHDR',0x00000020)
		win_const_mgr.add_const('ERROR_DEPENDENCY_ALREADY_EXISTS',0x0000138B)
		win_const_mgr.add_const('ESLFLAG_FULLPATH',0x00000001)
		win_const_mgr.add_const('LINECALLFEATURE_SETQOS',0x40000000)
		win_const_mgr.add_const('NRC_ILLCMD',0x00000003)
		win_const_mgr.add_const('INTERNET_SERVICE_FTP',0x00000001)
		win_const_mgr.add_const('PERF_MULTI_COUNTER',0x02000000)
		win_const_mgr.add_const('KP_PUB_PARAMS',0x00000027)
		win_const_mgr.add_const('MAX_PST_ERROR',0x800C0F00)
		win_const_mgr.add_const('OPTION_NETWORK_TIME_SERVERS',0x0000002A)
		win_const_mgr.add_const('PSF_HIDECHANGEICON',0x00000020)
		win_const_mgr.add_const('SPI_SETFONTSMOOTHINGCONTRAST',0x0000200D)
		win_const_mgr.add_const('IGIMII_HELP',0x00000010)
		win_const_mgr.add_const('UIS_CLEAR',0x00000002)
		win_const_mgr.add_const('ICMODE_FASTCOMPRESS',0x00000005)
		win_const_mgr.add_const('WM_SYSDEADCHAR',0x00000107)
		win_const_mgr.add_const('PIFMAXFILEPATH',0x00000104)
		win_const_mgr.add_const('WM_QUIT',0x00000012)
		win_const_mgr.add_const('ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER',0x00002146)
		win_const_mgr.add_const('WINHTTP_ACCESS_TYPE_NAMED_PROXY',0x00000003)
		win_const_mgr.add_const('RPC_PROTSEQ_HTTP',0x00000004)
		win_const_mgr.add_const('MCSC_TITLEBK',0x00000002)
		win_const_mgr.add_const('CHARS_IN_GUID',0x00000027)
		win_const_mgr.add_const('PFD_SUPPORT_GDI',0x00000010)
		win_const_mgr.add_const('GMEM_SHARE',0x00002000)
		win_const_mgr.add_const('KSPROPERTY_TYPE_DEFAULTVALUES',0x00010000)
		win_const_mgr.add_const('MDFF_ITALIC',0x00000002)
		win_const_mgr.add_const('DI_FORCECOPY',0x02000000)
		win_const_mgr.add_const('MDM_V110_SPEED_DEFAULT',0x00000000)
		win_const_mgr.add_const('COD_IMAGING_MINOR_DISPLAY_MASK',0x00000004)
		win_const_mgr.add_const('FILE_READ_DATA',0x00000001)
		win_const_mgr.add_const('DB_BINDFLAGS_ISSTRUCTUREDDOCUMENT',0x00000080)
		win_const_mgr.add_const('IMAGE_REL_IA64_SECREL64I',0x0000000D)
		win_const_mgr.add_const('DDF_HALFTONE',0x00001000)
		win_const_mgr.add_const('USER_PASSWORD_EXPIRED',0x00020000)
		win_const_mgr.add_const('PID_INTSITE_RECURSE',0x0000000C)
		win_const_mgr.add_const('AUDCLNT_STREAMFLAGS_LOOPBACK',0x00020000)
		win_const_mgr.add_const('DBIMF_NORMAL',0x00000000)
		win_const_mgr.add_const('JOY_BUTTON2CHG',0x00000200)
		win_const_mgr.add_const('F_LOCATION',0x0000000D)
		win_const_mgr.add_const('IDM_TRIED_IS_2D_ELEMENT',0x00000001)
		win_const_mgr.add_const('MDM_X75_DATA_DEFAULT',0x00000000)
		win_const_mgr.add_const('NOM_BS1',0x00000002)
		win_const_mgr.add_const('VK_BROWSER_HOME',0x000000AC)
		win_const_mgr.add_const('NET_VALIDATE_BAD_PASSWORD_TIME',0x00000002)
		win_const_mgr.add_const('MD_SERVER_COMMAND_START',0x00000001)
		win_const_mgr.add_const('NOM_BT2',0x00000200)
		win_const_mgr.add_const('EVENT_SYSTEM_CAPTUREEND',0x00000009)
		win_const_mgr.add_const('ERROR_NO_TRACKING_SERVICE',0x00000494)
		win_const_mgr.add_const('SQL_ROW_SUCCESS_WITH_INFO',0x00000006)
		win_const_mgr.add_const('ERROR_INVALID_MESSAGE',0x000003EA)
		win_const_mgr.add_const('KSFILTER_FLAG_DENY_USERMODE_ACCESS',0x80000000)
		win_const_mgr.add_const('HIGHLY_DELAY_SENSITIVE',0xFFFFFFFE)
		win_const_mgr.add_const('PORT_TEMPO',0x0000020E)
		win_const_mgr.add_const('CBA_EVENT',0x00000010)
		win_const_mgr.add_const('SHIL_EXTRALARGE',0x00000002)
		win_const_mgr.add_const('MCI_ANIM_PLAY_REVERSE',0x00020000)
		win_const_mgr.add_const('SOCKET_INFO_CONNECTION_SECURED',0x00000001)
		win_const_mgr.add_const('META_SETMAPMODE',0x00000103)
		win_const_mgr.add_const('IF_TYPE_V35',0x0000002D)
		win_const_mgr.add_const('PFM_NOLINENUMBER',0x00100000)
		win_const_mgr.add_const('DSPRINT_PENDING',0x80000000)
		win_const_mgr.add_const('SQL_SQL92_FOREIGN_KEY_UPDATE_RULE',0x0000009D)
		win_const_mgr.add_const('DCX_LOCKWINDOWUPDATE',0x00000400)
		win_const_mgr.add_const('CWCSTORAGENAME',0x00000020)
		win_const_mgr.add_const('EFS_USE_RECOVERY_KEYS',0x00000001)
		win_const_mgr.add_const('TXTBIT_CHARFORMATCHANGE',0x00020000)
		win_const_mgr.add_const('OPERATION_IDEMPOTENT',0x00000004)
		win_const_mgr.add_const('DMICM_ABS_COLORIMETRIC',0x00000004)
		win_const_mgr.add_const('PXE_ADDR_BROADCAST',0x00000001)
		win_const_mgr.add_const('ADS_SERVICE_FILE_SYSTEM_DRIVER',0x00000002)
		win_const_mgr.add_const('PF_MMX_INSTRUCTIONS_AVAILABLE',0x00000003)
		win_const_mgr.add_const('LUP_NOCONTAINERS',0x00000004)
		win_const_mgr.add_const('LINEDIALTONEMODE_EXTERNAL',0x00000008)
		win_const_mgr.add_const('SPDRP_ADDRESS',0x0000001C)
		win_const_mgr.add_const('NDIS_MAC_OPTION_NO_LOOPBACK',0x00000008)
		win_const_mgr.add_const('DBIF_VIEWMODE_VERTICAL',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED',0x00003624)
		win_const_mgr.add_const('MB_USERICON',0x00000080)
		win_const_mgr.add_const('ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED',0x00000BBD)
		win_const_mgr.add_const('MAPI_BODY_AS_FILE',0x00000200)
		win_const_mgr.add_const('OS_APPLIANCE',0x00000024)
		win_const_mgr.add_const('KSMETHOD_WAVE_QUEUED_BREAKLOOP',0x00000001)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_INTERMEDIATE_RESPONSE',0x00008000)
		win_const_mgr.add_const('INHERITED_ACE',0x00000010)
		win_const_mgr.add_const('USER_MARSHAL_IID',0x00000020)
		win_const_mgr.add_const('SSF_SHOWCOMPCOLOR',0x00000008)
		win_const_mgr.add_const('PID_IS_NAME',0x00000004)
		win_const_mgr.add_const('CRED_PRESERVE_CREDENTIAL_BLOB',0x00000001)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_SHOWMODALDIALOG',0x00000482)
		win_const_mgr.add_const('INTERNET_REQFLAG_CACHE_WRITE_DISABLED',0x00000040)
		win_const_mgr.add_const('KSDATARANGE_BIT_REQUIRED_ATTRIBUTES',0x00000002)
		win_const_mgr.add_const('MNS_MODELESS',0x40000000)
		win_const_mgr.add_const('SQL_PC_NON_PSEUDO',0x00000001)
		win_const_mgr.add_const('LANG_CROATIAN',0x00000001)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_PROCEDURE_COLUMNS',0x00000004)
		win_const_mgr.add_const('LVIF_IMAGE',0x00000002)
		win_const_mgr.add_const('TBSTATE_PRESSED',0x00000002)
		win_const_mgr.add_const('SQL_INSERT_STATEMENT',0x000000AC)
		win_const_mgr.add_const('VK_OEM_FJ_JISHO',0x00000092)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_ENDOFSTREAM',0x00000200)
		win_const_mgr.add_const('CDO_E_HTTP_FORBIDDEN',0x80040219)
		win_const_mgr.add_const('EVENT_HEADER_FLAG_32_BIT_HEADER',0x00000020)
		win_const_mgr.add_const('ERROR_SMARTCARD_SUBSYSTEM_FAILURE',0x000004F0)
		win_const_mgr.add_const('COD_MAJOR_UNCLASSIFIED',0x0000001F)
		win_const_mgr.add_const('SERIAL_IOC_MCR_LOOP',0x00000010)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_NETWORK_CONFIGURATION_OPS',0x0000022C)
		win_const_mgr.add_const('EN_REQUESTRESIZE',0x00000701)
		win_const_mgr.add_const('LINECALLINFOSTATE_RATE',0x00000008)
		win_const_mgr.add_const('DISPID_INVOKECONTEXTMENU',0x00000008)
		win_const_mgr.add_const('PAGE_EXECUTE_READ',0x00000020)
		win_const_mgr.add_const('NETE_CONNBUSY',0x00000003)
		win_const_mgr.add_const('SERVICE_INACTIVE',0x00000002)
		win_const_mgr.add_const('C3_NOTAPPLICABLE',0x00000000)
		win_const_mgr.add_const('WSA_QOS_EPROVSPECBUF',0x00002B0A)
		win_const_mgr.add_const('SQL_IS_SELECT_INTO',0x00000004)
		win_const_mgr.add_const('IEIFLAG_GLEAM',0x00000010)
		win_const_mgr.add_const('PLA_CAPABILITY_V1_SVC',0x00000001)
		win_const_mgr.add_const('ERROR_SERVICE_REQUEST_TIMEOUT',0x0000041D)
		win_const_mgr.add_const('ALG_SID_RSA_MSATWORK',0x00000002)
		win_const_mgr.add_const('CP_UTF8',0x0000FDE9)
		win_const_mgr.add_const('IMC_SETSTATUSWINDOWPOS',0x00000010)
		win_const_mgr.add_const('DSA_NOTIFY_PROP',0x00000008)
		win_const_mgr.add_const('CERT_CHAIN_REVOCATION_ACCUMULATIVE_TIMEOUT',0x08000000)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_BRADDR',0x00000007)
		win_const_mgr.add_const('PANE_PRIVACY',0x00000007)
		win_const_mgr.add_const('WINSTA_CREATEDESKTOP',0x00000008)
		win_const_mgr.add_const('ACCESS_DENIED_ACE_TYPE',0x00000001)
		win_const_mgr.add_const('WM_CONTEXTMENU',0x0000007B)
		win_const_mgr.add_const('WTNCA_NODRAWICON',0x00000002)
		win_const_mgr.add_const('SUBVERSION_MASK',0x000000FF)
		win_const_mgr.add_const('LGRPID_JAPANESE',0x00000007)
		win_const_mgr.add_const('CSIDL_WINDOWS',0x00000024)
		win_const_mgr.add_const('SCARD_SPECIFIC',0x00000006)
		win_const_mgr.add_const('IMAGE_RESOURCE_NAME_IS_STRING',0x80000000)
		win_const_mgr.add_const('SUBSTREAM_FILTER_VAL_NONE',0x10000000)
		win_const_mgr.add_const('PRINTER_STATUS_ERROR',0x00000002)
		win_const_mgr.add_const('MSV1_0_CRED_LM_PRESENT',0x00000001)
		win_const_mgr.add_const('CERT_CREATE_SELFSIGN_NO_KEY_INFO',0x00000002)
		win_const_mgr.add_const('DEBUG_MANRESET_DEFAULT',0x00000000)
		win_const_mgr.add_const('AM_GETDECODERCAP_QUERY_VMR_SUPPORT',0x00000001)
		win_const_mgr.add_const('MCI_OVLY_WINDOW_ENABLE_STRETCH',0x00100000)
		win_const_mgr.add_const('TMT_MSGBOXFONT',0x00000325)
		win_const_mgr.add_const('SERVICE_NT_MAXTIME',0x0000FFFF)
		win_const_mgr.add_const('IDB_STD_SMALL_COLOR',0x00000000)
		win_const_mgr.add_const('GROUP_ALL_PARMNUM',0x00000000)
		win_const_mgr.add_const('PID_SHARE_CSC_STATUS',0x00000002)
		win_const_mgr.add_const('MCI_STATUS_NUMBER_OF_TRACKS',0x00000003)
		win_const_mgr.add_const('PSR_DFL',0x00000012)
		win_const_mgr.add_const('TRUSTERROR_STEP_CATALOGFILE',0x00000006)
		win_const_mgr.add_const('SBSP_OPENMODE',0x00000010)
		win_const_mgr.add_const('DELTA_MAX_HASH_SIZE',0x00000020)
		win_const_mgr.add_const('NS_MS',0x0000001E)
		win_const_mgr.add_const('KP_RA',0x00000010)
		win_const_mgr.add_const('URLACTION_ALLOW_XDOMAIN_SUBFRAME_RESIZE',0x00001408)
		win_const_mgr.add_const('BLLI_L2_MODE_EXT',0x00000080)
		win_const_mgr.add_const('MAPI_ALLOW_OTHERS',0x00000008)
		win_const_mgr.add_const('DFS_VOLUME_STATE_OK',0x00000001)
		win_const_mgr.add_const('OCR_SIZENS',0x00007F85)
		win_const_mgr.add_const('MEDIA_WRITE_ONCE',0x00000002)
		win_const_mgr.add_const('CB_ADDSTRING',0x00000143)
		win_const_mgr.add_const('SERVICE_CCP_QUERY_HINT',0x00010000)
		win_const_mgr.add_const('SBSP_NAVIGATEBACK',0x00004000)
		win_const_mgr.add_const('KP_RP',0x00000017)
		win_const_mgr.add_const('PID_SYNC_COPY_IN',0x00000002)
		win_const_mgr.add_const('RPC_X_WRONG_ES_VERSION',0x00000724)
		win_const_mgr.add_const('DMPAPER_B6_JIS_ROTATED',0x00000059)
		win_const_mgr.add_const('MCI_SEQ_STATUS_COPYRIGHT',0x0000400C)
		win_const_mgr.add_const('BSIS_NOCONTEXTMENU',0x00000010)
		win_const_mgr.add_const('PROPFLAGS_INDEXED',0x00010000)
		win_const_mgr.add_const('WMPCOREEVENT_BASE',0x00001388)
		win_const_mgr.add_const('DECIMAL_BASE',0x0000000A)
		win_const_mgr.add_const('SPI_SETDISABLEOVERLAPPEDCONTENT',0x00001041)
		win_const_mgr.add_const('CR_CANT_SHARE_IRQ',0x0000002B)
		win_const_mgr.add_const('LOCALE_S2359',0x00000029)
		win_const_mgr.add_const('COMCTL32_VERSION',0x00000005)
		win_const_mgr.add_const('ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT',0x00000710)
		win_const_mgr.add_const('PORT_RLP',0x00000027)
		win_const_mgr.add_const('ERROR_SXS_DUPLICATE_CLSID',0x000036C7)
		win_const_mgr.add_const('TAPE_QUERY_MEDIA_CAPACITY',0x00000001)
		win_const_mgr.add_const('MIB_IPADDR_TRANSIENT',0x00000080)
		win_const_mgr.add_const('SQL_DB_DISCONNECT',0x00000001)
		win_const_mgr.add_const('ACTRL_DS_OPEN',0x00000000)
		win_const_mgr.add_const('COD_AUDIO_MINOR_CAR_AUDIO',0x00000008)
		win_const_mgr.add_const('IF_TYPE_WAN_ROUTER',0x00000003)
		win_const_mgr.add_const('CHANNEL_OPTION_PRI_LOW',0x02000000)
		win_const_mgr.add_const('MNID_ID',0x00000000)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_UNAUTH_USER_FLOW_COUNT',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_SH3_DIRECT32_NB',0x00000010)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_ITEM',0x00100000)
		win_const_mgr.add_const('SECURITY_LOCAL_RID',0x00000000)
		win_const_mgr.add_const('VM_NORMAL',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_TS_CARDINALITY',0x00000001)
		win_const_mgr.add_const('CBEMAXSTRLEN',0x00000104)
		win_const_mgr.add_const('FACILITY_WINCODEC_ERR',0x00000898)
		win_const_mgr.add_const('MDMEASURE_AGGR_AVG',0x00000005)
		win_const_mgr.add_const('PSIDENT_GDICENTRIC',0x00000000)
		win_const_mgr.add_const('KSMETHOD_TYPE_TOPOLOGY',0x10000000)
		win_const_mgr.add_const('XEPR_V2TEMPLATEOID',0x00000010)
		win_const_mgr.add_const('DDENUM_DETACHEDSECONDARYDEVICES',0x00000002)
		win_const_mgr.add_const('WSAEACCES',0x0000271D)
		win_const_mgr.add_const('STAT_CONTENT_QUERY_INCOMPLETE',0x00000080)
		win_const_mgr.add_const('CDO_E_BAD_DATA',0x80040229)
		win_const_mgr.add_const('PFD_GENERIC_ACCELERATED',0x00001000)
		win_const_mgr.add_const('SM_CXHSCROLL',0x00000015)
		win_const_mgr.add_const('DRIVERVERSION',0x00000000)
		win_const_mgr.add_const('TBS_COMMAND_PRIORITY_NORMAL',0x000000C8)
		win_const_mgr.add_const('SI_AUDITS_ELEVATION_REQUIRED',0x02000000)
		win_const_mgr.add_const('CRYPT_IMPL_UNKNOWN',0x00000004)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_RSS_PARAMETERS',0x00000089)
		win_const_mgr.add_const('FWP_OPTION_VALUE_ENABLE_LOOSE_SOURCE',0x00000001)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_BASIC_INFORMATION_DEFINED',0x00000001)
		win_const_mgr.add_const('OID_GEN_MAXIMUM_SEND_PACKETS',0x00010115)
		win_const_mgr.add_const('ERROR_SXS_XML_E_BADPEREFINSUBSET',0x000036EB)
		win_const_mgr.add_const('LCPRI_POWEROFF',0x0000A000)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_INDOUBT',0x00004000)
		win_const_mgr.add_const('PORT_EMFISCNTL',0x0000008D)
		win_const_mgr.add_const('ACM_FORMATENUMF_HARDWARE',0x00400000)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_USERS',0x80000001)
		win_const_mgr.add_const('DISPID_PRINT',0x0000001C)
		win_const_mgr.add_const('ACCESS_MIN_MS_OBJECT_ACE_TYPE',0x00000005)
		win_const_mgr.add_const('PORT_ECHO',0x00000007)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_ADD_CHAIN',0x00000001)
		win_const_mgr.add_const('REG_MULTI_SZ',0x00000007)
		win_const_mgr.add_const('UF_TRUSTED_FOR_DELEGATION',0x00080000)
		win_const_mgr.add_const('RTCEF_BUDDY2',0x00040000)
		win_const_mgr.add_const('ERROR_AMBIGUOUS_SYSTEM_DEVICE',0x00003B92)
		win_const_mgr.add_const('VK_VOLUME_MUTE',0x000000AD)
		win_const_mgr.add_const('TRACK_ONLINE_CACHE_ENTRY',0x00000020)
		win_const_mgr.add_const('DBPROPVAL_GB_EQUALS_SELECT',0x00000002)
		win_const_mgr.add_const('IPSEC_CIPHER_CONFIG_CBC_3DES',0x00000002)
		win_const_mgr.add_const('PRJOB_DESTNOPAPER',0x00000100)
		win_const_mgr.add_const('PMSF_MULTIPLE',0x00000001)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_MASK',0xFFFF0000)
		win_const_mgr.add_const('SKF_RWINLOCKED',0x00800000)
		win_const_mgr.add_const('NRC_BUFLEN',0x00000001)
		win_const_mgr.add_const('IDM_TRIED_DELETEROWS',0x00000010)
		win_const_mgr.add_const('DIRID_WINDOWS',0x0000000A)
		win_const_mgr.add_const('STATE_SYSTEM_ALERT_HIGH',0x10000000)
		win_const_mgr.add_const('LCRED_STATUS_UNKNOWN_ISSUER',0x00000002)
		win_const_mgr.add_const('AVI_INDEX_OF_SUB_2FIELD',0x00000003)
		win_const_mgr.add_const('DPNHCAPSFLAG_LOCALFIREWALLPRESENT',0x00000001)
		win_const_mgr.add_const('ENUM_S_LAST',0x000401BF)
		win_const_mgr.add_const('ERROR_NO_PDB_POINTER',0x00008802)
		win_const_mgr.add_const('DISPID_PICT_HPAL',0x00000002)
		win_const_mgr.add_const('IF_TYPE_FRAMERELAY_INTERCONNECT',0x0000003A)
		win_const_mgr.add_const('SQL_QUERY_TIMEOUT',0x00000000)
		win_const_mgr.add_const('VK_DBE_CODEINPUT',0x00000000)
		win_const_mgr.add_const('FACILITY_WINDOWS_CE',0x00000018)
		win_const_mgr.add_const('ERROR_ALREADY_ASSIGNED',0x00000055)
		win_const_mgr.add_const('CLONE_FLAG_NO_PRECONDITION',0x00000008)
		win_const_mgr.add_const('FWP_FILTER_ENUM_FLAG_BEST_TERMINATING_MATCH',0x00000001)
		win_const_mgr.add_const('PAN_SERIF_SQUARE',0x00000006)
		win_const_mgr.add_const('CRYPT_DELETE_DEFAULT',0x00000004)
		win_const_mgr.add_const('SCARD_W_CACHE_ITEM_NOT_FOUND',0x80100070)
		win_const_mgr.add_const('PORT_XDMCP',0x000000B1)
		win_const_mgr.add_const('AF_VOICEVIEW',0x00000012)
		win_const_mgr.add_const('ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG',0x00002185)
		win_const_mgr.add_const('LOCALE_SMONTHOUSANDSEP',0x00000017)
		win_const_mgr.add_const('SQL_API_SQLNATIVESQL',0x0000003E)
		win_const_mgr.add_const('HCF_LOGONDESKTOP',0x00000100)
		win_const_mgr.add_const('WVR_VALIDRECTS',0x00000400)
		win_const_mgr.add_const('DEX_IDS_BAD_MEDIATYPE',0x0000057E)
		win_const_mgr.add_const('TVIS_DROPHILITED',0x00000008)
		win_const_mgr.add_const('KSNODEPIN_SUM_MUX_IN',0x00000001)
		win_const_mgr.add_const('TO_ADVANCEDLAYOUT',0x00000008)
		win_const_mgr.add_const('MDLEVEL_TYPE_ALL',0x00000001)
		win_const_mgr.add_const('SGCM_RTL',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_ARGUMENT',0x00000009)
		win_const_mgr.add_const('DEBUG_OUTPUT_EXTENSION_WARNING',0x00000040)
		win_const_mgr.add_const('STDPROP_KEY',0x00000004)
		win_const_mgr.add_const('DBG_BREAK',0x00000006)
		win_const_mgr.add_const('MEM_RESET',0x00080000)
		win_const_mgr.add_const('MD_CPU_ENABLE_EVENT',0x00000001)
		win_const_mgr.add_const('CRYPT_VERIFY_CERT_SIGN_ISSUER_CERT',0x00000002)
		win_const_mgr.add_const('SPI_SETMOUSEHOVERWIDTH',0x00000063)
		win_const_mgr.add_const('RTM_MATCH_PREF',0x00000004)
		win_const_mgr.add_const('FILE_ATTRIBUTE_ENCRYPTED',0x00004000)
		win_const_mgr.add_const('PORT_MDBSDAEMON',0x00000320)
		win_const_mgr.add_const('COLOR_WINDOW',0x00000005)
		win_const_mgr.add_const('WIA_DPS_VERTICAL_SHEET_FEED_SIZE',0x00000C05)
		win_const_mgr.add_const('IP_UNBLOCK_SOURCE',0x00000012)
		win_const_mgr.add_const('SBSP_TRUSTEDFORACTIVEX',0x10000000)
		win_const_mgr.add_const('CMC_OTHER_INFO_FAIL_CHOICE',0x00000001)
		win_const_mgr.add_const('FWPM_NET_EVENT_FLAG_LOCAL_ADDR_SET',0x00000002)
		win_const_mgr.add_const('EMR_MASKBLT',0x0000004E)
		win_const_mgr.add_const('CMSG_HASH_ALGORITHM_PARAM',0x00000014)
		win_const_mgr.add_const('SCOPE_TYPE_MASK',0x00000000)
		win_const_mgr.add_const('D3DPS20CAPS_NOTEXINSTRUCTIONLIMIT',0x00000001)
		win_const_mgr.add_const('OBJ_DC',0x00000003)
		win_const_mgr.add_const('DDSCAPS2_VOLUME',0x00200000)
		win_const_mgr.add_const('MCI_VD_SEEK_REVERSE',0x00010000)
		win_const_mgr.add_const('CBA_SET_OPTIONS',0x00000008)
		win_const_mgr.add_const('CSIDL_SENDTO',0x00000009)
		win_const_mgr.add_const('ERROR_INVALID_FORM_SIZE',0x0000076F)
		win_const_mgr.add_const('IDM_SETDIRTY',0x00000926)
		win_const_mgr.add_const('SCRIPTPROP_DELAYEDEVENTSINKING',0x00001000)
		win_const_mgr.add_const('MD_LFHINT_NTA',0x00000003)
		win_const_mgr.add_const('SYSFXUI_DONOTSHOW_BASSMANAGEMENT',0x00000004)
		win_const_mgr.add_const('WINEVENT_KEYWORD_AUDIT_SUCCESS',0x20000000000000)
		win_const_mgr.add_const('ERROR_UNRECOGNIZED_MEDIA',0x000006F9)
		win_const_mgr.add_const('OCR_WAIT',0x00007F02)
		win_const_mgr.add_const('MPEGLAYER3_FLAG_PADDING_OFF',0x00000002)
		win_const_mgr.add_const('BTH_MAX_SERVICE_NAME_SIZE',0x00000100)
		win_const_mgr.add_const('INTERNET_FLAG_IDN_DIRECT',0x00000001)
		win_const_mgr.add_const('ERROR_PAGEFILE_QUOTA',0x000005AE)
		win_const_mgr.add_const('SFC_DISABLE_NORMAL',0x00000000)
		win_const_mgr.add_const('SCTE_EAS_IB_PID',0x00001FFB)
		win_const_mgr.add_const('DRM_AL_NOPERSIST',0x00000002)
		win_const_mgr.add_const('DDE_FRELEASE',0x00002000)
		win_const_mgr.add_const('MP_MSGCLASS_NONDELIVERY_REPORT',0x00000004)
		win_const_mgr.add_const('ERROR_LOG_SECTOR_PARITY_INVALID',0x000019C9)
		win_const_mgr.add_const('ACCESS_ALLOWED_OBJECT_ACE_TYPE',0x00000005)
		win_const_mgr.add_const('SPI_GETHIGHCONTRAST',0x00000042)
		win_const_mgr.add_const('PP_KEYSPEC',0x00000027)
		win_const_mgr.add_const('ERROR_INSTALL_SERVICE_SAFEBOOT',0x00000674)
		win_const_mgr.add_const('DRM_ACTIVATE_CANCEL',0x00000008)
		win_const_mgr.add_const('BCRYPT_ALG_HANDLE_HMAC_FLAG',0x00000008)
		win_const_mgr.add_const('SV_ERRORALERT_PARMNUM',0x00000026)
		win_const_mgr.add_const('GUARANTEED_SERV',0x00000002)
		win_const_mgr.add_const('XP1_PARTIAL_MESSAGE',0x00040000)
		win_const_mgr.add_const('NON_VALIDATED_LOGON',0x00000003)
		win_const_mgr.add_const('PAN_LETT_OBLIQUE_ROUNDED',0x0000000D)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_UNDEFINED_STATIC',0x0000000E)
		win_const_mgr.add_const('TPR_MIC_LEN',0x00000004)
		win_const_mgr.add_const('SERVICE_CONTROL_STOP',0x00000001)
		win_const_mgr.add_const('WM_CTLCOLORMSGBOX',0x00000132)
		win_const_mgr.add_const('EN_SAVECLIPBOARD',0x00000708)
		win_const_mgr.add_const('DB_DISP_LOG_MIN',0x00000014)
		win_const_mgr.add_const('SQLDATETIM4',0x00000003)
		win_const_mgr.add_const('WTNCA_NODRAWCAPTION',0x00000001)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_DEF_PEAK_RATE',0x0000001D)
		win_const_mgr.add_const('NI_NAMEREQD',0x00000004)
		win_const_mgr.add_const('CDO_E_RECIPIENTS_REJECTED',0x8004020F)
		win_const_mgr.add_const('CRYPT_LDAP_SCOPE_BASE_ONLY_RETRIEVAL',0x00002000)
		win_const_mgr.add_const('DEBUG_CES_TEXT_REPLACEMENTS',0x00004000)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_PARTIAL_READ_SUPPORT',0x00000010)
		win_const_mgr.add_const('CPLPAGE_MOUSE_PTRMOTION',0x00000002)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_DIRECTED_BYTES_RCV',0x00010000)
		win_const_mgr.add_const('MCI_MCIAVI_PLAY_WINDOW',0x01000000)
		win_const_mgr.add_const('DISPLAY_DEVICE_VGA_COMPATIBLE',0x00000010)
		win_const_mgr.add_const('SV_MAXLINKDELAY_PARMNUM',0x00000228)
		win_const_mgr.add_const('OID_GEN_MAXIMUM_LOOKAHEAD',0x00010105)
		win_const_mgr.add_const('ACTRL_READ_CONTROL',0x10000000)
		win_const_mgr.add_const('MF_COMPONENT_REVOKED',0x00002000)
		win_const_mgr.add_const('CB_GETDROPPEDSTATE',0x00000157)
		win_const_mgr.add_const('ERROR_IRQ_BUSY',0x0000045F)
		win_const_mgr.add_const('TMT_LASTUPDATED',0x0000057B)
		win_const_mgr.add_const('SECURITY_PACKAGE_SCHANNEL_RID',0x0000000E)
		win_const_mgr.add_const('OID_GEN_TIMEOUT_DPC_REQUEST_CAPABILITIES',0x00010210)
		win_const_mgr.add_const('FPSR_DD',0x00000001)
		win_const_mgr.add_const('IMAGE_FILE_UP_SYSTEM_ONLY',0x00004000)
		win_const_mgr.add_const('SQL_CDO_DEFAULT',0x00000002)
		win_const_mgr.add_const('BTH_ADDR_STRING_SIZE',0x0000000C)
		win_const_mgr.add_const('PID_CODEPAGE',0x00000001)
		win_const_mgr.add_const('FACILITY_TRANSACTION',0x00000019)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_PRINT_PROCESSOR',0x00000006)
		win_const_mgr.add_const('UF_LOCKOUT',0x00000010)
		win_const_mgr.add_const('MB_SETFOREGROUND',0x00010000)
		win_const_mgr.add_const('MD_LFHINT_NT1',0x00000001)
		win_const_mgr.add_const('DNS_TYPE_GID',0x00000066)
		win_const_mgr.add_const('IIS_MD_ID_BEGIN_RESERVED',0x00000001)
		win_const_mgr.add_const('HH_DISPLAY_TOC',0x00000001)
		win_const_mgr.add_const('SFVM_WINDOWCREATED',0x0000000F)
		win_const_mgr.add_const('MMC_VER',0x00000200)
		win_const_mgr.add_const('ERROR_I24_GEN_FAILURE',0x0000000C)
		win_const_mgr.add_const('WSA_FLAG_MULTIPOINT_D_ROOT',0x00000008)
		win_const_mgr.add_const('CRYPT_VERIFY_DATA_HASH',0x00000040)
		win_const_mgr.add_const('CR_FLG_CAXCHGCERT',0x00000008)
		win_const_mgr.add_const('SORT_DEFAULT',0x00000000)
		win_const_mgr.add_const('PID_INTSITE_VISITCOUNT',0x00000006)
		win_const_mgr.add_const('FACILITY_WPC',0x00000999)
		win_const_mgr.add_const('CRYPTUI_CERT_MGR_SINGLE_TAB_FLAG',0x00008000)
		win_const_mgr.add_const('MCI_AVI_SETVIDEO_PALETTE_HALFTONE',0x0000FFFF)
		win_const_mgr.add_const('WMS_CONTAINER_LIVE',0x00000008)
		win_const_mgr.add_const('IME_PROP_CANDLIST_START_FROM_1',0x00040000)
		win_const_mgr.add_const('CSURL_ADDTOCERTCDP',0x00000002)
		win_const_mgr.add_const('PF_COMPARE_EXCHANGE128',0x0000000E)
		win_const_mgr.add_const('FPSR_D3',0x00000035)
		win_const_mgr.add_const('FPSR_D2',0x00000028)
		win_const_mgr.add_const('FPSR_D1',0x0000001B)
		win_const_mgr.add_const('FPSR_D0',0x0000000E)
		win_const_mgr.add_const('LV_VIEW_LIST',0x00000003)
		win_const_mgr.add_const('PIFSHPROGSIZE',0x00000040)
		win_const_mgr.add_const('IDCANCEL',0x00000002)
		win_const_mgr.add_const('SQL_OJ_NOT_ORDERED',0x00000010)
		win_const_mgr.add_const('SERVER_ACCESS_ADMINISTER',0x00000001)
		win_const_mgr.add_const('GW_HWNDPREV',0x00000003)
		win_const_mgr.add_const('ALG_SID_SEAL',0x00000002)
		win_const_mgr.add_const('DATE_RTLREADING',0x00000020)
		win_const_mgr.add_const('OBM_UPARROW',0x00007FF1)
		win_const_mgr.add_const('KSPRIORITY_LOW',0x00000001)
		win_const_mgr.add_const('HDF_BITMAP_ON_RIGHT',0x00001000)
		win_const_mgr.add_const('FPS_INITIALIZING',0x20008000)
		win_const_mgr.add_const('PERF_COLLECT_END',0x00000006)
		win_const_mgr.add_const('ERRCLASS_NOTFND',0x00000008)
		win_const_mgr.add_const('MCI_DGV_FILE_MODE_LOADING_S',0x00008005)
		win_const_mgr.add_const('WM_UNINITMENUPOPUP',0x00000125)
		win_const_mgr.add_const('AEC_STATUS_FD_CURRENTLY_CONVERGED',0x00000008)
		win_const_mgr.add_const('LVBKIF_SOURCE_URL',0x00000002)
		win_const_mgr.add_const('SQLDATETIME',0x00000003)
		win_const_mgr.add_const('D3DSP_TEXTURETYPE_MASK',0x78000000)
		win_const_mgr.add_const('OID_FDDI_PORT_PMD_CLASS',0x03030265)
		win_const_mgr.add_const('COOKIE_LEASHED_CACHE_ENTRY',0x00002000)
		win_const_mgr.add_const('PCS_TRUNCATED',0x00000004)
		win_const_mgr.add_const('SQL_SFKD_NO_ACTION',0x00000002)
		win_const_mgr.add_const('SPEAKER_SIDE_RIGHT',0x00000400)
		win_const_mgr.add_const('SQLDATETIMN',0x00000006)
		win_const_mgr.add_const('APPCOMMAND_CLOSE',0x0000001F)
		win_const_mgr.add_const('CC_PIE',0x00000002)
		win_const_mgr.add_const('ERROR_DUP_FCB',0x00000051)
		win_const_mgr.add_const('DSF_DV_DEVICES',0x00000040)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_ACKPART',0x00000015)
		win_const_mgr.add_const('WMDRM_ACQUIRE_LICENSE_SILENT',0x00000001)
		win_const_mgr.add_const('WIA_IPA_CHANNELS_PER_PIXEL',0x0000100D)
		win_const_mgr.add_const('PHOTOACQ_DELETE_AFTER_ACQUIRE',0x00000020)
		win_const_mgr.add_const('SM_CYSMSIZE',0x00000035)
		win_const_mgr.add_const('DEBUG_SYMTYPE_EXPORT',0x00000004)
		win_const_mgr.add_const('DDFLIP_DONOTWAIT',0x00000020)
		win_const_mgr.add_const('CTRY_SLOVAK',0x000001A5)
		win_const_mgr.add_const('SI_RESET_DACL_TREE',0x00004000)
		win_const_mgr.add_const('ILC_COLOR24',0x00000018)
		win_const_mgr.add_const('JL_RECEIVER_ONLY',0x00000002)
		win_const_mgr.add_const('ERROR_NO_MORE_INFO',0x00000001)
		win_const_mgr.add_const('LINECALLCOMPLCOND_BUSY',0x00000001)
		win_const_mgr.add_const('DPNH_MAX_SIMULTANEOUS_PORTS',0x00000010)
		win_const_mgr.add_const('ERROR_KEY_HAS_CHILDREN',0x000003FC)
		win_const_mgr.add_const('DIF_ENABLECLASS',0x00000013)
		win_const_mgr.add_const('VCAPS_DST_CAN_CLIP',0x00000004)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_REGISTRATION_ATTRIBUTES',0x0000009E)
		win_const_mgr.add_const('SC_DLG_MINIMAL_UI',0x00000001)
		win_const_mgr.add_const('GCP_NEUTRALOVERRIDE',0x02000000)
		win_const_mgr.add_const('WMPCOREEVENT_CDROM_BASE',0x00001644)
		win_const_mgr.add_const('WMDRM_DEVICE_NEEDCLOCK',0x00000002)
		win_const_mgr.add_const('D3DFVFCAPS_TEXCOORDCOUNTMASK',0x00000000)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_STATISTICS',0x00000003)
		win_const_mgr.add_const('COPYFLG_NOSKIP',0x00000002)
		win_const_mgr.add_const('UM_SELTYPE_REMOTEUSER',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_ASYNCH_POPULATEONDEMAND',0x00000020)
		win_const_mgr.add_const('ISR_IA_VECTOR_LEN',0x00000008)
		win_const_mgr.add_const('ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE',0x0000370C)
		win_const_mgr.add_const('CAP_ATA_ID_CMD',0x00000001)
		win_const_mgr.add_const('LOCALE_ICURRDIGITS',0x00000019)
		win_const_mgr.add_const('RIP_INTERFACE_TABLE',0x00000001)
		win_const_mgr.add_const('WM_BACKUP_OVERWRITE',0x00000001)
		win_const_mgr.add_const('ERROR_UNEXPECTED_MM_EXTEND_ERR',0x0000022E)
		win_const_mgr.add_const('HHWIN_BUTTON_REFRESH',0x00000001)
		win_const_mgr.add_const('SQL_INTERVAL_HOUR',0x00000064)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_PICKUPGROUPID',0x00000002)
		win_const_mgr.add_const('PORT_ATRMTP',0x000000C9)
		win_const_mgr.add_const('RPCFLG_ACCESS_LOCAL',0x00400000)
		win_const_mgr.add_const('ERROR_NOT_TINY_STREAM',0x00000256)
		win_const_mgr.add_const('OID_802_3_RCV_OVERRUN',0x01020203)
		win_const_mgr.add_const('SNMP_AUTHAPI_TRIV_AUTH_FAILED',0x00000020)
		win_const_mgr.add_const('APPCOMMAND_OPEN',0x0000001E)
		win_const_mgr.add_const('OID_FDDI_SMT_STATION_ID',0x03030201)
		win_const_mgr.add_const('VS_VERSION_INFO',0x00000001)
		win_const_mgr.add_const('DB_DISP_DENIED',0x0000001F)
		win_const_mgr.add_const('FACILITY_MF_WIN32',0x00000007)
		win_const_mgr.add_const('AGP_FLAG_NO_SBA_ENABLE',0x00000100)
		win_const_mgr.add_const('ALG_SID_CAST',0x00000006)
		win_const_mgr.add_const('DBPROPVAL_CB_PRESERVE',0x00000002)
		win_const_mgr.add_const('LINEPROXYSTATUS_OPEN',0x00000001)
		win_const_mgr.add_const('SMC_GETAUTOEXPANDSTATE',0x00000041)
		win_const_mgr.add_const('SPIF_SENDWININICHANGE',0x00000002)
		win_const_mgr.add_const('CRYPTUI_WARN_UNTRUSTED_ROOT',0x00000400)
		win_const_mgr.add_const('CRYPT_LOCALIZED_NAME_ENCODING_TYPE',0x00000000)
		win_const_mgr.add_const('LSP_SYSTEM',0x80000000)
		win_const_mgr.add_const('IF_TYPE_MPLS_TUNNEL',0x00000096)
		win_const_mgr.add_const('ERROR_CURRENT_DOMAIN_NOT_ALLOWED',0x00000577)
		win_const_mgr.add_const('ERR_DISK_CREATE_ERROR',0xE0000002)
		win_const_mgr.add_const('TMT_BTNFACE',0x00000650)
		win_const_mgr.add_const('DEBUG_IOUTPUT_KD_PROTOCOL',0x80000000)
		win_const_mgr.add_const('TAPE_RETURN_STATISTICS',0x00000000)
		win_const_mgr.add_const('WMDM_STORAGE_ATTR_FOLDERS',0x00000100)
		win_const_mgr.add_const('IDM_SHOWSTYLETAGS',0x00000913)
		win_const_mgr.add_const('IMAGE_REL_MIPS_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('MCI_SAVE_FILE',0x00000100)
		win_const_mgr.add_const('IDM_GOTO',0x000008BF)
		win_const_mgr.add_const('DS_REPADD_NEVER_NOTIFY',0x00000200)
		win_const_mgr.add_const('GESTURE_DOWN_RIGHT',0x00000000)
		win_const_mgr.add_const('DDCREATE_EMULATIONONLY',0x00000002)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_FPO',0x00000003)
		win_const_mgr.add_const('D3DUSAGE_QUERY_SRGBWRITE',0x00040000)
		win_const_mgr.add_const('PERF_COUNTER_VALUE',0x00000000)
		win_const_mgr.add_const('USN_REASON_ENCRYPTION_CHANGE',0x00040000)
		win_const_mgr.add_const('SQL_CV_CREATE_VIEW',0x00000001)
		win_const_mgr.add_const('MDAXIS_SECTIONS',0x00000003)
		win_const_mgr.add_const('IP_FLAG_DF',0x00000002)
		win_const_mgr.add_const('TTFCFP_STD_MAC_CHAR_SET',0x00000000)
		win_const_mgr.add_const('PAN_SERIF_COVE',0x00000002)
		win_const_mgr.add_const('ISR_IR',0x00000026)
		win_const_mgr.add_const('CI_STATE_CONTENT_SCAN_REQUIRED',0x00000004)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETAGENTACTIVITYLIST',0x00000007)
		win_const_mgr.add_const('GOPHER_TYPE_HTML',0x00020000)
		win_const_mgr.add_const('OID_TAPI_DROP',0x07030109)
		win_const_mgr.add_const('MD_CHANGE_TYPE_SET_DATA',0x00000004)
		win_const_mgr.add_const('NETE_NOT_CONNECTED',0x000000E9)
		win_const_mgr.add_const('ALLOWED_FAIL',0x00000001)
		win_const_mgr.add_const('ADS_PRINTER_MANUAL_FEED',0x00000006)
		win_const_mgr.add_const('MAX_INTERPRETER_PARAM_OUT_SIZE',0x00000007)
		win_const_mgr.add_const('SCSI_IOCTL_DATA_OUT',0x00000000)
		win_const_mgr.add_const('BL_20M',0x01400000)
		win_const_mgr.add_const('EPR_0',0x00000000)
		win_const_mgr.add_const('AF_APPLETALK',0x00000010)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_HEADER',0x00003600)
		win_const_mgr.add_const('FR_PROP_ENCRYPTEDKEYHASH',0x0000000E)
		win_const_mgr.add_const('SERVICE_SINGLE_COPY',0x00000002)
		win_const_mgr.add_const('DXGI_MAX_SWAP_CHAIN_BUFFERS',0x00000010)
		win_const_mgr.add_const('IKEEXT_CERT_AUTH_DISABLE_SSL_CERT_VALIDATION',0x00000008)
		win_const_mgr.add_const('DISPID_HISTORY',0x00000001)
		win_const_mgr.add_const('IMPORTANCE_HIGH_MAX',0x00000005)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_BASE',0x00000032)
		win_const_mgr.add_const('D3DPS20_MIN_NUMINSTRUCTIONSLOTS',0x00000060)
		win_const_mgr.add_const('ERROR_DS_COULDNT_CONTACT_FSMO',0x000020AF)
		win_const_mgr.add_const('PIR_STATUS_TABLE_MSSPEC',0x00000001)
		win_const_mgr.add_const('LDAP_OPT_TIMELIMIT',0x00000004)
		win_const_mgr.add_const('VIEW_PARENTFOLDER',0x00000008)
		win_const_mgr.add_const('MM_DRVM_OPEN',0x000003D0)
		win_const_mgr.add_const('CSS_SHOW_HELP',0x00000010)
		win_const_mgr.add_const('ECO_SELECTIONBAR',0x01000000)
		win_const_mgr.add_const('ERROR_GRACEFUL_DISCONNECT',0x000004CA)
		win_const_mgr.add_const('HDI_LPARAM',0x00000008)
		win_const_mgr.add_const('CT_CTYPE1',0x00000001)
		win_const_mgr.add_const('FPSR_WRE1',0x00000014)
		win_const_mgr.add_const('SIGNERSCORE_AUTHENTICODE',0x0F000000)
		win_const_mgr.add_const('VARIABLE_DIM',0x00000001)
		win_const_mgr.add_const('LOCALE_NOUSEROVERRIDE',0x80000000)
		win_const_mgr.add_const('IDB_HIST_DISABLED',0x0000000E)
		win_const_mgr.add_const('AEC_STATUS_FD_HISTORY_UNINITIALIZED',0x00000000)
		win_const_mgr.add_const('META_POLYLINE',0x00000325)
		win_const_mgr.add_const('INV_LPM_HANDLE',0x00000001)
		win_const_mgr.add_const('TASK_JULY',0x00000040)
		win_const_mgr.add_const('HLNF_EXTERNALNAVIGATE',0x10000000)
		win_const_mgr.add_const('MSIM_DISPID_ONLISTREMOVERESULT',0x00000E03)
		win_const_mgr.add_const('SDP_DEFAULT_INQUIRY_SECONDS',0x00000006)
		win_const_mgr.add_const('DNS_ERROR_RECORD_FORMAT',0x000025E6)
		win_const_mgr.add_const('MEDIASINK_CAN_PREROLL',0x00000010)
		win_const_mgr.add_const('IDC_EL_CHANGESOURCE',0x000000C9)
		win_const_mgr.add_const('ERROR_SHARED_POLICY',0x0000201A)
		win_const_mgr.add_const('SUBLANG_ENGLISH_EIRE',0x00000006)
		win_const_mgr.add_const('WAVECAPS_VOLUME',0x00000004)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_CAN_FREEZE',0x00004002)
		win_const_mgr.add_const('IDM_ABSOLUTE_POSITION',0x0000095D)
		win_const_mgr.add_const('ERROR_INSTALL_TRANSFORM_REJECTED',0x0000066C)
		win_const_mgr.add_const('EIMES_GETCOMPSTRATONCE',0x00000001)
		win_const_mgr.add_const('TR_NOIND',0x00000000)
		win_const_mgr.add_const('SHARE_SERVER_PARMNUM',0x000001F7)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_CLEAR_DF_ON_TUNNEL',0x00000400)
		win_const_mgr.add_const('TMT_LOCALIZEDMIRRORIMAGE',0x000008AC)
		win_const_mgr.add_const('QUERY_ACTCTX_FLAG_ACTCTX_IS_HMODULE',0x00000008)
		win_const_mgr.add_const('ADS_PRINTER_PAUSED',0x00000001)
		win_const_mgr.add_const('WINEVENT_OPCODE_REPLY',0x00000006)
		win_const_mgr.add_const('GCP_DISPLAYZWG',0x00400000)
		win_const_mgr.add_const('DAOROWFETCH_BINDABSOLUTE',0x00000008)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_PEER_TRUST_FLAG',0x00001000)
		win_const_mgr.add_const('CSURL_SERVERPUBLISHDELTA',0x00000040)
		win_const_mgr.add_const('ERROR_SPL_NO_ADDJOB',0x00000BBC)
		win_const_mgr.add_const('NDIS_RING_SIGNAL_LOSS',0x00008000)
		win_const_mgr.add_const('DNS_PORT_NET_ORDER',0x00003500)
		win_const_mgr.add_const('WNPERM_DLG_OWNER',0x00000002)
		win_const_mgr.add_const('ISCSI_LOGIN_FLAG_ALLOW_PORTAL_HOPPING',0x00000008)
		win_const_mgr.add_const('MM_WIM_OPEN',0x000003BE)
		win_const_mgr.add_const('UD_MAXVAL',0x00000007)
		win_const_mgr.add_const('MCI_VCR_SETAUDIO_RECORD',0x00010000)
		win_const_mgr.add_const('EXITPUB_ACTIVEDIRECTORY',0x00000002)
		win_const_mgr.add_const('SHARE_FILE_SD_PARMNUM',0x000001F5)
		win_const_mgr.add_const('WIA_INCOMPAT_XP',0x00000001)
		win_const_mgr.add_const('GMMP_USE_DISPLAY_POINTS',0x00000001)
		win_const_mgr.add_const('PIR_STATUS_MINIPORT_MAX',0x00000008)
		win_const_mgr.add_const('SEC_WRITECOMBINE',0x40000000)
		win_const_mgr.add_const('NMPWAIT_USE_DEFAULT_WAIT',0x00000000)
		win_const_mgr.add_const('VCSTATUS_NEXT',0x00000001)
		win_const_mgr.add_const('MIB_IPADDR_DELETED',0x00000040)
		win_const_mgr.add_const('MUI_FULL_LANGUAGE',0x00000001)
		win_const_mgr.add_const('BCRYPT_NO_KEY_VALIDATION',0x00000008)
		win_const_mgr.add_const('MDM_X75_DATA_T_70',0x00000003)
		win_const_mgr.add_const('CDERR_GENERALCODES',0x00000000)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_NATIVE_WINDOWS',0x00000008)
		win_const_mgr.add_const('OID_GEN_MULTICAST_BYTES_XMIT',0x00020203)
		win_const_mgr.add_const('COLOR_APPWORKSPACE',0x0000000C)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_PROTOCOL_DRIVER_CHARACTERISTICS',0x00000095)
		win_const_mgr.add_const('XINPUT_GAMEPAD_DPAD_UP',0x00000001)
		win_const_mgr.add_const('LB_SETCOUNT',0x000001A7)
		win_const_mgr.add_const('SAFER_POLICY_SANDBOX_INERT',0x00020000)
		win_const_mgr.add_const('POLICY_KERBEROS_VALIDATE_CLIENT',0x00000080)
		win_const_mgr.add_const('MCI_DGV_LIST_AUDIO_QUALITY',0x00004001)
		win_const_mgr.add_const('IF_TYPE_IP',0x0000007E)
		win_const_mgr.add_const('TBSTYLE_TOOLTIPS',0x00000100)
		win_const_mgr.add_const('CLIPBRD_E_LAST',0x800401DF)
		win_const_mgr.add_const('IDM_2D_POSITION',0x0000095A)
		win_const_mgr.add_const('HTTP_LOG_FIELD_BYTES_SENT',0x00001000)
		win_const_mgr.add_const('SQL_SR_UPDATE_COLUMN',0x00004000)
		win_const_mgr.add_const('LVS_EX_JUSTIFYCOLUMNS',0x00200000)
		win_const_mgr.add_const('VP_TV_STANDARD_PAL_B',0x00000004)
		win_const_mgr.add_const('GET_FEATURE_FROM_THREAD_TRUSTED',0x00000020)
		win_const_mgr.add_const('VP_TV_STANDARD_PAL_N',0x00000080)
		win_const_mgr.add_const('ERROR_NO_SUCH_LOGON_SESSION',0x00000520)
		win_const_mgr.add_const('IDTB_CUSTOMIZE',0x000000DD)
		win_const_mgr.add_const('SPFILELOG_FORCENEW',0x00000002)
		win_const_mgr.add_const('VP_TV_STANDARD_PAL_H',0x00000010)
		win_const_mgr.add_const('VP_TV_STANDARD_PAL_I',0x00000020)
		win_const_mgr.add_const('MF_SYSMENU',0x00002000)
		win_const_mgr.add_const('ERROR_DS_SEC_DESC_INVALID',0x000020A2)
		win_const_mgr.add_const('ERROR_DS_NO_MORE_RIDS',0x00002011)
		win_const_mgr.add_const('AF_CHAOS',0x00000005)
		win_const_mgr.add_const('SW_SHOWNOACTIVATE',0x00000004)
		win_const_mgr.add_const('AMDDS_DCIPS',0x00000001)
		win_const_mgr.add_const('PFD_SUPPORT_COMPOSITION',0x00008000)
		win_const_mgr.add_const('NCRYPT_UNREGISTER_NOTIFY_FLAG',0x00000002)
		win_const_mgr.add_const('SV_TYPE_TIME_SOURCE',0x00000020)
		win_const_mgr.add_const('IP_BLOCK_SOURCE',0x00000011)
		win_const_mgr.add_const('TMT_MENUHILIGHT',0x0000065E)
		win_const_mgr.add_const('CAUSE_QOS_UNAVAILABLE',0x00000031)
		win_const_mgr.add_const('CTRY_IRAN',0x000003D5)
		win_const_mgr.add_const('CD_LBSELSUB',0x00000001)
		win_const_mgr.add_const('SENSITIVITY_PROP_PRIVATE',0x00000002)
		win_const_mgr.add_const('ERROR_NOT_LOGGED_ON',0x000004DD)
		win_const_mgr.add_const('FILE_FLAG_OVERLAPPED',0x40000000)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_UNTIL_TIME',0x00000011)
		win_const_mgr.add_const('OID_WAN_CO_GET_STATS_INFO',0x04010282)
		win_const_mgr.add_const('HSHELL_WINDOWCREATED',0x00000001)
		win_const_mgr.add_const('ERROR_DS_NCNAME_MISSING_CR_REF',0x000020DC)
		win_const_mgr.add_const('TAPE_DRIVE_LOGICAL_BLK',0x80004000)
		win_const_mgr.add_const('LINECALLFEATURE_MONITORDIGITS',0x00001000)
		win_const_mgr.add_const('VFT2_DRV_INPUTMETHOD',0x0000000B)
		win_const_mgr.add_const('ERROR_LOG_BLOCK_INVALID',0x000019D1)
		win_const_mgr.add_const('DMDISPLAYFLAGS_TEXTMODE',0x00000004)
		win_const_mgr.add_const('LINEERR_NOMULTIPLEINSTANCE',0x80000056)
		win_const_mgr.add_const('MF_SEPARATOR',0x00000800)
		win_const_mgr.add_const('KRB_NT_SRV_INST',0x00000002)
		win_const_mgr.add_const('NLS_VALID_LOCALE_MASK',0x00000000)
		win_const_mgr.add_const('WLX_SAS_TYPE_TIMEOUT',0x00000000)
		win_const_mgr.add_const('IDM_TRIED_BOLD',0x0000001C)
		win_const_mgr.add_const('STI_UNICODE',0x00000001)
		win_const_mgr.add_const('MAX_WST_VBI_LINES_PER_FIELD',0x00000011)
		win_const_mgr.add_const('DEBUG_OUTPUT_SYMBOLS_DEFAULT',0x00000000)
		win_const_mgr.add_const('DEBUG_FILTER_BREAK',0x00000000)
		win_const_mgr.add_const('RPC_C_PARM_MAX_PACKET_LENGTH',0x00000001)
		win_const_mgr.add_const('SPI_SETSCREENREADER',0x00000047)
		win_const_mgr.add_const('NCBDELNAME',0x00000031)
		win_const_mgr.add_const('CRYPT_SORTED_CTL_ENCODE_HASHED_SUBJECT_IDENTIFIER_FLAG',0x00010000)
		win_const_mgr.add_const('MD_EXTLOG_URI_QUERY',0x00000200)
		win_const_mgr.add_const('AA_A_DELETE',0x00004000)
		win_const_mgr.add_const('FOFX_PREFERHARDLINK',0x00020000)
		win_const_mgr.add_const('AI_NUMERICSERV',0x00000008)
		win_const_mgr.add_const('DR_RW',0x0000003E)
		win_const_mgr.add_const('IMAGE_REL_M32R_TOKEN',0x0000000E)
		win_const_mgr.add_const('DISPLAYDIB_BEGIN',0x00008000)
		win_const_mgr.add_const('ERROR_RESOURCE_NOT_ONLINE',0x0000138C)
		win_const_mgr.add_const('DPNHADDRESSTYPE_TCP',0x00000001)
		win_const_mgr.add_const('MD_LOGON_NETWORK_CLEARTEXT',0x00000003)
		win_const_mgr.add_const('DEBUG_STACK_PARAMETERS_NEWLINE',0x00000400)
		win_const_mgr.add_const('SQL_SCOPE_SESSION',0x00000002)
		win_const_mgr.add_const('ERROR_NO_SCROLLBARS',0x000005A7)
		win_const_mgr.add_const('MD_LOCATION',0x00002705)
		win_const_mgr.add_const('MCI_OPEN_TYPE',0x00002000)
		win_const_mgr.add_const('PDH_CALC_NEGATIVE_VALUE',0x800007D8)
		win_const_mgr.add_const('PAN_FAMILY_SCRIPT',0x00000003)
		win_const_mgr.add_const('CRL_REASON_CERTIFICATE_HOLD_FLAG',0x00000002)
		win_const_mgr.add_const('GMEM_FIXED',0x00000000)
		win_const_mgr.add_const('CERT_STORE_PROV_FREE_FIND_CRL_FUNC',0x00000012)
		win_const_mgr.add_const('PORT_ATNBP',0x000000CA)
		win_const_mgr.add_const('TF_MOD_LALT',0x00000040)
		win_const_mgr.add_const('MMIOM_CLOSE',0x00000004)
		win_const_mgr.add_const('SSA_LAYOUTRTL',0x20000000)
		win_const_mgr.add_const('ERROR_TOO_MANY_MODULES',0x000000D6)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_AM33',0x00000001)
		win_const_mgr.add_const('SV_HIDDEN_PARMNUM',0x00000010)
		win_const_mgr.add_const('IDC_IO_FILE',0x0000083A)
		win_const_mgr.add_const('ERROR_INSTALL_TEMP_UNWRITABLE',0x00000660)
		win_const_mgr.add_const('HHWIN_PROP_MENU',0x00000001)
		win_const_mgr.add_const('WIA_DPV_LAST_PICTURE_TAKEN',0x00000E02)
		win_const_mgr.add_const('EMR_SETSTRETCHBLTMODE',0x00000015)
		win_const_mgr.add_const('COOKIE_STATE_UB',0x00000005)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_TRANSFER_ENCODING',0x00000002)
		win_const_mgr.add_const('TVS_SINGLEEXPAND',0x00000400)
		win_const_mgr.add_const('SCHEDULE_INTERVAL',0x00000000)
		win_const_mgr.add_const('IF_TYPE_NSIP',0x0000001B)
		win_const_mgr.add_const('GCS_HELPTEXTA',0x00000001)
		win_const_mgr.add_const('TF_MOD_ON_KEYUP',0x00000200)
		win_const_mgr.add_const('RTCIF_DISABLE_MEDIA',0x00000001)
		win_const_mgr.add_const('PSWIZBF_ELEVATIONREQUIRED',0x00000001)
		win_const_mgr.add_const('SNMP_MGMTAPI_INVALID_CTL',0x0000002E)
		win_const_mgr.add_const('KLF_SHIFTLOCK',0x00010000)
		win_const_mgr.add_const('ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND',0x000032D1)
		win_const_mgr.add_const('GCS_HELPTEXTW',0x00000005)
		win_const_mgr.add_const('IF_TYPE_PERSONAL_WAN_ROUTER',0x00000006)
		win_const_mgr.add_const('MCI_DGV_FREEZE_OUTSIDE',0x00020000)
		win_const_mgr.add_const('NOPARITY',0x00000000)
		win_const_mgr.add_const('VK_LSHIFT',0x000000A0)
		win_const_mgr.add_const('CM_PROB_DRIVER_FAILED_PRIOR_UNLOAD',0x00000026)
		win_const_mgr.add_const('SAFER_POLICY_JOBID_UNTRUSTED',0x03000000)
		win_const_mgr.add_const('CRYPT_ASYNC_RETRIEVAL',0x00000010)
		win_const_mgr.add_const('ERROR_COMPRESSION_DISABLED',0x00000301)
		win_const_mgr.add_const('COLOR_LUM',0x000002C1)
		win_const_mgr.add_const('DBPROPVAL_PT_GUID_NAME',0x00000001)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_CALLID',0x00000022)
		win_const_mgr.add_const('HTTP_LOG_FIELD_QUEUE_NAME',0x04000000)
		win_const_mgr.add_const('KEY_CREATE_LINK',0x00000020)
		win_const_mgr.add_const('OR_INVALID_OID',0x00000777)
		win_const_mgr.add_const('MINCHAR',0x00000080)
		win_const_mgr.add_const('ERROR_NO_SUCH_MEMBER',0x0000056B)
		win_const_mgr.add_const('RT_MANIFEST',0x00000018)
		win_const_mgr.add_const('RC_FLOODFILL',0x00001000)
		win_const_mgr.add_const('BUTTON_IMAGELIST_ALIGN_BOTTOM',0x00000003)
		win_const_mgr.add_const('TVSIL_STATE',0x00000002)
		win_const_mgr.add_const('D3DSTENCILCAPS_DECRSAT',0x00000010)
		win_const_mgr.add_const('GESTURE_CHEVRON_LEFT',0x00000000)
		win_const_mgr.add_const('RPC_C_RPCHTTP_USE_LOAD_BALANCE',0x00000008)
		win_const_mgr.add_const('MCI_VCR_SET_COUNTER_VALUE',0x02000000)
		win_const_mgr.add_const('HELPINFO_WINDOW',0x00000001)
		win_const_mgr.add_const('EVENT_OBJECT_CREATE',0x00008000)
		win_const_mgr.add_const('LINEFORWARDMODE_UNCONDSPECIFIC',0x00000008)
		win_const_mgr.add_const('TAPE_ABSOLUTE_BLOCK',0x00000001)
		win_const_mgr.add_const('ISC_RET_USED_DCE_STYLE',0x00000200)
		win_const_mgr.add_const('OBM_RESTORED',0x00007FE8)
		win_const_mgr.add_const('VP_MODE_TV_PLAYBACK',0x00000002)
		win_const_mgr.add_const('ROTREGFLAGS_ALLOWANYCLIENT',0x00000001)
		win_const_mgr.add_const('SECTION_MAP_EXECUTE',0x00000008)
		win_const_mgr.add_const('PORT_NIMAIL',0x0000003D)
		win_const_mgr.add_const('ILGOS_FROMSTANDBY',0x00000001)
		win_const_mgr.add_const('WMIREG_FLAG_INSTANCE_BASENAME',0x00000008)
		win_const_mgr.add_const('D3DSP_WRITEMASK_3',0x00080000)
		win_const_mgr.add_const('DNS_ERROR_DATAFILE_BASE',0x000025B2)
		win_const_mgr.add_const('LONGLONG_MAX',0x7FFFFFFFFFFFFFFF)
		win_const_mgr.add_const('VER_ERR_NO_ARG',0xFFFFFFFF)
		win_const_mgr.add_const('ERROR_DS_CHILDREN_EXIST',0x0000208C)
		win_const_mgr.add_const('SFVM_GETNOTIFY',0x00000031)
		win_const_mgr.add_const('DXVA_CHROMA_FORMAT_444',0x00000003)
		win_const_mgr.add_const('MIXER_GETLINECONTROLSF_ONEBYTYPE',0x00000002)
		win_const_mgr.add_const('CDO_E_ROLE_NOMORE_AVAILABLE',0x80040236)
		win_const_mgr.add_const('ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING',0x000036FE)
		win_const_mgr.add_const('ERROR_NOT_SAFE_MODE_DRIVER',0x00000286)
		win_const_mgr.add_const('NCRYPT_ALLOW_ARCHIVING_FLAG',0x00000004)
		win_const_mgr.add_const('IME_ESC_AUTOMATA',0x00001009)
		win_const_mgr.add_const('SQL_API_SQLGETDATA',0x0000002B)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_IMPORT',0x00000001)
		win_const_mgr.add_const('SQL_ALTER_TABLE',0x00000056)
		win_const_mgr.add_const('THREAD_PRIORITY_NORMAL',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_RECONNECT',0x00000010)
		win_const_mgr.add_const('NCBDGRECVBC',0x00000023)
		win_const_mgr.add_const('USAGE_MATCH_TYPE_OR',0x00000001)
		win_const_mgr.add_const('MIIM_DATA',0x00000020)
		win_const_mgr.add_const('IDM_HORIZSPACEMAKEEQUAL',0x00000018)
		win_const_mgr.add_const('MD_NETLOGON_WKS_NONE',0x00000000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_POSTGAPALREADYINIMAGE',0x00000104)
		win_const_mgr.add_const('CM_PROB_TRANSLATION_FAILED',0x00000021)
		win_const_mgr.add_const('WMSZ_LEFT',0x00000001)
		win_const_mgr.add_const('ERROR_DS_SEMANTIC_ATT_TEST',0x000020BF)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_GROUP',0x00000005)
		win_const_mgr.add_const('SAM_MINUTES_PER_WEEK',0x0000003C)
		win_const_mgr.add_const('INDEX_INK_ANALYSIS_GUID_MAX',0x00000080)
		win_const_mgr.add_const('LDAP_OPT_PING_LIMIT',0x00000038)
		win_const_mgr.add_const('CM_PROB_PHANTOM',0x0000002D)
		win_const_mgr.add_const('CCHDEVICENAME',0x00000020)
		win_const_mgr.add_const('WMDM_GET_FORMAT_SUPPORT_AUDIO',0x00000001)
		win_const_mgr.add_const('MD_CPU_ENABLE_CGI_LOGGING',0x00000002)
		win_const_mgr.add_const('NDIS_802_11_AUTH_REQUEST_GROUP_ERROR',0x0000000E)
		win_const_mgr.add_const('URLOSTRM_GETNEWESTVERSION',0x00000003)
		win_const_mgr.add_const('SPDRP_UI_NUMBER_DESC_FORMAT',0x00000000)
		win_const_mgr.add_const('INDEX_GUID_CENTROID',0x0000000E)
		win_const_mgr.add_const('ERROR_RESOURCE_DATA_NOT_FOUND',0x00000714)
		win_const_mgr.add_const('BASE_ID',0x00006600)
		win_const_mgr.add_const('STATE_SYSTEM_FOCUSED',0x00000004)
		win_const_mgr.add_const('SUBLANG_SPANISH_EL_SALVADOR',0x00000011)
		win_const_mgr.add_const('WGL_FONT_LINES',0x00000000)
		win_const_mgr.add_const('MCI_QUALITY_DIALOG',0x00080000)
		win_const_mgr.add_const('SP_BAUD',0x00000002)
		win_const_mgr.add_const('EVCF_HASSETTINGS',0x00000001)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_EXTENSION',0x00000005)
		win_const_mgr.add_const('DI_FLAGSEX_ALWAYSWRITEIDS',0x00000200)
		win_const_mgr.add_const('OID_802_11_ADD_WEP',0x0D010113)
		win_const_mgr.add_const('MIB_IPROUTE_TYPE_DIRECT',0x00000003)
		win_const_mgr.add_const('VIF_CANNOTREADDST',0x00020000)
		win_const_mgr.add_const('TMT_MENU',0x00000645)
		win_const_mgr.add_const('HHWIN_PROP_TAB_FAVORITES',0x00000001)
		win_const_mgr.add_const('SP_COPY_WINDOWS_SIGNED',0x01000000)
		win_const_mgr.add_const('METADATA_ISINHERITED',0x00000020)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_PAL_S',0x00008013)
		win_const_mgr.add_const('FILE_DEVICE_DFS_FILE_SYSTEM',0x00000035)
		win_const_mgr.add_const('MD_EXTLOG_USERNAME',0x00000008)
		win_const_mgr.add_const('ASC_REQ_MUTUAL_AUTH',0x00000002)
		win_const_mgr.add_const('CRYPT_DATA_KEY',0x00000800)
		win_const_mgr.add_const('IPX_DEDICATED_LINK',0x00000001)
		win_const_mgr.add_const('MANAGED_APPS_INFOLEVEL_DEFAULT',0x00010000)
		win_const_mgr.add_const('PRINTER_ENUM_ICON8',0x00800000)
		win_const_mgr.add_const('NETERR_RING_STATUS_AUTO_REMOVAL_ERROR',0x00000400)
		win_const_mgr.add_const('ERROR_INVALID_NETNAME',0x000004BE)
		win_const_mgr.add_const('DDFXALPHACAPS_OVERLAYALPHAPIXELS',0x00000040)
		win_const_mgr.add_const('DEBUG_CES_CURRENT_THREAD',0x00000001)
		win_const_mgr.add_const('SEEK_SET',0x00000000)
		win_const_mgr.add_const('ERROR_CRM_PROTOCOL_ALREADY_EXISTS',0x00001A36)
		win_const_mgr.add_const('WINHTTP_QUERY_ACCEPT_RANGES',0x0000002A)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_PEER_DEAUTHENTICATED',0x00010000)
		win_const_mgr.add_const('DEBUG_ENGOPT_ALL',0x0003FFFF)
		win_const_mgr.add_const('LANG_SANSKRIT',0x00000004)
		win_const_mgr.add_const('TF_SFT_NOLABELS',0x00000100)
		win_const_mgr.add_const('CAT_E_FIRST',0x80040160)
		win_const_mgr.add_const('CFE_BOLD',0x00000001)
		win_const_mgr.add_const('TF_CONVERSIONMODE_ROMAN',0x00000010)
		win_const_mgr.add_const('SECPKG_NEGOTIATION_TRY_MULTICRED',0x00000004)
		win_const_mgr.add_const('STATUS_SEVERITY_WARNING',0x00000002)
		win_const_mgr.add_const('MD_EXTLOG_TIME',0x00000002)
		win_const_mgr.add_const('I24_OPERATION',0x00000001)
		win_const_mgr.add_const('E_XML_NOTWF',0xC00CE223)
		win_const_mgr.add_const('DNPROTO_NSP',0x00000001)
		win_const_mgr.add_const('ERROR_NOTIFY_ENUM_DIR',0x000003FE)
		win_const_mgr.add_const('FSHIFT',0x00000004)
		win_const_mgr.add_const('CM_GETIDLIST_FILTER_ENUMERATOR',0x00000001)
		win_const_mgr.add_const('ERROR_DS_SAM_INIT_FAILURE_CONSOLE',0x00002172)
		win_const_mgr.add_const('GESTURE_CIRCLE_TAP',0x00000000)
		win_const_mgr.add_const('TIMEPLAYITEM_OFFSET',0x00000C00)
		win_const_mgr.add_const('SPMODE_MSVM',0x00000040)
		win_const_mgr.add_const('FOFX_KEEPNEWERFILE',0x00400000)
		win_const_mgr.add_const('IS_EM',0x00000000)
		win_const_mgr.add_const('CHANNEL_EVENT_WRITE_CANCELLED',0x0000000C)
		win_const_mgr.add_const('DEBUG_ENGOPT_ALLOW_NETWORK_PATHS',0x00000004)
		win_const_mgr.add_const('REG_RESOURCE_LIST',0x00000008)
		win_const_mgr.add_const('VMRBITMAP_SRCCOLORKEY',0x00000008)
		win_const_mgr.add_const('LSA_NB_DISABLED_ADMIN',0x00000004)
		win_const_mgr.add_const('ERROR_EC_NO_ACTIVE_CHANNEL',0x00003AED)
		win_const_mgr.add_const('UOI_USER_SID',0x00000004)
		win_const_mgr.add_const('CERT_STORE_PROV_WRITE_CERT_FUNC',0x00000002)
		win_const_mgr.add_const('LBER_DEFAULT',0x00000000)
		win_const_mgr.add_const('SCARD_CLASS_IFD_PROTOCOL',0x00000008)
		win_const_mgr.add_const('IPX_STATIC_SERV_TABLE',0x00000005)
		win_const_mgr.add_const('WMDM_DEVICECAP_CANRECORD',0x00000004)
		win_const_mgr.add_const('EXPOSUREMETERING_MULTISPOT',0x00000003)
		win_const_mgr.add_const('CAUSE_INCORRECT_MESSAGE_LENGTH',0x00000068)
		win_const_mgr.add_const('SQL_DROP_CHARACTER_SET',0x00000089)
		win_const_mgr.add_const('MAXLEN_IFDESCR',0x00000100)
		win_const_mgr.add_const('R2_MASKPEN',0x00000009)
		win_const_mgr.add_const('CMC_STATUS_NO_SUPPORT',0x00000004)
		win_const_mgr.add_const('TT_NOIND',0x00000000)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_SELF',0x00000014)
		win_const_mgr.add_const('SERVICE_CTRL_INTERROGATE',0x00000000)
		win_const_mgr.add_const('DEBUG_SESSION_END_SESSION_ACTIVE_DETACH',0x00000002)
		win_const_mgr.add_const('TASK_FLAG_RUN_ONLY_IF_DOCKED',0x00000100)
		win_const_mgr.add_const('WKSTA_SIZERROR_PARMNUM',0x00000013)
		win_const_mgr.add_const('LINECALLPARAMFLAGS_DESTOFFHOOK',0x00000010)
		win_const_mgr.add_const('WS_DISABLED',0x08000000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_CLIENTNAME',0x0000010E)
		win_const_mgr.add_const('DEBUG_ENGOPT_DISABLE_MANAGED_SUPPORT',0x00004000)
		win_const_mgr.add_const('RAS_EAP_FLAG_ALTERNATIVE_USER_DB',0x00000800)
		win_const_mgr.add_const('BSF_RESIZABLE',0x00000200)
		win_const_mgr.add_const('SQL_DRIVER_PROMPT',0x00000002)
		win_const_mgr.add_const('IDF_NOCOMPRESSED',0x00000008)
		win_const_mgr.add_const('PBS_SMOOTHREVERSE',0x00000010)
		win_const_mgr.add_const('DDCAPS_ALIGNSIZESRC',0x00000010)
		win_const_mgr.add_const('MDPROPVAL_MOQ_OUTERREFERENCE',0x00000001)
		win_const_mgr.add_const('ARW_UP',0x00000004)
		win_const_mgr.add_const('IDS_CAP_STAT_I_FRAMES',0x000001FA)
		win_const_mgr.add_const('FILE_NOTIFY_CHANGE_SECURITY',0x00000100)
		win_const_mgr.add_const('TRANSACTION_MANAGER_COMMIT_SYSTEM_HIVES',0x00000004)
		win_const_mgr.add_const('LINEBEARERMODE_DATA',0x00000008)
		win_const_mgr.add_const('WIA_DPS_MIN_HORIZONTAL_SHEET_FEED_SIZE',0x00000C20)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_8',0x00000008)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_9',0x00000009)
		win_const_mgr.add_const('CERT_ALT_NAME_DIRECTORY_NAME',0x00000005)
		win_const_mgr.add_const('SBM_SETRANGEREDRAW',0x000000E6)
		win_const_mgr.add_const('CTRL_LOGOFF_EVENT',0x00000005)
		win_const_mgr.add_const('BCRYPT_RSAPRIVATE_MAGIC',0x32415352)
		win_const_mgr.add_const('AE_LOCKOUT',0x00000014)
		win_const_mgr.add_const('IRDA_PROTO_SOCK_STREAM',0x00000001)
		win_const_mgr.add_const('LINECALLSTATE_IDLE',0x00000001)
		win_const_mgr.add_const('VP_FLAGS_TV_STANDARD',0x00000002)
		win_const_mgr.add_const('OID_TAPI_SET_CALL_PARAMS',0x0703011E)
		win_const_mgr.add_const('DFM_VALIDATECMD',0x00000009)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATAEVENTARGS_ESTIMATEDREMAININGTIME',0x00000301)
		win_const_mgr.add_const('STN_CLICKED',0x00000000)
		win_const_mgr.add_const('STDPROP_USERPROP_BASE',0x00010000)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_SYSTEMPARAMETERS',0x00000008)
		win_const_mgr.add_const('CHANNEL_FLAG_LAST',0x00000002)
		win_const_mgr.add_const('GETVECTORBRUSHSIZE',0x0000001B)
		win_const_mgr.add_const('TF_MOD_RALT',0x00000008)
		win_const_mgr.add_const('CTF_INSIST',0x00000001)
		win_const_mgr.add_const('LM20_CNLEN',0x0000000F)
		win_const_mgr.add_const('SQL_COPT_SS_BASE_EX',0x000004D8)
		win_const_mgr.add_const('SI_USER_NOT_SCREENED',0x00000000)
		win_const_mgr.add_const('DEBUG_FILTER_EXIT_PROCESS',0x00000003)
		win_const_mgr.add_const('IMAGE_DLLCHARACTERISTICS_DYNAMIC_BASE',0x00000040)
		win_const_mgr.add_const('BTH_MINORVERSION',0x00000000)
		win_const_mgr.add_const('GOPHER_ATTRIBUTE_ID_BASE',0x00000000)
		win_const_mgr.add_const('ERROR_INDEX_ABSENT',0x0000064B)
		win_const_mgr.add_const('MDMSPKR_ON',0x00000002)
		win_const_mgr.add_const('ADS_PRINTER_POWER_SAVE',0x01000000)
		win_const_mgr.add_const('EVT_CLEAR_ACCESS',0x00000004)
		win_const_mgr.add_const('CORDLESS_EXTERNAL_NETWORK_ISDN',0x00000002)
		win_const_mgr.add_const('KSPROPERTY_CAMERACONTROL_FLAGS_AUTO',0x00000000)
		win_const_mgr.add_const('OQWF_OKCANCEL',0x00000001)
		win_const_mgr.add_const('MM_MIXM_LINE_CHANGE',0x000003D0)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_READONLY',0x00000004)
		win_const_mgr.add_const('OID_ATM_MAX_AAL5_PACKET_SIZE',0x0801010B)
		win_const_mgr.add_const('SPFILENOTIFY_LANGMISMATCH',0x00010000)
		win_const_mgr.add_const('WINHTTP_QUERY_VERSION',0x00000012)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_ALPHA64',0x00000007)
		win_const_mgr.add_const('FRS_ERR_INTERNAL_API',0x00001F44)
		win_const_mgr.add_const('URLACTION_SHELL_MAX',0x00000019)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2ERASE_MEDIATYPE',0x00000102)
		win_const_mgr.add_const('LVTVIM_COLUMNS',0x00000002)
		win_const_mgr.add_const('MCI_DGV_OPEN_32BIT',0x00100000)
		win_const_mgr.add_const('MAX_COLOR_CHANNELS',0x00000008)
		win_const_mgr.add_const('OEM_FIXED_FONT',0x0000000A)
		win_const_mgr.add_const('HS_DIAGCROSS',0x00000005)
		win_const_mgr.add_const('ECOOP_OR',0x00000002)
		win_const_mgr.add_const('D3DSHADER_ADDRESSMODE_MASK',0x00000001)
		win_const_mgr.add_const('DXVA_DCCMD_SURFACE_BUFFER',0x0000000C)
		win_const_mgr.add_const('DXVA_ENCRYPTPROTOCOLFUNCFLAG_ACCEL',0x00FFFF08)
		win_const_mgr.add_const('SQL_DS_RESTRICT',0x00000002)
		win_const_mgr.add_const('SQL_FD_FETCH_NEXT',0x00000001)
		win_const_mgr.add_const('HTTP_QUERY_ACCEPT_LANGUAGE',0x0000001B)
		win_const_mgr.add_const('SC_MANAGER_LOCK',0x00000008)
		win_const_mgr.add_const('CM_CDMASK_VALID',0x0000000F)
		win_const_mgr.add_const('DI_NEEDRESTART',0x00000080)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_NETWORK',0x80001000)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_COM_INTERFACE_REDIRECTION',0x00000005)
		win_const_mgr.add_const('ERROR_RESMON_ONLINE_FAILED',0x0000139A)
		win_const_mgr.add_const('SUBLANG_SPANISH_DOMINICAN_REPUBLIC',0x00000007)
		win_const_mgr.add_const('IR_STRINGSTART',0x00000100)
		win_const_mgr.add_const('PGS_DRAGNDROP',0x00000004)
		win_const_mgr.add_const('NRC_SABORT',0x00000018)
		win_const_mgr.add_const('CSIDL_NETHOOD',0x00000013)
		win_const_mgr.add_const('LINEOFFERINGMODE_ACTIVE',0x00000001)
		win_const_mgr.add_const('OBEX_PROTOCOL_UUID16',0x00000008)
		win_const_mgr.add_const('CHANNEL_OPTION_ENCRYPT_SC',0x20000000)
		win_const_mgr.add_const('DDBLTFX_ZBUFFERRANGE',0x00000080)
		win_const_mgr.add_const('BG_S_ERROR_CONTEXT_NONE',0x00200006)
		win_const_mgr.add_const('CONNECTION_LAN',0x00000001)
		win_const_mgr.add_const('SET_FEATURE_ON_THREAD_RESTRICTED',0x00000080)
		win_const_mgr.add_const('BACKGROUND_RED',0x00000040)
		win_const_mgr.add_const('SSF_SORTCOLUMNS',0x00000010)
		win_const_mgr.add_const('NUMPRS_INEXACT',0x00020000)
		win_const_mgr.add_const('WMDM_GET_FORMAT_SUPPORT_FILE',0x00000004)
		win_const_mgr.add_const('WAVECAPS_SAMPLEACCURATE',0x00000020)
		win_const_mgr.add_const('IF_TYPE_DDN_X25',0x00000004)
		win_const_mgr.add_const('SIC_ASCIIDIGIT',0x00000002)
		win_const_mgr.add_const('MCI_DGV_STATUS_GAMMA',0x00000400)
		win_const_mgr.add_const('DMPAPER_DBL_JAPANESE_POSTCARD',0x00000045)
		win_const_mgr.add_const('MQ_MAX_MSG_LABEL_LEN',0x000000FA)
		win_const_mgr.add_const('OID_FDDI_IF_SPECIFIC',0x0303028D)
		win_const_mgr.add_const('HTTP_QUERY_MIME_VERSION',0x00000000)
		win_const_mgr.add_const('D3DTEXOPCAPS_BUMPENVMAP',0x00200000)
		win_const_mgr.add_const('TAPE_QUERY_DRIVE_PARAMETERS',0x00000000)
		win_const_mgr.add_const('ERROR_ALREADY_RUNNING_LKG',0x00000432)
		win_const_mgr.add_const('TF_WRITE_BEHIND',0x00000004)
		win_const_mgr.add_const('WM_CANCELMODE',0x0000001F)
		win_const_mgr.add_const('PAN_CONTRAST_INDEX',0x00000004)
		win_const_mgr.add_const('TMPF_TRUETYPE',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_STGM_DIRECT',0x00010000)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_BIND_PARAMETERS',0x00000086)
		win_const_mgr.add_const('AIF_NO_VERSION_DIALOG',0x00000020)
		win_const_mgr.add_const('ERROR_SUBST_TO_SUBST',0x0000008B)
		win_const_mgr.add_const('OF_EXIST',0x00004000)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_REFLONG',0x00000001)
		win_const_mgr.add_const('UM_FOCUS_TYPE_DOMAIN',0x00000001)
		win_const_mgr.add_const('FAX_PORT_SET',0x00000020)
		win_const_mgr.add_const('DBT_DEVICEREMOVECOMPLETE',0x00008004)
		win_const_mgr.add_const('STGM_SHARE_DENY_WRITE',0x00000020)
		win_const_mgr.add_const('DMDO_90',0x00000001)
		win_const_mgr.add_const('_WIN32_MSM',0x00000064)
		win_const_mgr.add_const('CPLPAGE_MOUSE_BUTTONS',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_ARM_ADDR32',0x00000001)
		win_const_mgr.add_const('SQL_DIAG_REVOKE',0x0000003B)
		win_const_mgr.add_const('PFL_MULTIPLE_PROTO_ENTRIES',0x00000001)
		win_const_mgr.add_const('MCI_DGV_INFO_USAGE',0x00004000)
		win_const_mgr.add_const('VK_OEM_JUMP',0x000000EA)
		win_const_mgr.add_const('ERROR_SLOT_NOT_PRESENT',0x00000004)
		win_const_mgr.add_const('ICMF_CHOOSE_DATARATE',0x00000002)
		win_const_mgr.add_const('COLOR_SATACCEL',0x000002D4)
		win_const_mgr.add_const('PSD_INWININIINTLMEASURE',0x00000000)
		win_const_mgr.add_const('LOCALE_SNATIVECTRYNAME',0x00000008)
		win_const_mgr.add_const('LANG_VIETNAMESE',0x00000002)
		win_const_mgr.add_const('NOTE_COLOR_WHITE',0x00000004)
		win_const_mgr.add_const('ERROR_CLUSTER_NOT_INSTALLED',0x0000172C)
		win_const_mgr.add_const('NETLOGON_REPLICATION_NEEDED',0x00000001)
		win_const_mgr.add_const('GGO_METRICS',0x00000000)
		win_const_mgr.add_const('STI_GENCAP_WIA',0x00000010)
		win_const_mgr.add_const('DDSETSURFACEDESC_PRESERVEDC',0x00000001)
		win_const_mgr.add_const('ISC_SHOWUICOMPOSITIONWINDOW',0x80000000)
		win_const_mgr.add_const('CTF_COINIT_STA',0x00000008)
		win_const_mgr.add_const('SHTDN_REASON_MAJOR_HARDWARE',0x00010000)
		win_const_mgr.add_const('ERROR_DS_BUSY',0x0000200E)
		win_const_mgr.add_const('MD_SERVER_STATE_PAUSED',0x00000006)
		win_const_mgr.add_const('SCARD_STATE_PRESENT',0x00000020)
		win_const_mgr.add_const('RTM_VIEW_MASK_NONE',0x00000000)
		win_const_mgr.add_const('MCI_ANIM_STATUS_HWND',0x00004003)
		win_const_mgr.add_const('ERROR_EVT_CHANNEL_NOT_FOUND',0x00003A9F)
		win_const_mgr.add_const('TMT_ALPHATHRESHOLD',0x0000096F)
		win_const_mgr.add_const('DS_DOMAIN_DIRECT_OUTBOUND',0x00000002)
		win_const_mgr.add_const('ICERR_NEWPALETTE',0x00000002)
		win_const_mgr.add_const('SCARD_E_INVALID_VALUE',0x80100011)
		win_const_mgr.add_const('TTFCFP_ISO_PLATFORMID',0x00000002)
		win_const_mgr.add_const('MCI_DGV_INPUT_S',0x00008003)
		win_const_mgr.add_const('DI_NOWRITE_IDS',0x80000000)
		win_const_mgr.add_const('CM_CDMASK_DESCRIPTION',0x00000008)
		win_const_mgr.add_const('IDM_TRIED_PRINT',0x00000033)
		win_const_mgr.add_const('LINETONEMODE_BILLING',0x00000010)
		win_const_mgr.add_const('COD_MAJOR_MISCELLANEOUS',0x00000000)
		win_const_mgr.add_const('OFFLINE_STATUS_INCOMPLETE',0x00000004)
		win_const_mgr.add_const('EAP_METHOD_AUTHENTICATOR_CONFIG_IS_IDENTITY_PRIVACY',0x00000001)
		win_const_mgr.add_const('EAP_FLAG_RESUME_FROM_HIBERNATE',0x00000200)
		win_const_mgr.add_const('SV_TYPE_MASTER_BROWSER',0x00040000)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SHARPNESS',0x00004004)
		win_const_mgr.add_const('NETSETUP_JOIN_UNSECURE',0x00000040)
		win_const_mgr.add_const('LINECALLSTATE_SPECIALINFO',0x00000080)
		win_const_mgr.add_const('ERROR_BAD_USER_PROFILE',0x000004E5)
		win_const_mgr.add_const('IPPORT_TIMESERVER',0x00000025)
		win_const_mgr.add_const('SQL_HANDLE_DBC',0x00000002)
		win_const_mgr.add_const('IMAGE_SCN_SCALE_INDEX',0x00000001)
		win_const_mgr.add_const('WMDM_STATUS_DEVICECONTROL_REMOTE',0x00000040)
		win_const_mgr.add_const('IDC_IO_RESULTIMAGE',0x0000083C)
		win_const_mgr.add_const('IMAGE_SIZEOF_SECTION_HEADER',0x00000028)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_RADIO_OFF',0x00000003)
		win_const_mgr.add_const('IDTB_BROWSE_FWD',0x000000D3)
		win_const_mgr.add_const('PROPTYPE_STRING',0x00000004)
		win_const_mgr.add_const('VK_LEFT',0x00000025)
		win_const_mgr.add_const('FIXED_PITCH',0x00000001)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_MULTICAST',0x00000002)
		win_const_mgr.add_const('BATTERY_PERCENTAGE_UNKNOWN',0x000000FF)
		win_const_mgr.add_const('SV_ACTIVELOCKS_PARMNUM',0x000001A3)
		win_const_mgr.add_const('FLG_REGSVR_DLLINSTALL',0x00000002)
		win_const_mgr.add_const('PDH_UNKNOWN_LOG_FORMAT',0xC0000BD6)
		win_const_mgr.add_const('SNMPAPI_ON',0x00000001)
		win_const_mgr.add_const('PHONEFEATURE_GETBUTTONINFO',0x00000001)
		win_const_mgr.add_const('MCI_STATUS_START',0x00000200)
		win_const_mgr.add_const('BCSIF_IMAGE',0x00000002)
		win_const_mgr.add_const('CSIDL_NETWORK',0x00000012)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_TABLES',0x00000004)
		win_const_mgr.add_const('SHTDN_REASON_FLAG_COMMENT_REQUIRED',0x01000000)
		win_const_mgr.add_const('EVENT_CONSOLE_END_APPLICATION',0x00004007)
		win_const_mgr.add_const('FAX_ERR_FILE_ACCESS_DENIED',0x00001B60)
		win_const_mgr.add_const('SQL_COLLATION_SEQ',0x00002714)
		win_const_mgr.add_const('DBG_WOWINIT',0x00000011)
		win_const_mgr.add_const('MD_AUTH_MD5',0x00000010)
		win_const_mgr.add_const('SEARCH_ALL_NO_SEQ',0x00000004)
		win_const_mgr.add_const('DISPID_HTMLPOPUP',0x00006978)
		win_const_mgr.add_const('IDM_TRIED_JUSTIFYRIGHT',0x0000002E)
		win_const_mgr.add_const('SEE_MASK_CONNECTNETDRV',0x00000080)
		win_const_mgr.add_const('WIA_DPS_DITHER_PATTERN_DATA',0x00000C0D)
		win_const_mgr.add_const('WM_SIZE',0x00000005)
		win_const_mgr.add_const('CONSOLE_SELECTION_IN_PROGRESS',0x00000001)
		win_const_mgr.add_const('PROGRESS_CONTINUE',0x00000000)
		win_const_mgr.add_const('IMAGE_SYM_DTYPE_ARRAY',0x00000003)
		win_const_mgr.add_const('PE_HDR_LEN',0x00000002)
		win_const_mgr.add_const('MM_WIM_DATA',0x000003C0)
		win_const_mgr.add_const('DSA_NOTIFY_FLAG_FORCE_ADDITIONAL_DATA',0x00000001)
		win_const_mgr.add_const('BCSS_ALIGNLEFT',0x00000004)
		win_const_mgr.add_const('DC_DRIVER',0x0000000B)
		win_const_mgr.add_const('ITR_KERNEL_INDEX',0x00000001)
		win_const_mgr.add_const('MQ_LOOKUP_RECEIVE_CURRENT',0x40000020)
		win_const_mgr.add_const('GESTURE_SECTION',0x00000000)
		win_const_mgr.add_const('LINEBEARERMODE_RESTRICTEDDATA',0x00000080)
		win_const_mgr.add_const('INDEX_GUID_ROOT',0x00000000)
		win_const_mgr.add_const('DRM_LOCKBOXTYPE_BLACKBOX',0x00000002)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_PROPAGATE_PUSH',0x00010000)
		win_const_mgr.add_const('MM_MICROSOFT',0x00000001)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_OPEN_PARAMETERS',0x00000087)
		win_const_mgr.add_const('SNMP_LOG_TRACE',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_I386_DIR32NB',0x00000007)
		win_const_mgr.add_const('BG_S_OVERRIDDEN_BY_POLICY',0x00200055)
		win_const_mgr.add_const('DISPID_ORDERCHANGED',0x000000D2)
		win_const_mgr.add_const('LOCALE_INEGSIGNPOSN',0x00000053)
		win_const_mgr.add_const('SID_HASH_SIZE',0x00000020)
		win_const_mgr.add_const('SCH_CRED_FORMAT_CERT_HASH_STORE',0x00000002)
		win_const_mgr.add_const('NDIS_ENCAPSULATION_IEEE_802_3_P_AND_Q',0x00000004)
		win_const_mgr.add_const('SPC_UUID_LENGTH',0x00000010)
		win_const_mgr.add_const('SAFER_MAX_DESCRIPTION_SIZE',0x00000100)
		win_const_mgr.add_const('SERVICETYPE_GENERAL_INFORMATION',0x00000005)
		win_const_mgr.add_const('SO_BTH_MTU_MAX',0x80000008)
		win_const_mgr.add_const('WMDM_STORAGECAP_FILESINROOT',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_TR_BOTH',0x00000080)
		win_const_mgr.add_const('NRC_NOSAPS',0x00000037)
		win_const_mgr.add_const('IGP_PROPERTY',0x00000004)
		win_const_mgr.add_const('SQL_CA2_CRC_EXACT',0x00001000)
		win_const_mgr.add_const('FAULT_INVALID_VARIABLE',0x00000194)
		win_const_mgr.add_const('DICLASSPROP_INTERFACE',0x00000002)
		win_const_mgr.add_const('NTDDI_VERSION',0x06000000)
		win_const_mgr.add_const('JRO_MAJOR',0x00000002)
		win_const_mgr.add_const('PAN_LETT_NORMAL_OFF_CENTER',0x00000007)
		win_const_mgr.add_const('GLOBAL_INTERFACE_INDEX',0xFFFFFFFF)
		win_const_mgr.add_const('LVHT_TORIGHT',0x00000020)
		win_const_mgr.add_const('INDEX_DONT_CARE',0x00000000)
		win_const_mgr.add_const('CLRBREAK',0x00000009)
		win_const_mgr.add_const('MPEG_PAT_TID',0x00000000)
		win_const_mgr.add_const('IDM_ETCHED',0x00000041)
		win_const_mgr.add_const('SNMPAPI_TL_NOT_INITIALIZED',0x00000064)
		win_const_mgr.add_const('TME_NONCLIENT',0x00000010)
		win_const_mgr.add_const('ILD_OVERLAYMASK',0x00000F00)
		win_const_mgr.add_const('ERROR_WMI_DP_NOT_FOUND',0x0000106C)
		win_const_mgr.add_const('LINECALLFEATURE_ACCEPT',0x00000001)
		win_const_mgr.add_const('SUBSMGRUPDATE_MASK',0x00000001)
		win_const_mgr.add_const('ERROR_PIPE_BUSY',0x000000E7)
		win_const_mgr.add_const('DBPROPVAL_IC_UPPER',0x00000001)
		win_const_mgr.add_const('VK_SLEEP',0x0000005F)
		win_const_mgr.add_const('SQL_TYPE_NULL',0x00000000)
		win_const_mgr.add_const('LOCALE_STHOUSAND',0x0000000F)
		win_const_mgr.add_const('SHIL_LARGE',0x00000000)
		win_const_mgr.add_const('PPCF_ADDARGUMENTS',0x00000003)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME1',0x00000022)
		win_const_mgr.add_const('LINEADDRESSSTATE_DEVSPECIFIC',0x00000002)
		win_const_mgr.add_const('BSIS_AUTOGRIPPER',0x00000000)
		win_const_mgr.add_const('MCI_FORMAT_SAMPLES',0x00000009)
		win_const_mgr.add_const('MAPIFORM_CPU_M68',0x00000005)
		win_const_mgr.add_const('KSAUDIO_QUALITY_BASIC',0x00000002)
		win_const_mgr.add_const('ADS_PRINTER_PROCESSING',0x00004000)
		win_const_mgr.add_const('KAGPROP_AUTH_SERVERINTEGRATED',0x00000003)
		win_const_mgr.add_const('FLAGCOLOR_PURPLE',0x00000001)
		win_const_mgr.add_const('CERT_LDAP_STORE_OPENED_FLAG',0x00040000)
		win_const_mgr.add_const('MDPROPVAL_MNF_DRILLDOWNLEVEL',0x00000800)
		win_const_mgr.add_const('TRACE_PROVIDER_FLAG_PRE_ENABLE',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNCLOSEDENDTAG',0x000036ED)
		win_const_mgr.add_const('ALLOW_OUTOFBAND_NOTIFICATION',0x00000002)
		win_const_mgr.add_const('SSF_DONTPRETTYPATH',0x00000800)
		win_const_mgr.add_const('IDM_TRIED_SEND_BELOW_TEXT',0x0000000A)
		win_const_mgr.add_const('AF_PUP',0x00000004)
		win_const_mgr.add_const('CERT_STORE_BACKUP_RESTORE_FLAG',0x00000800)
		win_const_mgr.add_const('SLMFLAG_NO_SYMBOLS',0x00000004)
		win_const_mgr.add_const('CSIDL_PROGRAM_FILESX86',0x00000002)
		win_const_mgr.add_const('LVS_EX_UNDERLINEHOT',0x00000800)
		win_const_mgr.add_const('FACILITY_SL_ITF',0x00000004)
		win_const_mgr.add_const('MDLEVEL_TYPE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('SETUP_ATTEMPT_VROOT_CREATE',0x00000080)
		win_const_mgr.add_const('LINEDISCONNECTMODE_UNREACHABLE',0x00000100)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_BADVALUE',0x00000003)
		win_const_mgr.add_const('BHLI_ISO',0x00000000)
		win_const_mgr.add_const('RSVP_RESV_ERR',0x00000004)
		win_const_mgr.add_const('MAXLOGICALLOGNAMESIZE',0x00000100)
		win_const_mgr.add_const('PERF_NUMBER_DEC_1000',0x00020000)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_FOREIGN_KEYS',0x00000006)
		win_const_mgr.add_const('ERROR_MOUNT_POINT_NOT_RESOLVED',0x00000289)
		win_const_mgr.add_const('ERROR_LOG_BLOCK_VERSION',0x000019D0)
		win_const_mgr.add_const('ERROR_DS_INVALID_DN_SYNTAX',0x00002032)
		win_const_mgr.add_const('CSF_SHOWHELP',0x00000001)
		win_const_mgr.add_const('CFE_AUTOCOLOR',0x40000000)
		win_const_mgr.add_const('USER_TIMER_MAXIMUM',0x7FFFFFFF)
		win_const_mgr.add_const('CDO_E_CONTENTPROPXML_CONVERT_FAILED',0x80040230)
		win_const_mgr.add_const('PID_FILENAME',0x00000064)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_GRP_FLOW_DURATION',0x0000000A)
		win_const_mgr.add_const('SSM_SET',0x00000001)
		win_const_mgr.add_const('SV_TYPE_DCE',0x10000000)
		win_const_mgr.add_const('MM_WIM_CLOSE',0x000003BF)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_LOAD_SOFT_SA',0x00003614)
		win_const_mgr.add_const('TRUSTERROR_STEP_MSG_COUNTERSIGINFO',0x00000010)
		win_const_mgr.add_const('WM_ENTERMENULOOP',0x00000211)
		win_const_mgr.add_const('NDIS_RING_RING_RECOVERY',0x00000040)
		win_const_mgr.add_const('WINEVENT_LEVEL_WARNING',0x00000003)
		win_const_mgr.add_const('CERT_ARCHIVED_PROP_ID',0x00000013)
		win_const_mgr.add_const('IDM_BREAKATNEXT',0x00000907)
		win_const_mgr.add_const('SCHANNEL_RENEGOTIATE',0x00000000)
		win_const_mgr.add_const('RGN_COPY',0x00000005)
		win_const_mgr.add_const('CLUSTER_RUNNING',0x00000010)
		win_const_mgr.add_const('IDC_EL_UPDATENOW',0x000000D2)
		win_const_mgr.add_const('IF_TYPE_SRP',0x00000097)
		win_const_mgr.add_const('DDSPD_IUNKNOWNPOINTER',0x00000001)
		win_const_mgr.add_const('USER_DONT_REQUIRE_PREAUTH',0x00010000)
		win_const_mgr.add_const('PSR_MBZ0_V',0x00000007)
		win_const_mgr.add_const('SQL_UPDATE',0x00000002)
		win_const_mgr.add_const('DCIENUMSURFACE',0x00000004)
		win_const_mgr.add_const('NDIS_WMI_SET_HEADER_REVISION_1',0x00000001)
		win_const_mgr.add_const('MD_ROOT_ENABLE_EDIT_WHILE_RUNNING',0x0000270E)
		win_const_mgr.add_const('GROUP_SECURITY_INFORMATION',0x00000002)
		win_const_mgr.add_const('EASTEUROPE_CHARSET',0x000000EE)
		win_const_mgr.add_const('SHI1_NUM_ELEMENTS',0x00000004)
		win_const_mgr.add_const('IMAGE_FILE_BYTES_REVERSED_LO',0x00000080)
		win_const_mgr.add_const('ERROR_DS_INSUFF_ACCESS_RIGHTS',0x00002098)
		win_const_mgr.add_const('LINE_PROXYREQUEST',0x00000018)
		win_const_mgr.add_const('NTMSMLI_MAXIDSIZE',0x00000100)
		win_const_mgr.add_const('MCI_VCR_STATUS_TIME_TYPE',0x00004019)
		win_const_mgr.add_const('TAPE_DRIVE_SET_ECC',0x80000100)
		win_const_mgr.add_const('CRYPT_GET_URL_FROM_AUTH_ATTRIBUTE',0x00000008)
		win_const_mgr.add_const('CTRY_IRAQ',0x000003C4)
		win_const_mgr.add_const('DEBUG_STATUS_REVERSE_STEP_OVER',0x0000000D)
		win_const_mgr.add_const('MSV1_0_VALIDATION_USER_FLAGS',0x00000020)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_LOG_NO_CONTAINER_COUNT_MIN',0x00000080)
		win_const_mgr.add_const('I24_AREA',0x00000006)
		win_const_mgr.add_const('DDCAPS_ALIGNSIZEDEST',0x00000004)
		win_const_mgr.add_const('CM_QUERY_ARBITRATOR_TRANSLATED',0x00000001)
		win_const_mgr.add_const('KSPROPERTY_TYPE_UNSERIALIZESET',0x00001000)
		win_const_mgr.add_const('WMI_GUIDTYPE_TRACECONTROL',0x00000000)
		win_const_mgr.add_const('DDCKEYCAPS_SRCOVERLAYYUV',0x00020000)
		win_const_mgr.add_const('SQL_API_SQLSETCONNECTATTR',0x000003F8)
		win_const_mgr.add_const('ERROR_TRANSACTION_NOT_JOINED',0x00001A34)
		win_const_mgr.add_const('ERROR_NO_DBG_POINTER',0x00008801)
		win_const_mgr.add_const('ERROR_SXS_XML_E_MISSINGSEMICOLON',0x000036D7)
		win_const_mgr.add_const('FILE_DEVICE_TRANSPORT',0x00000021)
		win_const_mgr.add_const('PPP_LCP_EAP',0x0000C227)
		win_const_mgr.add_const('CTRY_YEMEN',0x000003C7)
		win_const_mgr.add_const('SETUP_W2K_SECURITY_NOT_UPGRADED_FLAG',0x00000800)
		win_const_mgr.add_const('ERROR_DS_SOURCE_AUDITING_NOT_ENABLED',0x00002168)
		win_const_mgr.add_const('APPCOMMAND_TREBLE_DOWN',0x00000016)
		win_const_mgr.add_const('CAL_ITWODIGITYEARMAX',0x00000030)
		win_const_mgr.add_const('TASK_FLAG_KILL_ON_IDLE_END',0x00000020)
		win_const_mgr.add_const('DOMAIN_USER_RID_ADMIN',0x000001F4)
		win_const_mgr.add_const('ERROR_SXS_INVALID_XML_NAMESPACE_URI',0x000036BE)
		win_const_mgr.add_const('IMAGE_REL_AMD64_TOKEN',0x0000000D)
		win_const_mgr.add_const('ERROR_REMOTE_SESSION_LIMIT_EXCEEDED',0x000004C4)
		win_const_mgr.add_const('HEAP_CREATE_ENABLE_EXECUTE',0x00040000)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_STARTING_SCOPE',0x00000001)
		win_const_mgr.add_const('SPDRP_UNUSED2',0x00000006)
		win_const_mgr.add_const('SPDRP_UNUSED1',0x00000005)
		win_const_mgr.add_const('SPDRP_UNUSED0',0x00000003)
		win_const_mgr.add_const('MAX_GOPHER_ATTRIBUTE_NAME',0x00000080)
		win_const_mgr.add_const('LVS_EX_BORDERSELECT',0x00008000)
		win_const_mgr.add_const('INTERNET_STATUS_COOKIE_HISTORY',0x00000147)
		win_const_mgr.add_const('FILE_SYSTEM_NOT_SUPPORT',0x00000006)
		win_const_mgr.add_const('SM_CYBORDER',0x00000006)
		win_const_mgr.add_const('SQL_CDO_CONSTRAINT_INITIALLY_IMMEDIATE',0x00000040)
		win_const_mgr.add_const('INTERNET_PREFETCH_PROGRESS',0x00000000)
		win_const_mgr.add_const('CM_DRP_UPPERFILTERS',0x00000012)
		win_const_mgr.add_const('HANDLE_PARAM_IS_OUT',0x00000020)
		win_const_mgr.add_const('PDH_NO_DIALOG_DATA',0xC0000BC7)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_CHARACTER_SETS',0x00000003)
		win_const_mgr.add_const('DDF_FULLSCREEN',0x00000100)
		win_const_mgr.add_const('SBS_TOPALIGN',0x00000002)
		win_const_mgr.add_const('DCI_OVERLAY',0x00000002)
		win_const_mgr.add_const('METAFILE_DRIVER',0x00000801)
		win_const_mgr.add_const('SQL_ATTR_ROW_ARRAY_SIZE',0x0000001B)
		win_const_mgr.add_const('LVBKIF_STYLE_NORMAL',0x00000000)
		win_const_mgr.add_const('NRC_IFBUSY',0x00000021)
		win_const_mgr.add_const('LOCALE_INEGCURR',0x0000001C)
		win_const_mgr.add_const('WM_MOUSEMOVE',0x00000200)
		win_const_mgr.add_const('LINECALLREASON_DIRECT',0x00000001)
		win_const_mgr.add_const('WMDM_STORAGE_ATTR_FILESYSTEM',0x00000001)
		win_const_mgr.add_const('FWPM_WEIGHT_RANGE_IKE_EXEMPTIONS',0x00000000)
		win_const_mgr.add_const('DISPID_FONT_BOLD',0x00000003)
		win_const_mgr.add_const('FKF_FILTERKEYSON',0x00000001)
		win_const_mgr.add_const('URLACTION_SHELL_FILE_DOWNLOAD',0x00001803)
		win_const_mgr.add_const('PHOTO_FLASH_NONE',0x00000000)
		win_const_mgr.add_const('CERT_PE_IMAGE_DIGEST_DEBUG_INFO',0x00000001)
		win_const_mgr.add_const('CTRY_ISRAEL',0x000003CC)
		win_const_mgr.add_const('ERROR_INVALID_MODULETYPE',0x000000BE)
		win_const_mgr.add_const('ERROR_CANNOT_ABORT_TRANSACTIONS',0x00001AC0)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_FWDCONSULT',0x00000100)
		win_const_mgr.add_const('WEBPOST_ERROR_PROV_DLL',0xC0042105)
		win_const_mgr.add_const('BSF_DELEGATEDNAVIGATION',0x00010000)
		win_const_mgr.add_const('D3DPMISCCAPS_TSSARGTEMP',0x00000400)
		win_const_mgr.add_const('DDSCL_SETFOCUSWINDOW',0x00000080)
		win_const_mgr.add_const('IDM_BOLD',0x00000034)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_BRIDGEDAPP',0x0000001C)
		win_const_mgr.add_const('CDO_E_CONNECTION_DROPPED',0x80040212)
		win_const_mgr.add_const('ERROR_FILE_ENCRYPTED',0x00001772)
		win_const_mgr.add_const('TMT_BORDERSIZE',0x00000963)
		win_const_mgr.add_const('DNSSEC_ALGORITHM_RSAMD5',0x00000001)
		win_const_mgr.add_const('TMT_TEXTAPPLYOVERLAY',0x000008A8)
		win_const_mgr.add_const('ERROR_INVALID_EVENTNAME',0x000004BB)
		win_const_mgr.add_const('BACKUP_SECURITY_DATA',0x00000003)
		win_const_mgr.add_const('NCBCHAINSENDNA',0x00000072)
		win_const_mgr.add_const('ACTRL_DS_SELF',0x00000008)
		win_const_mgr.add_const('SRRF_RT_REG_QWORD',0x00000040)
		win_const_mgr.add_const('SQL_API_SQLNUMPARAMS',0x0000003F)
		win_const_mgr.add_const('FAX_ERR_SRV_OUTOFMEMORY',0x00001B59)
		win_const_mgr.add_const('LINECALLCOMPLMODE_MESSAGE',0x00000008)
		win_const_mgr.add_const('WKSTA_NUMALERTS_PARMNUM',0x00000014)
		win_const_mgr.add_const('GOPHER_TYPE_GOPHER_PLUS',0x80000000)
		win_const_mgr.add_const('PD_CAN_STRETCHDIB',0x00000002)
		win_const_mgr.add_const('ALLOWED_IGNORE',0x00000008)
		win_const_mgr.add_const('MAPI_DIM',0x00000001)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_I386',0x00000014)
		win_const_mgr.add_const('DB_PROT_LEVEL_PKT_PRIVACY',0x00000005)
		win_const_mgr.add_const('WSASYS_STATUS_LEN',0x00000080)
		win_const_mgr.add_const('DN_WO',0x00000002)
		win_const_mgr.add_const('RF_CAC_INPUT',0x00000020)
		win_const_mgr.add_const('EMR_SETMAPPERFLAGS',0x00000010)
		win_const_mgr.add_const('SPI_SETTOGGLEKEYS',0x00000035)
		win_const_mgr.add_const('PORT_NETRJS3',0x00000049)
		win_const_mgr.add_const('TF_CONVERSIONMODE_SOFTKEYBOARD',0x00000080)
		win_const_mgr.add_const('COLOR_GREENACCEL',0x000002D7)
		win_const_mgr.add_const('WMS_STREAM_MIN_BITRATE',0x00000001)
		win_const_mgr.add_const('MFE_WRONG_IF',0x00000003)
		win_const_mgr.add_const('INTERNET_CONNECTION_MODEM_BUSY',0x00000008)
		win_const_mgr.add_const('MAJOR_VERSION_MASK',0x0000000F)
		win_const_mgr.add_const('MFOUTPUTATTRIBUTE_NONSTANDARDIMPLEMENTATION',0x00000002)
		win_const_mgr.add_const('ASC_RET_ALLOW_CONTEXT_REPLAY',0x00400000)
		win_const_mgr.add_const('IDC_CV_DISPLAYASICON',0x00000098)
		win_const_mgr.add_const('TABLE_ROW_MODIFIED',0x00000005)
		win_const_mgr.add_const('WINEVENT_OPCODE_EXTENSION',0x00000005)
		win_const_mgr.add_const('ATA_FLAGS_48BIT_COMMAND',0x00000001)
		win_const_mgr.add_const('DMPAPER_P16K_ROTATED',0x0000006A)
		win_const_mgr.add_const('CERT_STORE_PROV_WRITE_CRL_FUNC',0x00000006)
		win_const_mgr.add_const('SQL_FN_SYS_DBNAME',0x00000002)
		win_const_mgr.add_const('MDPROPVAL_NME_ALLDIMENSIONS',0x00000000)
		win_const_mgr.add_const('ITSSFLAG_KILL_ON_DESTROY',0x00000001)
		win_const_mgr.add_const('WIA_IPS_PREVIEW_TYPE',0x00000C27)
		win_const_mgr.add_const('IS_TEXT_UNICODE_REVERSE_ASCII16',0x00000010)
		win_const_mgr.add_const('ERROR_INSTALL_SERVICE_FAILURE',0x00000641)
		win_const_mgr.add_const('IOCTL_IP_ADDCHANGE_NOTIFY_REQUEST',0x00000066)
		win_const_mgr.add_const('AF_UNKNOWN1',0x00000014)
		win_const_mgr.add_const('SAFER_LEVELID_FULLYTRUSTED',0x00040000)
		win_const_mgr.add_const('HTTP_LOG_FIELD_URI_STEM',0x00000100)
		win_const_mgr.add_const('BTH_MFG_QUALCOMM',0x0000001D)
		win_const_mgr.add_const('UP_P2MP',0x00000001)
		win_const_mgr.add_const('IDASYNC',0x00007D01)
		win_const_mgr.add_const('IDS_CAP_MCI_CONTROL_ERROR',0x000001B4)
		win_const_mgr.add_const('ERROR_INVALID_TABLE',0x0000065C)
		win_const_mgr.add_const('VMRBITMAP_SRCRECT',0x00000010)
		win_const_mgr.add_const('URL_DONT_UNESCAPE',0x00020000)
		win_const_mgr.add_const('DCX_VALIDATE',0x00200000)
		win_const_mgr.add_const('NOTIFIER_TYPE_IMMEDIATE',0x00000010)
		win_const_mgr.add_const('ACM_FORMATENUMF_NSAMPLESPERSEC',0x00040000)
		win_const_mgr.add_const('IRLMP_SEND_PDU_LEN',0x00000013)
		win_const_mgr.add_const('FILE_LIST_DIRECTORY',0x00000001)
		win_const_mgr.add_const('MF_512_BYTE_ALIGNMENT',0x00000001)
		win_const_mgr.add_const('IDM_PLUGIN',0x00000880)
		win_const_mgr.add_const('IMAGE_REL_PPC_TOKEN',0x00000016)
		win_const_mgr.add_const('D3DVS20_MAX_NUMTEMPS',0x00000020)
		win_const_mgr.add_const('PSF_NOREFRESHDATAOBJECT',0x00000080)
		win_const_mgr.add_const('MD_ACCESS_NO_REMOTE_EXECUTE',0x00002000)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_REGISTRY',0x00020000)
		win_const_mgr.add_const('SYMOPT_FLAT_DIRECTORY',0x00400000)
		win_const_mgr.add_const('IDTIMEOUT',0x00007D00)
		win_const_mgr.add_const('PIFDEFFILESIZE',0x00000050)
		win_const_mgr.add_const('TABLET_DISABLE_PENTAPFEEDBACK',0x00000008)
		win_const_mgr.add_const('PP_ENUMCONTAINERS',0x00000002)
		win_const_mgr.add_const('DNS_ERROR_NAME_DOES_NOT_EXIST',0x000025F2)
		win_const_mgr.add_const('SET_FEATURE_ON_THREAD',0x00000001)
		win_const_mgr.add_const('IDM_PASTEFORMAT',0x000008BE)
		win_const_mgr.add_const('SQL_INTERVAL_HOUR_TO_MINUTE',0x00000064)
		win_const_mgr.add_const('TF_CONVERSIONMODE_EUDC',0x00000200)
		win_const_mgr.add_const('PID_LASTAUTHOR',0x00000008)
		win_const_mgr.add_const('PSD_DISABLEPAPER',0x00000200)
		win_const_mgr.add_const('COPY_FILE_FAIL_IF_EXISTS',0x00000001)
		win_const_mgr.add_const('SC_SEPARATOR',0x0000F00F)
		win_const_mgr.add_const('INTERNET_OPTION_PER_CONNECTION_OPTION',0x0000004B)
		win_const_mgr.add_const('DRV_CONFIGURE',0x00000007)
		win_const_mgr.add_const('RSC_FLAG_INF',0x00000001)
		win_const_mgr.add_const('GET_MODULE_HANDLE_EX_FLAG_FROM_ADDRESS',0x00000004)
		win_const_mgr.add_const('CF_GDIOBJLAST',0x000003FF)
		win_const_mgr.add_const('CMS_DISABLEINTENT',0x00000400)
		win_const_mgr.add_const('JOB_CONTROL_SENT_TO_PRINTER',0x00000006)
		win_const_mgr.add_const('LINECALLCOMPLMODE_CALLBACK',0x00000002)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_MM_AV',0x0000000F)
		win_const_mgr.add_const('APPCOMMAND_REPLY_TO_MAIL',0x00000027)
		win_const_mgr.add_const('ERROR_DEV_NOT_EXIST',0x00000037)
		win_const_mgr.add_const('CRED_MAX_TARGETNAME_ATTRIBUTE_LENGTH',0x00000100)
		win_const_mgr.add_const('REG_HIVE_EXACT_FILE_GROWTH',0x00000080)
		win_const_mgr.add_const('TF_MOD_LSHIFT',0x00000100)
		win_const_mgr.add_const('FACILITY_NTDSB',0x00000800)
		win_const_mgr.add_const('STRINGFORMAT_BINARY',0x00000004)
		win_const_mgr.add_const('LINEDEVSTATE_OPEN',0x00000200)
		win_const_mgr.add_const('CONNECT_DEFERRED',0x00000400)
		win_const_mgr.add_const('GD_ICONCOMPONENT',0x00000003)
		win_const_mgr.add_const('DRIVE_REMOVABLE',0x00000002)
		win_const_mgr.add_const('DDSCL_ALLOWMODEX',0x00000040)
		win_const_mgr.add_const('BTH_MFG_SIGNIA',0x0000001B)
		win_const_mgr.add_const('IPSEC_CIPHER_CONFIG_CBC_AES_128',0x00000003)
		win_const_mgr.add_const('OPTION_COOKIE_SERVERS',0x00000008)
		win_const_mgr.add_const('LINEPROXYREQUEST_SETAGENTSESSIONSTATE',0x0000000E)
		win_const_mgr.add_const('MCI_DEVTYPE_ANIMATION',0x00000207)
		win_const_mgr.add_const('LVN_LAST',0x00000000)
		win_const_mgr.add_const('CM_DRP_CONFIGFLAGS',0x0000000B)
		win_const_mgr.add_const('MCHT_CALENDARCONTROL',0x00100000)
		win_const_mgr.add_const('BIND_ALL_IMAGES',0x00000004)
		win_const_mgr.add_const('FPSR_TD0',0x0000000C)
		win_const_mgr.add_const('FPSR_TD1',0x00000019)
		win_const_mgr.add_const('USER_AUTH_FLAGS_PARMNUM',0x0000000A)
		win_const_mgr.add_const('FPSR_TD3',0x00000033)
		win_const_mgr.add_const('ERROR_DS_AFFECTS_MULTIPLE_DSAS',0x00002039)
		win_const_mgr.add_const('USER_PASSWORD_NOT_REQUIRED',0x00000004)
		win_const_mgr.add_const('ENHANCED_KEY',0x00000100)
		win_const_mgr.add_const('STOPBITS_10',0x00000001)
		win_const_mgr.add_const('DDCAPS_OVERLAYSTRETCH',0x00004000)
		win_const_mgr.add_const('USE_IPC',0x00000003)
		win_const_mgr.add_const('CTRY_PANAMA',0x000001FB)
		win_const_mgr.add_const('DEBUG_REQUEST_TARGET_CAN_DETACH',0x00000008)
		win_const_mgr.add_const('CERT_CHAIN_MAX_AIA_URL_RETRIEVAL_BYTE_COUNT_DEFAULT',0x000186A0)
		win_const_mgr.add_const('SSF_SHOWSUPERHIDDEN',0x00040000)
		win_const_mgr.add_const('INFINITE',0xFFFFFFFF)
		win_const_mgr.add_const('MDM_SHIFT_X75_DATA',0x00000000)
		win_const_mgr.add_const('TYMED_CALLBACK',0x00000080)
		win_const_mgr.add_const('IMAGE_REL_MIPS_JMPADDR16',0x00000010)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_BROADCAST_MGMT',0x00040000)
		win_const_mgr.add_const('LOGON32_PROVIDER_WINNT35',0x00000001)
		win_const_mgr.add_const('MD_APPPOOL_IDENTITY_TYPE_NETWORKSERVICE',0x00000002)
		win_const_mgr.add_const('SQL_SR_SELECT_TABLE',0x00001000)
		win_const_mgr.add_const('HHWIN_PARAM_PROPERTIES',0x00000001)
		win_const_mgr.add_const('TMT_MINSIZE4',0x00000D4F)
		win_const_mgr.add_const('DBTF_NET',0x00000002)
		win_const_mgr.add_const('SSPROPVAL_USEPROCFORPREP_ON',0x00000001)
		win_const_mgr.add_const('LDAP_DIRSYNC_PUBLIC_DATA_ONLY',0x00002000)
		win_const_mgr.add_const('CSVER_MINOR_WHISTLER_BETA3',0x00000002)
		win_const_mgr.add_const('CSVER_MINOR_WHISTLER_BETA2',0x00000001)
		win_const_mgr.add_const('PFM_PAGEBREAKBEFORE',0x00080000)
		win_const_mgr.add_const('ERROR_MOD_NOT_FOUND',0x0000007E)
		win_const_mgr.add_const('DBT_LOW_DISK_SPACE',0x00000048)
		win_const_mgr.add_const('KEYEVENTF_KEYUP',0x00000002)
		win_const_mgr.add_const('D3D10_SRGB_TO_FLOAT_THRESHOLD',0x00000000)
		win_const_mgr.add_const('EVENT_SRCSPEW',0x00000064)
		win_const_mgr.add_const('ERROR_NETLOGON_NOT_STARTED',0x00000700)
		win_const_mgr.add_const('FRS_ERR_SYSVOL_DEMOTE',0x00001F50)
		win_const_mgr.add_const('ERROR_OPLOCK_BREAK_IN_PROGRESS',0x000002E6)
		win_const_mgr.add_const('USE_SPECIFIC_TRANSPORT',0x80000000)
		win_const_mgr.add_const('ERROR_I24_DISK_CHANGE',0x0000000D)
		win_const_mgr.add_const('RATING_THREE_STARS_MIN',0x00000026)
		win_const_mgr.add_const('EN_ALIGNLTR',0x00000710)
		win_const_mgr.add_const('SDP_ATTRIB_RECORD_HANDLE',0x00000000)
		win_const_mgr.add_const('SO_GROUP_PRIORITY',0x00002002)
		win_const_mgr.add_const('IF_TYPE_PLC',0x000000AE)
		win_const_mgr.add_const('IPX_INTERFACE_ANSI_NAME_LEN',0x00000030)
		win_const_mgr.add_const('IDM_OBJECT',0x00000879)
		win_const_mgr.add_const('RPC_S_CANT_CREATE_ENDPOINT',0x000006B8)
		win_const_mgr.add_const('SPI_GETMENUSHOWDELAY',0x0000006A)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_ON_SRCSOCKET',0x00000004)
		win_const_mgr.add_const('IDD_CONVERTONLY4',0x00000450)
		win_const_mgr.add_const('DBT_DEVICEQUERYREMOVEFAILED',0x00008002)
		win_const_mgr.add_const('MD_APP_POOL_RECYCLE_PRIVATE_MEMORY',0x00000080)
		win_const_mgr.add_const('ERROR_SEEK',0x00000019)
		win_const_mgr.add_const('IMAGE_REL_SHM_REFHALF',0x00000015)
		win_const_mgr.add_const('TBS_COMMAND_PRIORITY_SYSTEM',0x00000190)
		win_const_mgr.add_const('CF_NULL',0x00000000)
		win_const_mgr.add_const('GESTURE_BRACKET_RIGHT',0x00000000)
		win_const_mgr.add_const('OID_FDDI_PORT_REQUESTED_PATHS',0x03030261)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH',0x0000363F)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_SECURITY_DESCRIPTOR',0x0000000C)
		win_const_mgr.add_const('ERROR_INVALID_PRINTER_NAME',0x00000709)
		win_const_mgr.add_const('TABLE_ROW_ADDED',0x00000003)
		win_const_mgr.add_const('IPX_SERV_TABLE',0x00000004)
		win_const_mgr.add_const('SQL_ROW_NUMBER',0x0000000E)
		win_const_mgr.add_const('WPF_ASYNCWINDOWPLACEMENT',0x00000004)
		win_const_mgr.add_const('ICW_ALREADYRUN',0x00000004)
		win_const_mgr.add_const('TCS_RIGHT',0x00000002)
		win_const_mgr.add_const('SUBLANG_LOWER_SORBIAN_GERMANY',0x00000002)
		win_const_mgr.add_const('DEBUG_SERVERS_PROCESS',0x00000002)
		win_const_mgr.add_const('MDM_V23_OVERRIDE',0x00000400)
		win_const_mgr.add_const('CR_PROP_POLICYDESCRIPTION',0x00000005)
		win_const_mgr.add_const('DWORD64_MAX',0x00000000)
		win_const_mgr.add_const('FACILITY_FILTER_MANAGER',0x0000001C)
		win_const_mgr.add_const('WMS_STREAM_MAX_PACKET_SIZE',0x00000004)
		win_const_mgr.add_const('SUBLANG_PORTUGUESE_BRAZILIAN',0x00000001)
		win_const_mgr.add_const('CERT_VALIDITY_CRL_OUT_OF_DATE',0x40000000)
		win_const_mgr.add_const('CLFS_MGMT_CLIENT_REGISTRATION_VERSION',0x00000001)
		win_const_mgr.add_const('HDF_SORTUP',0x00000400)
		win_const_mgr.add_const('TIMERR_NOERROR',0x00000000)
		win_const_mgr.add_const('TP_ELEMENT_MEMORY',0x00000001)
		win_const_mgr.add_const('LANG_ALSATIAN',0x00000084)
		win_const_mgr.add_const('TMT_HIGHLIGHT',0x0000064E)
		win_const_mgr.add_const('LINEEQOSINFO_GENERICERROR',0x00000004)
		win_const_mgr.add_const('ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN',0x00002143)
		win_const_mgr.add_const('VALIDATEUNC_PERSIST',0x00000008)
		win_const_mgr.add_const('WLX_DIRECTORY_LENGTH',0x00000100)
		win_const_mgr.add_const('FACILITY_PLA',0x00000030)
		win_const_mgr.add_const('MCS_MULTISELECT',0x00000002)
		win_const_mgr.add_const('UNDNAME_NO_LEADING_UNDERSCORES',0x00000001)
		win_const_mgr.add_const('WAVE_FORMAT_96M16',0x00040000)
		win_const_mgr.add_const('CRL_REASON_SUPERSEDED_FLAG',0x00000008)
		win_const_mgr.add_const('D3DCS_BOTTOM',0x00000008)
		win_const_mgr.add_const('BOE_RTLDIR',0x00000001)
		win_const_mgr.add_const('DEBUG_EINDEX_FROM_CURRENT',0x00000002)
		win_const_mgr.add_const('WSAEPROTONOSUPPORT',0x0000273B)
		win_const_mgr.add_const('SO_CONNOPTLEN',0x00007005)
		win_const_mgr.add_const('TBS_AUTOTICKS',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_NO_ZONE_INFO',0x00002582)
		win_const_mgr.add_const('CERT_TRUST_IS_REVOKED',0x00000004)
		win_const_mgr.add_const('ERROR_MCA_EXCEPTION',0x00000310)
		win_const_mgr.add_const('PFM_NUMBERINGSTYLE',0x00002000)
		win_const_mgr.add_const('CMSG_MAX_LENGTH_FLAG',0x00000020)
		win_const_mgr.add_const('REG_NONE',0x00000000)
		win_const_mgr.add_const('DE_E_REDIRECT_FAILED',0x800C0014)
		win_const_mgr.add_const('ASC_RET_CONFIDENTIALITY',0x00000010)
		win_const_mgr.add_const('SCRIPTITEM_NOCODE',0x00000400)
		win_const_mgr.add_const('PAN_WEIGHT_THIN',0x00000004)
		win_const_mgr.add_const('LINEDISCONNECTMODE_BUSY',0x00000020)
		win_const_mgr.add_const('MFASYNC_CALLBACK_QUEUE_IO',0x00000003)
		win_const_mgr.add_const('IDM_IMGARTREWIND',0x000008E4)
		win_const_mgr.add_const('MDMEMBER_TYPE_REGULAR',0x00000001)
		win_const_mgr.add_const('NCBENUM',0x00000037)
		win_const_mgr.add_const('BTHNS_RESULT_DEVICE_REMEMBERED',0x00020000)
		win_const_mgr.add_const('MD_NOTIFY_ACCESS_DENIED',0x00000800)
		win_const_mgr.add_const('DUMP_POINTERS_VERSION_1',0x00000001)
		win_const_mgr.add_const('CM_ADD_ID_COMPATIBLE',0x00000001)
		win_const_mgr.add_const('PROGRESS_STOP',0x00000002)
		win_const_mgr.add_const('SQL_CA1_LOCK_UNLOCK',0x00000100)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_PROPAGATE_PULL',0x00008000)
		win_const_mgr.add_const('SUF_EXPRESS',0x00000002)
		win_const_mgr.add_const('MAPI_OLE_STATIC',0x00000002)
		win_const_mgr.add_const('LINEPROXYREQUEST_AGENTSPECIFIC',0x00000006)
		win_const_mgr.add_const('LOCALE_SMONTHNAME3',0x0000003A)
		win_const_mgr.add_const('LOCALE_SMONTHNAME2',0x00000039)
		win_const_mgr.add_const('LOCALE_SMONTHNAME1',0x00000038)
		win_const_mgr.add_const('CM_CDMASK_RESDES',0x00000002)
		win_const_mgr.add_const('LOCALE_SMONTHNAME7',0x0000003E)
		win_const_mgr.add_const('LOCALE_SMONTHNAME6',0x0000003D)
		win_const_mgr.add_const('LOCALE_SMONTHNAME5',0x0000003C)
		win_const_mgr.add_const('LOCALE_SMONTHNAME4',0x0000003B)
		win_const_mgr.add_const('SF_NOTIFY_END_OF_NET_SESSION',0x00000100)
		win_const_mgr.add_const('LOCALE_SMONTHNAME9',0x00000040)
		win_const_mgr.add_const('BG_E_BLOCKED_BY_POLICY',0x8020003E)
		win_const_mgr.add_const('HHWIN_PARAM_TB_FLAGS',0x00000001)
		win_const_mgr.add_const('CFU_UNDERLINEHAIRLINE',0x0000000A)
		win_const_mgr.add_const('TXTBIT_HIDESELECTION',0x00000020)
		win_const_mgr.add_const('WINHTTP_OPTION_MAX_HTTP_AUTOMATIC_REDIRECTS',0x00000059)
		win_const_mgr.add_const('ERROR_SXS_DUPLICATE_TLBID',0x000036C9)
		win_const_mgr.add_const('KRB_NT_ENTERPRISE_PRINCIPAL',0x0000000A)
		win_const_mgr.add_const('DEBUG_TBINFO_PRIORITY_CLASS',0x00000002)
		win_const_mgr.add_const('ERROR_UNABLE_TO_INVENTORY_TRANSPORT',0x000010E7)
		win_const_mgr.add_const('IMAGE_REL_ARM_TOKEN',0x00000005)
		win_const_mgr.add_const('DXGI_PRESENT_DO_NOT_SEQUENCE',0x00000002)
		win_const_mgr.add_const('IF_TYPE_H323_GATEKEEPER',0x000000A4)
		win_const_mgr.add_const('FCW_INTERNETBAR',0x00000006)
		win_const_mgr.add_const('LINEFEATURE_SETMEDIACONTROL',0x00000010)
		win_const_mgr.add_const('RPC_C_QOS_CAPABILITIES_MUTUAL_AUTH',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_XML_E_MULTIPLEROOTS',0x000036E6)
		win_const_mgr.add_const('IMAGE_FILE_LARGE_ADDRESS_AWARE',0x00000020)
		win_const_mgr.add_const('LANG_LUXEMBOURGISH',0x00000006)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_PROTOCOL_RESTART_PARAMETERS',0x000000A3)
		win_const_mgr.add_const('ATTRIB_TRANSPARENCY',0x00000001)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_RECONFIG',0x00000005)
		win_const_mgr.add_const('MCI_DGV_LIST_VIDEO_STREAM',0x00004007)
		win_const_mgr.add_const('SHRINK_VOLUME_FLAG_FAIL_ON_BAD_CLUSTERS',0x00000001)
		win_const_mgr.add_const('ERROR_TOO_MANY_CONTEXT_IDS',0x00000568)
		win_const_mgr.add_const('OID_802_3_XMIT_HEARTBEAT_FAILURE',0x01020205)
		win_const_mgr.add_const('PAN_SERIF_PERP_SANS',0x0000000D)
		win_const_mgr.add_const('FIND_FORMAT',0x00000040)
		win_const_mgr.add_const('IME_PROP_COMPLETE_ON_UNSELECT',0x00100000)
		win_const_mgr.add_const('DBPROPVAL_IC_LOWER',0x00000002)
		win_const_mgr.add_const('DMPAPER_A5_ROTATED',0x0000004E)
		win_const_mgr.add_const('CI_STATE_MASTER_MERGE',0x00000002)
		win_const_mgr.add_const('ENABLE_POWER_MANAGEMENT',0x00000007)
		win_const_mgr.add_const('CBS_SORT',0x00000100)
		win_const_mgr.add_const('CFS_EXCLUDE',0x00000080)
		win_const_mgr.add_const('MF_MEDIATYPE_EQUAL_MAJOR_TYPES',0x00000001)
		win_const_mgr.add_const('UIA_E_INVALIDOPERATION',0x80131509)
		win_const_mgr.add_const('OID_FDDI_RING_MGT_STATE',0x03020106)
		win_const_mgr.add_const('BN_UNHILITE',0x00000003)
		win_const_mgr.add_const('SPOOL_FILE_TEMPORARY',0x00000002)
		win_const_mgr.add_const('SNMPAPI_OTHER_ERROR',0x00000063)
		win_const_mgr.add_const('BCRYPT_RSAPUBLIC_MAGIC',0x31415352)
		win_const_mgr.add_const('TIME_MIDI',0x00000010)
		win_const_mgr.add_const('INTERNET_OPTION_ORIGINAL_CONNECT_FLAGS',0x00000061)
		win_const_mgr.add_const('SHI2_NUM_ELEMENTS',0x0000000A)
		win_const_mgr.add_const('MDTREEOP_DESCENDANTS',0x00000010)
		win_const_mgr.add_const('AUDIO_MAX_FRAMERATE',0x0005DC00)
		win_const_mgr.add_const('JOY_RETURNZ',0x00000004)
		win_const_mgr.add_const('OLEMISC_NOUIACTIVATE',0x00004000)
		win_const_mgr.add_const('JOY_RETURNX',0x00000001)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_USER_SUM_FLOW_RATE',0x00000027)
		win_const_mgr.add_const('ISR_MBZ2_V',0x00000000)
		win_const_mgr.add_const('COLOR_BTNFACE',0x0000000F)
		win_const_mgr.add_const('CONTEXT_AMD64',0x00100000)
		win_const_mgr.add_const('JOY_RETURNR',0x00000008)
		win_const_mgr.add_const('DDCAPS_CANCLIPSTRETCHED',0x40000000)
		win_const_mgr.add_const('SQL_NOSCAN_ON',0x00000001)
		win_const_mgr.add_const('JOY_RETURNV',0x00000020)
		win_const_mgr.add_const('CSIDL_FLAG_CREATE',0x00008000)
		win_const_mgr.add_const('JOY_RETURNU',0x00000010)
		win_const_mgr.add_const('GESTURE_STAR',0x00000000)
		win_const_mgr.add_const('WINHTTP_DISABLE_REDIRECTS',0x00000002)
		win_const_mgr.add_const('IDD_WIZEXTN_FIRST',0x00005000)
		win_const_mgr.add_const('OCSP_BASIC_RESPONSE_V1',0x00000000)
		win_const_mgr.add_const('LOCALE_SNATIVECURRNAME',0x00001008)
		win_const_mgr.add_const('MPEG2_PROGRAM_PACK_HEADER',0x00000003)
		win_const_mgr.add_const('LDAP_PORT',0x00000185)
		win_const_mgr.add_const('MFOUTPUTATTRIBUTE_VIDEO',0x00000004)
		win_const_mgr.add_const('MCI_DEVTYPE_VIDEODISC',0x00000202)
		win_const_mgr.add_const('MAPI_GUARANTEE_FIFO',0x00000100)
		win_const_mgr.add_const('ERROR_MESSAGE_EXCEEDS_MAX_SIZE',0x000010F0)
		win_const_mgr.add_const('LINEERR_INVALLINESTATE',0x8000002C)
		win_const_mgr.add_const('CRYPTUI_DISABLE_EXPORT',0x00002000)
		win_const_mgr.add_const('DBPROPVAL_GU_NOTSUPPORTED',0x00000001)
		win_const_mgr.add_const('IPX_GETNETINFO',0x00004008)
		win_const_mgr.add_const('ERROR_DIFFERENT_SERVICE_ACCOUNT',0x00000437)
		win_const_mgr.add_const('SVSI_EDIT',0x00000003)
		win_const_mgr.add_const('MSIM_LIST_REVERSE',0x00000008)
		win_const_mgr.add_const('TXTLOG_CMI',0x10000000)
		win_const_mgr.add_const('RESOURCES_ALLOCATED',0x00000001)
		win_const_mgr.add_const('IDM_EXECPRINT',0x0000005D)
		win_const_mgr.add_const('CERT_KEY_AGREEMENT_KEY_USAGE',0x00000008)
		win_const_mgr.add_const('ASYNC_RECO_RESETCONTEXT_FAILED',0x00000010)
		win_const_mgr.add_const('ISR_X',0x00000020)
		win_const_mgr.add_const('FD_WRITE',0x00000001)
		win_const_mgr.add_const('MD_ERROR_SUB401_FILTER',0x00000004)
		win_const_mgr.add_const('SIO_GET_ATM_ADDRESS',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_CU_PRIVILEGE_DEFINITION',0x00000008)
		win_const_mgr.add_const('DDOVER_OVERRIDEBOBWEAVE',0x00400000)
		win_const_mgr.add_const('EDITF_BASICCONSTRAINTSCA',0x00000080)
		win_const_mgr.add_const('ERROR_POINT_NOT_FOUND',0x00000493)
		win_const_mgr.add_const('ERROR_REGISTRY_IO_FAILED',0x000003F8)
		win_const_mgr.add_const('POLLRDNORM',0x00000100)
		win_const_mgr.add_const('IT_MSG_TERMINATION',0x00000004)
		win_const_mgr.add_const('EAP_I_USER_ACCOUNT_OTHER_ERROR',0x40420110)
		win_const_mgr.add_const('WLX_SAS_ACTION_RECONNECTED',0x0000000F)
		win_const_mgr.add_const('LOCALE_SSHORTESTDAYNAME7',0x00000066)
		win_const_mgr.add_const('META_FRAMEREGION',0x00000429)
		win_const_mgr.add_const('PTE_OWNER',0x00000007)
		win_const_mgr.add_const('IDD_CONVERT4',0x0000044F)
		win_const_mgr.add_const('IS_TEXT_UNICODE_REVERSE_MASK',0x000000F0)
		win_const_mgr.add_const('DSOBJECT_ISCONTAINER',0x00000001)
		win_const_mgr.add_const('DDCKEYCAPS_SRCOVERLAYCLRSPACEYUV',0x00008000)
		win_const_mgr.add_const('WSANOTINITIALISED',0x0000276D)
		win_const_mgr.add_const('ISR_MBZ2',0x0000002C)
		win_const_mgr.add_const('ERROR_HOST_DOWN',0x000004E8)
		win_const_mgr.add_const('STI_VERSION_REAL',0x00000002)
		win_const_mgr.add_const('ISR_MBZ1',0x00000028)
		win_const_mgr.add_const('ISC_RET_ALLOCATED_MEMORY',0x00000100)
		win_const_mgr.add_const('URLACTION_AUTOMATIC_DOWNLOAD_UI',0x00002200)
		win_const_mgr.add_const('SEE_MASK_UNICODE',0x00004000)
		win_const_mgr.add_const('MUTZ_IGNORE_ZONE_MAPPINGS',0x00004000)
		win_const_mgr.add_const('SYSTEM_AUDIT_OBJECT_ACE_TYPE',0x00000007)
		win_const_mgr.add_const('DBPROPVAL_RT_FREETHREAD',0x00000001)
		win_const_mgr.add_const('SV_OPLOCKBREAKRESPONSEWAIT_PARMNUM',0x00000217)
		win_const_mgr.add_const('ITIR_PS',0x00000002)
		win_const_mgr.add_const('WINHTTP_QUERY_CONNECTION',0x00000017)
		win_const_mgr.add_const('DEBUG_STATUS_WAIT_TIMEOUT',0x200000000)
		win_const_mgr.add_const('DEBUG_INTERRUPT_ACTIVE',0x00000000)
		win_const_mgr.add_const('SQL_CVT_WCHAR',0x00200000)
		win_const_mgr.add_const('LINEDISCONNECTMODE_CONGESTION',0x00000200)
		win_const_mgr.add_const('DEBUG_EXPR_MASM',0x00000000)
		win_const_mgr.add_const('META_CHORD',0x00000830)
		win_const_mgr.add_const('MDDISPINFO_PARENT_SAME_AS_PREV',0x00020000)
		win_const_mgr.add_const('OID_FDDI_SMT_MASTER_CT',0x0303020A)
		win_const_mgr.add_const('IDC_PS_ICONDISPLAY',0x000001FB)
		win_const_mgr.add_const('MFASYNC_FAST_IO_PROCESSING_CALLBACK',0x00000001)
		win_const_mgr.add_const('PORT_SNET',0x000000A6)
		win_const_mgr.add_const('TMT_BODYFONT',0x00000329)
		win_const_mgr.add_const('ERROR_LOG_FULL',0x000019E4)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_PORT_NAME',0x00000003)
		win_const_mgr.add_const('COD_MAJOR_LAN_ACCESS',0x00000003)
		win_const_mgr.add_const('SYMFLAG_TLSREL',0x00004000)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_BOW_TIE',0x0000000B)
		win_const_mgr.add_const('IN_CLASSA_NSHIFT',0x00000018)
		win_const_mgr.add_const('CPL_SETUP',0x000000C8)
		win_const_mgr.add_const('DC_FIELDS',0x00000001)
		win_const_mgr.add_const('AD_COUNTERCLOCKWISE',0x00000001)
		win_const_mgr.add_const('CF_HIDECHANGEICON',0x00000080)
		win_const_mgr.add_const('JOB_CONTROL_RESTART',0x00000004)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_NSI_NETWORK_RW_STRUCT',0x000000AC)
		win_const_mgr.add_const('IF_TYPE_PARA',0x00000022)
		win_const_mgr.add_const('CM_LOCATE_DEVNODE_CANCELREMOVE',0x00000002)
		win_const_mgr.add_const('CMSG_HASHED_DATA_V0',0x00000000)
		win_const_mgr.add_const('PS1',0x00000002)
		win_const_mgr.add_const('NS_BTH',0x00000010)
		win_const_mgr.add_const('ERROR_SXS_CORRUPT_ACTIVATION_STACK',0x00003702)
		win_const_mgr.add_const('CHANNEL_RC_NO_BUFFER',0x00000008)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETAGENTCAPS',0x00000004)
		win_const_mgr.add_const('DEBUG_SCOPE_GROUP_LOCALS',0x00000002)
		win_const_mgr.add_const('D3DCLEAR_STENCIL',0x00000004)
		win_const_mgr.add_const('MKF_MODIFIERS',0x00000040)
		win_const_mgr.add_const('TAPE_DRIVE_EJECT_MEDIA',0x01000000)
		win_const_mgr.add_const('GESTURE_SWAP',0x00000000)
		win_const_mgr.add_const('RASLCPAD_CHAP_MSV2',0x00000081)
		win_const_mgr.add_const('HCI_CONNNECTION_TYPE_ACL',0x00000001)
		win_const_mgr.add_const('GDT_NONE',0x00000001)
		win_const_mgr.add_const('OID_WAN_LINE_COUNT',0x0401010A)
		win_const_mgr.add_const('CF_SETCONVERTDEFAULT',0x00000002)
		win_const_mgr.add_const('DISKQUOTA_STATE_ENFORCE',0x00000002)
		win_const_mgr.add_const('DI_FLAGSEX_RECURSIVESEARCH',0x40000000)
		win_const_mgr.add_const('PS5',0x00000020)
		win_const_mgr.add_const('WSAENOTSOCK',0x00002736)
		win_const_mgr.add_const('IPX_SERVICE_FILTER_DENY',0x00000002)
		win_const_mgr.add_const('WIA_DPC_CAPTURE_DELAY',0x00000822)
		win_const_mgr.add_const('XACT_S_LAST',0x0004D010)
		win_const_mgr.add_const('INTERNET_OPTION_SEND_UTF8_SERVERNAME_TO_PROXY',0x00000058)
		win_const_mgr.add_const('META_SELECTOBJECT',0x0000012D)
		win_const_mgr.add_const('SQL_CONVERT_GUID',0x000000AD)
		win_const_mgr.add_const('PFD_OVERLAY_PLANE',0x00000001)
		win_const_mgr.add_const('TC_RA_ABLE',0x00002000)
		win_const_mgr.add_const('HH_DISPLAY_TOPIC',0x00000000)
		win_const_mgr.add_const('MSV1_0_SUBAUTHENTICATION_DLL_IIS',0x00000084)
		win_const_mgr.add_const('SPFILEQ_FILE_IN_USE',0x00000001)
		win_const_mgr.add_const('DBIMF_VARIABLEHEIGHT',0x00000008)
		win_const_mgr.add_const('FR_RAW',0x00020000)
		win_const_mgr.add_const('MDM_AUTO_ML_DEFAULT',0x00000000)
		win_const_mgr.add_const('TC_NOTIFY_PARAM_CHANGED',0x00000004)
		win_const_mgr.add_const('DISPID_TABLEPARAMS_TABLEATTRS',0x00000003)
		win_const_mgr.add_const('SCH_CRED_MAX_SUPPORTED_ALGS',0x00000100)
		win_const_mgr.add_const('INTERNET_OPTION_CONNECT_TIME',0x00000037)
		win_const_mgr.add_const('WPF_SHOWPAGE_DESTSITE',0x00040000)
		win_const_mgr.add_const('ACM_DRIVERENUMF_NOLOCAL',0x40000000)
		win_const_mgr.add_const('MDM_FORCED_EC',0x00000004)
		win_const_mgr.add_const('FLASHMODE_REDEYE_FILL',0x00000005)
		win_const_mgr.add_const('SUBLANG_CROATIAN_CROATIA',0x00000001)
		win_const_mgr.add_const('VK_LMENU',0x000000A4)
		win_const_mgr.add_const('CERT_STORE_ADD_NEWER',0x00000006)
		win_const_mgr.add_const('MXDC_ESCAPE',0x0000101A)
		win_const_mgr.add_const('LANG_TAMAZIGHT',0x00000005)
		win_const_mgr.add_const('FILE_ATTRIBUTE_COMPRESSED',0x00000800)
		win_const_mgr.add_const('DNS_ERROR_DNAME_COLLISION',0x000025F9)
		win_const_mgr.add_const('PORT_HOSTNAME',0x00000065)
		win_const_mgr.add_const('SV_SCAVQOSINFOUPDATETIME_PARMNUM',0x0000022B)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_INITIALIZEDISCRECORDER',0x00000106)
		win_const_mgr.add_const('APPNAMEBUFFERLEN',0x00000028)
		win_const_mgr.add_const('BG_E_INSUFFICIENT_RANGE_SUPPORT',0x80200013)
		win_const_mgr.add_const('LOCALE_SLANGUAGE',0x00000002)
		win_const_mgr.add_const('RPC_IF_ALLOW_CALLBACKS_WITH_NO_AUTH',0x00000010)
		win_const_mgr.add_const('WIA_IPC_THUMB_WIDTH',0x00001403)
		win_const_mgr.add_const('TMSUCCESS',0x04000000)
		win_const_mgr.add_const('MCI_INFO_COPYRIGHT',0x00002000)
		win_const_mgr.add_const('AM_AC3_SERVICE_NO_DIALOG',0x00000001)
		win_const_mgr.add_const('LIS_VISITED',0x00000004)
		win_const_mgr.add_const('SERVICE_PAUSABLE',0x00000020)
		win_const_mgr.add_const('TMT_GLYPHIMAGEFILE',0x00000BC0)
		win_const_mgr.add_const('ERROR_INSTALL_USEREXIT',0x00000642)
		win_const_mgr.add_const('SUBLANG_NEPALI_NEPAL',0x00000001)
		win_const_mgr.add_const('DDFXCAPS_BLTMIRRORLEFTRIGHT',0x00000040)
		win_const_mgr.add_const('WMDM_RIGHTS_COPY_TO_NON_SDMI_DEVICE',0x00000002)
		win_const_mgr.add_const('SQL_DTC_ENLIST_EXPENSIVE',0x00000001)
		win_const_mgr.add_const('SET_FEATURE_IN_REGISTRY',0x00000004)
		win_const_mgr.add_const('BATTERY_CLASS_MINOR_VERSION',0x00000000)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_RECORD',0x00100000)
		win_const_mgr.add_const('CRYPT_GET_URL_FROM_EXTENSION',0x00000002)
		win_const_mgr.add_const('APPLY_OPTION_FAIL_IF_EXACT',0x00000001)
		win_const_mgr.add_const('INTERNET_FLAG_CACHE_ASYNC',0x00000080)
		win_const_mgr.add_const('DDCKEYCAPS_DESTOVERLAYCLRSPACE',0x00000020)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_TRUST_USES_RC4_ENCRYPTION',0x00000080)
		win_const_mgr.add_const('DTM_FIRST',0x00001000)
		win_const_mgr.add_const('EAP_E_EAPHOST_XML_MALFORMED',0x80420019)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_SOFTWARE_UPDATE_UNINSTALL',0x00000014)
		win_const_mgr.add_const('SMSET_DONTOWN',0x00000001)
		win_const_mgr.add_const('KAGPROP_TIMEDATEFUNCTIONS',0x00000016)
		win_const_mgr.add_const('MCI_DGV_LIST_VIDEO_QUALITY',0x00004006)
		win_const_mgr.add_const('PP_SGC_INFO',0x00000025)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_SECURITY',0x00000010)
		win_const_mgr.add_const('ERR_INVALID_SOURCE_NAME',0xE0000009)
		win_const_mgr.add_const('ERROR_VOLUME_MOUNTED',0x000002E7)
		win_const_mgr.add_const('LINEERR_INVALTONE',0x8000003C)
		win_const_mgr.add_const('WM_MDICASCADE',0x00000227)
		win_const_mgr.add_const('PSINJECT_ENDSTREAM',0x00000014)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW3_CLIPBOARDDATA',0x00000497)
		win_const_mgr.add_const('SI_RESET_DACL',0x00040000)
		win_const_mgr.add_const('MM_HIMETRIC',0x00000003)
		win_const_mgr.add_const('FD_ACCEPT',0x00000001)
		win_const_mgr.add_const('SORT_JAPANESE_XJIS',0x00000000)
		win_const_mgr.add_const('SQL_DIAG_NATIVE',0x00000005)
		win_const_mgr.add_const('MCI_FORMAT_SMPTE_30DROP',0x00000007)
		win_const_mgr.add_const('ERROR_MORE_DATA',0x000000EA)
		win_const_mgr.add_const('PSR_MBZ4',0x00000000)
		win_const_mgr.add_const('CSC_MASK',0x00000030)
		win_const_mgr.add_const('D3DUSAGE_AUTOGENMIPMAP',0x00000400)
		win_const_mgr.add_const('IDM_TRIED_SET_ALIGNMENT',0x00000003)
		win_const_mgr.add_const('RELATIVE',0x00000002)
		win_const_mgr.add_const('D3DPMISCCAPS_NULLREFERENCE',0x00001000)
		win_const_mgr.add_const('DDOVERZ_INSERTINFRONTOF',0x00000004)
		win_const_mgr.add_const('PRINTER_DRIVER_PACKAGE_AWARE',0x00000001)
		win_const_mgr.add_const('DSDSOF_DONTSIGNSEAL',0x00000004)
		win_const_mgr.add_const('PAN_STROKE_GRADUAL_VERT',0x00000004)
		win_const_mgr.add_const('PHOTOACQ_DISABLE_SETTINGS_LINK',0x00000400)
		win_const_mgr.add_const('TVHT_ONITEMINDENT',0x00000008)
		win_const_mgr.add_const('MK_S_LAST',0x000401EF)
		win_const_mgr.add_const('GESTURE_DIGIT_6',0x00000000)
		win_const_mgr.add_const('IDC_PU_CONVERT',0x00000386)
		win_const_mgr.add_const('CDO_E_CONTENTPROPXML_WRONG_CHARSET',0x8004022E)
		win_const_mgr.add_const('CTRY_ARGENTINA',0x00000036)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_IO_WRITE_INIT',0x0000000D)
		win_const_mgr.add_const('GENERATE_METHOD_PREFIX',0x00000001)
		win_const_mgr.add_const('DISPID_WINDOWRESIZE',0x0000006E)
		win_const_mgr.add_const('DNS_TYPE_AXFR',0x00000000)
		win_const_mgr.add_const('DEBUG_OUTCTL_IGNORE',0x00000003)
		win_const_mgr.add_const('HELPINFO_MENUITEM',0x00000002)
		win_const_mgr.add_const('ASC_RET_DATAGRAM',0x00000400)
		win_const_mgr.add_const('VIDEO_CONFIGURE_MAX',0x00000080)
		win_const_mgr.add_const('IDC_LP_TIME',0x000003FB)
		win_const_mgr.add_const('MDPROPVAL_MNF_COVARIANCE',0x00000020)
		win_const_mgr.add_const('MDM_HDLCPPP_AUTH_MSCHAP',0x00000004)
		win_const_mgr.add_const('MD_GLOBAL_SESSIONKEY',0x0000270F)
		win_const_mgr.add_const('OS_ADVSERVER',0x00000016)
		win_const_mgr.add_const('SFGAO_ENCRYPTED',0x00002000)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_LENGTH',0x00000005)
		win_const_mgr.add_const('SERVICE_CONTROL_POWEREVENT',0x0000000D)
		win_const_mgr.add_const('SND_PURGE',0x00000040)
		win_const_mgr.add_const('SPI_GETCOMBOBOXANIMATION',0x00001004)
		win_const_mgr.add_const('IDM_PAGEBREAK',0x00000881)
		win_const_mgr.add_const('IO_COMPLETION_MODIFY_STATE',0x00000002)
		win_const_mgr.add_const('BASIC_CONSTRAINTS_CERT_CHAIN_POLICY_CA_FLAG',0x80000000)
		win_const_mgr.add_const('ADS_PRINTER_ERROR',0x00000003)
		win_const_mgr.add_const('CACHE_ENTRY_TYPE_FC',0x00001000)
		win_const_mgr.add_const('ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS',0x000013CB)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_MM_GPF',0x0000000D)
		win_const_mgr.add_const('PID_IS_HOTKEY',0x00000006)
		win_const_mgr.add_const('EMR_RESERVED_119',0x00000077)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_NON_CACHEABLE_PRINCIPALS_GROUP',0x0000023C)
		win_const_mgr.add_const('ERROR_DS_BACKLINK_WITHOUT_LINK',0x00002122)
		win_const_mgr.add_const('E_FILTER_MULTIPLETAGS',0x80100004)
		win_const_mgr.add_const('EMR_RESERVED_110',0x0000006E)
		win_const_mgr.add_const('CDO_E_FROM_MISSING',0x8004020D)
		win_const_mgr.add_const('WININET_API_FLAG_USE_CONTEXT',0x00000008)
		win_const_mgr.add_const('CSVER_MINOR_LONGHORN_BETA1',0x00000001)
		win_const_mgr.add_const('AUTH_FLAG_DISABLE_NEGOTIATE',0x00000001)
		win_const_mgr.add_const('MCI_VCR_UNFREEZE_INPUT',0x00010000)
		win_const_mgr.add_const('SNMP_OUTPUT_TO_CONSOLE',0x00000001)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_BUFFEREDTRANSFER',0x00000400)
		win_const_mgr.add_const('SPI_SETPENWINDOWS',0x00000031)
		win_const_mgr.add_const('ERROR_SESSION_CREDENTIAL_CONFLICT',0x000004C3)
		win_const_mgr.add_const('NCBASTAT',0x00000033)
		win_const_mgr.add_const('SNMPAPI_OID_INVALID',0x00000009)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_OFFLOAD_ENCAPSULATION',0x000000A8)
		win_const_mgr.add_const('SQL_FN_NUM_SIN',0x00002000)
		win_const_mgr.add_const('SHPWHF_NORECOMPRESS',0x00000001)
		win_const_mgr.add_const('BL_24M',0x01800000)
		win_const_mgr.add_const('SAC_CERT_V1',0x00000002)
		win_const_mgr.add_const('SPDRP_DEVICE_POWER_DATA',0x0000001E)
		win_const_mgr.add_const('PSD_RETURNDEFAULT',0x00000400)
		win_const_mgr.add_const('IME_HOTKEY_DSWITCH_LAST',0x0000011F)
		win_const_mgr.add_const('CC_ENABLEHOOK',0x00000010)
		win_const_mgr.add_const('MAXNUMERICLEN',0x00000010)
		win_const_mgr.add_const('DT_BOTTOM',0x00000008)
		win_const_mgr.add_const('CERT_STORE_CRL_CONTEXT',0x00000002)
		win_const_mgr.add_const('NDR64_FC_AUTO_HANDLE',0x00000003)
		win_const_mgr.add_const('DB_INVALID_HACCESSOR',0x00000000)
		win_const_mgr.add_const('BLLI_L2_HDLC_ARM',0x00000009)
		win_const_mgr.add_const('UNSUPPORTED_CREDENTIAL_TYPE',0x00000002)
		win_const_mgr.add_const('PROV_STT_BRND',0x00000009)
		win_const_mgr.add_const('PKR_MBZ1',0x00000020)
		win_const_mgr.add_const('PKR_MBZ0',0x00000004)
		win_const_mgr.add_const('OFN_ENABLEHOOK',0x00000020)
		win_const_mgr.add_const('REQDISP_ISSUE',0x00000001)
		win_const_mgr.add_const('ISFBVIEWMODE_SMALLICONS',0x00000001)
		win_const_mgr.add_const('FILE_WRITE_DATA',0x00000002)
		win_const_mgr.add_const('D3DUSAGE_RTPATCHES',0x00000080)
		win_const_mgr.add_const('HTTP_LOG_FIELD_USER_NAME',0x00000008)
		win_const_mgr.add_const('ADMINDATA_MAX_NAME_LEN',0x00000100)
		win_const_mgr.add_const('MCI_STATUS_POSITION',0x00000002)
		win_const_mgr.add_const('EVCF_OUTOFDISKSPACE',0x00000040)
		win_const_mgr.add_const('DNS_UPDATE_RESERVED',0x00000000)
		win_const_mgr.add_const('USER_MD_ID_BASE_RESERVED',0x00000000)
		win_const_mgr.add_const('BT_PORT_DYN_FIRST',0x00001001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_SITUATION',0x00003627)
		win_const_mgr.add_const('EMR_SETLAYOUT',0x00000073)
		win_const_mgr.add_const('HTTP_QUERY_IF_UNMODIFIED_SINCE',0x0000003B)
		win_const_mgr.add_const('CREDUIWIN_AUTHPACKAGE_ONLY',0x00000010)
		win_const_mgr.add_const('WINHTTP_QUERY_UPGRADE',0x00000040)
		win_const_mgr.add_const('SQL_INFO_DRIVER_START',0x000003E8)
		win_const_mgr.add_const('ILMM_IE4',0x00000000)
		win_const_mgr.add_const('DEBUG_EVENT_CREATE_THREAD',0x00000004)
		win_const_mgr.add_const('FWPS_CLASSIFY_OUT_FLAG_ABSORB',0x00000001)
		win_const_mgr.add_const('ERROR_BAD_NET_RESP',0x0000003A)
		win_const_mgr.add_const('IP_STATUS_BASE',0x00002AF8)
		win_const_mgr.add_const('OID_FDDI_IF_SPEED',0x0303027C)
		win_const_mgr.add_const('BATTERY_FLAG_NO_BATTERY',0x00000080)
		win_const_mgr.add_const('MCI_DGV_STATUS_FILE_MODE',0x00000401)
		win_const_mgr.add_const('TMT_RESERVEDHIGH',0x00001F3F)
		win_const_mgr.add_const('CERT_LOGOTYPE_DIRECT_INFO_CHOICE',0x00000001)
		win_const_mgr.add_const('OR_INVALID_OXID',0x00000776)
		win_const_mgr.add_const('EC_WINDOW_DESTROYED',0x00000015)
		win_const_mgr.add_const('ERROR_DS_LINK_ID_NOT_AVAILABLE',0x00002181)
		win_const_mgr.add_const('ERROR_INVALID_MESSAGEDEST',0x000004C2)
		win_const_mgr.add_const('ERROR_NOT_A_REPARSE_POINT',0x00001126)
		win_const_mgr.add_const('OFN_LONGNAMES',0x00200000)
		win_const_mgr.add_const('PF_FLOATING_POINT_PRECISION_ERRATA',0x00000000)
		win_const_mgr.add_const('CM_OUT_OF_GAMUT',0x000000FF)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_DELETE',0x00003611)
		win_const_mgr.add_const('EMR_PIE',0x0000002F)
		win_const_mgr.add_const('IGIMII_CONFIGURE',0x00000004)
		win_const_mgr.add_const('SUBLANG_MALAY_BRUNEI_DARUSSALAM',0x00000002)
		win_const_mgr.add_const('ERROR_NOT_CONTAINER',0x000004B7)
		win_const_mgr.add_const('LINETERMMODE_LAMPS',0x00000002)
		win_const_mgr.add_const('D3DPTADDRESSCAPS_WRAP',0x00000001)
		win_const_mgr.add_const('TRUST_ATTRIBUTES_VALID',0xFF03FFFF)
		win_const_mgr.add_const('GCP_KASHIDA',0x00000400)
		win_const_mgr.add_const('BIND_CACHE_IMPORT_DLLS',0x00000008)
		win_const_mgr.add_const('SECPKG_INTERFACE_VERSION_3',0x00040000)
		win_const_mgr.add_const('EAP_I_USER_FIRST',0x40420100)
		win_const_mgr.add_const('DNS_RCODE_NOTIMPL',0x00000004)
		win_const_mgr.add_const('SECPKG_INTERFACE_VERSION_4',0x00080000)
		win_const_mgr.add_const('PORT_PWDGEN',0x00000081)
		win_const_mgr.add_const('TVS_SHOWSELALWAYS',0x00000020)
		win_const_mgr.add_const('MCI_VCR_STATUS_AUDIO_SOURCE',0x00004006)
		win_const_mgr.add_const('WMDM_STATUS_STORAGE_NOTSUPPORTED',0x00000800)
		win_const_mgr.add_const('ILD_ASYNC',0x00008000)
		win_const_mgr.add_const('IF_TYPE_E1',0x00000013)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_MINI_MUTANT_1',0x00000007)
		win_const_mgr.add_const('GPO_OPTION_DISABLE_MACHINE',0x00000002)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_MINI_MUTANT_2',0x00000008)
		win_const_mgr.add_const('MOUSEEVENTF_RIGHTUP',0x00000010)
		win_const_mgr.add_const('PP_USE_HARDWARE_RNG',0x00000026)
		win_const_mgr.add_const('ETW_SBYTE_TYPE_VALUE',0x00000003)
		win_const_mgr.add_const('GESTURE_DOUBLE_RIGHT',0x00000000)
		win_const_mgr.add_const('HCI_CONNNECTION_TYPE_SCO',0x00000002)
		win_const_mgr.add_const('JOY_RETURNPOV',0x00000040)
		win_const_mgr.add_const('PSR_IA',0x0000002D)
		win_const_mgr.add_const('LINEERR_INVALGROUPID',0x8000002A)
		win_const_mgr.add_const('TBMF_BARPAD',0x00000002)
		win_const_mgr.add_const('VK_ICO_00',0x000000E4)
		win_const_mgr.add_const('DCI_OK',0x00000000)
		win_const_mgr.add_const('LCPRI_HARDWIRED',0x0000E000)
		win_const_mgr.add_const('TF_IPP_CAPS_WOW16SUPPORT',0x00000010)
		win_const_mgr.add_const('BLLI_L2_X25M',0x00000007)
		win_const_mgr.add_const('TBIF_DEFAULT',0x00000000)
		win_const_mgr.add_const('D3D10_DEFAULT_MAX_ANISOTROPY',0x00000010)
		win_const_mgr.add_const('HCCC_PROTOCOL_UUID16',0x00000012)
		win_const_mgr.add_const('PROFILE_USER',0x10000000)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_MISC',0x00000004)
		win_const_mgr.add_const('CDO_E_NOT_ASSIGNEDTO_USER',0x80040238)
		win_const_mgr.add_const('UNRECOVERED_WRITES_VALID',0x00000002)
		win_const_mgr.add_const('DDLOCK_DONOTWAIT',0x00004000)
		win_const_mgr.add_const('D3DPTEXTURECAPS_ALPHA',0x00000004)
		win_const_mgr.add_const('REG_DWORD',0x00000004)
		win_const_mgr.add_const('MD_PASSPORT_TRY_MAPPING',0x00000001)
		win_const_mgr.add_const('ERROR_LAST_ADMIN',0x0000052A)
		win_const_mgr.add_const('ERROR_NO_TXF_METADATA',0x00001AA0)
		win_const_mgr.add_const('IDLE_PRIORITY_CLASS',0x00000040)
		win_const_mgr.add_const('TAPE_DRIVE_ERASE_BOP_ONLY',0x00000040)
		win_const_mgr.add_const('WSAEDISCON',0x00002775)
		win_const_mgr.add_const('SNMP_TRAP_COLDSTART',0x00000000)
		win_const_mgr.add_const('ERROR_SERVICE_SPECIFIC_ERROR',0x0000042A)
		win_const_mgr.add_const('IKEEXT_CERT_FLAG_INTERMEDIATE_CA',0x00000008)
		win_const_mgr.add_const('LINETERMDEV_SPEAKER',0x00000004)
		win_const_mgr.add_const('WM_LBUTTONDOWN',0x00000201)
		win_const_mgr.add_const('ERROR_DS_DUP_MSDS_INTID',0x00002195)
		win_const_mgr.add_const('SHERB_NOSOUND',0x00000004)
		win_const_mgr.add_const('FACILITY_SYSTEM',0x00000000)
		win_const_mgr.add_const('GROUP_COMMENT_PARMNUM',0x00000002)
		win_const_mgr.add_const('HH_SET_INFO_TYPE',0x00000008)
		win_const_mgr.add_const('DTN_FIRST',0x00000000)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_OBJECT_ACTIONS',0x00000001)
		win_const_mgr.add_const('PDH_CSTATUS_BAD_COUNTERNAME',0xC0000BC0)
		win_const_mgr.add_const('SPSVCINST_NOCLOBBER_LOADORDERGROUP',0x00000040)
		win_const_mgr.add_const('SDP_ATTRIB_PROTOCOL_DESCRIPTOR_LIST',0x00000004)
		win_const_mgr.add_const('VFT_VXD',0x00000005)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_GUARANTEE_ENCRYPTION',0x00000008)
		win_const_mgr.add_const('SQL_DP_ON',0x00000001)
		win_const_mgr.add_const('IDD_CHANGEICON',0x000003E9)
		win_const_mgr.add_const('TAPE_DRIVE_ABS_BLK_IMMED',0x80002000)
		win_const_mgr.add_const('MDAXIS_COLUMNS',0x00000000)
		win_const_mgr.add_const('TVSI_NOSINGLEEXPAND',0x00008000)
		win_const_mgr.add_const('DPD_DELETE_SPECIFIC_VERSION',0x00000002)
		win_const_mgr.add_const('PDERR_LOADDRVFAILURE',0x00001004)
		win_const_mgr.add_const('RC_BIGFONT',0x00000400)
		win_const_mgr.add_const('LINEERR_INVALCOMPLETIONID',0x8000001F)
		win_const_mgr.add_const('SPCRP_CHARACTERISTICS',0x0000001B)
		win_const_mgr.add_const('BS_INDEXED',0x00000004)
		win_const_mgr.add_const('LVGGR_LABEL',0x00000002)
		win_const_mgr.add_const('D3DSP_REGTYPE_MASK2',0x00001800)
		win_const_mgr.add_const('SN_CMP_SIGONLY',0x00000002)
		win_const_mgr.add_const('LP_MONOCHROME',0x00000001)
		win_const_mgr.add_const('WMDM_E_MAC_CHECK_FAILED',0x8004500A)
		win_const_mgr.add_const('LOCALE_SCURRENCY',0x00000014)
		win_const_mgr.add_const('LDAP_DEREF_SEARCHING',0x00000001)
		win_const_mgr.add_const('SFGAO_DROPTARGET',0x00000100)
		win_const_mgr.add_const('MAPI_MULTITHREAD_NOTIFICATIONS',0x00000001)
		win_const_mgr.add_const('STRING_DESCRIPTION_OFFSET',0x00000001)
		win_const_mgr.add_const('ERROR_NOT_SNAPSHOT_VOLUME',0x00001AB9)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NO_POLICY',0x00003601)
		win_const_mgr.add_const('HDI_ORDER',0x00000080)
		win_const_mgr.add_const('OS_EMBEDDED',0x0000000D)
		win_const_mgr.add_const('SERVICE_INSTALL_STATE',0x00000003)
		win_const_mgr.add_const('ERROR_REQUEST_ABORTED',0x000004D3)
		win_const_mgr.add_const('CERT_STORE_READONLY_FLAG',0x00008000)
		win_const_mgr.add_const('PAN_WEIGHT_NORD',0x0000000B)
		win_const_mgr.add_const('EC_ERROR_STILLPLAYING',0x00000008)
		win_const_mgr.add_const('IO_REPARSE_TAG_DFSR',0x80000012)
		win_const_mgr.add_const('MIXER_SHORT_NAME_CHARS',0x00000010)
		win_const_mgr.add_const('WPF_RESTORETOMAXIMIZED',0x00000002)
		win_const_mgr.add_const('SECPKG_ATTR_CREDS',0x80000080)
		win_const_mgr.add_const('LMEM_FIXED',0x00000000)
		win_const_mgr.add_const('SECURITY_VALID_SQOS_FLAGS',0x001F0000)
		win_const_mgr.add_const('XA_RBBASE',0x00000064)
		win_const_mgr.add_const('MSG_TRUNC',0x00000100)
		win_const_mgr.add_const('SE_ADT_OBJECT_ONLY',0x00000001)
		win_const_mgr.add_const('DFM_MERGECONTEXTMENU',0x00000001)
		win_const_mgr.add_const('IDM_TOOLBOX',0x0000002A)
		win_const_mgr.add_const('BCRYPT_KEY_DATA_BLOB_VERSION1',0x00000001)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY1',0x00010000)
		win_const_mgr.add_const('CRYPTDLG_ACTION_MASK',0xFFFF0000)
		win_const_mgr.add_const('MCI_ANIM_WINDOW_HWND',0x00010000)
		win_const_mgr.add_const('SERVICE_QUERY_CONFIG',0x00000001)
		win_const_mgr.add_const('MF_MEDIATYPE_EQUAL_FORMAT_DATA',0x00000004)
		win_const_mgr.add_const('USE_REMOTE_PARMNUM',0x00000002)
		win_const_mgr.add_const('CF_PALETTE',0x00000009)
		win_const_mgr.add_const('PBT_APMRESUMESTANDBY',0x00000008)
		win_const_mgr.add_const('DDOVER_AUTOFLIP',0x00100000)
		win_const_mgr.add_const('PIDVSI_DATA_RATE',0x00000008)
		win_const_mgr.add_const('OID_GEN_MACHINE_NAME',0x0001021A)
		win_const_mgr.add_const('SUCCESSFUL_ACCESS_ACE_FLAG',0x00000040)
		win_const_mgr.add_const('CERT_STORE_ADD_NEWER_INHERIT_PROPERTIES',0x00000007)
		win_const_mgr.add_const('WLX_DESKTOP_HANDLE',0x00000002)
		win_const_mgr.add_const('RP_DSN_SENT_RELAYED',0x00010040)
		win_const_mgr.add_const('CHANGER_LOCK_UNLOCK',0x00000080)
		win_const_mgr.add_const('LINEAGENTSTATE_BUSYOTHER',0x00000040)
		win_const_mgr.add_const('ERROR_PARTITION_FAILURE',0x00000451)
		win_const_mgr.add_const('EMR_WIDENPATH',0x00000042)
		win_const_mgr.add_const('V86FLAGS_ALIGNMENT',0x00040000)
		win_const_mgr.add_const('SMDM_HMENU',0x00000002)
		win_const_mgr.add_const('SORT_CHINESE_PRC',0x00000002)
		win_const_mgr.add_const('CERT_PROT_ROOT_INHIBIT_ADD_AT_INIT_FLAG',0x00000002)
		win_const_mgr.add_const('SSRVOPT_PROXYW',0x00040000)
		win_const_mgr.add_const('OCSP_BASIC_BY_KEY_RESPONDER_ID',0x00000002)
		win_const_mgr.add_const('WIA_PAGE_A4',0x00000000)
		win_const_mgr.add_const('IDS_CAP_STAT_PALETTE_BUILD',0x000001F8)
		win_const_mgr.add_const('XINPUT_GAMEPAD_A',0x00001000)
		win_const_mgr.add_const('LINEAGENTSESSIONSTATE_ENDED',0x00000010)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY8',0x00800000)
		win_const_mgr.add_const('TAPE_LOGICAL_BLOCK',0x00000002)
		win_const_mgr.add_const('SCARD_PROTOCOL_UNDEFINED',0x00000000)
		win_const_mgr.add_const('REPL_STATE_NO_MASTER',0x00000001)
		win_const_mgr.add_const('FACILITY_BACKUP',0x000007FF)
		win_const_mgr.add_const('RSC_MBZ0',0x00000005)
		win_const_mgr.add_const('SQL_C_DEFAULT',0x00000063)
		win_const_mgr.add_const('REG_START_JOURNAL',0x00000040)
		win_const_mgr.add_const('PTE_LARGE_PAGE',0x00000036)
		win_const_mgr.add_const('CAUSE_TEMPORARY_FAILURE',0x00000029)
		win_const_mgr.add_const('PHONEERR_STRUCTURETOOSMALL',0x90000021)
		win_const_mgr.add_const('IMAGE_REL_AM_ADDR32NB',0x00000002)
		win_const_mgr.add_const('LVKF_SHIFT',0x00000004)
		win_const_mgr.add_const('ETW_SINGLE_TYPE_VALUE',0x0000000C)
		win_const_mgr.add_const('WMDM_E_BUFFERTOOSMALL',0x80045008)
		win_const_mgr.add_const('IPRTRMGR_PID',0x00002710)
		win_const_mgr.add_const('DNS_RCODE_NOTAUTH',0x00000009)
		win_const_mgr.add_const('OID_FDDI_MAC_UNDA_FLAG',0x0303024B)
		win_const_mgr.add_const('SYMFLAG_SLOT',0x00008000)
		win_const_mgr.add_const('SPI_SETKEYBOARDSPEED',0x0000000B)
		win_const_mgr.add_const('BTH_MFG_OPEN_INTERFACE',0x00000027)
		win_const_mgr.add_const('REO_LINK',0x80000000)
		win_const_mgr.add_const('ERROR_PAGE_FAULT_GUARD_PAGE',0x000002EE)
		win_const_mgr.add_const('SQL_GD_ANY_ORDER',0x00000002)
		win_const_mgr.add_const('THREAD_BASE_PRIORITY_MAX',0x00000002)
		win_const_mgr.add_const('ERROR_INIT_STATUS_NEEDED',0x00000011)
		win_const_mgr.add_const('DISPLAYDIB_STOP',0x00000005)
		win_const_mgr.add_const('WIA_PAGE_ISO_B8',0x00000019)
		win_const_mgr.add_const('METADATA_LOCAL_MACHINE_ONLY',0x00000080)
		win_const_mgr.add_const('CRYPT_OID_INFO_OID_KEY_FLAGS_MASK',0xFFFF0000)
		win_const_mgr.add_const('GESTURE_TRIPLE_LEFT',0x00000000)
		win_const_mgr.add_const('SFVS_SELECT_NONE',0x00000000)
		win_const_mgr.add_const('DDCKEY_COLORSPACE',0x00000001)
		win_const_mgr.add_const('LDAP_MODRDN_CMD',0x00000006)
		win_const_mgr.add_const('ML_CROSSCODEPAGE_MASK',0x00000007)
		win_const_mgr.add_const('SYMFLAG_ILREL',0x00010000)
		win_const_mgr.add_const('IMAGE_REL_IA64_GPREL22',0x00000009)
		win_const_mgr.add_const('CM_GLOBAL_STATE_DETECTION_PENDING',0x00000010)
		win_const_mgr.add_const('GETSETPRINTORIENT',0x0000001E)
		win_const_mgr.add_const('RTCEF_MEDIA',0x00000020)
		win_const_mgr.add_const('DMPAPER_11X17',0x00000011)
		win_const_mgr.add_const('RQ_MAP_REQUEST_HANDLER',0x00000010)
		win_const_mgr.add_const('IDM_CELLPROPERTIES',0x000008A3)
		win_const_mgr.add_const('OPER_STATE_UP',0x00000002)
		win_const_mgr.add_const('VK_F6',0x00000075)
		win_const_mgr.add_const('SQL_ATTR_AUTO_IPD',0x00002711)
		win_const_mgr.add_const('ERROR_IPSEC_QM_POLICY_IN_USE',0x000032CA)
		win_const_mgr.add_const('DEBUG_GSEL_ALLOW_HIGHER',0x00000004)
		win_const_mgr.add_const('GESTURE_SEMICIRCLE_RIGHT',0x00000000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_CERT',0x0000360B)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_ALLOW_UNKNOWN_CA_FLAG',0x00000010)
		win_const_mgr.add_const('DDSCAPS_VIDEOMEMORY',0x00004000)
		win_const_mgr.add_const('BCRYPT_SIGNATURE_OPERATION',0x00000010)
		win_const_mgr.add_const('MD_EXTLOG_SERVER_IP',0x00000040)
		win_const_mgr.add_const('SHACF_FILESYS_ONLY',0x00000010)
		win_const_mgr.add_const('MAX_STR_BLOCKREASON',0x00000100)
		win_const_mgr.add_const('DISPID_IBLOCKFORMATS_COUNT',0x00000001)
		win_const_mgr.add_const('DEBUG_STATUS_REVERSE_STEP_BRANCH',0x0000000C)
		win_const_mgr.add_const('DRAFTMODE',0x00000007)
		win_const_mgr.add_const('ERROR_MUI_FILE_NOT_LOADED',0x00003B01)
		win_const_mgr.add_const('FACILITY_IPSEC',0x00000036)
		win_const_mgr.add_const('ERROR_DRIVER_FAILED_SLEEP',0x00000279)
		win_const_mgr.add_const('HHWIN_BUTTON_TOC_NEXT',0x00000001)
		win_const_mgr.add_const('CRED_TYPE_GENERIC_CERTIFICATE',0x00000005)
		win_const_mgr.add_const('ERROR_DS_CANT_START',0x00002153)
		win_const_mgr.add_const('ERROR_CLUSCFG_ROLLBACK_FAILED',0x0000170E)
		win_const_mgr.add_const('IN6ADDR_TEREDOPREFIX_LENGTH',0x00000020)
		win_const_mgr.add_const('CREDUI_FLAGS_PERSIST',0x00001000)
		win_const_mgr.add_const('OID_GEN_LINK_SPEED',0x00010107)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_AUTHORIZATIONACCESS',0x00000230)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_WORKGROUP',0x00000080)
		win_const_mgr.add_const('OQWF_HIDEMENUS',0x00000400)
		win_const_mgr.add_const('DMBIN_FORMSOURCE',0x0000000F)
		win_const_mgr.add_const('NTM_TYPE1',0x00100000)
		win_const_mgr.add_const('IDC_EL_OPENSOURCE',0x000000D3)
		win_const_mgr.add_const('KLF_SETFORPROCESS',0x00000100)
		win_const_mgr.add_const('DI_FLAGSEX_INET_DRIVER',0x00020000)
		win_const_mgr.add_const('CSIDL_COMMON_VIDEO',0x00000037)
		win_const_mgr.add_const('VIEW_PRIORITY_SHELLEXT_ASBACKUP',0x00000015)
		win_const_mgr.add_const('MDPROPVAL_NL_SCHEMAONLY',0x00000004)
		win_const_mgr.add_const('NETLOGON_CONTROL_SYNCHRONIZE',0x00000003)
		win_const_mgr.add_const('X3_EMPTY_INST_WORD_X',0x00000001)
		win_const_mgr.add_const('SYMSEARCH_MASKOBJS',0x00000001)
		win_const_mgr.add_const('CDIS_OTHERSIDEHOT',0x00000800)
		win_const_mgr.add_const('MUI_USER_PREFERRED_UI_LANGUAGES',0x00000010)
		win_const_mgr.add_const('DIF_DESTROYPRIVATEDATA',0x0000000C)
		win_const_mgr.add_const('DTN_FIRST2',0x00000000)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_INDIVIDUAL',0x00000002)
		win_const_mgr.add_const('IDM_RESPECTVISIBILITY_INDESIGN',0x00000965)
		win_const_mgr.add_const('LINEMAPPER',0xFFFFFFFF)
		win_const_mgr.add_const('SPDRP_LOCATION_PATHS',0x00000023)
		win_const_mgr.add_const('AVIERR_OK',0x00000000)
		win_const_mgr.add_const('EMR_STRETCHDIBITS',0x00000051)
		win_const_mgr.add_const('MF_UNCHECKED',0x00000000)
		win_const_mgr.add_const('HTTP_QUERY_ORIG_URI',0x00000022)
		win_const_mgr.add_const('LINEERR_INVALLINEHANDLE',0x8000002B)
		win_const_mgr.add_const('POLICY_SHOWREASONUI_WORKSTATIONONLY',0x00000002)
		win_const_mgr.add_const('ERROR_PARAMETER_QUOTA_EXCEEDED',0x00000503)
		win_const_mgr.add_const('MAXIMUM_WAIT_OBJECTS',0x00000040)
		win_const_mgr.add_const('BCRYPT_DSA_PARAMETERS_MAGIC',0x00000004)
		win_const_mgr.add_const('MD_APPPOOL_COMMAND_START',0x00000001)
		win_const_mgr.add_const('PD_ENABLEPRINTTEMPLATE',0x00004000)
		win_const_mgr.add_const('SHPPFW_MEDIACHECKONLY',0x00000010)
		win_const_mgr.add_const('PLA_CAPABILITY_V1_SYSTEM',0x00000004)
		win_const_mgr.add_const('WS_EX_TOOLWINDOW',0x00000080)
		win_const_mgr.add_const('TC_SA_CONTIN',0x00000100)
		win_const_mgr.add_const('SSF_AVAILABLE',0x00000002)
		win_const_mgr.add_const('DEBUG_SESSION_END_SESSION_ACTIVE_TERMINATE',0x00000001)
		win_const_mgr.add_const('DNS_QUERY_TREAT_AS_FQDN',0x00001000)
		win_const_mgr.add_const('IDD_LINKPROPS4',0x00000453)
		win_const_mgr.add_const('PF_XMMI64_INSTRUCTIONS_AVAILABLE',0x0000000A)
		win_const_mgr.add_const('NDW_INSTALLFLAG_INSTALLSPECIFIC',0x00002000)
		win_const_mgr.add_const('IDM_MP_EMAILPICTURE',0x000008F0)
		win_const_mgr.add_const('DDCAPS2_DYNAMICTEXTURES',0x20000000)
		win_const_mgr.add_const('FLI_GLYPHS',0x00040000)
		win_const_mgr.add_const('SPDRP_ENUMERATOR_NAME',0x00000016)
		win_const_mgr.add_const('IF_NUMBER',0x00000000)
		win_const_mgr.add_const('PSF_SELECTPASTELINK',0x00000004)
		win_const_mgr.add_const('INTERNET_OPTION_CONNECT_RETRIES',0x00000003)
		win_const_mgr.add_const('SELCERT_PROPERTIES',0x00000064)
		win_const_mgr.add_const('CSIDL_COMMON_PROGRAMS',0x00000000)
		win_const_mgr.add_const('PAN_STRAIGHT_ARMS_DOUBLE_SERIF',0x00000006)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_USER_ENTERED_DOWNLEVEL_SCOPE',0x00000200)
		win_const_mgr.add_const('SQL_MAX_BINARY_LITERAL_LEN',0x00000070)
		win_const_mgr.add_const('URLACTION_ACTIVEX_MAX',0x00000013)
		win_const_mgr.add_const('ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED',0x00001A45)
		win_const_mgr.add_const('IDM_FORM',0x00000885)
		win_const_mgr.add_const('PROTO_IP_NT_STATIC',0x00002716)
		win_const_mgr.add_const('GMEM_VALID_FLAGS',0x00007F72)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_SUBMITTED',0x00000010)
		win_const_mgr.add_const('RPC_BUFFER_COMPLETE',0x00001000)
		win_const_mgr.add_const('ERROR_DS_CANT_ADD_TO_GC',0x00002166)
		win_const_mgr.add_const('ERROR_NOT_DOS_DISK',0x0000001A)
		win_const_mgr.add_const('TXTBIT_PARAFORMATCHANGE',0x00040000)
		win_const_mgr.add_const('MCI_DGV_STEP_FRAMES',0x00020000)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_SAMPLE_ROTATION',0x00000002)
		win_const_mgr.add_const('WLAN_PROFILE_CONNECTION_MODE_SET_BY_CLIENT',0x00010000)
		win_const_mgr.add_const('MFCLOCK_TOLERANCE_UNKNOWN',0x0000C350)
		win_const_mgr.add_const('STYPE_IPC',0x00000003)
		win_const_mgr.add_const('SNMP_BERAPI_SHORT_BUFFER',0x0000000D)
		win_const_mgr.add_const('WOW64_SIZE_OF_80387_REGISTERS',0x00000050)
		win_const_mgr.add_const('LOCALE_USE_CP_ACP',0x40000000)
		win_const_mgr.add_const('FR_PROP_PENDINFOTOKEN',0x00000008)
		win_const_mgr.add_const('CERT_RDN_ISO646_STRING',0x00000009)
		win_const_mgr.add_const('ULW_ALPHA',0x00000002)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_AFFINITY',0x00000010)
		win_const_mgr.add_const('DBG_GPFAULT',0x00000007)
		win_const_mgr.add_const('CMC_STATUS_CONFIRM_REQUIRED',0x00000005)
		win_const_mgr.add_const('MS_MAX_PROFILE_NAME_LENGTH',0x00000100)
		win_const_mgr.add_const('NCRYPT_PERSIST_FLAG',0x80000000)
		win_const_mgr.add_const('DBPROPVAL_OS_RESOURCEPOOLING',0x00000001)
		win_const_mgr.add_const('ERROR_TRANSACTION_REQUIRED_PROMOTION',0x00001AB5)
		win_const_mgr.add_const('PSH_DEFAULT',0x00000000)
		win_const_mgr.add_const('PDH_INVALID_DATASOURCE',0xC0000BDD)
		win_const_mgr.add_const('HDS_FLAT',0x00000200)
		win_const_mgr.add_const('CF_ENHMETAFILE',0x0000000E)
		win_const_mgr.add_const('NDIS_RING_AUTO_REMOVAL_ERROR',0x00000400)
		win_const_mgr.add_const('PDH_MAX_COUNTER_NAME',0x00000400)
		win_const_mgr.add_const('RES_UNUSED_1',0x00000001)
		win_const_mgr.add_const('THREAD_SET_INFORMATION',0x00000020)
		win_const_mgr.add_const('OI_ASYNC',0xFFFFEEEE)
		win_const_mgr.add_const('DF_ALLOWOTHERACCOUNTHOOK',0x00000001)
		win_const_mgr.add_const('SOUND_SYSTEM_STARTUP',0x00000001)
		win_const_mgr.add_const('DISPID_WINDOWSETRESIZABLE',0x00000106)
		win_const_mgr.add_const('SQLNVARCHAR',0x00000000)
		win_const_mgr.add_const('SW_PARENTOPENING',0x00000003)
		win_const_mgr.add_const('RSC_FLAG_DELAYREGISTEROCX',0x00000200)
		win_const_mgr.add_const('MPEG2_PROGRAM_PES_STREAM',0x00000004)
		win_const_mgr.add_const('DS_WRITABLE_FLAG',0x00000100)
		win_const_mgr.add_const('LANG_UKRAINIAN',0x00000022)
		win_const_mgr.add_const('MFSTARTUP_FULL',0x00000000)
		win_const_mgr.add_const('DNS_PORT_HOST_ORDER',0x00000035)
		win_const_mgr.add_const('ICDRAW_HDC',0x00000004)
		win_const_mgr.add_const('DISP_CHANGE_SUCCESSFUL',0x00000000)
		win_const_mgr.add_const('CERT_PROT_ROOT_DISABLE_NOT_DEFINED_NAME_CONSTRAINT_FLAG',0x00000020)
		win_const_mgr.add_const('WM_USER',0x00000400)
		win_const_mgr.add_const('ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH',0x0000215C)
		win_const_mgr.add_const('MDM_BEARERMODE_GSM',0x00000002)
		win_const_mgr.add_const('CERT_STORE_SAVE_AS_PKCS7',0x00000002)
		win_const_mgr.add_const('ERROR_POLICY_ONLY_IN_DS',0x0000201C)
		win_const_mgr.add_const('IPV6_V6ONLY',0x0000001B)
		win_const_mgr.add_const('LB_GETHORIZONTALEXTENT',0x00000193)
		win_const_mgr.add_const('SPMODE_FORMATTEXT',0x00000080)
		win_const_mgr.add_const('IDI_RESOURCE',0x0000009F)
		win_const_mgr.add_const('MDPROPVAL_MC_SINGLECASE',0x00000001)
		win_const_mgr.add_const('KERB_RETRIEVE_TICKET_AS_KERB_CRED',0x00000008)
		win_const_mgr.add_const('MINIDUMP_THREAD_INFO_WRITING_THREAD',0x00000002)
		win_const_mgr.add_const('DNS_RTYPE_NXT',0x00000001)
		win_const_mgr.add_const('SHGNLI_PIDL',0x00000001)
		win_const_mgr.add_const('DISPID_RUNONCEHASSHOWN',0x0000001C)
		win_const_mgr.add_const('ICU_DECODE',0x10000000)
		win_const_mgr.add_const('CB_INSERTSTRING',0x0000014A)
		win_const_mgr.add_const('WIA_IPA_ITEMS_STORED',0x0000101F)
		win_const_mgr.add_const('IF_TYPE_TDLC',0x00000074)
		win_const_mgr.add_const('CONSOLE_FULLSCREEN_MODE',0x00000001)
		win_const_mgr.add_const('STD_HELP',0x0000000B)
		win_const_mgr.add_const('ACCESS_DELETE',0x00000010)
		win_const_mgr.add_const('BLLI_L2_Q922',0x0000000E)
		win_const_mgr.add_const('TXFS_RM_FLAG_SHRINK_LOG',0x00000800)
		win_const_mgr.add_const('ACMFILTERCHOOSE_STYLEF_SHOWHELP',0x00000004)
		win_const_mgr.add_const('ADS_SERVICE_OWN_PROCESS',0x00000010)
		win_const_mgr.add_const('IDC_PS_RESULTIMAGE',0x000001FD)
		win_const_mgr.add_const('CB_SETCURSEL',0x0000014E)
		win_const_mgr.add_const('SQL_ENSURE',0x00000001)
		win_const_mgr.add_const('OPTION_MERIT_DUMP_FILE',0x0000000E)
		win_const_mgr.add_const('LUP_RETURN_COMMENT',0x00000080)
		win_const_mgr.add_const('SUBLANG_UKRAINIAN_UKRAINE',0x00000001)
		win_const_mgr.add_const('TMT_BACKGROUND',0x00000642)
		win_const_mgr.add_const('WM_IME_COMPOSITION',0x0000010F)
		win_const_mgr.add_const('PBS_SMOOTH',0x00000001)
		win_const_mgr.add_const('SQL_FETCH_RELATIVE',0x00000006)
		win_const_mgr.add_const('MOUSEEVENTF_MOVE_NOCOALESCE',0x00002000)
		win_const_mgr.add_const('IPPROTO_PUP',0x0000000C)
		win_const_mgr.add_const('ASP_MD_ID_END_RESERVED',0x00000074)
		win_const_mgr.add_const('ERROR_SUCCESS_RESTART_REQUIRED',0x00000BC3)
		win_const_mgr.add_const('PO_RENAME',0x00000014)
		win_const_mgr.add_const('INV_REQ_HANDLE',0x00000003)
		win_const_mgr.add_const('ERROR_DLL_MIGHT_BE_INCOMPATIBLE',0x000002AF)
		win_const_mgr.add_const('VER_BUILDNUMBER',0x00000004)
		win_const_mgr.add_const('EV_RLSD',0x00000020)
		win_const_mgr.add_const('LANG_SWEDISH',0x00000001)
		win_const_mgr.add_const('ERROR_ALREADY_FIBER',0x00000500)
		win_const_mgr.add_const('SQL_FN_TD_HOUR',0x00000400)
		win_const_mgr.add_const('FD_SETSIZE',0x00000040)
		win_const_mgr.add_const('GCP_DBCS',0x00000001)
		win_const_mgr.add_const('IDM_PRINT',0x0000001B)
		win_const_mgr.add_const('IDC_UL_STOP',0x00000406)
		win_const_mgr.add_const('SHARE_CURRENT_USES_PARMNUM',0x00000007)
		win_const_mgr.add_const('DEBUG_ATTACH_INVASIVE_RESUME_PROCESS',0x00000010)
		win_const_mgr.add_const('PVD_CONFIG',0x00003001)
		win_const_mgr.add_const('RBS_REGISTERDROP',0x00001000)
		win_const_mgr.add_const('CQFF_NOGLOBALPAGES',0x00000001)
		win_const_mgr.add_const('IMPLINK_IP',0x0000009B)
		win_const_mgr.add_const('TRUSTERROR_STEP_MSG_COUNTERSIGCERT',0x00000011)
		win_const_mgr.add_const('CTRY_KUWAIT',0x000003C5)
		win_const_mgr.add_const('PAN_STRAIGHT_ARMS_WEDGE',0x00000003)
		win_const_mgr.add_const('ISMEX_NOSEND',0x00000000)
		win_const_mgr.add_const('DMBIN_MANUAL',0x00000004)
		win_const_mgr.add_const('SECPKG_ATTR_AUTHENTICATION_ID',0x00000014)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_203',0x801900CB)
		win_const_mgr.add_const('CRSWPP_SECURITY_PACKAGE_NOT_FOUND',0xC0042204)
		win_const_mgr.add_const('WMS_STREAM_PREROLL',0x00000006)
		win_const_mgr.add_const('SQL_MAX_CHAR_LITERAL_LEN',0x0000006C)
		win_const_mgr.add_const('FACILITY_RPC_RUNTIME',0x00000002)
		win_const_mgr.add_const('SW_SHOWMINNOACTIVE',0x00000007)
		win_const_mgr.add_const('PLAL_ALERT_CMD_LINE_C_NAME',0x00000400)
		win_const_mgr.add_const('RIDEV_CAPTUREMOUSE',0x00000200)
		win_const_mgr.add_const('LINECALLSTATE_DIALING',0x00000010)
		win_const_mgr.add_const('EAP_E_SERVER_LAST',0x804202FF)
		win_const_mgr.add_const('ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE',0x00001AB2)
		win_const_mgr.add_const('CAUSE_VPI_VCI_UNAVAILABLE',0x00000023)
		win_const_mgr.add_const('DDCKEY_DESTOVERLAY',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_PPC_REL14',0x00000007)
		win_const_mgr.add_const('SYNCH_DATA_STORE_MESSAGES',0x00000006)
		win_const_mgr.add_const('INTERNET_MAX_SCHEME_LENGTH',0x00000020)
		win_const_mgr.add_const('WHDR_PREPARED',0x00000002)
		win_const_mgr.add_const('BSF_TRUSTEDFORACTIVEX',0x00020000)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_10',0x00000000)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_11',0x00000000)
		win_const_mgr.add_const('DXGI_USAGE_READ_ONLY',0x00000001)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_BYTES_XMIT',0x00000200)
		win_const_mgr.add_const('PHONEERR_INVALRINGMODE',0x90000017)
		win_const_mgr.add_const('SLE_ERROR',0x00000001)
		win_const_mgr.add_const('AUTH_REQ_OK_AS_DELEGATE',0x00000100)
		win_const_mgr.add_const('DOT11_MIN_PDU_SIZE',0x00000100)
		win_const_mgr.add_const('LCMAP_TRADITIONAL_CHINESE',0x04000000)
		win_const_mgr.add_const('INTERNET_KEEP_ALIVE_DISABLED',0x00000000)
		win_const_mgr.add_const('LINEDEVSTATE_SIGNAL',0x00010000)
		win_const_mgr.add_const('DISPID_BEFORENAVIGATE',0x00000064)
		win_const_mgr.add_const('SP_COPY_NEWER_ONLY',0x00010000)
		win_const_mgr.add_const('D3DPRESENT_LINEAR_CONTENT',0x00000002)
		win_const_mgr.add_const('SFVM_ADDOBJECT',0x00000003)
		win_const_mgr.add_const('CDO_E_ARGUMENT3',0x80044002)
		win_const_mgr.add_const('TC_OP_CHARACTER',0x00000001)
		win_const_mgr.add_const('NDIS_MAC_OPTION_COPY_LOOKAHEAD_DATA',0x00000001)
		win_const_mgr.add_const('DDSCAPS_ZBUFFER',0x00020000)
		win_const_mgr.add_const('REG_NO_COMPRESSION',0x00000004)
		win_const_mgr.add_const('DE_E_RESOURCE_NOT_FOUND',0x800C0005)
		win_const_mgr.add_const('LUP_NEAREST',0x00000008)
		win_const_mgr.add_const('IDM_CHANGEFONTSIZE',0x000008C1)
		win_const_mgr.add_const('TAPE_TENSION',0x00000002)
		win_const_mgr.add_const('SQL_ASYNC_ENABLE_ON',0x00000001)
		win_const_mgr.add_const('MF_BOOT_DRIVER_VERIFICATION_FAILED',0x00100000)
		win_const_mgr.add_const('USN_REASON_RENAME_OLD_NAME',0x00001000)
		win_const_mgr.add_const('INTERNET_CACHE_GROUP_ADD',0x00000000)
		win_const_mgr.add_const('IME_CMODE_NATIVE',0x00000001)
		win_const_mgr.add_const('WINHTTP_OPTION_ENABLE_FEATURE',0x0000004F)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_DATATYPE',0x0000000B)
		win_const_mgr.add_const('DE_E_INVALID_URL',0x800C0002)
		win_const_mgr.add_const('ADDURL_SILENT',0x00000000)
		win_const_mgr.add_const('IF_TYPE_SHDSL',0x000000A9)
		win_const_mgr.add_const('END_NESTED_SYSTEM_CHANGE',0x00000067)
		win_const_mgr.add_const('IDS_CAP_INFO',0x00000191)
		win_const_mgr.add_const('PDH_DATA_SOURCE_IS_REAL_TIME',0xC0000BCF)
		win_const_mgr.add_const('ERROR_LOG_PINNED',0x000019F4)
		win_const_mgr.add_const('SYMOPT_NO_IMAGE_SEARCH',0x00020000)
		win_const_mgr.add_const('VFT2_DRV_LANGUAGE',0x00000003)
		win_const_mgr.add_const('IMAGE_REL_M32R_SECTION',0x0000000C)
		win_const_mgr.add_const('DEBUG_ECREATE_PROCESS_DEFAULT',0x00000000)
		win_const_mgr.add_const('FWPM_TXN_READ_ONLY',0x00000001)
		win_const_mgr.add_const('TRUETYPE_FONTTYPE',0x00000004)
		win_const_mgr.add_const('NIIF_NDIS_RESERVED1',0x00000004)
		win_const_mgr.add_const('LINECALLSTATE_ACCEPTED',0x00000004)
		win_const_mgr.add_const('NIIF_NDIS_RESERVED3',0x00000010)
		win_const_mgr.add_const('NIIF_NDIS_RESERVED2',0x00000008)
		win_const_mgr.add_const('LINEFORWARDMODE_UNKNOWN',0x00010000)
		win_const_mgr.add_const('DBT_DEVICETYPESPECIFIC',0x00008005)
		win_const_mgr.add_const('ADS_PRINTER_OUTPUT_BIN_FULL',0x00000800)
		win_const_mgr.add_const('WLX_PROFILE_TYPE_V1_0',0x00000001)
		win_const_mgr.add_const('USER_HOME_DIR_DRIVE_PARMNUM',0x00000035)
		win_const_mgr.add_const('ERROR_DS_ROOT_CANT_BE_SUBREF',0x00002086)
		win_const_mgr.add_const('SQL_CVT_TIMESTAMP',0x00020000)
		win_const_mgr.add_const('LVSICF_NOSCROLL',0x00000002)
		win_const_mgr.add_const('DESKTOP_ENUMERATE',0x00000040)
		win_const_mgr.add_const('OPTION_ALL_SUBNETS_MTU',0x0000001B)
		win_const_mgr.add_const('IMAGE_REL_BASED_DIR64',0x0000000A)
		win_const_mgr.add_const('SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFO',0x00000006)
		win_const_mgr.add_const('ENABLEDUPLEX',0x0000001C)
		win_const_mgr.add_const('RPC_C_MQ_PERMANENT',0x00000001)
		win_const_mgr.add_const('VK_ACCEPT',0x0000001E)
		win_const_mgr.add_const('SV_CACHEDDIRECTORYLIMIT_PARMNUM',0x0000024B)
		win_const_mgr.add_const('OS_DOMAINMEMBER',0x0000001C)
		win_const_mgr.add_const('WMS_STREAM_CONCEALED_FLAG',0x00000004)
		win_const_mgr.add_const('SEE_MASK_INVOKEIDLIST',0x00000000)
		win_const_mgr.add_const('STATE_SYSTEM_DEFAULT',0x00000100)
		win_const_mgr.add_const('DOT11_SERVICE_CLASS_STRICTLY_ORDERED',0x00000001)
		win_const_mgr.add_const('X3_I_SIZE_X',0x00000001)
		win_const_mgr.add_const('DISPID_ONREADYSTATECHANGE',0x00000010)
		win_const_mgr.add_const('FIND_RET',0x0000F000)
		win_const_mgr.add_const('CLRDTR',0x00000006)
		win_const_mgr.add_const('RSVP_SHARED_EXPLICIT_STYLE',0x00000003)
		win_const_mgr.add_const('WNODE_FLAG_LOG_WNODE',0x00040000)
		win_const_mgr.add_const('DSBI_NOLINES',0x00000002)
		win_const_mgr.add_const('MCW_VERTICAL',0x00000008)
		win_const_mgr.add_const('OS_XPORGREATER',0x00000012)
		win_const_mgr.add_const('LINEERR_INVALDEVICECLASS',0x80000023)
		win_const_mgr.add_const('TRUSTERROR_STEP_MSG_INNERCNTTYPE',0x0000000A)
		win_const_mgr.add_const('PIDASI_STREAM_NUMBER',0x00000008)
		win_const_mgr.add_const('CONNDLG_PERSIST',0x00000010)
		win_const_mgr.add_const('DDCAPS_ALIGNBOUNDARYSRC',0x00000008)
		win_const_mgr.add_const('CIF_SELECTFROMFILE',0x00000008)
		win_const_mgr.add_const('ERROR_DS_NO_PARENT_OBJECT',0x00002089)
		win_const_mgr.add_const('WM_MDIDESTROY',0x00000221)
		win_const_mgr.add_const('CPL_SELECT',0x00000004)
		win_const_mgr.add_const('CERT_INFO_EXTENSION_FLAG',0x0000000B)
		win_const_mgr.add_const('SQLAOPVAR',0x00000032)
		win_const_mgr.add_const('SHPPFW_IGNOREFILENAME',0x00000004)
		win_const_mgr.add_const('SE_GROUP_INTEGRITY_ENABLED',0x00000040)
		win_const_mgr.add_const('LDAP_FILTER_SUBSTRINGS',0x00000000)
		win_const_mgr.add_const('ERROR_PAGE_FAULT_TRANSITION',0x000002EB)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_DISABLE_FLUSH',0xFFFFFFFF)
		win_const_mgr.add_const('HEAP_DISABLE_COALESCE_ON_FREE',0x00000080)
		win_const_mgr.add_const('CTRY_AUSTRIA',0x0000002B)
		win_const_mgr.add_const('BIND_NO_UPDATE',0x00000002)
		win_const_mgr.add_const('CMSG_ENCRYPT_PARAM',0x0000001A)
		win_const_mgr.add_const('D3D10_SHADER_ENABLE_STRICTNESS',0x00000001)
		win_const_mgr.add_const('PP_SIGNATURE_PIN',0x00000021)
		win_const_mgr.add_const('CERT_LAST_RESERVED_PROP_ID',0x00007FFF)
		win_const_mgr.add_const('SKF_RCTLLATCHED',0x08000000)
		win_const_mgr.add_const('IME_SETCONVERSIONFONTEX',0x00000019)
		win_const_mgr.add_const('SO_OPENTYPE',0x00007008)
		win_const_mgr.add_const('DVASPECT_COPY',0x00000003)
		win_const_mgr.add_const('MCI_NOTIFY_SUCCESSFUL',0x00000001)
		win_const_mgr.add_const('IDS_CAP_SETFILESIZE',0x000001A0)
		win_const_mgr.add_const('COLOR_BTNHIGHLIGHT',0x00000014)
		win_const_mgr.add_const('ERROR_CLEANER_CARTRIDGE_SPENT',0x000010ED)
		win_const_mgr.add_const('BLLI_L3_MODE_NORMAL',0x00000040)
		win_const_mgr.add_const('GESTURE_SQUARE',0x00000000)
		win_const_mgr.add_const('HEAP_CREATE_ENABLE_TRACING',0x00020000)
		win_const_mgr.add_const('LANG_YAKUT',0x00000085)
		win_const_mgr.add_const('DNOBJECT_DTERM',0x00000017)
		win_const_mgr.add_const('OID_ENCODING',0x0000000B)
		win_const_mgr.add_const('IDM_TRIED_OUTDENT',0x00000030)
		win_const_mgr.add_const('CR_NO_CM_SERVICES',0x00000032)
		win_const_mgr.add_const('OS_TERMINALSERVER',0x00000018)
		win_const_mgr.add_const('MCI_STATUS_READY',0x00000007)
		win_const_mgr.add_const('MM_MSFT_ACM_WMAUDIO',0x00000027)
		win_const_mgr.add_const('ISSP_MODE',0x00000001)
		win_const_mgr.add_const('SB_LINEUP',0x00000000)
		win_const_mgr.add_const('LVCF_IDEALWIDTH',0x00000100)
		win_const_mgr.add_const('STI_VERSION_FLAG_UNICODE',0x01000000)
		win_const_mgr.add_const('MD_ERROR_SUB401_LOGON',0x00000001)
		win_const_mgr.add_const('OID_IRDA_RESERVED2',0x0A01020F)
		win_const_mgr.add_const('ILDRF_OVERLAYLOWQUALITY',0x00000010)
		win_const_mgr.add_const('RPC_S_PROTSEQ_NOT_SUPPORTED',0x000006A7)
		win_const_mgr.add_const('PORT_NETSCDEV',0x0000009B)
		win_const_mgr.add_const('PD_HIDEPRINTTOFILE',0x00100000)
		win_const_mgr.add_const('ERROR_INVALID_EDIT_HEIGHT',0x00000590)
		win_const_mgr.add_const('KSPROBE_STREAMWRITE',0x00000001)
		win_const_mgr.add_const('FR_DOWN',0x00000001)
		win_const_mgr.add_const('IMF_FORCEACTIVE',0x00000040)
		win_const_mgr.add_const('RTM_CHANGE_TYPE_BEST',0x00000002)
		win_const_mgr.add_const('SQL_FN_NUM_RADIANS',0x00200000)
		win_const_mgr.add_const('WIA_DPS_PAD_COLOR',0x00000C0A)
		win_const_mgr.add_const('LINEROAMMODE_HOME',0x00000004)
		win_const_mgr.add_const('FAX_ERR_GROUP_IN_USE',0x00001B5C)
		win_const_mgr.add_const('NUM_SSRVOPTS',0x0000001E)
		win_const_mgr.add_const('SW_OTHERUNZOOM',0x00000004)
		win_const_mgr.add_const('SPI_GETCARETWIDTH',0x00002006)
		win_const_mgr.add_const('MD_BACKUP_MAX_LEN',0x00000064)
		win_const_mgr.add_const('RGN_OR',0x00000002)
		win_const_mgr.add_const('ISC_SHOWUIGUIDELINE',0x40000000)
		win_const_mgr.add_const('CORDLESS_EXTERNAL_NETWORK_ANALOG_CELLULAR',0x00000005)
		win_const_mgr.add_const('ATADDRESSLEN',0x00000020)
		win_const_mgr.add_const('DBPROPVAL_TR_COMMIT_NO',0x00000004)
		win_const_mgr.add_const('ERROR_INVALID_REPARSE_DATA',0x00001128)
		win_const_mgr.add_const('NCBUNLINK',0x00000070)
		win_const_mgr.add_const('ERROR_GENERIC_NOT_MAPPED',0x00000550)
		win_const_mgr.add_const('ERROR_RESOURCE_REQUIREMENTS_CHANGED',0x000002F4)
		win_const_mgr.add_const('CERT_VALIDITY_KEY_USAGE_EXT_FAILURE',0x00000010)
		win_const_mgr.add_const('DBPROPVAL_DF_INITIALLY_DEFERRED',0x00000001)
		win_const_mgr.add_const('HTTP_QUERY_HOST',0x00000037)
		win_const_mgr.add_const('PAGE_WRITECOPY',0x00000008)
		win_const_mgr.add_const('SNMPAPI_TL_SRC_INVALID',0x00000069)
		win_const_mgr.add_const('MCI_DEVTYPE_SEQUENCER',0x0000020B)
		win_const_mgr.add_const('TAPIMEDIATYPE_VIDEO',0x00008000)
		win_const_mgr.add_const('SVSI_SELECTIONMARK',0x00000040)
		win_const_mgr.add_const('IPX_INTERFACE_TABLE',0x00000001)
		win_const_mgr.add_const('DNS_TYPE_UNSPEC',0x00000067)
		win_const_mgr.add_const('SO_DISCDATA',0x00007002)
		win_const_mgr.add_const('DISPID_COUNTVIEWTYPES',0x00000016)
		win_const_mgr.add_const('UNITS_PER_DAY',0x00000018)
		win_const_mgr.add_const('ERROR_CANT_ACCESS_DOMAIN_INFO',0x00000547)
		win_const_mgr.add_const('CERT_STORE_CTL_CONTEXT',0x00000003)
		win_const_mgr.add_const('CERT_TRUST_CTL_IS_NOT_VALID_FOR_USAGE',0x00080000)
		win_const_mgr.add_const('WM_LBUTTONDBLCLK',0x00000203)
		win_const_mgr.add_const('HTTP_QUERY_ACCEPT_CHARSET',0x00000019)
		win_const_mgr.add_const('TMT_DISKSTREAM',0x000000D5)
		win_const_mgr.add_const('WSAEINPROGRESS',0x00002734)
		win_const_mgr.add_const('ERROR_PROFILE_NOT_FOUND',0x000007E0)
		win_const_mgr.add_const('RTL_CRITSECT_TYPE',0x00000000)
		win_const_mgr.add_const('SHADOW_IRQL_IMPLEMENTATION',0x00000001)
		win_const_mgr.add_const('CCS_NORESIZE',0x00000004)
		win_const_mgr.add_const('ERROR_DS_INAPPROPRIATE_MATCHING',0x0000202E)
		win_const_mgr.add_const('MFASYNC_CALLBACK_QUEUE_ALL',0xFFFFFFFF)
		win_const_mgr.add_const('RESOURCEUSAGE_RESERVED',0x80000000)
		win_const_mgr.add_const('OPTION_BOOT_FILE_SIZE',0x0000000D)
		win_const_mgr.add_const('SEE_MASK_FLAG_NO_UI',0x00000400)
		win_const_mgr.add_const('PS_COMPONENT_DRRSEQ',0x00000005)
		win_const_mgr.add_const('LB_GETITEMRECT',0x00000198)
		win_const_mgr.add_const('MCI_AVI_STATUS_LAST_PLAY_SPEED',0x00008002)
		win_const_mgr.add_const('WSB_PROP_CYVTHUMB',0x00000020)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_INLINE_REFLONG',0x00000009)
		win_const_mgr.add_const('AD_CLOCKWISE',0x00000002)
		win_const_mgr.add_const('DMPAPER_STATEMENT',0x00000006)
		win_const_mgr.add_const('ERROR_INVALID_HANDLE_STATE',0x00000649)
		win_const_mgr.add_const('WIA_INTENT_IMAGE_TYPE_MASK',0x0000000F)
		win_const_mgr.add_const('C3_LOWSURROGATE',0x00001000)
		win_const_mgr.add_const('SV_TYPE_BACKUP_BROWSER',0x00020000)
		win_const_mgr.add_const('OID_GEN_NDIS_RESERVED_4',0x0001020B)
		win_const_mgr.add_const('TTF_RTLREADING',0x00000004)
		win_const_mgr.add_const('DS_BEHAVIOR_LONGHORN',0x00000003)
		win_const_mgr.add_const('WIA_DPS_ENDORSER_STRING',0x00000C15)
		win_const_mgr.add_const('WIZ_BODYCX',0x000000B8)
		win_const_mgr.add_const('PFN_BULLET',0x00000001)
		win_const_mgr.add_const('PFM_SPACEAFTER',0x00000080)
		win_const_mgr.add_const('SO_CONDITIONAL_ACCEPT',0x00003002)
		win_const_mgr.add_const('ADO_VERSION',0x00000006)
		win_const_mgr.add_const('INTERNET_PER_CONN_PROXY_BYPASS',0x00000003)
		win_const_mgr.add_const('DEBUG_TYPEOPTS_UNICODE_DISPLAY',0x00000001)
		win_const_mgr.add_const('MAXINTATOM',0x0000C000)
		win_const_mgr.add_const('ERROR_EVT_PUBLISHER_DISABLED',0x00003ABD)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_PER_HANDLE_OPERATIONS',0x00000009)
		win_const_mgr.add_const('DI_NOBROWSE',0x00000200)
		win_const_mgr.add_const('DI_NORMAL',0x00000003)
		win_const_mgr.add_const('SQL_MAX_NUMERIC_LEN',0x00000010)
		win_const_mgr.add_const('SQL_ALL_EXCEPT_LIKE',0x00000002)
		win_const_mgr.add_const('MSV1_0_MAX_NTLM3_LIFE',0x0001FA40)
		win_const_mgr.add_const('SQL_FC_OFF',0x00000000)
		win_const_mgr.add_const('VIF_FILEINUSE',0x00000080)
		win_const_mgr.add_const('TAPE_DRIVE_ECC',0x00010000)
		win_const_mgr.add_const('ERROR_DS_DRA_REF_NOT_FOUND',0x00002101)
		win_const_mgr.add_const('TMT_HEADING1TEXTCOLOR',0x00000EF1)
		win_const_mgr.add_const('CONNECT_REDIRECT',0x00000080)
		win_const_mgr.add_const('SCH_CRED_IGNORE_REVOCATION_OFFLINE',0x00001000)
		win_const_mgr.add_const('DNS_RCLASS_NONE',0x00000000)
		win_const_mgr.add_const('UF_INTERDOMAIN_TRUST_ACCOUNT',0x00000800)
		win_const_mgr.add_const('EXECUTE_FLAG_SAME_URL',0x00000010)
		win_const_mgr.add_const('EAP_E_USER_CERT_OTHER_ERROR',0x80420104)
		win_const_mgr.add_const('ERROR_CLUSTER_MEMBERSHIP_HALT',0x00001704)
		win_const_mgr.add_const('MAX_ISCSI_PORTAL_NAME_LEN',0x00000100)
		win_const_mgr.add_const('LINEMEDIAMODE_TELEX',0x00000800)
		win_const_mgr.add_const('RP_RECIP_FLAGS_RESERVED',0x0000000F)
		win_const_mgr.add_const('PERFSTATE_POLICY_CHANGE_ROCKET',0x00000002)
		win_const_mgr.add_const('MD_LOGCUSTOM_DATATYPE_LPWSTR',0x00000007)
		win_const_mgr.add_const('KSPRIORITY_HIGH',0x80000000)
		win_const_mgr.add_const('EC_VIDEO_SIZE_CHANGED',0x0000000A)
		win_const_mgr.add_const('ISR_NI',0x00000027)
		win_const_mgr.add_const('VP_TV_STANDARD_PAL_M',0x00000040)
		win_const_mgr.add_const('CRYPT_INSTALL_OID_FUNC_BEFORE_FLAG',0x00000001)
		win_const_mgr.add_const('IPPORT_WHOIS',0x0000002B)
		win_const_mgr.add_const('ERROR_INVALID_MONITOR_HANDLE',0x000005B5)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_NEXTWRITABLEADDRESS',0x0000010A)
		win_const_mgr.add_const('ABM_SETAUTOHIDEBAR',0x00000008)
		win_const_mgr.add_const('STN_DBLCLK',0x00000001)
		win_const_mgr.add_const('IDM_MIMECSET__FIRST__',0x00000E19)
		win_const_mgr.add_const('PATCH_OPTION_USE_LZX_LARGE',0x00000004)
		win_const_mgr.add_const('MS_RING_ON',0x00000040)
		win_const_mgr.add_const('MAPI_LOGON_UI',0x00000001)
		win_const_mgr.add_const('DLG_FLAGS_SEC_CERT_DATE_INVALID',0x04000000)
		win_const_mgr.add_const('DMPAPER_TABLOID_EXTRA',0x00000034)
		win_const_mgr.add_const('RBBIM_CHEVRONSTATE',0x00002000)
		win_const_mgr.add_const('ISOPROTO_X25',0x00000020)
		win_const_mgr.add_const('SPI_SETHIGHCONTRAST',0x00000043)
		win_const_mgr.add_const('CRL_REASON_CESSATION_OF_OPERATION_FLAG',0x00000004)
		win_const_mgr.add_const('CM_PROB_NEED_RESTART',0x0000000E)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_DESCRIPTION',0x00000004)
		win_const_mgr.add_const('GETSETPAPERMETRICS',0x00000023)
		win_const_mgr.add_const('ALERT_SYSTEM_QUERY',0x00000004)
		win_const_mgr.add_const('MD_APPPOOL_IDENTITY_TYPE_LOCALSERVICE',0x00000001)
		win_const_mgr.add_const('HHWIN_BUTTON_CONTENTS',0x00000001)
		win_const_mgr.add_const('KERN_CONTEXT_CERT_INFO_V1',0x00000000)
		win_const_mgr.add_const('DI_FLAGSEX_ALTPLATFORM_DRVSEARCH',0x10000000)
		win_const_mgr.add_const('STATE_SYSTEM_EXTSELECTABLE',0x02000000)
		win_const_mgr.add_const('LINEDEVSTATE_TRANSLATECHANGE',0x00400000)
		win_const_mgr.add_const('MCI_DGV_STATUS_SIZE',0x00004010)
		win_const_mgr.add_const('DDSCL_SETDEVICEWINDOW',0x00000100)
		win_const_mgr.add_const('SQL_UP_ON',0x00000001)
		win_const_mgr.add_const('CONFIGFLAG_NET_BOOT',0x00000010)
		win_const_mgr.add_const('LVS_NOCOLUMNHEADER',0x00004000)
		win_const_mgr.add_const('SCRIPT_DIGITSUBSTITUTE_NONE',0x00000001)
		win_const_mgr.add_const('DEBUG_KNOWN_STRUCT_SUPPRESS_TYPE_NAME',0x00000003)
		win_const_mgr.add_const('ERROR_TRANSLATION_COMPLETE',0x000002F5)
		win_const_mgr.add_const('OID_802_5_CURRENT_FUNCTIONAL',0x02010103)
		win_const_mgr.add_const('DEBUG_TBINFO_AFFINITY',0x00000020)
		win_const_mgr.add_const('CS_BYTEALIGNCLIENT',0x00001000)
		win_const_mgr.add_const('WIA_DIP_HW_CONFIG',0x0000000B)
		win_const_mgr.add_const('STM_SETIMAGE',0x00000172)
		win_const_mgr.add_const('ERROR_REPARSE_TAG_INVALID',0x00001129)
		win_const_mgr.add_const('MFT_STREAMS_UNLIMITED',0xFFFFFFFF)
		win_const_mgr.add_const('CGD_STRING_PROPERTY',0x00000001)
		win_const_mgr.add_const('PST_PC_ROAMABLE',0x00000020)
		win_const_mgr.add_const('DEBUG_SRCFILE_SYMBOL_TOKEN_SOURCE_COMMAND_WIDE',0x00000001)
		win_const_mgr.add_const('HHT_NOWHERE',0x00000001)
		win_const_mgr.add_const('IF_ENABLEEXITKEYRETRIEVAL',0x00000800)
		win_const_mgr.add_const('PANE_NAVIGATION',0x00000005)
		win_const_mgr.add_const('MUI_FILETYPE_LANGUAGE_NEUTRAL_MAIN',0x00000002)
		win_const_mgr.add_const('ALPHA_SHIFT',0x00000018)
		win_const_mgr.add_const('IDM_CELLSPLIT',0x0000089D)
		win_const_mgr.add_const('SQL_AD_ADD_CONSTRAINT_INITIALLY_IMMEDIATE',0x00000040)
		win_const_mgr.add_const('BTH_MFG_ZEEVO',0x00000012)
		win_const_mgr.add_const('CERT_RDN_UNICODE_STRING',0x0000000C)
		win_const_mgr.add_const('TBMF_PAD',0x00000001)
		win_const_mgr.add_const('WINHTTP_OPTION_HANDLE_TYPE',0x00000009)
		win_const_mgr.add_const('WINHTTP_OPTION_REDIRECT_POLICY',0x00000058)
		win_const_mgr.add_const('STARTF_USESTDHANDLES',0x00000100)
		win_const_mgr.add_const('SQL_CONVERT_LONGVARCHAR',0x0000003E)
		win_const_mgr.add_const('CTRY_UNITED_KINGDOM',0x0000002C)
		win_const_mgr.add_const('WM_CONVERTREQUEST',0x0000010A)
		win_const_mgr.add_const('WH_MAX',0x0000000B)
		win_const_mgr.add_const('LINEERR_INVALTRANSFERMODE',0x8000003F)
		win_const_mgr.add_const('DEF_PWUNIQUENESS',0x00000005)
		win_const_mgr.add_const('IRLMP_ENUMDEVICES',0x00000010)
		win_const_mgr.add_const('SPI_SETDOUBLECLICKTIME',0x00000020)
		win_const_mgr.add_const('AF_TCNMESSAGE',0x0000001E)
		win_const_mgr.add_const('DISPID_RETREATERROR',0x0000000B)
		win_const_mgr.add_const('FLG_DELREG_OPERATION_MASK',0x000000FE)
		win_const_mgr.add_const('PHONEBUTTONSTATE_DOWN',0x00000002)
		win_const_mgr.add_const('PAN_XHEIGHT_DUCKING_LARGE',0x00000007)
		win_const_mgr.add_const('GESTURE_DOUBLE_CURLICUE',0x00000000)
		win_const_mgr.add_const('LANG_GUJARATI',0x00000047)
		win_const_mgr.add_const('OBM_RGARROWI',0x00007FDF)
		win_const_mgr.add_const('IDM_ZOOMPERCENT',0x00000032)
		win_const_mgr.add_const('META_SETRELABS',0x00000105)
		win_const_mgr.add_const('LANG_MARATHI',0x00000004)
		win_const_mgr.add_const('STREAM_FORMAT_WIN32_MODULE',0x00000002)
		win_const_mgr.add_const('SECURITY_RESTRICTED_CODE_RID',0x0000000C)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_CSWITCH',0x00000010)
		win_const_mgr.add_const('DEBUG_BREAKPOINT_ADDER_ONLY',0x00000008)
		win_const_mgr.add_const('NDR_CONTEXT_HANDLE_NOSERIALIZE',0x00000004)
		win_const_mgr.add_const('RF_STROKEREORDER',0x00002000)
		win_const_mgr.add_const('ICM_SET_MODE',0x00000001)
		win_const_mgr.add_const('DTS_LONGDATEFORMAT',0x00000004)
		win_const_mgr.add_const('IDM_1D',0x0000087A)
		win_const_mgr.add_const('FTP_TRANSFER_TYPE_ASCII',0x00000001)
		win_const_mgr.add_const('DEBUG_VALUE_INT16',0x00000002)
		win_const_mgr.add_const('SSA_NOKASHIDA',0x80000000)
		win_const_mgr.add_const('OFN_NODEREFERENCELINKS',0x00100000)
		win_const_mgr.add_const('IDD_ACMFILTERCHOOSE_BTN_DELNAME',0x00000068)
		win_const_mgr.add_const('L2CAP_MIN_MTU',0x00000030)
		win_const_mgr.add_const('IME_MODE_NOCODEINPUT',0x00000100)
		win_const_mgr.add_const('SOCK_RDM',0x00000004)
		win_const_mgr.add_const('FILE_DEVICE_TAPE',0x00000001)
		win_const_mgr.add_const('IPSEC_POLICY_FLAG_ND_BOUNDARY',0x00000004)
		win_const_mgr.add_const('OID_WAN_PROTOCOL_TYPE',0x04010104)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_HANDLES',0x00000001)
		win_const_mgr.add_const('MOUSEEVENTF_MOVE',0x00000001)
		win_const_mgr.add_const('SFC_DISABLE_SETUP',0x00000003)
		win_const_mgr.add_const('SPFILENOTIFY_QUEUESCAN_SIGNERINFO',0x00000040)
		win_const_mgr.add_const('WAVE_FORMAT_44S08',0x00000200)
		win_const_mgr.add_const('INTERNET_OPTION_DETECT_POST_SEND',0x00000047)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_IHV_START',0x80000000)
		win_const_mgr.add_const('FILE_TYPE_PIPE',0x00000003)
		win_const_mgr.add_const('OPTION_NETWORK_INFO_SERVERS',0x00000029)
		win_const_mgr.add_const('EAP_E_SERVER_ROOT_CERT_NAME_REQUIRED',0x80420406)
		win_const_mgr.add_const('DBT_DEVTYP_OEM',0x00000000)
		win_const_mgr.add_const('D3DPRESENTFLAG_LOCKABLE_BACKBUFFER',0x00000001)
		win_const_mgr.add_const('WSA_QOS_EUNKOWNPSOBJ',0x00002B10)
		win_const_mgr.add_const('FILE_DEVICE_MOUSE',0x00000000)
		win_const_mgr.add_const('TH32CS_INHERIT',0x80000000)
		win_const_mgr.add_const('OBM_OLD_UPARROW',0x00007FFD)
		win_const_mgr.add_const('IMAGE_SCN_LNK_NRELOC_OVFL',0x01000000)
		win_const_mgr.add_const('SQL_RESET_YES',0x00000001)
		win_const_mgr.add_const('DS_GFTI_UPDATE_TDO',0x00000001)
		win_const_mgr.add_const('IMN_SETOPENSTATUS',0x00000008)
		win_const_mgr.add_const('DA_LAST',0x7FFFFFFF)
		win_const_mgr.add_const('ACM_METRIC_COUNT_LOCAL_CONVERTERS',0x00000016)
		win_const_mgr.add_const('MCI_SET',0x0000080D)
		win_const_mgr.add_const('SPI_SETDESKPATTERN',0x00000015)
		win_const_mgr.add_const('WINTRUST_MAX_HASH_BYTES_TO_MAP_DEFAULT',0x00100000)
		win_const_mgr.add_const('ISO_GLOBAL',0x00000001)
		win_const_mgr.add_const('WHDR_ENDLOOP',0x00000008)
		win_const_mgr.add_const('DSF_WIA_CAMERAS',0x00000002)
		win_const_mgr.add_const('COD_PERIPHERAL_MINOR_POINTER_MASK',0x00000020)
		win_const_mgr.add_const('LM20_DEVLEN',0x00000008)
		win_const_mgr.add_const('VK_OEM_FJ_LOYA',0x00000095)
		win_const_mgr.add_const('POLICY_VIEW_AUDIT_INFORMATION',0x00000002)
		win_const_mgr.add_const('R2_MERGEPENNOT',0x0000000E)
		win_const_mgr.add_const('ERROR_USER_EXISTS',0x00000524)
		win_const_mgr.add_const('WLX_PROFILE_TYPE_V2_0',0x00000002)
		win_const_mgr.add_const('SFVM_QUERYFSNOTIFY',0x00000019)
		win_const_mgr.add_const('SPFILELOG_QUERYONLY',0x00000004)
		win_const_mgr.add_const('OID_GEN_MAXIMUM_FRAME_SIZE',0x00010106)
		win_const_mgr.add_const('VIEW_LIST',0x00000002)
		win_const_mgr.add_const('DEBUG_CDS_REGISTERS',0x00000001)
		win_const_mgr.add_const('SFVM_COLUMNCLICK',0x00000018)
		win_const_mgr.add_const('SQLINT2',0x00000034)
		win_const_mgr.add_const('IMAGE_COMDAT_SELECT_ASSOCIATIVE',0x00000005)
		win_const_mgr.add_const('SERVICE_UNINSTALLABLE',0x00000010)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAOEVENTARGS_CURRENTTRACKNUMBER',0x00000300)
		win_const_mgr.add_const('KAGPROP_OUTERJOINS',0x00000013)
		win_const_mgr.add_const('SQLINT4',0x00000038)
		win_const_mgr.add_const('KS_NABTS_GROUPID_ORIGINAL_CONTENT_ADVERTISER_BASE',0x00000810)
		win_const_mgr.add_const('SQLINT8',0x00000007)
		win_const_mgr.add_const('TF_CLUIE_DOCUMENTMGR',0x00000001)
		win_const_mgr.add_const('DB_DISP_CA_CERT_CHAIN',0x00000010)
		win_const_mgr.add_const('JOY_CAL_READVONLY',0x08000000)
		win_const_mgr.add_const('SO_CONNOPT',0x00007001)
		win_const_mgr.add_const('DISPID_ONKEYUP',0x0000000E)
		win_const_mgr.add_const('IPPROTO_IP',0x00000000)
		win_const_mgr.add_const('PORT_NETNEWS',0x00000214)
		win_const_mgr.add_const('SCH_CRED_REVOCATION_CHECK_END_CERT',0x00000100)
		win_const_mgr.add_const('HEAP_ZERO_MEMORY',0x00000008)
		win_const_mgr.add_const('TF_MENUREADY',0x00000001)
		win_const_mgr.add_const('TAPE_DRIVE_WRITE_LONG_FMKS',0x88000000)
		win_const_mgr.add_const('DDSCAPS_WRITEONLY',0x00010000)
		win_const_mgr.add_const('DDSGR_CALIBRATE',0x00000001)
		win_const_mgr.add_const('SHIMSTCAPFLAG_PURGEABLE',0x00000002)
		win_const_mgr.add_const('CERT_KEY_CONTEXT_PROP_ID',0x00000005)
		win_const_mgr.add_const('ANY_SIZE',0x00000001)
		win_const_mgr.add_const('ERROR_WRITE_PROTECT',0x00000013)
		win_const_mgr.add_const('URLACTION_CLIENT_CERT_PROMPT',0x00001A04)
		win_const_mgr.add_const('WIA_DPS_ENDORSER_CHARACTERS',0x00000C14)
		win_const_mgr.add_const('RPC_PROTSEQ_LRPC',0x00000003)
		win_const_mgr.add_const('LAYOUT_BTT',0x00000002)
		win_const_mgr.add_const('ERROR_LOST_WRITEBEHIND_DATA',0x00000254)
		win_const_mgr.add_const('SM_CYKANJIWINDOW',0x00000012)
		win_const_mgr.add_const('DISPID_SELECTEDITEMCHANGED',0x000000DC)
		win_const_mgr.add_const('WM_XBUTTONDBLCLK',0x0000020D)
		win_const_mgr.add_const('MDDISPINFO_DRILLED_DOWN',0x00010000)
		win_const_mgr.add_const('MMIO_READWRITE',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_TI_READCOMMITTED',0x00001000)
		win_const_mgr.add_const('OID_FDDI_MAC_UPSTREAM_NBR',0x03030225)
		win_const_mgr.add_const('COD_MAJOR_PERIPHERAL',0x00000005)
		win_const_mgr.add_const('TASK_APRIL',0x00000008)
		win_const_mgr.add_const('TWOSTOPBITS',0x00000002)
		win_const_mgr.add_const('D3DTEXOPCAPS_MODULATECOLOR_ADDALPHA',0x00040000)
		win_const_mgr.add_const('PORT_NETBIOSSSN',0x0000008B)
		win_const_mgr.add_const('SPI_SETLOWPOWERTIMEOUT',0x00000051)
		win_const_mgr.add_const('CM_REMOVE_UI_OK',0x00000000)
		win_const_mgr.add_const('RIS_INTERFACE_MEDIA_PRESENT',0x00000003)
		win_const_mgr.add_const('DDBLT_COLORFILL',0x00000400)
		win_const_mgr.add_const('DDCAPS2_WIDESURFACES',0x00001000)
		win_const_mgr.add_const('BTH_MFG_CSR',0x0000000A)
		win_const_mgr.add_const('RRF_RT_REG_SZ',0x00000002)
		win_const_mgr.add_const('DMPAPER_ENV_MONARCH',0x00000025)
		win_const_mgr.add_const('WIA_DIP_UI_CLSID',0x0000000A)
		win_const_mgr.add_const('BM_GETIMAGE',0x000000F6)
		win_const_mgr.add_const('D3DCREATE_FPU_PRESERVE',0x00000002)
		win_const_mgr.add_const('MDM_V110_SPEED_4DOT8K',0x00000003)
		win_const_mgr.add_const('KRB_NT_SRV_XHST',0x00000004)
		win_const_mgr.add_const('VK_CANCEL',0x00000003)
		win_const_mgr.add_const('MOD_SWSYNTH',0x00000007)
		win_const_mgr.add_const('ERROR_UNSUPPORTED_TYPE',0x0000065E)
		win_const_mgr.add_const('LINEEQOSINFO_NOQOS',0x00000001)
		win_const_mgr.add_const('VFF_FILEINUSE',0x00000002)
		win_const_mgr.add_const('CM_GETIDLIST_FILTER_NONE',0x00000000)
		win_const_mgr.add_const('RPC_S_CALL_FAILED',0x000006BE)
		win_const_mgr.add_const('CRYPT_LDAP_INSERT_ENTRY_ATTRIBUTE',0x00008000)
		win_const_mgr.add_const('ISC_REQ_CONFIDENTIALITY',0x00000010)
		win_const_mgr.add_const('IDS_CAP_STAT_VIDEOCURRENT',0x000001FE)
		win_const_mgr.add_const('URLACTION_NETWORK_MAX',0x0000001B)
		win_const_mgr.add_const('BS_NOTIFY',0x00004000)
		win_const_mgr.add_const('USER_ACCT_EXPIRES_PARMNUM',0x00000011)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_USER_FLOW_RATE',0x00000017)
		win_const_mgr.add_const('DDPCAPS_PRIMARYSURFACE',0x00000010)
		win_const_mgr.add_const('PS_LEN',0x00000006)
		win_const_mgr.add_const('D3DDTCAPS_UDEC3',0x00000040)
		win_const_mgr.add_const('IDM_SHOWCOMMENTTAGS',0x00000914)
		win_const_mgr.add_const('ASPECTXY',0x0000002C)
		win_const_mgr.add_const('SECPKG_ATTR_ROOT_STORE',0x00000055)
		win_const_mgr.add_const('OPTION_PAD',0x00000000)
		win_const_mgr.add_const('MCI_UNDO',0x00000879)
		win_const_mgr.add_const('DS_CENTER',0x00000800)
		win_const_mgr.add_const('IF_TYPE_PROP_DOCS_WIRELESS_UPSTREAM',0x000000B6)
		win_const_mgr.add_const('ALG_SID_RSA_PKCS',0x00000001)
		win_const_mgr.add_const('ERROR_I24_READ_FAULT',0x0000000B)
		win_const_mgr.add_const('PST_PC_SMARTCARD',0x00000004)
		win_const_mgr.add_const('DMPAPER_JENV_CHOU3',0x00000049)
		win_const_mgr.add_const('DDBLTFX_ZBUFFERBASEDEST',0x00000100)
		win_const_mgr.add_const('MCI_OVLY_PUT_SOURCE',0x00020000)
		win_const_mgr.add_const('AM_MPEG_AUDIO_DUAL_LEFT',0x00000001)
		win_const_mgr.add_const('TB_ENDTRACK',0x00000008)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_SCROLL',0x00000488)
		win_const_mgr.add_const('IP_GENERAL_INFO_BASE',0x00000000)
		win_const_mgr.add_const('PRIVACY_TEMPLATE_MEDIUM',0x00000003)
		win_const_mgr.add_const('SCARD_F_INTERNAL_ERROR',0x80100001)
		win_const_mgr.add_const('DEF_PRIORITY',0x00000001)
		win_const_mgr.add_const('VFT2_DRV_SYSTEM',0x00000007)
		win_const_mgr.add_const('NTDDI_WINXPSP1',0x05010100)
		win_const_mgr.add_const('NTDDI_WINXPSP2',0x05010200)
		win_const_mgr.add_const('CFM_BOLD',0x00000001)
		win_const_mgr.add_const('HHWIN_PROP_NO_TOOLBAR',0x00000001)
		win_const_mgr.add_const('OID_FDDI_IF_OUT_NUCAST_PKTS',0x03030289)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_NO_LOCAL',0x00010000)
		win_const_mgr.add_const('HHT_ONDIVOPEN',0x00000008)
		win_const_mgr.add_const('EVENT_MIN_LEVEL',0x00000000)
		win_const_mgr.add_const('ASN_CONSTRUCTOR',0x00000020)
		win_const_mgr.add_const('NET_VALIDATE_LOCKOUT_TIME',0x00000004)
		win_const_mgr.add_const('ERROR_DS_OUT_OF_VERSION_STORE',0x0000217D)
		win_const_mgr.add_const('ERROR_IPSEC_INVALID_PACKET',0x0000365A)
		win_const_mgr.add_const('INTERNET_STATUS_HANDLE_CLOSING',0x00000046)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_GRP_SUM_FLOW_RATE',0x00000026)
		win_const_mgr.add_const('DATABITS_16X',0x00000020)
		win_const_mgr.add_const('RPC_S_INVALID_TAG',0x000006C5)
		win_const_mgr.add_const('LSA_FTRECORD_DISABLED_REASONS',0x0000FFFF)
		win_const_mgr.add_const('SPI_SETTOOLTIPANIMATION',0x00001017)
		win_const_mgr.add_const('CRYPT_X942_KEY_LENGTH_BYTE_LENGTH',0x00000004)
		win_const_mgr.add_const('CRYPT_ACQUIRE_NO_HEALING',0x00000008)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_INTERACTIVE',0x80000800)
		win_const_mgr.add_const('SQL_USER_NAME',0x0000002F)
		win_const_mgr.add_const('NMPWAIT_WAIT_FOREVER',0x00000000)
		win_const_mgr.add_const('BTH_MFG_ALCATEL',0x00000024)
		win_const_mgr.add_const('DEV_PORT_SIM',0x00000001)
		win_const_mgr.add_const('WMDM_STATUS_READY',0x00000001)
		win_const_mgr.add_const('TVS_RTLREADING',0x00000040)
		win_const_mgr.add_const('DDCAPS_CANCLIP',0x20000000)
		win_const_mgr.add_const('X3_BTYPE_QP_SIZE_X',0x00000009)
		win_const_mgr.add_const('ALG_SID_KEA',0x00000004)
		win_const_mgr.add_const('MCI_ANIM_WINDOW_DISABLE_STRETCH',0x00200000)
		win_const_mgr.add_const('COD_AUDIO_MINOR_UNCLASSIFIED',0x00000000)
		win_const_mgr.add_const('SQL_API_LOADBYORDINAL',0x000000C7)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_GPDISP',0x00000006)
		win_const_mgr.add_const('VK_HANGEUL',0x00000015)
		win_const_mgr.add_const('HTBOTTOMLEFT',0x00000010)
		win_const_mgr.add_const('CR_INVALID_PRIORITY',0x00000027)
		win_const_mgr.add_const('RUNCMDS_DELAYPOSTCMD',0x00000004)
		win_const_mgr.add_const('DCI_VISIBLE',0x00000010)
		win_const_mgr.add_const('OS_WEBSERVER',0x0000001F)
		win_const_mgr.add_const('STIF_SUPPORT_HEX',0x00000001)
		win_const_mgr.add_const('SECPKG_FLAG_MUTUAL_AUTH',0x00010000)
		win_const_mgr.add_const('INDEX_GUID_SEMANTICTYPE',0x00000005)
		win_const_mgr.add_const('ERROR_NO_DATA_DETECTED',0x00000450)
		win_const_mgr.add_const('SYMSTOREOPT_PASS_IF_EXISTS',0x00000040)
		win_const_mgr.add_const('IPSEC_POLICY_FLAG_NAT_ENCAP_ALLOW_GENERAL_NAT_TRAVERSAL',0x00000020)
		win_const_mgr.add_const('LDAP_RES_MODRDN',0x00000006)
		win_const_mgr.add_const('MCI_MONITOR',0x00000871)
		win_const_mgr.add_const('VALID_NTFT',0x000000C0)
		win_const_mgr.add_const('API_RECEIVE_RESPONSE',0x00000001)
		win_const_mgr.add_const('D3DFVF_XYZB2',0x00000008)
		win_const_mgr.add_const('ERROR_DS_ALIAS_DEREF_PROBLEM',0x00002034)
		win_const_mgr.add_const('CAUSE_CHANNEL_NONEXISTENT',0x00000052)
		win_const_mgr.add_const('PSNRET_INVALID',0x00000001)
		win_const_mgr.add_const('WM_PENWINLAST',0x0000038F)
		win_const_mgr.add_const('LB_ADDSTRING',0x00000180)
		win_const_mgr.add_const('LVGF_TASK',0x00000200)
		win_const_mgr.add_const('MFASYNC_CALLBACK_QUEUE_LONG_FUNCTION',0x00000007)
		win_const_mgr.add_const('IDM_SPECIALCHAR',0x0000086C)
		win_const_mgr.add_const('TMT_NOETCHEDEFFECT',0x000008A7)
		win_const_mgr.add_const('LANG_LITHUANIAN',0x00000027)
		win_const_mgr.add_const('KS_VIDEOSTREAM_CC',0x00000100)
		win_const_mgr.add_const('DNS_RTYPE_KEY',0x00001900)
		win_const_mgr.add_const('INTERNET_OPTION_CONNECTED_STATE',0x00000032)
		win_const_mgr.add_const('ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED',0x00003B66)
		win_const_mgr.add_const('MAX_INTERPRETER_OUT_SIZE',0x00000080)
		win_const_mgr.add_const('DBPROP_INIT_TREATASOFFLINE',0x00000004)
		win_const_mgr.add_const('PSR_PK',0x0000000F)
		win_const_mgr.add_const('SQL_FN_NUM_TRUNCATE',0x00800000)
		win_const_mgr.add_const('DXVA_MV_PRECISION_AND_CHROMA_RELATION_MPEG2',0x00000000)
		win_const_mgr.add_const('SQL_CB_PRESERVE',0x00000002)
		win_const_mgr.add_const('SQL_PC_ON',0x00000001)
		win_const_mgr.add_const('WN_VALID_LOGON_ACCOUNT',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_ASSEMBLY_MISSING',0x00003701)
		win_const_mgr.add_const('MCI_VCR_STATUS_VIDEO_RECORD',0x00004017)
		win_const_mgr.add_const('ISOPROTO_TP2',0x0000001B)
		win_const_mgr.add_const('DBPROP_CI_EXCLUDE_SCOPES',0x00000005)
		win_const_mgr.add_const('DEBUG_OUTTYPE_COMPACT_OUTPUT',0x00000008)
		win_const_mgr.add_const('D3DRENDERSTATE_WRAPBIAS',0x00000080)
		win_const_mgr.add_const('DOMAIN_PASSWORD_NO_CLEAR_CHANGE',0x00000004)
		win_const_mgr.add_const('ISOPROTO_TP4',0x0000001D)
		win_const_mgr.add_const('SORT_CHINESE_PRCP',0x00000000)
		win_const_mgr.add_const('NLS_CP_CPINFO',0x10000000)
		win_const_mgr.add_const('DSDSOF_DSAVAILABLE',0x40000000)
		win_const_mgr.add_const('OID_FDDI_IF_IN_DISCARDS',0x03030284)
		win_const_mgr.add_const('GESTURE_RIGHT_ARROW_UP',0x00000000)
		win_const_mgr.add_const('ERROR_DISK_CHANGE',0x0000006B)
		win_const_mgr.add_const('DDGBS_ISBLTDONE',0x00000002)
		win_const_mgr.add_const('LINETRANSLATERESULT_NOTINTOLLLIST',0x00000020)
		win_const_mgr.add_const('DBT_USERDEFINED',0x0000FFFF)
		win_const_mgr.add_const('DCI_STATUS_STRIDECHANGED',0x00000002)
		win_const_mgr.add_const('CERT_ALT_NAME_IP_ADDRESS',0x00000008)
		win_const_mgr.add_const('CRLF_PRESERVE_REVOKED_CA_CERTS',0x00080000)
		win_const_mgr.add_const('SCRIPTPROP_BUILDNUMBER',0x00000003)
		win_const_mgr.add_const('BL_16M',0x01000000)
		win_const_mgr.add_const('SW_SHOWMAXIMIZED',0x00000003)
		win_const_mgr.add_const('SFVM_GETHELPTEXT',0x00000003)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_EVEN',0x00000002)
		win_const_mgr.add_const('MCI_FORMAT_MSF',0x00000002)
		win_const_mgr.add_const('EM_LINEINDEX',0x000000BB)
		win_const_mgr.add_const('MS_CTS_ON',0x00000010)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_MAGIC_NUMBER_2',0x00000001)
		win_const_mgr.add_const('SECPKG_ATTR_CIPHER_STRENGTHS',0x00000057)
		win_const_mgr.add_const('MP_STATUS_CATEGORIZED',0x00000005)
		win_const_mgr.add_const('WMDM_S_NOT_ALL_PROPERTIES_RETRIEVED',0x00045002)
		win_const_mgr.add_const('MD_USER_ISOLATION_AD',0x00000002)
		win_const_mgr.add_const('MD_ERROR_SUB403_SSL128_REQUIRED',0x00000005)
		win_const_mgr.add_const('INF_STYLE_CACHE_ENABLE',0x00000010)
		win_const_mgr.add_const('CDO_E_PROP_NONHEADER',0x8004022A)
		win_const_mgr.add_const('ACTRL_DELETE',0x08000000)
		win_const_mgr.add_const('DOSOPTF_USESPMODE',0x00000008)
		win_const_mgr.add_const('SQL_SP_MATCH_UNIQUE_FULL',0x00000020)
		win_const_mgr.add_const('CDS_FULLSCREEN',0x00000004)
		win_const_mgr.add_const('USE_QWORD_JUMP',0x00000040)
		win_const_mgr.add_const('CR_REMOTE_COMM_FAILURE',0x00000030)
		win_const_mgr.add_const('ERROR_DHCP_ADDRESS_CONFLICT',0x00001004)
		win_const_mgr.add_const('SQL_DESC_OCTET_LENGTH',0x000003F5)
		win_const_mgr.add_const('IDI_QUESTION',0x00007F02)
		win_const_mgr.add_const('ERROR_WAIT_3',0x000002DD)
		win_const_mgr.add_const('ERROR_WAIT_2',0x000002DC)
		win_const_mgr.add_const('ERROR_WAIT_1',0x000002DB)
		win_const_mgr.add_const('MCI_DGV_RECORD_AUDIO_STREAM',0x00040000)
		win_const_mgr.add_const('CMSG_CTRL_MAIL_LIST_DECRYPT',0x00000012)
		win_const_mgr.add_const('MUI_NON_LANG_NEUTRAL_FILE',0x00000200)
		win_const_mgr.add_const('IME_CMODE_KATAKANA',0x00000002)
		win_const_mgr.add_const('META_CREATEPALETTE',0x00000000)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_BREAKAWAY_OK',0x00000800)
		win_const_mgr.add_const('INTERNET_OPTION_DIGEST_AUTH_UNLOAD',0x0000004C)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_RECORD',0x00000030)
		win_const_mgr.add_const('PSM_HID_INTERRUPT',0x00000013)
		win_const_mgr.add_const('MD_CPU_THROTTLE',0x00000003)
		win_const_mgr.add_const('DBPROPVAL_TC_DDL_LOCK',0x00000010)
		win_const_mgr.add_const('COLOR_GRADIENTACTIVECAPTION',0x0000001B)
		win_const_mgr.add_const('PS_1M',0x00000014)
		win_const_mgr.add_const('DEBUG_OUTPUT_DEBUGGEE_PROMPT',0x00000100)
		win_const_mgr.add_const('DLL_PROCESS_DETACH',0x00000000)
		win_const_mgr.add_const('RP_DSN_NOTIFY_INVALID',0x00000000)
		win_const_mgr.add_const('STDPROP_INDEX_LENGTH',0x000000CB)
		win_const_mgr.add_const('NIIF_NDIS_ENDPOINT_INTERFACE',0x00000040)
		win_const_mgr.add_const('DISPID_SHOWBROWSERUI',0x0000000D)
		win_const_mgr.add_const('DMA_ENTRY',0x00000004)
		win_const_mgr.add_const('RF_ADVISEINKCHANGE',0x00001000)
		win_const_mgr.add_const('DEBUG_VALUE_FLOAT80',0x00000007)
		win_const_mgr.add_const('UPDP_SILENT_UPLOAD',0x00000001)
		win_const_mgr.add_const('AVI_INDEX_OF_CHUNKS',0x00000001)
		win_const_mgr.add_const('CR_FLG_PUBLISHERROR',0x80000000)
		win_const_mgr.add_const('TMREGISTER',0x00000001)
		win_const_mgr.add_const('OFN_EXPLORER',0x00080000)
		win_const_mgr.add_const('PROPID_MGMT_QUEUE_BASE',0x00000000)
		win_const_mgr.add_const('DCI_STATUS_WASSTILLDRAWING',0x00000020)
		win_const_mgr.add_const('D3DDEVCAPS_EXECUTESYSTEMMEMORY',0x00000010)
		win_const_mgr.add_const('TR_MA',0x00000002)
		win_const_mgr.add_const('ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2',0x0000218A)
		win_const_mgr.add_const('MDPROPVAL_MJC_MULTICUBES',0x00000002)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_ND_PEER_NAT_BOUNDARY',0x00000004)
		win_const_mgr.add_const('MAXIMUM_ALLOWED',0x02000000)
		win_const_mgr.add_const('IDM_MARQUEE',0x00000886)
		win_const_mgr.add_const('TC_NOTIFY_FLOW_CLOSE',0x00000005)
		win_const_mgr.add_const('RP_HANDLED',0x00000010)
		win_const_mgr.add_const('ISOPROTO_TP3',0x0000001C)
		win_const_mgr.add_const('FWPM_NET_EVENT_FLAG_APP_ID_SET',0x00000020)
		win_const_mgr.add_const('CM_DRP_UI_NUMBER_DESC_FORMAT',0x0000001E)
		win_const_mgr.add_const('DMBIN_USER',0x00000100)
		win_const_mgr.add_const('STRINGFORMAT_DBCS',0x00000002)
		win_const_mgr.add_const('SQL_FN_TD_DAYNAME',0x00008000)
		win_const_mgr.add_const('GPO_INFO_FLAG_BACKGROUND',0x00000010)
		win_const_mgr.add_const('SQL_FETCH_FIRST',0x00000002)
		win_const_mgr.add_const('SQL_CP_OFF',0x00000000)
		win_const_mgr.add_const('SQL_NULLABLE_UNKNOWN',0x00000002)
		win_const_mgr.add_const('CRLF_REBUILD_MODIFIED_SUBJECT_ONLY',0x00000020)
		win_const_mgr.add_const('ISR_PROBE',0x00000002)
		win_const_mgr.add_const('ST_SELECTION',0x00000002)
		win_const_mgr.add_const('ERROR_NOT_ENOUGH_QUOTA',0x00000718)
		win_const_mgr.add_const('SV_ACCESSALERT_PARMNUM',0x00000028)
		win_const_mgr.add_const('PDH_PLA_SERVICE_ERROR',0xC0000BF1)
		win_const_mgr.add_const('ACM_STREAMSIZEF_SOURCE',0x00000000)
		win_const_mgr.add_const('ES_OEMCONVERT',0x00000400)
		win_const_mgr.add_const('SQL_CODE_MONTH',0x00000002)
		win_const_mgr.add_const('ENM_PAGECHANGE',0x00000040)
		win_const_mgr.add_const('EVT_WRITE_ACCESS',0x00000002)
		win_const_mgr.add_const('ERROR_INVALID_SERVICE_CONTROL',0x0000041C)
		win_const_mgr.add_const('PSH_PROPTITLE',0x00000001)
		win_const_mgr.add_const('N_TSHIFT',0x00000002)
		win_const_mgr.add_const('DC_BINADJUST',0x00000013)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_ZONE',0x00000040)
		win_const_mgr.add_const('MUTZ_FORCE_INTRANET_FLAGS',0x00002000)
		win_const_mgr.add_const('D3DDEVCAPS2_DMAPNPATCH',0x00000002)
		win_const_mgr.add_const('STORAGE_PRIORITY_HINT_SUPPORTED',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_NODE_IS_CNAME',0x000025EC)
		win_const_mgr.add_const('STATURL_QUERYFLAG_TOPLEVEL',0x00080000)
		win_const_mgr.add_const('MCI_FORMAT_SMPTE_30',0x00000006)
		win_const_mgr.add_const('EVENT_SYSTEM_MENUPOPUPSTART',0x00000006)
		win_const_mgr.add_const('SPI_SETSHOWIMEUI',0x0000006F)
		win_const_mgr.add_const('BTH_ERROR_ACL_CONNECTION_ALREADY_EXISTS',0x00000000)
		win_const_mgr.add_const('INTERNET_PER_CONN_AUTOCONFIG_SECONDARY_URL',0x00000006)
		win_const_mgr.add_const('DXVA_CONFIG_DATA_TYPE_AYUV',0x00000003)
		win_const_mgr.add_const('SUBLANG_VIETNAMESE_VIETNAM',0x00000001)
		win_const_mgr.add_const('WM_LBUTTONUP',0x00000202)
		win_const_mgr.add_const('ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED',0x000013D7)
		win_const_mgr.add_const('TCIF_STATE',0x00000010)
		win_const_mgr.add_const('RENDBIND_DEFAULTUSERNAME',0x00000004)
		win_const_mgr.add_const('MC_CAPS_MONITOR_TECHNOLOGY_TYPE',0x00000001)
		win_const_mgr.add_const('SQL_CONVERT_DATE',0x00000039)
		win_const_mgr.add_const('HSHELL_WINDOWACTIVATED',0x00000004)
		win_const_mgr.add_const('CONSOLE_TEXTMODE_BUFFER',0x00000001)
		win_const_mgr.add_const('INCLUDED_FDI',0x00000001)
		win_const_mgr.add_const('PRAGMA_DEPRECATED_DDK',0x00000000)
		win_const_mgr.add_const('DFCS_CAPTIONRESTORE',0x00000003)
		win_const_mgr.add_const('JIFMK_JPG11',0x0000FFFB)
		win_const_mgr.add_const('EAP_FLAG_MACHINE_AUTH',0x00000020)
		win_const_mgr.add_const('TBCDRF_HILITEHOTTRACK',0x00020000)
		win_const_mgr.add_const('DSOP_FILTER_GLOBAL_GROUPS_SE',0x00000080)
		win_const_mgr.add_const('DEFAULT_GUI_FONT',0x00000011)
		win_const_mgr.add_const('SQL_ATTR_DISCONNECT_BEHAVIOR',0x00000072)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_HINT',0x00000008)
		win_const_mgr.add_const('DEBUG_EVENT_CREATE_PROCESS',0x00000010)
		win_const_mgr.add_const('ISQLANG_V1',0x00000001)
		win_const_mgr.add_const('ISQLANG_V2',0x00000002)
		win_const_mgr.add_const('FAULT_DEVICE_INTERNAL_ERROR',0x000001F5)
		win_const_mgr.add_const('D3DTEXOPCAPS_SELECTARG2',0x00000004)
		win_const_mgr.add_const('ACCESS_FAIL_SHIFT',0x00000004)
		win_const_mgr.add_const('OID_GEN_ALIAS',0x00010289)
		win_const_mgr.add_const('SUBLANG_ENGLISH_SOUTH_AFRICA',0x00000007)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_1024BYTES',0x00B00000)
		win_const_mgr.add_const('VK_BACK',0x00000008)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_SETWRITESPEED',0x00000202)
		win_const_mgr.add_const('D3DPTADDRESSCAPS_MIRRORONCE',0x00000020)
		win_const_mgr.add_const('CALL_PENDING',0x00000002)
		win_const_mgr.add_const('WTS_PROTOCOL_TYPE_RDP',0x00000002)
		win_const_mgr.add_const('SQL_CA1_BULK_FETCH_BY_BOOKMARK',0x00080000)
		win_const_mgr.add_const('TF_SENTENCEMODE_NONE',0x00000000)
		win_const_mgr.add_const('ISMEX_CALLBACK',0x00000004)
		win_const_mgr.add_const('WMS_CONTAINER_PART_OF_PLAYLIST',0x00000020)
		win_const_mgr.add_const('DNS_ERROR_RCODE_REFUSED',0x0000232D)
		win_const_mgr.add_const('WIA_DATA_DITHER',0x00000001)
		win_const_mgr.add_const('DEVLEN',0x00000050)
		win_const_mgr.add_const('OID_FDDI_IF_LAST_CHANGE',0x03030280)
		win_const_mgr.add_const('WVR_VREDRAW',0x00000200)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_NOT_PAUSED',0x000013C2)
		win_const_mgr.add_const('ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT',0x00003715)
		win_const_mgr.add_const('SE_ERR_ACCESSDENIED',0x00000005)
		win_const_mgr.add_const('OID_LTALK_NO_DATA_ERRORS',0x05020204)
		win_const_mgr.add_const('INDEX_GUID_ASCENDER',0x00000007)
		win_const_mgr.add_const('PI_APPLYPOLICY',0x00000002)
		win_const_mgr.add_const('IDD_DYNAWIZ_SELECTDEV_PAGE',0x00002719)
		win_const_mgr.add_const('IMAGE_REL_M32R_REFLO',0x0000000A)
		win_const_mgr.add_const('MANAGED_APPTYPE_UNSUPPORTED',0x00000003)
		win_const_mgr.add_const('SERVICE_REDIR_COMM_PAUSED',0x00000400)
		win_const_mgr.add_const('ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND',0x00003A9A)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_FORWARD',0x0000000C)
		win_const_mgr.add_const('LIF_ITEMINDEX',0x00000001)
		win_const_mgr.add_const('MD_GLOBAL_XMLSCHEMATIMESTAMP',0x00002708)
		win_const_mgr.add_const('MD_CPU_ENABLE_TOTAL_PROCS',0x00000020)
		win_const_mgr.add_const('SQL_RETURN_VALUE',0x00000005)
		win_const_mgr.add_const('WINHTTP_QUERY_STATUS_TEXT',0x00000014)
		win_const_mgr.add_const('CRYPTPROTECT_CRED_SYNC',0x00000008)
		win_const_mgr.add_const('SPEAKER_TOP_BACK_LEFT',0x00008000)
		win_const_mgr.add_const('IPPROTO_IGMP',0x00000002)
		win_const_mgr.add_const('SQL_DROP_TRANSLATION',0x0000008E)
		win_const_mgr.add_const('CREATE_FOR_IMPORT',0x00000001)
		win_const_mgr.add_const('BTH_ERROR_PAGE_TIMEOUT',0x00000004)
		win_const_mgr.add_const('SSRVOPT_PROXY',0x00001000)
		win_const_mgr.add_const('SDP_SERVICE_SEARCH_REQUEST',0x00000001)
		win_const_mgr.add_const('CONNECT_CMD_SAVECRED',0x00001000)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_SENDING',0x00000010)
		win_const_mgr.add_const('LVFI_WRAP',0x00000020)
		win_const_mgr.add_const('KSATTRIBUTE_REQUIRED',0x00000001)
		win_const_mgr.add_const('GESTURE_BRACE_OVER',0x00000000)
		win_const_mgr.add_const('SDP_ATTRIB_HID_DESCRIPTOR_LIST',0x00000206)
		win_const_mgr.add_const('SS_REALSIZEIMAGE',0x00000800)
		win_const_mgr.add_const('BG_E_REMOTE_NOT_SUPPORTED',0x80200014)
		win_const_mgr.add_const('WMDRM_CERTIFICATE_TYPE_XML',0x00000001)
		win_const_mgr.add_const('WM_CHARTOITEM',0x0000002F)
		win_const_mgr.add_const('EPSPRINTING',0x00000021)
		win_const_mgr.add_const('TBSTYLE_CUSTOMERASE',0x00002000)
		win_const_mgr.add_const('RPC_S_SERVER_TOO_BUSY',0x000006BB)
		win_const_mgr.add_const('RPCFLG_HAS_CALLBACK',0x04000000)
		win_const_mgr.add_const('LVS_EX_MULTIWORKAREAS',0x00002000)
		win_const_mgr.add_const('OVERWRITE_HIDDEN',0x00000004)
		win_const_mgr.add_const('RESOURCE_GLOBALNET',0x00000002)
		win_const_mgr.add_const('ERROR_CTX_WINSTATION_NOT_FOUND',0x00001B6E)
		win_const_mgr.add_const('NIIF_ICON_MASK',0x0000000F)
		win_const_mgr.add_const('IMC_SETCANDIDATEPOS',0x00000008)
		win_const_mgr.add_const('MOUSE_VIRTUAL_DESKTOP',0x00000002)
		win_const_mgr.add_const('ERROR_MUTANT_LIMIT_EXCEEDED',0x0000024B)
		win_const_mgr.add_const('DWFAF_GROUP2',0x00000004)
		win_const_mgr.add_const('PARITY_EVEN',0x00000400)
		win_const_mgr.add_const('DWFAF_GROUP1',0x00000002)
		win_const_mgr.add_const('CM_PROB_DEVLOADER_FAILED',0x00000002)
		win_const_mgr.add_const('EVENT_TRACE_CONTROL_FLUSH',0x00000003)
		win_const_mgr.add_const('ERROR_ADDRESS_ALREADY_ASSOCIATED',0x000004CB)
		win_const_mgr.add_const('IF_TYPE_ARCNET',0x00000023)
		win_const_mgr.add_const('CERT_FIND_OPTIONAL_ENHKEY_USAGE_FLAG',0x00000001)
		win_const_mgr.add_const('MSV1_0_TRY_GUEST_ACCOUNT_ONLY',0x00000100)
		win_const_mgr.add_const('ERROR_LOG_INVALID_RANGE',0x000019CC)
		win_const_mgr.add_const('PRIMARY_CRED_LOGON_PACKAGE_SHIFT',0x00000018)
		win_const_mgr.add_const('AE_AUTODIS',0x00000002)
		win_const_mgr.add_const('SPI_SETDRAGWIDTH',0x0000004C)
		win_const_mgr.add_const('CDERR_NOHINSTANCE',0x00000004)
		win_const_mgr.add_const('CONNECTION_WAN',0x00000002)
		win_const_mgr.add_const('RPC_S_CALL_CANCELLED',0x0000071A)
		win_const_mgr.add_const('SQL_LOGIN_TIMEOUT_DEFAULT',0x0000000F)
		win_const_mgr.add_const('DVASPECT_LINK',0x00000004)
		win_const_mgr.add_const('DISPLAY_DEVICE_MIRRORING_DRIVER',0x00000008)
		win_const_mgr.add_const('LINEERR_INVALMEDIALIST',0x8000002E)
		win_const_mgr.add_const('IDM_INDENT',0x0000088A)
		win_const_mgr.add_const('PD_USELARGETEMPLATE',0x10000000)
		win_const_mgr.add_const('SQL_CTR_CREATE_TRANSLATION',0x00000001)
		win_const_mgr.add_const('ERROR_IEPORT_FULL',0x000010F5)
		win_const_mgr.add_const('UME_VERSION',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_ORS_INDEX',0x00000001)
		win_const_mgr.add_const('BSF_NOLOCALFILEWARNING',0x00000010)
		win_const_mgr.add_const('SQL_SG_DELETE_TABLE',0x00000020)
		win_const_mgr.add_const('ACM_METRIC_HARDWARE_WAVE_OUTPUT',0x0000001F)
		win_const_mgr.add_const('LDAP_DEREF_FINDING',0x00000002)
		win_const_mgr.add_const('ACM_FILTERDETAILSF_INDEX',0x00000000)
		win_const_mgr.add_const('DS_REPL_NBR_PREEMPTED',0x01000000)
		win_const_mgr.add_const('TF_RP_LOCALPROCESS',0x00000004)
		win_const_mgr.add_const('ACM_MPEG_JOINTSTEREO',0x00000002)
		win_const_mgr.add_const('EDITF_ADDOLDKEYUSAGE',0x00000008)
		win_const_mgr.add_const('ALG_SID_RC5',0x0000000D)
		win_const_mgr.add_const('DIRID_PROGRAM_FILES_X86',0x0000402A)
		win_const_mgr.add_const('IF_TYPE_ISO88024_TOKENBUS',0x00000008)
		win_const_mgr.add_const('DV_NTSC',0x00000000)
		win_const_mgr.add_const('CR_INVALID_CONFLICT_LIST',0x00000039)
		win_const_mgr.add_const('CERT_COMPARE_KEY_SPEC',0x00000009)
		win_const_mgr.add_const('SQL_FD_FETCH_RELATIVE',0x00000020)
		win_const_mgr.add_const('RSC_FLAG_SETUPAPI',0x00000400)
		win_const_mgr.add_const('SQL_ISV_USAGE_PRIVILEGES',0x00080000)
		win_const_mgr.add_const('PHONEBUTTONMODE_FEATURE',0x00000004)
		win_const_mgr.add_const('DN_RO',0x00000001)
		win_const_mgr.add_const('WBF_LEVEL1',0x00000080)
		win_const_mgr.add_const('MF_4_BYTE_ALIGNMENT',0x00000003)
		win_const_mgr.add_const('D3DTEXOPCAPS_PREMODULATE',0x00010000)
		win_const_mgr.add_const('AGP_FLAG_REVERSE_INITIALIZATION',0x00000080)
		win_const_mgr.add_const('FROM_LEFT_4TH_BUTTON_PRESSED',0x00000010)
		win_const_mgr.add_const('MD_ERROR_SUB404_VERB_DENIED',0x00000006)
		win_const_mgr.add_const('DESKTOP_CREATEWINDOW',0x00000002)
		win_const_mgr.add_const('ULONG64_ERROR',0x00000000)
		win_const_mgr.add_const('INTERENT_GOONLINE_MASK',0x00000001)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_MAGIC_NUMBER',0x00000001)
		win_const_mgr.add_const('IDM_LINEBREAKNORMAL',0x00000867)
		win_const_mgr.add_const('IF_TYPE_AAL2',0x000000BB)
		win_const_mgr.add_const('KP_MODE_BITS',0x00000005)
		win_const_mgr.add_const('CRED_MAX_CREDENTIAL_BLOB_SIZE',0x00000200)
		win_const_mgr.add_const('HTTP_QUERY_MESSAGE_ID',0x0000000C)
		win_const_mgr.add_const('SV_DISC_PARMNUM',0x0000000A)
		win_const_mgr.add_const('CM_CDMASK_FLAGS',0x00000004)
		win_const_mgr.add_const('ERROR_LOG_SPACE_RESERVED_INVALID',0x000019E2)
		win_const_mgr.add_const('WSAEDESTADDRREQ',0x00002737)
		win_const_mgr.add_const('TBIF_SIZE',0x00000040)
		win_const_mgr.add_const('INTERNET_OPTION_CODEPAGE_EXTRA',0x00000065)
		win_const_mgr.add_const('KSEG4_VRN',0x00000005)
		win_const_mgr.add_const('DSROLE_PRIMARY_DS_MIXED_MODE',0x00000002)
		win_const_mgr.add_const('GL_ID_NOMODULE',0x00000001)
		win_const_mgr.add_const('VMR_RENDER_DEVICE_SYSMEM',0x00000004)
		win_const_mgr.add_const('CA_LOG_FILTER',0x00000002)
		win_const_mgr.add_const('DISPID_UPDATEIMAGE',0x000000DE)
		win_const_mgr.add_const('QUOTA_LIMITS_HARDWS_MIN_DISABLE',0x00000002)
		win_const_mgr.add_const('STREAM_FLAGS_DONTCACHEXSL',0x00000020)
		win_const_mgr.add_const('VREFRESH',0x00000074)
		win_const_mgr.add_const('MPV_WRITE_CONTENT',0x00000002)
		win_const_mgr.add_const('MCI_DGV_WHERE_WINDOW',0x00200000)
		win_const_mgr.add_const('START_PROCESS_RID',0x00000004)
		win_const_mgr.add_const('TF_TMAE_CONSOLE',0x00000040)
		win_const_mgr.add_const('IPP_E_MDAC_VERSION',0xC004800D)
		win_const_mgr.add_const('CACHE_ENTRY_MODTIME_FC',0x00000040)
		win_const_mgr.add_const('CMSG_ENVELOPED',0x00000003)
		win_const_mgr.add_const('PIR_STATUS_MINIPORT_COMPATIBLE',0x00000001)
		win_const_mgr.add_const('TPM_RIGHTBUTTON',0x00000002)
		win_const_mgr.add_const('ICEE_CREATE_MACHINE_ILLEGAL',0x00000000)
		win_const_mgr.add_const('DISPID_AUTOCOMPLETEATTACH',0x0000000C)
		win_const_mgr.add_const('SPI_GETMOUSEVANISH',0x00001020)
		win_const_mgr.add_const('CM_ENABLEHOOK',0x00000001)
		win_const_mgr.add_const('LINEERR_STRUCTURETOOSMALL',0x8000004D)
		win_const_mgr.add_const('AF_UNSPEC',0x00000000)
		win_const_mgr.add_const('STI_TRACE_INFORMATION',0x00000001)
		win_const_mgr.add_const('GGL_PRIVATE',0x00000004)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_LABEL',0x00000006)
		win_const_mgr.add_const('WTS_WSD_SHUTDOWN',0x00000002)
		win_const_mgr.add_const('ERROR_NOT_SAME_DEVICE',0x00000011)
		win_const_mgr.add_const('UPNP_ADDRESSFAMILY_BOTH',0x00000003)
		win_const_mgr.add_const('MM_DRVM_DATA',0x000003D2)
		win_const_mgr.add_const('TAPE_DRIVE_REPORT_SMKS',0x00080000)
		win_const_mgr.add_const('LINEDEVSTATE_INSERVICE',0x00000040)
		win_const_mgr.add_const('RTM_MATCH_NONE',0x00000000)
		win_const_mgr.add_const('SPFILENOTIFY_RENAMEERROR',0x00000000)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_BASIC',0x00000000)
		win_const_mgr.add_const('LVGMF_TEXTCOLOR',0x00000004)
		win_const_mgr.add_const('UNDEFINE_PRIMARY',0x0000000C)
		win_const_mgr.add_const('DBPROP_USECONTENTINDEX',0x00000002)
		win_const_mgr.add_const('CREDUI_MAX_CAPTION_LENGTH',0x00000080)
		win_const_mgr.add_const('SUBLANG_ENGLISH_TRINIDAD',0x00000000)
		win_const_mgr.add_const('MCI_VD_GETDEVCAPS_CLV',0x00010000)
		win_const_mgr.add_const('IDS_POSTED_AT',0x00011003)
		win_const_mgr.add_const('LANG_BASQUE',0x00000002)
		win_const_mgr.add_const('IF_ENABLEADMINASAUDITOR',0x00001000)
		win_const_mgr.add_const('SQL_UB_OFF',0x00000000)
		win_const_mgr.add_const('SUBLANG_TIBETAN_PRC',0x00000001)
		win_const_mgr.add_const('USER_NO_AUTH_DATA_REQUIRED',0x00080000)
		win_const_mgr.add_const('TVGN_PREVIOUS',0x00000002)
		win_const_mgr.add_const('WPP_POST_POSTING_SERVER_ERROR',0xC0042382)
		win_const_mgr.add_const('SPREG_DLLINSTALL',0x00000004)
		win_const_mgr.add_const('LOCALE_SMONDECIMALSEP',0x00000016)
		win_const_mgr.add_const('WSAEINVALIDPROVIDER',0x00002779)
		win_const_mgr.add_const('D3DPS20_MAX_NUMINSTRUCTIONSLOTS',0x00000200)
		win_const_mgr.add_const('CERT_PROT_ROOT_DISABLE_LM_AUTH_FLAG',0x00000008)
		win_const_mgr.add_const('SQL_BP_CLOSE',0x00000001)
		win_const_mgr.add_const('CERT_STORE_PROV_GET_CRL_PROPERTY_FUNC',0x00000013)
		win_const_mgr.add_const('TRUST_AUTH_TYPE_NONE',0x00000000)
		win_const_mgr.add_const('PHYSICALWIDTH',0x0000006E)
		win_const_mgr.add_const('WM_UNDO',0x00000304)
		win_const_mgr.add_const('DDCAPS_READSCANLINE',0x00020000)
		win_const_mgr.add_const('SMART_IDE_ERROR',0x00000001)
		win_const_mgr.add_const('INTERNET_DIAL_UNATTENDED',0x00008000)
		win_const_mgr.add_const('MAX_SCOPE_NAME_LEN',0x000000FF)
		win_const_mgr.add_const('HTTP_QUERY_TRANSFER_ENCODING',0x0000003F)
		win_const_mgr.add_const('DS_NETBIOS_ADDRESS',0x00000002)
		win_const_mgr.add_const('MOUSEEVENTF_WHEEL',0x00000800)
		win_const_mgr.add_const('LOCALE_SDAYNAME5',0x0000002E)
		win_const_mgr.add_const('LOCALE_SDAYNAME4',0x0000002D)
		win_const_mgr.add_const('IDS_CAP_DEFPALEXT',0x00000198)
		win_const_mgr.add_const('ERROR_DS_CANT_DEL_MASTER_CROSSREF',0x000020B7)
		win_const_mgr.add_const('LOCALE_SDAYNAME1',0x0000002A)
		win_const_mgr.add_const('SCESTATUS_RECORD_NOT_FOUND',0x00000002)
		win_const_mgr.add_const('SQL_DROP_VIEW',0x0000008F)
		win_const_mgr.add_const('FEI_MODEM_POWERED_ON',0x00000011)
		win_const_mgr.add_const('WNODE_FLAG_INTERNAL',0x00000100)
		win_const_mgr.add_const('SERVICE_START_PENDING',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_INVALID_ACTCTXDATA_FORMAT',0x000036B2)
		win_const_mgr.add_const('ACMFILTERTAGDETAILS_FILTERTAG_CHARS',0x00000030)
		win_const_mgr.add_const('MAPI_E_ATTACHMENT_WRITE_FAILURE',0x0000000D)
		win_const_mgr.add_const('SECPKG_CRED_DEFAULT',0x00000004)
		win_const_mgr.add_const('D3DSTREAMSOURCE_INSTANCEDATA',0x00000002)
		win_const_mgr.add_const('DDSD_ALPHABITDEPTH',0x00000080)
		win_const_mgr.add_const('SERVICE_IP_WAITTIME_SHIFT',0x00000008)
		win_const_mgr.add_const('SHTDN_REASON_FLAG_DIRTY_UI',0x08000000)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_D55',0x00000014)
		win_const_mgr.add_const('ERROR_PATH_BUSY',0x00000094)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NO_PRIVATE_KEY',0x000035FC)
		win_const_mgr.add_const('SPI_SETICONTITLEWRAP',0x0000001A)
		win_const_mgr.add_const('DIALOPTION_DIALTONE',0x00000100)
		win_const_mgr.add_const('WM_DESTROYCLIPBOARD',0x00000307)
		win_const_mgr.add_const('SQL_XL_ON',0x00000001)
		win_const_mgr.add_const('MIXERCONTROL_CT_CLASS_LIST',0x70000000)
		win_const_mgr.add_const('WS_EX_APPWINDOW',0x00040000)
		win_const_mgr.add_const('LPD_SHARE_ACCUM',0x00000100)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_NOAUTH',0x00000001)
		win_const_mgr.add_const('SQL_DIAG_SERVER_NAME',0x0000000B)
		win_const_mgr.add_const('ARCONTENT_SVCD',0x00000800)
		win_const_mgr.add_const('SQL_ATTR_PARAM_BIND_OFFSET_PTR',0x00000011)
		win_const_mgr.add_const('SEVERITY_SUCCESS',0x00000000)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_USER_PEAK_RATE',0x0000001B)
		win_const_mgr.add_const('IMAPI_SECTORS_PER_SECOND_AT_1X_DVD',0x000002A8)
		win_const_mgr.add_const('D3DUSAGE_QUERY_LEGACYBUMPMAP',0x00008000)
		win_const_mgr.add_const('APPLY_OPTION_FAIL_IF_CLOSE',0x00000002)
		win_const_mgr.add_const('NTDDI_LONGHORN',0x06000000)
		win_const_mgr.add_const('SSF_WIN95CLASSIC',0x00000400)
		win_const_mgr.add_const('HTTP_SERVICE_CONFIG_SSL_FLAG_NEGOTIATE_CLIENT_CERT',0x00000002)
		win_const_mgr.add_const('MCI_OVLY_WINDOW_TEXT',0x00080000)
		win_const_mgr.add_const('AA_S_OPEN',0x00000010)
		win_const_mgr.add_const('TAPE_DRIVE_TENSION_IMMED',0x80000040)
		win_const_mgr.add_const('TBCDRF_USECDCOLORS',0x00800000)
		win_const_mgr.add_const('ADAM_REPL_AUTHENTICATION_MODE_NEGOTIATE_PASS_THROUGH',0x00000000)
		win_const_mgr.add_const('OID_GEN_GET_TIME_CAPS',0x0002020F)
		win_const_mgr.add_const('DSA_NOTIFY_REN',0x00000002)
		win_const_mgr.add_const('SMC_GETBKCONTEXTMENU',0x00000044)
		win_const_mgr.add_const('DBPROPVAL_TC_DML',0x00000001)
		win_const_mgr.add_const('DDSD_WIDTH',0x00000004)
		win_const_mgr.add_const('DE_E_CANNOT_LOCK_REQUEST',0x800C0016)
		win_const_mgr.add_const('MD_EXTLOG_SERVER_PORT',0x00008000)
		win_const_mgr.add_const('GROUP_ATTRIBUTES_PARMNUM',0x00000003)
		win_const_mgr.add_const('CM_DRP_INSTALL_STATE',0x00000023)
		win_const_mgr.add_const('SQL_SR_REFERENCES_COLUMN',0x00000800)
		win_const_mgr.add_const('ERROR_SEM_USER_LIMIT',0x0000006A)
		win_const_mgr.add_const('TVGN_ROOT',0x00000000)
		win_const_mgr.add_const('MSG_SERVICE_CONFIGURE',0x00000003)
		win_const_mgr.add_const('TBSTYLE_EX_DOUBLEBUFFER',0x00000080)
		win_const_mgr.add_const('ERROR_TXF_DIR_NOT_EMPTY',0x00001AAA)
		win_const_mgr.add_const('PATCH_TRANSFORM_PE_RESOURCE_2',0x00000100)
		win_const_mgr.add_const('SYMOPT_NO_PROMPTS',0x00080000)
		win_const_mgr.add_const('SECPKG_ATTR_REMOTE_CRED',0x00000051)
		win_const_mgr.add_const('DOT11_PSD_IE_MAX_ENTRY_NUMBER',0x00000005)
		win_const_mgr.add_const('ACE_INHERITED_OBJECT_TYPE_PRESENT',0x00000002)
		win_const_mgr.add_const('SQL_SCC_XOPEN_CLI_VERSION1',0x00000001)
		win_const_mgr.add_const('DI_MEMORYMAP_WRITE',0x00000001)
		win_const_mgr.add_const('VK_OEM_CLEAR',0x000000FE)
		win_const_mgr.add_const('NDIS_TCP_CONNECTION_OFFLOAD_REVISION_1',0x00000001)
		win_const_mgr.add_const('VER_ERR_TYPE_E',0x00004000)
		win_const_mgr.add_const('ILLUMINANT_D65',0x00000006)
		win_const_mgr.add_const('SQL_API_SQLCOLATTRIBUTES',0x00000006)
		win_const_mgr.add_const('RI_KEY_TERMSRV_SET_LED',0x00000008)
		win_const_mgr.add_const('S_PERIODVOICE',0x00000003)
		win_const_mgr.add_const('PDERR_DNDMMISMATCH',0x00001009)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_DEF_SUM_FLOW_RATE',0x00000021)
		win_const_mgr.add_const('DDSD_LPSURFACE',0x00000800)
		win_const_mgr.add_const('LINEERR_INVALAGENTGROUP',0x80000058)
		win_const_mgr.add_const('BS_BOTTOM',0x00000800)
		win_const_mgr.add_const('BL_28M',0x01C00000)
		win_const_mgr.add_const('PSM_BNEP',0x0000000F)
		win_const_mgr.add_const('CRYPT_OID_PUBKEY_ENCRYPT_ONLY_FLAG',0x40000000)
		win_const_mgr.add_const('WM_IME_KEYUP',0x00000291)
		win_const_mgr.add_const('IMAGE_REL_SH3_SIZEOF_SECTION',0x0000000D)
		win_const_mgr.add_const('DISPID_WINDOWSETWIDTH',0x0000010A)
		win_const_mgr.add_const('DISPID_WINDOWREGISTERED',0x000000C8)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_COMPUTERS',0x80000008)
		win_const_mgr.add_const('KF_FLAG_DEFAULT_PATH',0x00000400)
		win_const_mgr.add_const('TPM_RECURSE',0x00000001)
		win_const_mgr.add_const('VER_SUITE_PERSONAL',0x00000200)
		win_const_mgr.add_const('IDM_LEFTALIGNPARA',0x000008CB)
		win_const_mgr.add_const('MCI_OVLY_GETDEVCAPS_CAN_STRETCH',0x00004001)
		win_const_mgr.add_const('DISKQUOTA_USERNAME_RESOLVE_ASYNC',0x00000002)
		win_const_mgr.add_const('D3DDEVCAPS2_STREAMOFFSET',0x00000001)
		win_const_mgr.add_const('WIA_IPS_THRESHOLD',0x0000180F)
		win_const_mgr.add_const('AM_VIDEO_FLAG_B_SAMPLE',0x00000020)
		win_const_mgr.add_const('TVGN_LASTVISIBLE',0x0000000A)
		win_const_mgr.add_const('OID_ARCNET_CURRENT_ADDRESS',0x06010102)
		win_const_mgr.add_const('PRINTER_CONTROL_SET_STATUS',0x00000004)
		win_const_mgr.add_const('HTTP_STATUS_REQUEST_TOO_LARGE',0x0000019D)
		win_const_mgr.add_const('PDH_LOG_FILE_OPEN_ERROR',0xC0000BCA)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONNFAIL',0x00000011)
		win_const_mgr.add_const('VER_ERR_TYPE_1',0x00000800)
		win_const_mgr.add_const('SV_USERSECURITY',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_DOUBLE',0x00000007)
		win_const_mgr.add_const('PS_COSMETIC',0x00000000)
		win_const_mgr.add_const('PBT_APMQUERYSUSPENDFAILED',0x00000002)
		win_const_mgr.add_const('ICW_MAX_EMAILNAME',0x00000040)
		win_const_mgr.add_const('LVGS_HIDDEN',0x00000002)
		win_const_mgr.add_const('MDPROPVAL_MNF_AGGREGATE',0x00000010)
		win_const_mgr.add_const('VER_ERR_TYPE_2',0x00001000)
		win_const_mgr.add_const('TF_CLUIE_CURRENTPAGE',0x00000020)
		win_const_mgr.add_const('DIRID_USER',0x00008000)
		win_const_mgr.add_const('LINEMEDIACONTROL_RESUME',0x00000010)
		win_const_mgr.add_const('INTERNET_SUPPRESS_COOKIE_POLICY_RESET',0x00000002)
		win_const_mgr.add_const('GENERATE_METHOD_INFLECT',0x00000002)
		win_const_mgr.add_const('OID_GEN_XMIT_OK',0x00020101)
		win_const_mgr.add_const('TRUST_DIRECTION_DISABLED',0x00000000)
		win_const_mgr.add_const('SF_TEXT',0x00000001)
		win_const_mgr.add_const('CRYPTUI_DONT_OPEN_STORES',0x00000100)
		win_const_mgr.add_const('LOCALE_SCONSOLEFALLBACKNAME',0x00000006)
		win_const_mgr.add_const('CERT_KEY_PROV_HANDLE_PROP_ID',0x00000001)
		win_const_mgr.add_const('MSV1_0_CLEARTEXT_PASSWORD_ALLOWED',0x00000002)
		win_const_mgr.add_const('SDP_ATTRIB_HID_PARSER_VERSION',0x00000201)
		win_const_mgr.add_const('KAGPROP_ODBCSQLCONFORMANCE',0x00000012)
		win_const_mgr.add_const('REG_QWORD',0x0000000B)
		win_const_mgr.add_const('DDCAPS2_CERTIFIED',0x00000001)
		win_const_mgr.add_const('IF_NOLOCALICERTADMINBACKUP',0x00000080)
		win_const_mgr.add_const('OID_802_11_ADD_KEY',0x0D01011D)
		win_const_mgr.add_const('NIIF_INFO',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE',0x000036FF)
		win_const_mgr.add_const('SECURITY_FLAG_STRENGTH_WEAK',0x10000000)
		win_const_mgr.add_const('KSPROPERTY_SUPPORT_GET',0x00000001)
		win_const_mgr.add_const('NDIS_802_11_PMKID_CANDIDATE_PREAUTH_ENABLED',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_AM_REL32_2',0x00000006)
		win_const_mgr.add_const('ISC_REQ_SEQUENCE_DETECT',0x00000008)
		win_const_mgr.add_const('IMAGE_COMDAT_SELECT_NEWEST',0x00000007)
		win_const_mgr.add_const('MFBYTESTREAM_SEEK_FLAG_CANCEL_PENDING_IO',0x00000001)
		win_const_mgr.add_const('ICC_PROGRESS_CLASS',0x00000020)
		win_const_mgr.add_const('NT5_MAJOR_VERSION',0x00000003)
		win_const_mgr.add_const('NO_ERROR',0x00000000)
		win_const_mgr.add_const('DISPID_SEARCHCOMMAND_ERROR',0x00000006)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_FILTER_MEMORY',0x00000020)
		win_const_mgr.add_const('SS_ENDELLIPSIS',0x00004000)
		win_const_mgr.add_const('EMARCH_ENC_I17_SIGN_SIZE_X',0x00000001)
		win_const_mgr.add_const('GPO_BROWSE_INITTOALL',0x00000010)
		win_const_mgr.add_const('DS_LIST_ACCOUNT_OBJECT_FOR_SERVER',0x00000002)
		win_const_mgr.add_const('IF_TYPE_TR008',0x000000B0)
		win_const_mgr.add_const('D3DSTENCILCAPS_INCRSAT',0x00000008)
		win_const_mgr.add_const('URLACTION_FEATURE_SCRIPT_STATUS_BAR',0x00002103)
		win_const_mgr.add_const('PGS_HORZ',0x00000001)
		win_const_mgr.add_const('KS_VIDEO_FLAG_I_FRAME',0x00000000)
		win_const_mgr.add_const('CSURL_ADDTOCERTOCSP',0x00000020)
		win_const_mgr.add_const('IMAGE_ROM_OPTIONAL_HDR_MAGIC',0x00000107)
		win_const_mgr.add_const('SCERR_NOGUIDS',0x00008000)
		win_const_mgr.add_const('ARCONTENT_AUDIOCD',0x00000004)
		win_const_mgr.add_const('X3_IMM39_1_SIZE_X',0x00000017)
		win_const_mgr.add_const('MCS_WEEKNUMBERS',0x00000004)
		win_const_mgr.add_const('MOUSE_ATTRIBUTES_CHANGED',0x00000004)
		win_const_mgr.add_const('PORT_INGRESNET',0x00000086)
		win_const_mgr.add_const('TMT_WINDOWFRAME',0x00000647)
		win_const_mgr.add_const('MIXER_OBJECTF_MIXER',0x00000000)
		win_const_mgr.add_const('DFS_PROPERTY_FLAG_INSITE_REFERRALS',0x00000001)
		win_const_mgr.add_const('ERROR_NON_MDICHILD_WINDOW',0x000005A5)
		win_const_mgr.add_const('RSVP_PATH',0x00000001)
		win_const_mgr.add_const('CONTEXT_SERVICE_ACTIVE',0x10000000)
		win_const_mgr.add_const('ELEMENT_STATUS_INENAB',0x00000020)
		win_const_mgr.add_const('MDPROPVAL_NL_NAMEDLEVELS',0x00000001)
		win_const_mgr.add_const('CM_CDFLAGS_ROOT_OWNED',0x00000002)
		win_const_mgr.add_const('URL_CONVERT_IF_DOSPATH',0x00200000)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME5',0x00000048)
		win_const_mgr.add_const('PDH_MAX_INSTANCE_NAME',0x00000400)
		win_const_mgr.add_const('RPC_S_INVALID_ASYNC_HANDLE',0x0000077A)
		win_const_mgr.add_const('RESOURCE_MANAGER_MAXIMUM_OPTION',0x00000003)
		win_const_mgr.add_const('SDP_ATTRIB_PAN_SECURITY_DESCRIPTION',0x0000030A)
		win_const_mgr.add_const('KSAC3_SERVICE_HEARING_IMPAIRED',0x00000003)
		win_const_mgr.add_const('SQL_FN_STR_RIGHT',0x00000200)
		win_const_mgr.add_const('GETTRACKKERNTABLE',0x00000103)
		win_const_mgr.add_const('ERROR_DS_INVALID_GROUP_TYPE',0x00002141)
		win_const_mgr.add_const('SYMSTOREOPT_RETURNINDEX',0x00000004)
		win_const_mgr.add_const('TMT_COPYRIGHT',0x0000025D)
		win_const_mgr.add_const('DDLOCK_WRITEONLY',0x00000020)
		win_const_mgr.add_const('PRINTER_CHANGE_SET_JOB',0x00000200)
		win_const_mgr.add_const('MD_NOTIFY_LOG',0x00000200)
		win_const_mgr.add_const('WIA_FILM_BW_NEGATIVE',0x00000002)
		win_const_mgr.add_const('MB_TOPMOST',0x00040000)
		win_const_mgr.add_const('ERROR_QUORUM_RESOURCE_ONLINE_FAILED',0x000013A3)
		win_const_mgr.add_const('HKCOMB_NONE',0x00000001)
		win_const_mgr.add_const('OID_TAPI_DEV_SPECIFIC',0x07030107)
		win_const_mgr.add_const('DIF_NEWDEVICEWIZARD_POSTANALYZE',0x0000001D)
		win_const_mgr.add_const('SDP_ATTRIB_FAX_AUDIO_FEEDBACK_SUPPORT',0x00000305)
		win_const_mgr.add_const('DNS_RTYPE_MAILA',0x00000000)
		win_const_mgr.add_const('GL_APPLICATION_START',0x00000200)
		win_const_mgr.add_const('ADS_SERVICE_ERROR_SEVERE',0x00000002)
		win_const_mgr.add_const('SPEAKER_FRONT_LEFT',0x00000001)
		win_const_mgr.add_const('CRYPT_USER_KEYSET',0x00001000)
		win_const_mgr.add_const('WM_WINDOWPOSCHANGING',0x00000046)
		win_const_mgr.add_const('SQL_SP_BETWEEN',0x00000800)
		win_const_mgr.add_const('FNOINVERT',0x00000002)
		win_const_mgr.add_const('CR_DEFAULT',0x00000001)
		win_const_mgr.add_const('CB_GETITEMDATA',0x00000150)
		win_const_mgr.add_const('ERROR_RESTART_APPLICATION',0x000005BB)
		win_const_mgr.add_const('IDD_INSERTOBJECT',0x000003E8)
		win_const_mgr.add_const('DECODE_IS_USED',0x00000020)
		win_const_mgr.add_const('DWL_USER',0x00000008)
		win_const_mgr.add_const('PHOTO_ORIENTATION_TRANSPOSE',0x00000005)
		win_const_mgr.add_const('GD_ACCELERATORS',0x00000009)
		win_const_mgr.add_const('DISPID_IHTMLOPSPROFILE_DOWRITEREQUEST',0x00000009)
		win_const_mgr.add_const('ERROR_LOGIN_TIME_RESTRICTION',0x000004D7)
		win_const_mgr.add_const('ICU_NO_META',0x08000000)
		win_const_mgr.add_const('D3DCREATE_MULTITHREADED',0x00000004)
		win_const_mgr.add_const('GOPHER_TYPE_INLINE',0x00100000)
		win_const_mgr.add_const('SQL_SRJO_LEFT_OUTER_JOIN',0x00000040)
		win_const_mgr.add_const('CR_PROP_CANAME',0x00000006)
		win_const_mgr.add_const('OID_FDDI_MAC_OLD_DOWNSTREAM_NBR',0x03030228)
		win_const_mgr.add_const('DE_E_NO_SESSION',0x800C0003)
		win_const_mgr.add_const('MDM_V110_SPEED_28DOT8K',0x00000008)
		win_const_mgr.add_const('ARCONTENT_BLANKDVD',0x00000020)
		win_const_mgr.add_const('PSINJECT_PAGENUMBER',0x00000064)
		win_const_mgr.add_const('SV_TYPE_WORKSTATION',0x00000001)
		win_const_mgr.add_const('DDCAPS_NOHARDWARE',0x02000000)
		win_const_mgr.add_const('TBCD_TICS',0x00000001)
		win_const_mgr.add_const('LWS_IGNORERETURN',0x00000002)
		win_const_mgr.add_const('RTM_VIEW_ID_MCAST',0x00000001)
		win_const_mgr.add_const('TMT_NAME',0x00000258)
		win_const_mgr.add_const('EVT_VARIANT_TYPE_MASK',0x00000007)
		win_const_mgr.add_const('ELEMENT_STATUS_LUN_VALID',0x00001000)
		win_const_mgr.add_const('SYMF_OMAP_MODIFIED',0x00000002)
		win_const_mgr.add_const('FLG_BITREG_SETBITS',0x00000001)
		win_const_mgr.add_const('KSPIN_FLAG_SOME_FRAMES_REQUIRED_FOR_PROCESSING',0x00800000)
		win_const_mgr.add_const('TCS_VERTICAL',0x00000080)
		win_const_mgr.add_const('IPX_BASE_ENTRY',0x00000000)
		win_const_mgr.add_const('USER_CODE_DESCRIPTOR',0xCFBFFFFF00000000)
		win_const_mgr.add_const('FILE_ADD_FILE',0x00000002)
		win_const_mgr.add_const('SUBLANG_ARABIC_LIBYA',0x00000004)
		win_const_mgr.add_const('ERROR_PRINTER_DRIVER_IN_USE',0x00000BB9)
		win_const_mgr.add_const('ETW_BOOLEAN_TYPE_VALUE',0x0000000E)
		win_const_mgr.add_const('LOCALE_ICOUNTRY',0x00000005)
		win_const_mgr.add_const('BOE_NEUTRALOVERRIDE',0x00000004)
		win_const_mgr.add_const('CM_DEVCAP_UNIQUEID',0x00000010)
		win_const_mgr.add_const('SECPKG_ATTR_LOGOFF_TIME',0x00000015)
		win_const_mgr.add_const('MCAST_JOIN_GROUP',0x00000029)
		win_const_mgr.add_const('PLAL_ALERT_CMD_LINE_MASK',0x00007F00)
		win_const_mgr.add_const('PRINTER_CONTROL_PURGE',0x00000003)
		win_const_mgr.add_const('SQLAOPMIN',0x00000051)
		win_const_mgr.add_const('DEBUG_ADDSYNTHMOD_DEFAULT',0x00000000)
		win_const_mgr.add_const('MF_64_BYTE_ALIGNMENT',0x00000003)
		win_const_mgr.add_const('DBIM_ACTUAL',0x00000008)
		win_const_mgr.add_const('CERT_ENCODING_TYPE_MASK',0x0000FFFF)
		win_const_mgr.add_const('IF_TYPE_SLIP',0x0000001C)
		win_const_mgr.add_const('RAS_EAP_FLAG_SAVE_CREDMAN',0x00200000)
		win_const_mgr.add_const('AD_GETWP_IMAGE',0x00000001)
		win_const_mgr.add_const('CHANNEL_RC_NO_MEMORY',0x0000000C)
		win_const_mgr.add_const('TASK_FLAG_KILL_IF_GOING_ON_BATTERIES',0x00000080)
		win_const_mgr.add_const('PAN_LETT_NORMAL_ROUNDED',0x00000006)
		win_const_mgr.add_const('SIOM_RESERVED_SLOWFILE',0x00000002)
		win_const_mgr.add_const('SCARD_READER_TYPE_USB',0x00000020)
		win_const_mgr.add_const('DRM_EL_MACHINE',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_SET_COOKIE',0x0000002B)
		win_const_mgr.add_const('EDITF_ENABLEAKIISSUERNAME',0x00000800)
		win_const_mgr.add_const('URLPOLICY_CHANNEL_SOFTDIST_PROHIBIT',0x00010000)
		win_const_mgr.add_const('LSA_TLN_DISABLED_NEW',0x00000001)
		win_const_mgr.add_const('SM_CYICONSPACING',0x00000027)
		win_const_mgr.add_const('MDM_V110_SPEED_2DOT4K',0x00000002)
		win_const_mgr.add_const('ERROR_LOGON_SESSION_EXISTS',0x00000553)
		win_const_mgr.add_const('DSS_PREFIXONLY',0x00000400)
		win_const_mgr.add_const('INCL_WINSOCK_API_PROTOTYPES',0x00000001)
		win_const_mgr.add_const('HTTP_SEND_RESPONSE_FLAG_DISCONNECT',0x00000001)
		win_const_mgr.add_const('EC_REPAINT',0x00000005)
		win_const_mgr.add_const('LINECALLFEATURE2_COMPLMESSAGE',0x00000020)
		win_const_mgr.add_const('FRAME_TSS',0x00000002)
		win_const_mgr.add_const('HCDC_PROTOCOL_UUID16',0x00000014)
		win_const_mgr.add_const('ITWW_OPEN_NOCONNECT',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_ENCODING',0x0000001D)
		win_const_mgr.add_const('ERROR_INVALID_SERVICENAME',0x000004BD)
		win_const_mgr.add_const('AUXCAPS_CDAUDIO',0x00000001)
		win_const_mgr.add_const('IF_TYPE_X25_PLE',0x00000028)
		win_const_mgr.add_const('LVS_EX_FLATSB',0x00000100)
		win_const_mgr.add_const('ALG_SID_SHA_512',0x0000000E)
		win_const_mgr.add_const('FWPS_INCOMING_FLAG_ABSORB',0x00000004)
		win_const_mgr.add_const('INTERNET_REQFLAG_VIA_PROXY',0x00000004)
		win_const_mgr.add_const('TRUSTERROR_STEP_FINAL_CERTPROV',0x00000022)
		win_const_mgr.add_const('DBPROPVAL_CB_NULL',0x00000001)
		win_const_mgr.add_const('RAS_FLAGS_MESSENGER_PRESENT',0x00000002)
		win_const_mgr.add_const('D3D10_SHADER_PACK_MATRIX_ROW_MAJOR',0x00000001)
		win_const_mgr.add_const('WNODE_FLAG_USE_TIMESTAMP',0x00000200)
		win_const_mgr.add_const('LINETRANSLATERESULT_VOICEDETECT',0x00000400)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST5',0x0000004D)
		win_const_mgr.add_const('STGFMT_DOCUMENT',0x00000000)
		win_const_mgr.add_const('PHOTO_PROGRAMMODE_MANUAL',0x00000001)
		win_const_mgr.add_const('FILE_DEVICE_TAPE_FILE_SYSTEM',0x00000020)
		win_const_mgr.add_const('SERVICE_NO_TRAFFIC_CONTROL',0x81000000)
		win_const_mgr.add_const('OLEMISC_ALIGNABLE',0x00008000)
		win_const_mgr.add_const('CR_CALL_NOT_IMPLEMENTED',0x00000034)
		win_const_mgr.add_const('TMT_COLORIZATIONCOLOR',0x0000097F)
		win_const_mgr.add_const('DEBUG_REQUEST_READ_CAPTURED_EVENT_CODE_STREAM',0x0000000B)
		win_const_mgr.add_const('PTE_ACCESS_MASK',0x00000020)
		win_const_mgr.add_const('TMT_BTNSHADOW',0x00000651)
		win_const_mgr.add_const('RBHT_CHEVRON',0x00000008)
		win_const_mgr.add_const('DXVA_AYUV_BUFFER',0x00000008)
		win_const_mgr.add_const('PHONEERR_SERVICE_NOT_RUNNING',0x90000025)
		win_const_mgr.add_const('TVS_INFOTIP',0x00000800)
		win_const_mgr.add_const('LUP_RETURN_QUERY_STRING',0x00000800)
		win_const_mgr.add_const('OID_TCP6_OFFLOAD_STATS',0xFC010208)
		win_const_mgr.add_const('BTHNS_RESULT_DEVICE_CONNECTED',0x00010000)
		win_const_mgr.add_const('CF_METAFILEPICT',0x00000003)
		win_const_mgr.add_const('PHOTO_PHOTOMETRIC_YCBCR',0x00000006)
		win_const_mgr.add_const('MCI_DGV_FF_RJPEG',0x00004005)
		win_const_mgr.add_const('CRYPT_STRING_HEXADDR',0x00000000)
		win_const_mgr.add_const('CM_PROB_DISABLED',0x00000016)
		win_const_mgr.add_const('EAP_E_EAPHOST_LAST',0x804200FF)
		win_const_mgr.add_const('IKEEXT_POLICY_FLAG_ENABLE_OPTIONAL_DH',0x00000008)
		win_const_mgr.add_const('DNS_RCODE_MAX',0x0000000F)
		win_const_mgr.add_const('ERROR_DS_ILLEGAL_MOD_OPERATION',0x00002077)
		win_const_mgr.add_const('PERF_OBJECT_TIMER',0x00200000)
		win_const_mgr.add_const('OID_TAPI_ACCEPT',0x07030101)
		win_const_mgr.add_const('TXTLOG_UMPNPMGR',0x02000000)
		win_const_mgr.add_const('DN_RW',0x00000003)
		win_const_mgr.add_const('ERROR_WMI_INSTANCE_NOT_FOUND',0x00001069)
		win_const_mgr.add_const('DBPROPVAL_LM_NONE',0x00000001)
		win_const_mgr.add_const('NCRYPT_SILENT_FLAG',0x00000040)
		win_const_mgr.add_const('METADATA_NON_SECURE_ONLY',0x00000100)
		win_const_mgr.add_const('PC_FOLLOWING',0x00000001)
		win_const_mgr.add_const('X3_IMM39_2_SIZE_X',0x00000010)
		win_const_mgr.add_const('IMEA_INIT',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_AM_SECTION',0x00000008)
		win_const_mgr.add_const('DEBUG_REQUEST_GET_CAPTURED_EVENT_CODE_OFFSET',0x0000000A)
		win_const_mgr.add_const('ERROR_DS_CANT_MOD_SYSTEM_ONLY',0x000020B1)
		win_const_mgr.add_const('D3DCAPS2_CANMANAGERESOURCE',0x10000000)
		win_const_mgr.add_const('KSDATAFORMAT_TEMPORAL_COMPRESSION',0x00000001)
		win_const_mgr.add_const('PROOF_MODE',0x00000001)
		win_const_mgr.add_const('DFS_PROPERTY_FLAG_SITE_COSTING',0x00000004)
		win_const_mgr.add_const('ERROR_DOMAIN_TRUST_INCONSISTENT',0x00000712)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_SETWRITESPEED',0x00000204)
		win_const_mgr.add_const('PRINTER_NOTIFY_INFO_DISCARDED',0x00000001)
		win_const_mgr.add_const('SB_PIXEL_ALPHA',0x00000002)
		win_const_mgr.add_const('WKSTA_NUMCHARBUF_PARMNUM',0x00000016)
		win_const_mgr.add_const('ERROR_DELAY_LOAD_FAILED',0x00000505)
		win_const_mgr.add_const('FS_VIETNAMESE',0x00000100)
		win_const_mgr.add_const('NETERR_RING_STATUS_SOFT_ERROR',0x00002000)
		win_const_mgr.add_const('CAUSE_LOC_PUBLIC_REMOTE',0x00000004)
		win_const_mgr.add_const('CLRES_VERSION_V1_00',0x00000100)
		win_const_mgr.add_const('WSA_QOS_EFILTERCOUNT',0x00002B0D)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_13',0x00000000)
		win_const_mgr.add_const('TBSTATE_INDETERMINATE',0x00000010)
		win_const_mgr.add_const('WGL_SWAPMULTIPLE_MAX',0x00000010)
		win_const_mgr.add_const('DI_FLAGSEX_FINISHINSTALL_ACTION',0x00000008)
		win_const_mgr.add_const('PHONEERR_INCOMPATIBLEAPIVERSION',0x90000003)
		win_const_mgr.add_const('DS_DS_FLAG',0x00000010)
		win_const_mgr.add_const('IDIGNORE',0x00000005)
		win_const_mgr.add_const('ACMFILTERCHOOSE_STYLEF_ENABLEHOOK',0x00000008)
		win_const_mgr.add_const('ERROR_I24_BAD_UNIT',0x00000001)
		win_const_mgr.add_const('WLX_SAS_TYPE_CTRL_ALT_DEL',0x00000001)
		win_const_mgr.add_const('IKEEXT_POLICY_FLAG_NO_MACHINE_LUID_VERIFY',0x00000002)
		win_const_mgr.add_const('CERT_STORE_BASE_CRL_FLAG',0x00000100)
		win_const_mgr.add_const('FEI_FATAL_ERROR',0x00000000)
		win_const_mgr.add_const('IOCTL_MTP_CUSTOM_COMMAND',0x03150544)
		win_const_mgr.add_const('DEBUG_MODULE_USER_MODE',0x00000002)
		win_const_mgr.add_const('MCI_GETDEVCAPS_COMPOUND_DEVICE',0x00000006)
		win_const_mgr.add_const('OID_FDDI_IF_OUT_UCAST_PKTS',0x03030288)
		win_const_mgr.add_const('PXE_TRACE_ERROR',0x00080000)
		win_const_mgr.add_const('WMIREG_FLAG_RESERVED2',0x00040000)
		win_const_mgr.add_const('INDEX_GUID_TOPINKBREAKSONLY',0x00000009)
		win_const_mgr.add_const('BSM_ALLDESKTOPS',0x00000010)
		win_const_mgr.add_const('WMIREG_FLAG_RESERVED1',0x00020000)
		win_const_mgr.add_const('FWPM_NET_EVENT_FLAG_SCOPE_ID_SET',0x00000080)
		win_const_mgr.add_const('RBNM_LPARAM',0x00000004)
		win_const_mgr.add_const('DEBUG_OUTTYPE_VERBOSE',0x00000004)
		win_const_mgr.add_const('ICDRAW_FULLSCREEN',0x00000002)
		win_const_mgr.add_const('MCIWNDOPENF_NEW',0x00000001)
		win_const_mgr.add_const('MAX_ERROR_TEXT_LEN',0x000000A0)
		win_const_mgr.add_const('ERROR_FILE_NOT_FOUND',0x00000002)
		win_const_mgr.add_const('OID_FDDI_PORT_CONNECTION_POLICIES',0x0303025E)
		win_const_mgr.add_const('XEKL_KEYSIZE_DEFAULT',0x00000004)
		win_const_mgr.add_const('DPNHADDRESSTYPE_GATEWAY',0x00000010)
		win_const_mgr.add_const('D3DSTREAMSOURCE_INDEXEDDATA',0x00000001)
		win_const_mgr.add_const('OID_GEN_OPERATIONAL_STATUS',0x00010283)
		win_const_mgr.add_const('DB_BINDFLAGS_RECURSIVE',0x00000004)
		win_const_mgr.add_const('MCN_LAST',0x00000000)
		win_const_mgr.add_const('RPC_C_MQ_TEMPORARY',0x00000000)
		win_const_mgr.add_const('RPC_IF_SEC_CACHE_PER_PROC',0x00000080)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_15',0x0000000F)
		win_const_mgr.add_const('RTCMT_T120_SENDRECV',0x00000010)
		win_const_mgr.add_const('SSA_GLYPHS',0x00000080)
		win_const_mgr.add_const('IDM_HORIZSPACEINCREASE',0x00000017)
		win_const_mgr.add_const('LINEDEVSTATE_MSGWAITON',0x00000010)
		win_const_mgr.add_const('LINECALLFEATURE_SETCALLPARAMS',0x00200000)
		win_const_mgr.add_const('CMSG_RC4_NO_SALT_FLAG',0x40000000)
		win_const_mgr.add_const('SECPKG_ATTR_MAPPED_CRED_ATTR',0x00000005)
		win_const_mgr.add_const('SV_PLATFORM_ID_PARMNUM',0x00000065)
		win_const_mgr.add_const('WEBPOST_ERROR_INVALID_POSTINFO',0x40042118)
		win_const_mgr.add_const('SECURITY_WRITE_RESTRICTED_CODE_RID',0x00000021)
		win_const_mgr.add_const('STREAM_FORMAT_WIN32_MANIFEST',0x00000004)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_SHAREADMIN',0x00000008)
		win_const_mgr.add_const('WLX_OPTION_SMART_CARD_PRESENT',0x00010001)
		win_const_mgr.add_const('DMPAPER_A3',0x00000008)
		win_const_mgr.add_const('LVIF_STATE',0x00000008)
		win_const_mgr.add_const('D3D10_EFFECT_COMPILE_CHILD_EFFECT',0x00000001)
		win_const_mgr.add_const('DMPAPER_A4',0x00000009)
		win_const_mgr.add_const('CRYPT_MODE_CFBP',0x00000007)
		win_const_mgr.add_const('IMAGE_REL_AMD64_SREL32',0x0000000E)
		win_const_mgr.add_const('MAPI_E_NO_MESSAGES',0x00000010)
		win_const_mgr.add_const('EXPOSUREMETERING_AVERAGE',0x00000001)
		win_const_mgr.add_const('PIR_STATUS_MINIPORT_ERROR',0x00000004)
		win_const_mgr.add_const('CERT_STORE_PROV_READ_CTL_FUNC',0x00000009)
		win_const_mgr.add_const('GESTURE_DIGIT_4',0x00000000)
		win_const_mgr.add_const('MP_STATUS_SUCCESS',0x00000000)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_SAMPLE_BLENDING',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_DST_MDP',0x00000002)
		win_const_mgr.add_const('D3DVS20_MIN_DYNAMICFLOWCONTROLDEPTH',0x00000000)
		win_const_mgr.add_const('SCSI_IOCTL_DATA_IN',0x00000001)
		win_const_mgr.add_const('WH_FOREGROUNDIDLE',0x0000000B)
		win_const_mgr.add_const('IDC_VP_RELATIVE',0x000003ED)
		win_const_mgr.add_const('RESOURCEMANAGER_GET_NOTIFICATION',0x00000010)
		win_const_mgr.add_const('CIF_SHOWHELP',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_SETUP_BASE',0x0000267A)
		win_const_mgr.add_const('SV_USERS_PER_LICENSE',0x00000005)
		win_const_mgr.add_const('INTERNET_CACHE_FLAG_GET_STRUCT_ONLY',0x00001000)
		win_const_mgr.add_const('PCS_FATAL',0x80000000)
		win_const_mgr.add_const('SQL_DIAG_CREATE_TRANSLATION',0x0000004F)
		win_const_mgr.add_const('WNFMT_MULTILINE',0x00000001)
		win_const_mgr.add_const('URLACTION_SHELL_MIN',0x00001800)
		win_const_mgr.add_const('OPTION_MESSAGE_TYPE',0x00000035)
		win_const_mgr.add_const('SM_CXFULLSCREEN',0x00000010)
		win_const_mgr.add_const('X3_I_SIGN_VAL_POS_X',0x0000003B)
		win_const_mgr.add_const('OID_ATM_MAX_AAL0_PACKET_SIZE',0x08010108)
		win_const_mgr.add_const('SW_AUTOPROF_LOAD_MASK',0x00000001)
		win_const_mgr.add_const('EMR_ENDPATH',0x0000003C)
		win_const_mgr.add_const('VMR_RENDER_DEVICE_OVERLAY',0x00000001)
		win_const_mgr.add_const('FW_DONTCARE',0x00000000)
		win_const_mgr.add_const('IF_TYPE_BASIC_ISDN',0x00000014)
		win_const_mgr.add_const('DBIM_TITLE',0x00000010)
		win_const_mgr.add_const('ERROR_I24_WRONG_DISK',0x0000000F)
		win_const_mgr.add_const('TABLE_SORT_DONE',0x00000006)
		win_const_mgr.add_const('SQL_NULL_HDESC',0x00000000)
		win_const_mgr.add_const('INDEX_GUID_PREFIXTEXT',0x00000005)
		win_const_mgr.add_const('ERROR_INVALID_SERVER_STATE',0x00000548)
		win_const_mgr.add_const('MCI_DGV_STATUS_MONITOR',0x00000400)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_INACTIVE',0x00000008)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_15',0x00000000)
		win_const_mgr.add_const('UNDNAME_COMPLETE',0x00000000)
		win_const_mgr.add_const('CERT_INFO_VERSION_FLAG',0x00000001)
		win_const_mgr.add_const('GL_THREAD_CLEANUP',0x00008000)
		win_const_mgr.add_const('IDF_NOBROWSE',0x00000001)
		win_const_mgr.add_const('VTBIT_UI4',0x00000001)
		win_const_mgr.add_const('TRANSACTION_MANAGER_COMMIT_LOWEST',0x00000008)
		win_const_mgr.add_const('WM_HOTKEY',0x00000312)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_SECURITY',0x0000000D)
		win_const_mgr.add_const('CRYPT_RETRIEVE_MULTIPLE_OBJECTS',0x00000001)
		win_const_mgr.add_const('DXVA_QUERYORREPLYFUNCFLAG_DECODER_LOCK_QUERY',0x00FFFFF5)
		win_const_mgr.add_const('DOT11_ENCAP_RFC_1042',0x00000001)
		win_const_mgr.add_const('STGM_PRIORITY',0x00040000)
		win_const_mgr.add_const('HTTP_QUERY_COOKIE',0x0000002C)
		win_const_mgr.add_const('CONTEXT_EXCEPTION_ACTIVE',0x08000000)
		win_const_mgr.add_const('OID_GEN_RECEIVE_SCALE_PARAMETERS',0x00010204)
		win_const_mgr.add_const('WMS_VER_MAJOR',0x00000009)
		win_const_mgr.add_const('IO_REPARSE_TAG_MOUNT_POINT',0xA0000003)
		win_const_mgr.add_const('INTERNET_FLAG_NEED_FILE',0x00000010)
		win_const_mgr.add_const('TVHT_TORIGHT',0x00000400)
		win_const_mgr.add_const('WIA_DPS_TRANSPARENCY_STATUS',0x00000C23)
		win_const_mgr.add_const('PRIVACY_URLISTOPLEVEL',0x00010000)
		win_const_mgr.add_const('LOCALE_IDATE',0x00000021)
		win_const_mgr.add_const('PROCESS_QUERY_LIMITED_INFORMATION',0x00001000)
		win_const_mgr.add_const('XP_GRACEFUL_CLOSE',0x00000020)
		win_const_mgr.add_const('SERVICE_IP_NO_HINT',0x00000000)
		win_const_mgr.add_const('LONGHORN_MAJOR_VERSION',0x00000005)
		win_const_mgr.add_const('ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION',0x00001AC5)
		win_const_mgr.add_const('HSE_URL_FLAGS_WRITE',0x00000002)
		win_const_mgr.add_const('JIFMK_EOI',0x0000FFD9)
		win_const_mgr.add_const('LINEMEDIAMODE_DATAMODEM',0x00000010)
		win_const_mgr.add_const('JOY_RETURNY',0x00000002)
		win_const_mgr.add_const('CERT_INFO_ISSUER_UNIQUE_ID_FLAG',0x00000009)
		win_const_mgr.add_const('KSEVENT_ENTRY_BUFFERED',0x00000004)
		win_const_mgr.add_const('VARIANT_CALENDAR_GREGORIAN',0x00000040)
		win_const_mgr.add_const('CR_PROP_CASIGCERT',0x0000000C)
		win_const_mgr.add_const('DS_REPDEL_WRITEABLE',0x00000002)
		win_const_mgr.add_const('CM_PROB_DEVLOADER_NOT_READY',0x00000017)
		win_const_mgr.add_const('LVIF_COLUMNS',0x00000200)
		win_const_mgr.add_const('DRIVE_NO_ROOT_DIR',0x00000001)
		win_const_mgr.add_const('SB_TOP',0x00000006)
		win_const_mgr.add_const('SVAUD_SERVICE',0x00000001)
		win_const_mgr.add_const('LF32_FREE',0x00000002)
		win_const_mgr.add_const('EC_STREAM_CONTROL_STOPPED',0x0000001A)
		win_const_mgr.add_const('ERROR_SEVERITY_WARNING',0x80000000)
		win_const_mgr.add_const('PHOTO_METERINGMODE_PARTIAL',0x00000006)
		win_const_mgr.add_const('SQL_CVT_TIME',0x00010000)
		win_const_mgr.add_const('MOD_MAPPER',0x00000005)
		win_const_mgr.add_const('OID_FDDI_PATH_RING_LATENCY',0x03030252)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_CONFIGURATION_OBJECT',0x000000A9)
		win_const_mgr.add_const('PF_XMMI_INSTRUCTIONS_AVAILABLE',0x00000006)
		win_const_mgr.add_const('ACM_METRIC_HARDWARE_WAVE_INPUT',0x0000001E)
		win_const_mgr.add_const('FILE_DEVICE_NETWORK',0x00000012)
		win_const_mgr.add_const('INTERNET_COOKIE_IS_SECURE',0x00000001)
		win_const_mgr.add_const('PDE_OFFSET_LEN',0x0000000A)
		win_const_mgr.add_const('IP_ADD_IFLIST',0x0000001D)
		win_const_mgr.add_const('PDH_LOG_TYPE_NOT_FOUND',0xC0000BCB)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_CONFERENCEHELD',0x00004000)
		win_const_mgr.add_const('SECPKG_STATE_WORKSTATION',0x00000008)
		win_const_mgr.add_const('SV_PRODUCTTYPE_PARMNUM',0x00000230)
		win_const_mgr.add_const('SS_BLACKRECT',0x00000004)
		win_const_mgr.add_const('IDM_TRIED_GETBLOCKFMTS',0x00000027)
		win_const_mgr.add_const('COMP_ELEM_CURITEMSTATE',0x00004000)
		win_const_mgr.add_const('IDM_SHOWGRID',0x00000045)
		win_const_mgr.add_const('EVENT_CONSOLE_UPDATE_REGION',0x00004002)
		win_const_mgr.add_const('DLGC_DEFPUSHBUTTON',0x00000010)
		win_const_mgr.add_const('ERROR_SPL_NO_STARTDOC',0x00000BBB)
		win_const_mgr.add_const('NUMPRS_DECIMAL',0x00000100)
		win_const_mgr.add_const('RPC_C_AUTHZ_NAME',0x00000001)
		win_const_mgr.add_const('AE_LIM_EXPIRED',0x00000002)
		win_const_mgr.add_const('PLATFORM_ID_NT',0x000001F4)
		win_const_mgr.add_const('OID_TAPI_GET_DEV_CONFIG',0x07030111)
		win_const_mgr.add_const('MF_BYPOSITION',0x00000400)
		win_const_mgr.add_const('DDBLT_ALPHASRCCONSTOVERRIDE',0x00000040)
		win_const_mgr.add_const('LVIS_CUT',0x00000004)
		win_const_mgr.add_const('DTBG_OMITCONTENT',0x00000008)
		win_const_mgr.add_const('FWPS_INCOMING_FLAG_CONNECTION_FAILING_INDICATION',0x00000008)
		win_const_mgr.add_const('PIDDSI_COMPANY',0x0000000F)
		win_const_mgr.add_const('IME_SMODE_PHRASEPREDICT',0x00000008)
		win_const_mgr.add_const('SPQ_FLAG_ABORT_IF_UNSIGNED',0x00000002)
		win_const_mgr.add_const('OID_GEN_MAC_OPTIONS',0x00010113)
		win_const_mgr.add_const('DS_CENTERMOUSE',0x00001000)
		win_const_mgr.add_const('UNICODE_STRING_MAX_CHARS',0x00007FFF)
		win_const_mgr.add_const('CM_SETUP_WRITE_LOG_CONFS',0x00000002)
		win_const_mgr.add_const('CMSG_SIGNED_FLAG',0x00000001)
		win_const_mgr.add_const('ERROR_NO_CHILD_PROCESS',0x000000B8)
		win_const_mgr.add_const('ERROR_MEMBER_NOT_IN_GROUP',0x00000529)
		win_const_mgr.add_const('CFE_SUBSCRIPT',0x00010000)
		win_const_mgr.add_const('OFN_ENABLETEMPLATE',0x00000040)
		win_const_mgr.add_const('IMAGE_DLLCHARACTERISTICS_NO_ISOLATION',0x00000200)
		win_const_mgr.add_const('CM_DELETE_CLASS_BITS',0x00000003)
		win_const_mgr.add_const('BACKUP_TXFS_DATA',0x00000000)
		win_const_mgr.add_const('AVRF_ENUM_RESOURCES_FLAGS_DONT_RESOLVE_TRACES',0x00000002)
		win_const_mgr.add_const('SPEAKER_TOP_BACK_RIGHT',0x00020000)
		win_const_mgr.add_const('SQL_IK_NONE',0x00000000)
		win_const_mgr.add_const('UP_P2P',0x00000000)
		win_const_mgr.add_const('UI_CURRENT_PROVIDER_FIRST',0x00000004)
		win_const_mgr.add_const('VK_ESCAPE',0x0000001B)
		win_const_mgr.add_const('COMMON_LVB_GRID_RVERTICAL',0x00001000)
		win_const_mgr.add_const('ALG_SID_ECDSA',0x00000003)
		win_const_mgr.add_const('TMT_DISPLAYNAME',0x00000259)
		win_const_mgr.add_const('WMDM_SEEK_REMOTECONTROL',0x00000001)
		win_const_mgr.add_const('ADS_SERVICE_PAUSE_PENDING',0x00000006)
		win_const_mgr.add_const('KSMETHOD_TYPE_MODIFY',0x00000003)
		win_const_mgr.add_const('CTFMODEBIAS_FULLWIDTHALPHANUMERIC',0x0000000B)
		win_const_mgr.add_const('IMAGE_REL_SH3_DIRECT16',0x00000001)
		win_const_mgr.add_const('IITWBC_BREAK_ACCEPT_WILDCARDS',0x00000001)
		win_const_mgr.add_const('WM_MENUCOMMAND',0x00000126)
		win_const_mgr.add_const('CI_STATE_BATTERY_POWER',0x00000800)
		win_const_mgr.add_const('SRCLIST_SYSTEM',0x00000010)
		win_const_mgr.add_const('MIB_IPADDR_DISCONNECTED',0x00000008)
		win_const_mgr.add_const('READ_THRESHOLD_BUFFER_SIZE',0x00000200)
		win_const_mgr.add_const('SW_INVALIDATE',0x00000002)
		win_const_mgr.add_const('MAX_L2CAP_INFO_DATA_LENGTH',0x0000002C)
		win_const_mgr.add_const('BG_E_SERVER_EXECUTE_ENABLE',0x80200023)
		win_const_mgr.add_const('WM_PAINTICON',0x00000026)
		win_const_mgr.add_const('WSAENETUNREACH',0x00002743)
		win_const_mgr.add_const('MDPROPVAL_MNF_LINREG2',0x00000200)
		win_const_mgr.add_const('PARTTYPE_MASK',0x00030000)
		win_const_mgr.add_const('RF_DEMAND_UPDATE_ROUTES',0x00000004)
		win_const_mgr.add_const('DISPID_REFRESHDOC',0x00000020)
		win_const_mgr.add_const('ENM_PARAGRAPHEXPANDED',0x00000020)
		win_const_mgr.add_const('SQL_DIAG_DYNAMIC_DELETE_CURSOR',0x00000026)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_GLOBALPTR',0x00000008)
		win_const_mgr.add_const('SO_BTH_MTU_MIN',0x08000000)
		win_const_mgr.add_const('LINETERMSHARING_SHAREDEXCL',0x00000002)
		win_const_mgr.add_const('CMSG_CTRL_DEL_CRL',0x0000000D)
		win_const_mgr.add_const('PSBTN_MAX',0x00000006)
		win_const_mgr.add_const('DNS_RTYPE_A',0x00000100)
		win_const_mgr.add_const('MD_LOGFILE_PERIOD_MAXSIZE',0x00000000)
		win_const_mgr.add_const('DDLOCK_READONLY',0x00000010)
		win_const_mgr.add_const('CBN_SELENDCANCEL',0x0000000A)
		win_const_mgr.add_const('PDH_LOG_FILE_CREATE_ERROR',0xC0000BC9)
		win_const_mgr.add_const('ICM_ADDPROFILE',0x00000001)
		win_const_mgr.add_const('NS_NTDS',0x00000020)
		win_const_mgr.add_const('NOTE_COLOR_PINK',0x00000002)
		win_const_mgr.add_const('SESSION_QUERY_ACCESS',0x00000001)
		win_const_mgr.add_const('LMEM_LOCKCOUNT',0x000000FF)
		win_const_mgr.add_const('DOT11_MAX_NUM_DEFAULT_KEY',0x00000004)
		win_const_mgr.add_const('FWPM_TUNNEL_FLAG_POINT_TO_POINT',0x00000001)
		win_const_mgr.add_const('LINECALLINFOSTATE_REDIRECTINGID',0x00080000)
		win_const_mgr.add_const('DN_NEEDS_LOCKING',0x02000000)
		win_const_mgr.add_const('WIA_PHOTO_WHITE_1',0x00000000)
		win_const_mgr.add_const('ERROR_CTX_MODEM_INF_NOT_FOUND',0x00001B61)
		win_const_mgr.add_const('COD_LAN_ACCESS_67_USED',0x00000004)
		win_const_mgr.add_const('LAYOUT_VBH',0x00000004)
		win_const_mgr.add_const('ERROR_LOCK_VIOLATION',0x00000021)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_CONFERENCEMAKE',0x00008000)
		win_const_mgr.add_const('SYMFLAG_REGREL',0x00000010)
		win_const_mgr.add_const('MCI_VCR_SETTUNER_CHANNEL',0x00010000)
		win_const_mgr.add_const('HDF_OWNERDRAW',0x00008000)
		win_const_mgr.add_const('TTFCFP_FLAGS_TTC',0x00000004)
		win_const_mgr.add_const('EC_READ_ACCESS',0x00000001)
		win_const_mgr.add_const('NCRYPT_IMPL_SOFTWARE_FLAG',0x00000002)
		win_const_mgr.add_const('DIRID_HELP',0x00000012)
		win_const_mgr.add_const('RF_OBJECT',0x00000002)
		win_const_mgr.add_const('NDW_INSTALLFLAG_SKIPISDEVINSTALLED',0x00000800)
		win_const_mgr.add_const('DTT_BORDERCOLOR',0x00000001)
		win_const_mgr.add_const('D3DCREATE_DISABLE_PRINTSCREEN',0x00008000)
		win_const_mgr.add_const('WC_ERR_INVALID_CHARS',0x00000080)
		win_const_mgr.add_const('HTTP_MINOR_VERSION',0x00000000)
		win_const_mgr.add_const('GCS_UNICODE',0x00000004)
		win_const_mgr.add_const('JS_RETRYING',0x00000020)
		win_const_mgr.add_const('RSOP_INFO_FLAG_DIAGNOSTIC_MODE',0x00000001)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_MULTICAST_MGMT',0x00080000)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_DBGPRINT',0x00040000)
		win_const_mgr.add_const('NS_SLP',0x00000005)
		win_const_mgr.add_const('EC_FULLSCREEN_LOST',0x00000012)
		win_const_mgr.add_const('IP_ADAPTER_ADDRESS_DNS_ELIGIBLE',0x00000001)
		win_const_mgr.add_const('NT_FE_CONSOLE_PROPS_SIG',0xA0000004)
		win_const_mgr.add_const('IOF_SELECTCREATECONTROL',0x00002000)
		win_const_mgr.add_const('PIPE_ACCESS_INBOUND',0x00000001)
		win_const_mgr.add_const('PIDDSI_LINECOUNT',0x00000005)
		win_const_mgr.add_const('LR_CREATEDIBSECTION',0x00002000)
		win_const_mgr.add_const('IF_TYPE_ISDN_U',0x0000004C)
		win_const_mgr.add_const('SECPKG_CALL_URGENT',0x00000004)
		win_const_mgr.add_const('IF_TYPE_ISDN_S',0x0000004B)
		win_const_mgr.add_const('FILE_NOTIFY_CHANGE_DIR_NAME',0x00000002)
		win_const_mgr.add_const('PC_STYLED',0x00000020)
		win_const_mgr.add_const('USER_MNS_LOGON_ACCOUNT',0x00000020)
		win_const_mgr.add_const('PROCESSOR_ARM820',0x00000820)
		win_const_mgr.add_const('CERT_TRUST_IS_PEER_TRUSTED',0x00000800)
		win_const_mgr.add_const('ERROR_DS_OBJ_NOT_FOUND',0x0000208D)
		win_const_mgr.add_const('ERROR_INVALID_DLL',0x00000482)
		win_const_mgr.add_const('DISPID_ONMENUBAR',0x00000100)
		win_const_mgr.add_const('DDBLT_KEYSRC',0x00008000)
		win_const_mgr.add_const('ERROR_SXS_XML_E_MISSINGWHITESPACE',0x000036D5)
		win_const_mgr.add_const('SPI_GETFLATMENU',0x00001022)
		win_const_mgr.add_const('SSPROP_MAXBLOBLENGTH',0x00000008)
		win_const_mgr.add_const('AM_LOADSTATUS_CLOSED',0x00000000)
		win_const_mgr.add_const('SERVICE_AUTO_START',0x00000002)
		win_const_mgr.add_const('OID_802_11_TX_POWER_LEVEL',0x0D010205)
		win_const_mgr.add_const('MDM_MASK_HDLCPPP_AUTH',0x00000007)
		win_const_mgr.add_const('CI_STATE_LOW_MEMORY',0x00000080)
		win_const_mgr.add_const('EXCHIVERB_REPLYTOALL',0x00000067)
		win_const_mgr.add_const('ERROR_UNABLE_TO_LOAD_MEDIUM',0x000010E4)
		win_const_mgr.add_const('ISFB_STATE_QLINKSMODE',0x00000020)
		win_const_mgr.add_const('ERROR_CLUSTERLOG_CORRUPT',0x000013A5)
		win_const_mgr.add_const('IP_DONTFRAGMENT',0x0000000E)
		win_const_mgr.add_const('WSA_QOS_ADMISSION_FAILURE',0x00002B02)
		win_const_mgr.add_const('BG_E_MAXDOWNLOAD_TIMEOUT',0x80200054)
		win_const_mgr.add_const('USER_PRIMARY_GROUP_PARMNUM',0x00000033)
		win_const_mgr.add_const('DNS_RCODE_NOTZONE',0x0000000A)
		win_const_mgr.add_const('PRIMARY_CRED_CLEAR_PASSWORD',0x00000001)
		win_const_mgr.add_const('LINECALLPARTYID_UNAVAIL',0x00000040)
		win_const_mgr.add_const('GETFACENAME',0x00000201)
		win_const_mgr.add_const('PRIMARY_CRED_LOGON_NO_TCB',0x00000010)
		win_const_mgr.add_const('ERROR_DLL_MIGHT_BE_INSECURE',0x000002AE)
		win_const_mgr.add_const('CERT_STORE_SAVE_TO_FILE',0x00000001)
		win_const_mgr.add_const('SSF_DESKTOPHTML',0x00000200)
		win_const_mgr.add_const('IFS_V_LEN',0x00000001)
		win_const_mgr.add_const('TBS_BOTTOM',0x00000000)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_SAMPLE_ADV_BLENDING',0x00000008)
		win_const_mgr.add_const('PHONEFEATURE_GETHOOKSWITCHSPEAKER',0x00000080)
		win_const_mgr.add_const('KSMETHOD_TYPE_WRITE',0x00000002)
		win_const_mgr.add_const('PROPTYPE_BINARY',0x00000003)
		win_const_mgr.add_const('DVB_RST_PID',0x00000013)
		win_const_mgr.add_const('MOUSEEVENTF_LEFTDOWN',0x00000002)
		win_const_mgr.add_const('INSTALLED_CACHE_ENTRY',0x10000000)
		win_const_mgr.add_const('DNS_MAX_LABEL_LENGTH',0x0000003F)
		win_const_mgr.add_const('ICC_HOTKEY_CLASS',0x00000040)
		win_const_mgr.add_const('DPAM_UNION',0x00000004)
		win_const_mgr.add_const('DRIVER_KERNELMODE',0x00000001)
		win_const_mgr.add_const('WTS_WSD_REBOOT',0x00000004)
		win_const_mgr.add_const('ADS_PRINTER_PAPER_OUT',0x00000005)
		win_const_mgr.add_const('WIA_IPA_PROP_STREAM_COMPAT_ID',0x0000101A)
		win_const_mgr.add_const('LINEQOSSERVICELEVEL_NEEDED',0x00000001)
		win_const_mgr.add_const('KS_VBI_FLAG_TVTUNER_CHANGE',0x00000010)
		win_const_mgr.add_const('EMR_POLYGON',0x00000003)
		win_const_mgr.add_const('NRC_NOCALL',0x00000014)
		win_const_mgr.add_const('LVS_NOSCROLL',0x00002000)
		win_const_mgr.add_const('OPENCHANNEL',0x0000100E)
		win_const_mgr.add_const('PAGE_NOCACHE',0x00000200)
		win_const_mgr.add_const('ERROR_DS_ATT_VAL_ALREADY_EXISTS',0x00002083)
		win_const_mgr.add_const('XP1_MULTIPOINT_CONTROL_PLANE',0x00000800)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_ID',0x0000360A)
		win_const_mgr.add_const('IME_ESC_MAX_KEY',0x00001005)
		win_const_mgr.add_const('IF_TYPE_IPOVER_CLAW',0x0000006E)
		win_const_mgr.add_const('DB_MODE_SHARE_DENY_WRITE',0x00000008)
		win_const_mgr.add_const('ILR_VERTICAL_BOTTOM',0x00000020)
		win_const_mgr.add_const('CSIDL_ADMINTOOLS',0x00000030)
		win_const_mgr.add_const('WIA_DPF_MOUNT_POINT',0x00000D02)
		win_const_mgr.add_const('ERROR_IPSEC_MM_POLICY_PENDING_DELETION',0x000032DD)
		win_const_mgr.add_const('WIA_DPC_FOCUS_MODE',0x00000809)
		win_const_mgr.add_const('DISPID_SELECTEDITEMS',0x00000018)
		win_const_mgr.add_const('DATE_LONGDATE',0x00000002)
		win_const_mgr.add_const('IDM_SHOWALIGNEDSITETAGS',0x00000911)
		win_const_mgr.add_const('FLAG_LOOPBACK_REPLACE',0x08000000)
		win_const_mgr.add_const('SERVICE_CCP_CHKPT_NUM',0x000000FF)
		win_const_mgr.add_const('PTE_EXC_DEFER',0x10000000000000)
		win_const_mgr.add_const('UNLOCK_ELEMENT',0x00000001)
		win_const_mgr.add_const('SQL_INDEX_UNIQUE',0x00000000)
		win_const_mgr.add_const('SQL_API_SQLBROWSECONNECT',0x00000037)
		win_const_mgr.add_const('MD_ERROR_SUB404_CONTENT_LENGTH_TOO_LARGE',0x0000000D)
		win_const_mgr.add_const('MAX_MODULE_NAME32',0x000000FF)
		win_const_mgr.add_const('HSE_URL_FLAGS_READ',0x00000001)
		win_const_mgr.add_const('TUISPIDLL_OBJECT_PHONEID',0x00000002)
		win_const_mgr.add_const('SM_RESERVED1',0x00000018)
		win_const_mgr.add_const('TLS1_ALERT_INSUFFIENT_SECURITY',0x00000047)
		win_const_mgr.add_const('SQL_RETRIEVE_DATA',0x0000000B)
		win_const_mgr.add_const('FOFX_SHOWELEVATIONPROMPT',0x00040000)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_UNSTABLE',0x00000006)
		win_const_mgr.add_const('DN_NONE',0x00000000)
		win_const_mgr.add_const('SND_ASYNC',0x00000001)
		win_const_mgr.add_const('CTRY_LIECHTENSTEIN',0x00000029)
		win_const_mgr.add_const('MCI_DGV_RECORD_VIDEO_STREAM',0x00080000)
		win_const_mgr.add_const('SP_COPY_OEM_F6_INF',0x00200000)
		win_const_mgr.add_const('VK_CLEAR',0x0000000C)
		win_const_mgr.add_const('RC_SAVEBITMAP',0x00000040)
		win_const_mgr.add_const('SM_RESERVED2',0x00000019)
		win_const_mgr.add_const('MFT_RIGHTORDER',0x00002000)
		win_const_mgr.add_const('LOCALE_SPOSITIVESIGN',0x00000050)
		win_const_mgr.add_const('CAUSE_UNIMPLEMENTED_MESSAGE_TYPE',0x00000061)
		win_const_mgr.add_const('EMR_EXTFLOODFILL',0x00000035)
		win_const_mgr.add_const('ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER',0x00002188)
		win_const_mgr.add_const('PGB_TOPORLEFT',0x00000000)
		win_const_mgr.add_const('IMAPI_SECTORS_PER_SECOND_AT_1X_CD',0x0000004B)
		win_const_mgr.add_const('PST_EXTERN_PROPID_BASE',0x00006700)
		win_const_mgr.add_const('REFERENCE_WHITE_MIN',0x00001770)
		win_const_mgr.add_const('DEBUG_DATA_KPRCB_OFFSET',0x00000001)
		win_const_mgr.add_const('SUBLANG_MAORI_NEW_ZEALAND',0x00000001)
		win_const_mgr.add_const('EMR_RESERVED_109',0x0000006D)
		win_const_mgr.add_const('NTMS_DEVICENAME_LENGTH',0x00000040)
		win_const_mgr.add_const('IOC_OUT',0x40000000)
		win_const_mgr.add_const('HTTP_ADDREQ_FLAG_REPLACE',0x80000000)
		win_const_mgr.add_const('CRLF_PUBLISH_EXPIRED_CERT_CRLS',0x00000200)
		win_const_mgr.add_const('ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN',0x00002179)
		win_const_mgr.add_const('IF_TYPE_ETHERNET_3MBIT',0x0000001A)
		win_const_mgr.add_const('DEBUG_STACK_FRAME_MEMORY_USAGE',0x00000200)
		win_const_mgr.add_const('CR_CREATE_BLOCKED',0x00000015)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_CLEAR_SAVEPOINT',0x00200000)
		win_const_mgr.add_const('DNS_OPCODE_QUERY',0x00000000)
		win_const_mgr.add_const('EFFECTMODE_BW',0x00000002)
		win_const_mgr.add_const('LOGON32_LOGON_NETWORK_CLEARTEXT',0x00000008)
		win_const_mgr.add_const('SQL_API_SQLFREEHANDLE',0x000003EE)
		win_const_mgr.add_const('SQL_ISV_SQL_LANGUAGES',0x00004000)
		win_const_mgr.add_const('DRM_EL_GROUPIDENTITY_LID',0x00000008)
		win_const_mgr.add_const('ATADDR_BROADCAST',0x000000FF)
		win_const_mgr.add_const('DEBUG_OUTTYPE_NO_INDENT',0x00000001)
		win_const_mgr.add_const('MCI_SAVE',0x00000813)
		win_const_mgr.add_const('SCARD_READER_SWALLOWS',0x00000001)
		win_const_mgr.add_const('NETERR_RING_STATUS_HARD_ERROR',0x00004000)
		win_const_mgr.add_const('KAGPROP_FILEUSAGE',0x00000017)
		win_const_mgr.add_const('INDEX_GUID_ALLOWPARTIALDICTIONARYTERMS',0x00000004)
		win_const_mgr.add_const('SS_BLACKFRAME',0x00000007)
		win_const_mgr.add_const('FACILITY_DRIVER_FRAMEWORK',0x00000020)
		win_const_mgr.add_const('CMC_FAIL_INTERNAL_CA_ERROR',0x0000000B)
		win_const_mgr.add_const('MAX_PATH16',0x000000FF)
		win_const_mgr.add_const('CONFIGFLAG_CANTSTOPACHILD',0x00000080)
		win_const_mgr.add_const('TASK_FLAG_RUN_ONLY_IF_LOGGED_ON',0x00002000)
		win_const_mgr.add_const('RPC_S_INVALID_ENDPOINT_FORMAT',0x000006AA)
		win_const_mgr.add_const('SQL_API_SQLSETSTMTATTR',0x000003FC)
		win_const_mgr.add_const('IDD_WIZEXTN_LAST',0x00005100)
		win_const_mgr.add_const('ERROR_WMI_DP_FAILED',0x00001071)
		win_const_mgr.add_const('SP_PROT_PCT1_SERVER',0x00000001)
		win_const_mgr.add_const('ERROR_LOG_CONTAINER_OPEN_FAILED',0x000019F1)
		win_const_mgr.add_const('MAPI_USER_ABORT',0x00000001)
		win_const_mgr.add_const('ACCESS_MAX_MS_V3_ACE_TYPE',0x00000004)
		win_const_mgr.add_const('CCERR_CHOOSECOLORCODES',0x00005000)
		win_const_mgr.add_const('ACM_FORMATENUMF_SUGGEST',0x00200000)
		win_const_mgr.add_const('ERROR_DS_SRC_SID_EXISTS_IN_FOREST',0x0000215B)
		win_const_mgr.add_const('PATCH_SYMBOL_RESERVED1',0x80000000)
		win_const_mgr.add_const('TCS_MULTILINE',0x00000200)
		win_const_mgr.add_const('PROPID_Q_BASE',0x00000064)
		win_const_mgr.add_const('EVENT_S_LAST',0x0004021F)
		win_const_mgr.add_const('SUBLANG_BENGALI_BANGLADESH',0x00000002)
		win_const_mgr.add_const('DFCS_INACTIVE',0x00000100)
		win_const_mgr.add_const('CERT_PUBKEY_HASH_RESERVED_PROP_ID',0x00000008)
		win_const_mgr.add_const('SERVICETYPE_QUALITATIVE',0x0000000D)
		win_const_mgr.add_const('FR_MATCHALEFHAMZA',0x80000000)
		win_const_mgr.add_const('LCID_INSTALLED',0x00000001)
		win_const_mgr.add_const('CMF_NOVERBS',0x00000008)
		win_const_mgr.add_const('D3DPRESENT_RATE_DEFAULT',0x00000000)
		win_const_mgr.add_const('LGRPID_ARABIC',0x00000000)
		win_const_mgr.add_const('SKF_RWINLATCHED',0x80000000)
		win_const_mgr.add_const('KSALLOCATOR_REQUIREMENTF_INPLACE_MODIFIER',0x00000001)
		win_const_mgr.add_const('ERROR_DIR_NOT_ROOT',0x00000090)
		win_const_mgr.add_const('HSHELL_TASKMAN',0x00000007)
		win_const_mgr.add_const('MCI_DGV_STATUS_FILE_COMPLETION',0x00004020)
		win_const_mgr.add_const('REGSTR_MAX_VALUE_LENGTH',0x00000100)
		win_const_mgr.add_const('DBPROPVAL_OO_SINGLETON',0x00000020)
		win_const_mgr.add_const('SCRIPTPROP_CATCHEXCEPTION',0x00001001)
		win_const_mgr.add_const('PFM_TABLE',0x40000000)
		win_const_mgr.add_const('PORT_ANYTERMACC',0x00000039)
		win_const_mgr.add_const('DBC_GS_SIZEDOWN',0x00000001)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_SECURITYFIX',0x00000000)
		win_const_mgr.add_const('CS_CLASSDC',0x00000040)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_SETREPDIAL',0x00000028)
		win_const_mgr.add_const('VK_F18',0x00000081)
		win_const_mgr.add_const('ERROR_DS_NAME_TYPE_UNKNOWN',0x0000209F)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_STOP',0x0000000D)
		win_const_mgr.add_const('MCI_DGV_STATUS_VIDEO_RECORD',0x00000401)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_PROMOTE_NEW',0x10000000)
		win_const_mgr.add_const('BTH_MFG_C_TECHNOLOGIES',0x00000026)
		win_const_mgr.add_const('DDCAPS_PALETTEVSYNC',0x00010000)
		win_const_mgr.add_const('DBPROPVAL_MR_CONCURRENT',0x00000002)
		win_const_mgr.add_const('NTDSDSA_OPT_DISABLE_SPN_REGISTRATION',0x00000001)
		win_const_mgr.add_const('IDTB_FAVORITES',0x000000D9)
		win_const_mgr.add_const('TVS_EX_NOINDENTSTATE',0x00000008)
		win_const_mgr.add_const('LDAP_OPT_IO_FN_PTRS',0x00000000)
		win_const_mgr.add_const('ERROR_DS_CLASS_NOT_DSA',0x00002097)
		win_const_mgr.add_const('DBPROPVAL_STGM_TRANSACTED',0x00020000)
		win_const_mgr.add_const('DI_QUIETINSTALL',0x00800000)
		win_const_mgr.add_const('VER_NT_WORKSTATION',0x00000001)
		win_const_mgr.add_const('SKF_LSHIFTLATCHED',0x01000000)
		win_const_mgr.add_const('WLX_DLG_USER_LOGOFF',0x00000068)
		win_const_mgr.add_const('ERROR_NO_IMPERSONATION_TOKEN',0x0000051D)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_FILTER_RESTART_PARAMETERS',0x0000009B)
		win_const_mgr.add_const('SCESTATUS_NOT_ENOUGH_RESOURCE',0x00000008)
		win_const_mgr.add_const('CAUSE_ACCESS_INFORMAION_DISCARDED',0x0000002B)
		win_const_mgr.add_const('MSG_SERVICE_UI_READ_ONLY',0x00000008)
		win_const_mgr.add_const('CLCTL_GLOBAL_SHIFT',0x00000017)
		win_const_mgr.add_const('IDC_BZ_MESSAGE1',0x0000025A)
		win_const_mgr.add_const('PDH_LOG_WRITE_ACCESS',0x00020000)
		win_const_mgr.add_const('VK_CRSEL',0x000000F7)
		win_const_mgr.add_const('MCIWNDF_NOAUTOSIZEMOVIE',0x00000004)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_ACKFULL',0x00000014)
		win_const_mgr.add_const('ERRCLASS_OUTRES',0x00000001)
		win_const_mgr.add_const('TAPE_REWIND',0x00000000)
		win_const_mgr.add_const('TASK_MONDAY',0x00000002)
		win_const_mgr.add_const('D3DCREATE_DISABLE_DRIVER_MANAGEMENT_EX',0x00000400)
		win_const_mgr.add_const('WAVEOUT_MAPPER_STATUS_FORMAT',0x00000002)
		win_const_mgr.add_const('IF_TYPE_PROTEON_80MBIT',0x0000000D)
		win_const_mgr.add_const('LINECALLHUBTRACKING_ALLCALLS',0x00000002)
		win_const_mgr.add_const('IMN_SETCOMPOSITIONWINDOW',0x0000000B)
		win_const_mgr.add_const('MCSC_BACKGROUND',0x00000000)
		win_const_mgr.add_const('SRRF_RT_REG_BINARY',0x00000008)
		win_const_mgr.add_const('ERROR_PNP_BAD_MPS_TABLE',0x0000029F)
		win_const_mgr.add_const('FNERR_SUBCLASSFAILURE',0x00003001)
		win_const_mgr.add_const('KSFILTER_FLAG_RECEIVE_ZERO_LENGTH_SAMPLES',0x00000008)
		win_const_mgr.add_const('ERROR_DS_MISSING_FSMO_SETTINGS',0x000020F2)
		win_const_mgr.add_const('UIA_E_PROXYASSEMBLYNOTLOADED',0x80040203)
		win_const_mgr.add_const('HTTP_AUTH_ENABLE_DIGEST',0x00000002)
		win_const_mgr.add_const('WM_CT_INTERLACED',0x00000080)
		win_const_mgr.add_const('ERROR_ALREADY_INITIALIZED',0x000004DF)
		win_const_mgr.add_const('DNS_STATUS_FQDN',0x00002555)
		win_const_mgr.add_const('TMNOMIGRATE',0x00000002)
		win_const_mgr.add_const('NTDDI_WS03SP1',0x05020100)
		win_const_mgr.add_const('LVS_EX_AUTOAUTOARRANGE',0x01000000)
		win_const_mgr.add_const('MCI_RECORD_OVERWRITE',0x00000200)
		win_const_mgr.add_const('PORT_TIME',0x00000025)
		win_const_mgr.add_const('DCI_SURFACE_TYPE',0x0000000F)
		win_const_mgr.add_const('LB_GETSEL',0x00000187)
		win_const_mgr.add_const('INVALID_RUNDOWN_ROUTINE_INDEX',0x000000FF)
		win_const_mgr.add_const('KERB_CHECKSUM_MD5_DES',0x00000008)
		win_const_mgr.add_const('ERROR_SERVICE_DEPENDENCY_DELETED',0x00000433)
		win_const_mgr.add_const('LINEDISCONNECTMODE_CANCELLED',0x00080000)
		win_const_mgr.add_const('DC_BINNAMES',0x0000000C)
		win_const_mgr.add_const('SUBLANG_BASHKIR_RUSSIA',0x00000001)
		win_const_mgr.add_const('SQL_COLUMN_DISPLAY_SIZE',0x00000006)
		win_const_mgr.add_const('TRUSTEE_ACCESS_EXPLICIT',0x00000001)
		win_const_mgr.add_const('REO_INVERTEDSELECT',0x00000004)
		win_const_mgr.add_const('RATING_TWO_STARS_MAX',0x00000025)
		win_const_mgr.add_const('NCBDGSENDBC',0x00000022)
		win_const_mgr.add_const('STDPROP_USERPROP_MAX',0x7FFFFFFF)
		win_const_mgr.add_const('R2_NOT',0x00000006)
		win_const_mgr.add_const('TBCDRF_NOEDGES',0x00010000)
		win_const_mgr.add_const('BLLI_L3_ISO_8208',0x00000007)
		win_const_mgr.add_const('IDM_NOACTIVATENORMALOLECONTROLS',0x0000091C)
		win_const_mgr.add_const('SNMP_MGMTAPI_SELECT_FDERRORS',0x00000029)
		win_const_mgr.add_const('CERT_NAME_STR_DISABLE_UTF8_DIR_STR_FLAG',0x00100000)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_NETWORK_SERVICE',0x80080000)
		win_const_mgr.add_const('SQL_SQL92_ROW_VALUE_CONSTRUCTOR',0x000000A3)
		win_const_mgr.add_const('PATCH_OPTION_SIGNATURE_MD5',0x01000000)
		win_const_mgr.add_const('GLEX_PUSHBACK',0x00000004)
		win_const_mgr.add_const('TT_ENABLED',0x00000002)
		win_const_mgr.add_const('PIDDSI_SLIDECOUNT',0x00000007)
		win_const_mgr.add_const('BSIM_STATE',0x00000001)
		win_const_mgr.add_const('SPI_SETSELECTIONFADE',0x00001015)
		win_const_mgr.add_const('SERVICE_UI_ALLOWED',0x00000010)
		win_const_mgr.add_const('DRIVER_UNTRUSTED_HARDWAREID_RANK',0x00008FFF)
		win_const_mgr.add_const('PFD_SWAP_EXCHANGE',0x00000200)
		win_const_mgr.add_const('QOS_CLASS3',0x00000003)
		win_const_mgr.add_const('OID_802_3_XMIT_MORE_COLLISIONS',0x01020103)
		win_const_mgr.add_const('SPI_SETSHOWSOUNDS',0x00000039)
		win_const_mgr.add_const('OID_GEN_STATISTICS',0x00020106)
		win_const_mgr.add_const('DPAM_INTERSECT',0x00000008)
		win_const_mgr.add_const('OID_FDDI_PORT_LER_FLAG',0x03030275)
		win_const_mgr.add_const('FS_CHINESESIMP',0x00040000)
		win_const_mgr.add_const('SQL_NAMED',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_BD_XTRANSACTION',0x00000002)
		win_const_mgr.add_const('DEVPROP_TYPE_UINT32',0x00000007)
		win_const_mgr.add_const('D3DCAPS2_RESERVED',0x02000000)
		win_const_mgr.add_const('PAGESETUPDLGORD',0x0000060A)
		win_const_mgr.add_const('CDO_E_FAILED_TO_CONNECT',0x80040213)
		win_const_mgr.add_const('CRED_FLAGS_VALID_FLAGS',0x0000F01F)
		win_const_mgr.add_const('DPAM_NORMAL',0x00000002)
		win_const_mgr.add_const('VP_FLAGS_FLICKER',0x00000004)
		win_const_mgr.add_const('FD_LONGHORN',0x00000001)
		win_const_mgr.add_const('SUCCEED_ABORT',0x00000002)
		win_const_mgr.add_const('SIZE_T_MAX',0x00000000)
		win_const_mgr.add_const('ERROR_MENU_ITEM_NOT_FOUND',0x000005B0)
		win_const_mgr.add_const('DPNHADDRESSTYPE_FIXEDPORTS',0x00000002)
		win_const_mgr.add_const('DDBLTFX_ARITHSTRETCHY',0x00000001)
		win_const_mgr.add_const('SNMPAPI_TL_RESOURCE_ERROR',0x00000067)
		win_const_mgr.add_const('MAX_SERVICE_NAME_LEN',0x00000100)
		win_const_mgr.add_const('LC_STYLED',0x00000020)
		win_const_mgr.add_const('RPCFLG_INPUT_SYNCHRONOUS',0x20000000)
		win_const_mgr.add_const('PS_NULL',0x00000005)
		win_const_mgr.add_const('DB_PROT_LEVEL_PKT',0x00000003)
		win_const_mgr.add_const('ERROR_I24_WRITE_FAULT',0x0000000A)
		win_const_mgr.add_const('LINEDISCONNECTMODE_PICKUP',0x00000008)
		win_const_mgr.add_const('SCH_CRED_REVOCATION_CHECK_CACHE_ONLY',0x00004000)
		win_const_mgr.add_const('DELTA_FILE_SIZE_LIMIT',0x00000020)
		win_const_mgr.add_const('SQL_COLUMN_SEARCHABLE',0x0000000D)
		win_const_mgr.add_const('IPX_PACE_DEFVAL',0x00000012)
		win_const_mgr.add_const('SL_INTERNAL_ZONE',0x0000E000)
		win_const_mgr.add_const('SHOP_VOLUMEGUID',0x00000004)
		win_const_mgr.add_const('NUMPRS_NEG',0x00010000)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_SILENT_BREAKAWAY_OK',0x00001000)
		win_const_mgr.add_const('JIFMK_SOS',0x0000FFDA)
		win_const_mgr.add_const('ERROR_PIPE_LISTENING',0x00000218)
		win_const_mgr.add_const('PAN_NO_FIT',0x00000001)
		win_const_mgr.add_const('PBT_APMQUERYSUSPEND',0x00000000)
		win_const_mgr.add_const('SECURITY_NT_NON_UNIQUE_SUB_AUTH_COUNT',0x00000003)
		win_const_mgr.add_const('NSTYPE_ENUMERABLE',0x00000004)
		win_const_mgr.add_const('IMGCHG_COMPLETE',0x00000004)
		win_const_mgr.add_const('VER_GREATER_EQUAL',0x00000003)
		win_const_mgr.add_const('DISPID_SHOWDETAILS',0x0000000B)
		win_const_mgr.add_const('PS_16K',0x0000000E)
		win_const_mgr.add_const('WMDM_STORAGECAP_FILESINFOLDERS',0x00000008)
		win_const_mgr.add_const('DEBUG_VALUE_FLOAT64',0x00000006)
		win_const_mgr.add_const('PS_16M',0x00000018)
		win_const_mgr.add_const('SCH_CRED_REVOCATION_CHECK_CHAIN_EXCLUDE_ROOT',0x00000400)
		win_const_mgr.add_const('IPPORT_TELNET',0x00000017)
		win_const_mgr.add_const('DNS_TYPE_SOA',0x00000006)
		win_const_mgr.add_const('IDM_CUT',0x00000010)
		win_const_mgr.add_const('CM_DEVCAP_DOCKDEVICE',0x00000008)
		win_const_mgr.add_const('CMSG_CTRL_DEL_SIGNER',0x00000007)
		win_const_mgr.add_const('PST_KEY_LOCAL_MACHINE',0x00000001)
		win_const_mgr.add_const('ERROR_WRONG_TARGET_NAME',0x00000574)
		win_const_mgr.add_const('MMIO_FHOPEN',0x00000010)
		win_const_mgr.add_const('FIND_DIR',0x0000000F)
		win_const_mgr.add_const('ALG_SID_ECDH',0x00000005)
		win_const_mgr.add_const('CM_NONE',0x00000000)
		win_const_mgr.add_const('ICEE_CREATE_MACHINE_I386',0x00000100)
		win_const_mgr.add_const('MD_AUTH_SINGLEREQUEST',0x00000040)
		win_const_mgr.add_const('SUBLANG_DARI_AFGHANISTAN',0x00000001)
		win_const_mgr.add_const('IDM_TRIED_INSERTCELL',0x00000014)
		win_const_mgr.add_const('LAYERED_PROTOCOL',0x00000000)
		win_const_mgr.add_const('TLS1_ALERT_ACCESS_DENIED',0x00000031)
		win_const_mgr.add_const('IF_TYPE_MEDIAMAILOVERIP',0x0000008B)
		win_const_mgr.add_const('ERROR_SXS_XML_E_MISSING_PAREN',0x000036DC)
		win_const_mgr.add_const('VK_F17',0x00000080)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_R3000',0x00000162)
		win_const_mgr.add_const('DS_PDC_FLAG',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK',0x00001727)
		win_const_mgr.add_const('EM_GETSEL',0x000000B0)
		win_const_mgr.add_const('TRANSPORT_TYPE_LPC',0x00000004)
		win_const_mgr.add_const('OUT_RASTER_PRECIS',0x00000006)
		win_const_mgr.add_const('ALG_SID_AES',0x00000011)
		win_const_mgr.add_const('THREAD_TERMINATE',0x00000001)
		win_const_mgr.add_const('PD_NONETWORKBUTTON',0x00200000)
		win_const_mgr.add_const('FILE_COMPRESSION_NTCAB',0x00000003)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_SECURITYFIX_UNINSTALL',0x00000018)
		win_const_mgr.add_const('NORM_IGNORECASE',0x00000001)
		win_const_mgr.add_const('PFM_RIGHTINDENT',0x00000002)
		win_const_mgr.add_const('WINVER',0x00000500)
		win_const_mgr.add_const('SWP_FRAMECHANGED',0x00000020)
		win_const_mgr.add_const('ERROR_DEPENDENCY_NOT_ALLOWED',0x000013CD)
		win_const_mgr.add_const('FILE_DEVICE_UNKNOWN',0x00000022)
		win_const_mgr.add_const('FWP_V6_ADDR_SIZE',0x00000010)
		win_const_mgr.add_const('MKF_INDICATOR',0x00000020)
		win_const_mgr.add_const('STRSAFE_FILL_ON_FAILURE',0x00000400)
		win_const_mgr.add_const('DS_BEHAVIOR_WIN2003_WITH_MIXED_DOMAINS',0x00000001)
		win_const_mgr.add_const('SPFEI_ALL_SR_EVENTS',0x1FFFFC00000000)
		win_const_mgr.add_const('TIMERMODE_NORMAL',0x00000000)
		win_const_mgr.add_const('TMT_TEXTGLOWSIZE',0x00000979)
		win_const_mgr.add_const('DB_REMOTE',0x00000001)
		win_const_mgr.add_const('DIRECT3D_VERSION',0x00000900)
		win_const_mgr.add_const('__REQUIRED_RPCSAL_H_VERSION__',0x00000064)
		win_const_mgr.add_const('CFM_PROTECTED',0x00000010)
		win_const_mgr.add_const('CERT_STORE_TIME_VALIDITY_FLAG',0x00000002)
		win_const_mgr.add_const('NMPWAIT_NOWAIT',0x00000001)
		win_const_mgr.add_const('FEI_RINGING',0x00000000)
		win_const_mgr.add_const('SCARD_CLASS_VENDOR_INFO',0x00000001)
		win_const_mgr.add_const('UF_NO_AUTH_DATA_REQUIRED',0x02000000)
		win_const_mgr.add_const('DBG_DIVOVERFLOW',0x00000008)
		win_const_mgr.add_const('CRYPTUI_HIDE_DETAILPAGE',0x00000002)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY4',0x00000010)
		win_const_mgr.add_const('SMS_EXTERN_PROPID_BASE',0x00006700)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_COMMIT_COMPLETE',0x00000040)
		win_const_mgr.add_const('RTM_VIEW_MASK_MCAST',0x00000002)
		win_const_mgr.add_const('CHANNEL_FLAG_SUSPEND',0x00000020)
		win_const_mgr.add_const('PXE_BA_CUSTOM',0x00000002)
		win_const_mgr.add_const('OID_GEN_ENUMERATE_PORTS',0x0001020D)
		win_const_mgr.add_const('SUBLANG_PASHTO_AFGHANISTAN',0x00000001)
		win_const_mgr.add_const('SERVICE_CONTROL_STATUS_REASON_INFO',0x00000001)
		win_const_mgr.add_const('BOM_PLAINTEXT',0x00000002)
		win_const_mgr.add_const('D3DCREATE_DISABLE_PSGP_THREADING',0x00002000)
		win_const_mgr.add_const('WINHTTP_FLAG_ESCAPE_DISABLE',0x00000040)
		win_const_mgr.add_const('PSR_TB',0x0000001A)
		win_const_mgr.add_const('IMAGE_SCN_LNK_COMDAT',0x00001000)
		win_const_mgr.add_const('TPM_TOPALIGN',0x00000000)
		win_const_mgr.add_const('SQL_DIAG_MESSAGE_TEXT',0x00000006)
		win_const_mgr.add_const('DS_REPSYNC_SELECT_SECRETS',0x00008000)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_IS_IPSEC_NATT_RECLASSIFY',0x00000080)
		win_const_mgr.add_const('BG_E_INVALID_HASH_ALGORITHM',0x80200041)
		win_const_mgr.add_const('E_FILTER_SCRIPTLISTING',0x80100008)
		win_const_mgr.add_const('RTL_RUN_ONCE_ASYNC',0x00000002)
		win_const_mgr.add_const('MCI_VCR_STATUS_AUDIO_SOURCE_NUMBER',0x00004007)
		win_const_mgr.add_const('BAUD_600',0x00000020)
		win_const_mgr.add_const('RBBS_HIDETITLE',0x00000400)
		win_const_mgr.add_const('IDTB_INDEX',0x000000D6)
		win_const_mgr.add_const('SECPKG_CALL_PROCESS_TERM',0x00000100)
		win_const_mgr.add_const('IDM_GETDOCDLGFLAGS',0x00003A9D)
		win_const_mgr.add_const('SQL_OJ_ALL_COMPARISON_OPS',0x00000040)
		win_const_mgr.add_const('SPINST_FILES',0x00000010)
		win_const_mgr.add_const('PORT_RXE',0x000002F9)
		win_const_mgr.add_const('MCI_GETDEVCAPS_DEVICE_TYPE',0x00000004)
		win_const_mgr.add_const('PRINTER_CHANGE_ADD_PRINTER',0x00000001)
		win_const_mgr.add_const('ERROR_DS_DST_NC_MISMATCH',0x00002126)
		win_const_mgr.add_const('HTMLDLG_MODAL',0x00000020)
		win_const_mgr.add_const('HTTP_LOG_FIELD_URI',0x00800000)
		win_const_mgr.add_const('MD_CHANGE_TYPE_ADD_OBJECT',0x00000002)
		win_const_mgr.add_const('SHACF_URLHISTORY',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_SRVACQFAIL',0x0000361F)
		win_const_mgr.add_const('COLOR_SCHEMES',0x000002CB)
		win_const_mgr.add_const('ETW_DECIMAL_TYPE_VALUE',0x0000000F)
		win_const_mgr.add_const('SDP_ATTRIB_HID_LANG_ID_BASE_LIST',0x00000207)
		win_const_mgr.add_const('LINETERMSHARING_PRIVATE',0x00000001)
		win_const_mgr.add_const('XINPUT_GAMEPAD_RIGHT_SHOULDER',0x00000200)
		win_const_mgr.add_const('DISABLE_VHPT_WALKER',0x0000000A)
		win_const_mgr.add_const('TAPIMEDIATYPE_AUDIO',0x00000008)
		win_const_mgr.add_const('IDTB_PRINT',0x000000CF)
		win_const_mgr.add_const('ILDI_QUERYACCESS',0x00000008)
		win_const_mgr.add_const('ERROR_INSTALL_TRANSFORM_FAILURE',0x00000658)
		win_const_mgr.add_const('NRB_FUNCTION_REMOVE_LBAS_PINNED_SET',0x00000011)
		win_const_mgr.add_const('KSPIN_FLAG_PROCESS_IF_ANY_IN_RUN_STATE',0x01000000)
		win_const_mgr.add_const('SPI_SETLANGTOGGLE',0x0000005B)
		win_const_mgr.add_const('TABLET_DISABLE_TOUCHUIFORCEON',0x00000100)
		win_const_mgr.add_const('DI_FLAGSEX_INSTALLEDDRIVER',0x04000000)
		win_const_mgr.add_const('IMN_PRIVATE',0x0000000E)
		win_const_mgr.add_const('NET_STRING_IPV4_ADDRESS',0x00000001)
		win_const_mgr.add_const('DN_ARM_WAKEUP',0x04000000)
		win_const_mgr.add_const('WIA_PAGE_BUSINESSCARD',0x00000006)
		win_const_mgr.add_const('DISPID_WINDOWACTIVATE',0x0000006F)
		win_const_mgr.add_const('ERROR_CANTFETCHBACKWARDS',0x00000302)
		win_const_mgr.add_const('DDBLT_KEYDEST',0x00002000)
		win_const_mgr.add_const('OID_FDDI_SMT_LAST_SET_STATION_ID',0x0303021E)
		win_const_mgr.add_const('CERT_COMPARE_SUBJECT_CERT',0x0000000B)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW3_PRINT',0x00000496)
		win_const_mgr.add_const('FE_FONTSMOOTHINGDOCKING',0x00008000)
		win_const_mgr.add_const('REG_LINK',0x00000006)
		win_const_mgr.add_const('IIS_MD_UT_WAM',0x00000064)
		win_const_mgr.add_const('FWPM_ACTRL_ADD',0x00000001)
		win_const_mgr.add_const('SQL_ROW_NOROW',0x00000003)
		win_const_mgr.add_const('MCI_LOAD',0x00000850)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_RESUME',0x00000007)
		win_const_mgr.add_const('VALID_INHERIT_FLAGS',0x0000001F)
		win_const_mgr.add_const('IOF_SHOWHELP',0x00000001)
		win_const_mgr.add_const('OID_WAN_CO_GET_COMP_INFO',0x04010280)
		win_const_mgr.add_const('IDM_ADDRESS',0x0000088D)
		win_const_mgr.add_const('INTENT_SATURATION',0x00000002)
		win_const_mgr.add_const('IDM_TRIED_FONT',0x00000023)
		win_const_mgr.add_const('GESTURE_DOUBLE_UP',0x00000000)
		win_const_mgr.add_const('SQL_API_ODBC3_ALL_FUNCTIONS',0x000003E7)
		win_const_mgr.add_const('DPROMPT_OUTOFMEMORY',0x00000004)
		win_const_mgr.add_const('SECQOP_WRAP_OOB_DATA',0x40000000)
		win_const_mgr.add_const('DOMAIN_USER_RID_MAX',0x000003E7)
		win_const_mgr.add_const('STN_ENABLE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_CANT_DELETE',0x000020CE)
		win_const_mgr.add_const('ERROR_SXS_XML_E_MISSINGEQUALS',0x000036F9)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_UNDEFINED',0x00001004)
		win_const_mgr.add_const('LOCALE_SGROUPING',0x00000010)
		win_const_mgr.add_const('SYMSTOREOPT_UNICODE',0x00000020)
		win_const_mgr.add_const('PIDDRSI_PROTECTED',0x00000002)
		win_const_mgr.add_const('DRV_USER',0x00004000)
		win_const_mgr.add_const('CLUSCTL_RESOURCE_STATE_CHANGE_REASON_VERSION_1',0x00000001)
		win_const_mgr.add_const('URL_MK_NO_CANONICALIZE',0x00000002)
		win_const_mgr.add_const('PRINTER_ENUM_ICON6',0x00200000)
		win_const_mgr.add_const('PRINTER_ENUM_ICON7',0x00400000)
		win_const_mgr.add_const('SCARD_READER_TYPE_PARALELL',0x00000002)
		win_const_mgr.add_const('PRINTER_ENUM_ICON5',0x00100000)
		win_const_mgr.add_const('PRINTER_ENUM_ICON2',0x00020000)
		win_const_mgr.add_const('MD_ERROR_NOT_INITIALIZED',0x800CC800)
		win_const_mgr.add_const('SUBLANG_KONKANI_INDIA',0x00000001)
		win_const_mgr.add_const('PRINTER_ENUM_ICON1',0x00010000)
		win_const_mgr.add_const('DEBUG_ENGOPT_DISABLE_EXECUTION_COMMANDS',0x00010000)
		win_const_mgr.add_const('ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE',0x00002137)
		win_const_mgr.add_const('PAGEMASK_16KB',0x00000003)
		win_const_mgr.add_const('RTM_ENUM_RANGE',0x00000002)
		win_const_mgr.add_const('AGP_FLAG_NO_4X_RATE',0x00000004)
		win_const_mgr.add_const('ERROR_BAD_EXE_FORMAT',0x000000C1)
		win_const_mgr.add_const('USER_PARTIAL_SECRETS_ACCOUNT',0x00100000)
		win_const_mgr.add_const('TASK_TUESDAY',0x00000004)
		win_const_mgr.add_const('BAUD_128K',0x00010000)
		win_const_mgr.add_const('IPV6_RECVRTHDR',0x00000026)
		win_const_mgr.add_const('EVENT_TRACE_BUFFERING_MODE',0x00000400)
		win_const_mgr.add_const('TBBF_LARGE',0x00000001)
		win_const_mgr.add_const('DRM_EL_EUL_LID',0x00000040)
		win_const_mgr.add_const('APPCOMMAND_BROWSER_FORWARD',0x00000002)
		win_const_mgr.add_const('ERROR_SERVICE_CANNOT_ACCEPT_CTRL',0x00000425)
		win_const_mgr.add_const('URLACTION_XPS_DOCUMENTS',0x00002401)
		win_const_mgr.add_const('TF_CONVERSIONMODE_FULLSHAPE',0x00000008)
		win_const_mgr.add_const('CB_SHOWDROPDOWN',0x0000014F)
		win_const_mgr.add_const('PLAL_ALERT_CMD_LINE_L_VAL',0x00001000)
		win_const_mgr.add_const('MC_SUPPORTED_COLOR_TEMPERATURE_5000K',0x00000002)
		win_const_mgr.add_const('CLFS_MGMT_POLICY_VERSION',0x00000001)
		win_const_mgr.add_const('DTS_SHORTDATECENTURYFORMAT',0x0000000C)
		win_const_mgr.add_const('SDP_ATTRIB_PAN_MAX_NET_ACCESS_RATE',0x0000030C)
		win_const_mgr.add_const('PORT_DSP',0x00000021)
		win_const_mgr.add_const('NDIS_MAC_OPTION_RECEIVE_SERIALIZED',0x00000002)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_FORCE_KCC_WHISTLER_BEHAVIOR',0x00000001)
		win_const_mgr.add_const('IF_TYPE_FRAMERELAY_MPI',0x0000005C)
		win_const_mgr.add_const('ERROR_EVENT_DONE',0x000002C6)
		win_const_mgr.add_const('LINEERR_INVALAGENTID',0x80000057)
		win_const_mgr.add_const('SIZE_MAXHIDE',0x00000004)
		win_const_mgr.add_const('LVHT_EX_GROUP_HEADER',0x10000000)
		win_const_mgr.add_const('CRLF_DELTA_USE_OLDEST_UNEXPIRED_BASE',0x00000001)
		win_const_mgr.add_const('MFASFINDEXER_NO_FIXED_INTERVAL',0x00000000)
		win_const_mgr.add_const('PO_PORTCHANGE',0x00000020)
		win_const_mgr.add_const('TABLE_CHANGED',0x00000001)
		win_const_mgr.add_const('IF_TYPE_V37',0x00000078)
		win_const_mgr.add_const('IF_TYPE_V36',0x00000041)
		win_const_mgr.add_const('SHA_HASH_LEN',0x00000014)
		win_const_mgr.add_const('PORT_DSF',0x0000022B)
		win_const_mgr.add_const('SQL_DIAG_CALL',0x00000007)
		win_const_mgr.add_const('LINEERR_REQUESTOVERRUN',0x8000004C)
		win_const_mgr.add_const('AUTHZ_GENERATE_FAILURE_AUDIT',0x00000002)
		win_const_mgr.add_const('CSIDL_ALTSTARTUP',0x00000001)
		win_const_mgr.add_const('PSR_DFH',0x00000013)
		win_const_mgr.add_const('CTRY_SOUTH_AFRICA',0x0000001B)
		win_const_mgr.add_const('COMP_ELEM_POS_TOP',0x00000020)
		win_const_mgr.add_const('ERROR_DS_DATABASE_ERROR',0x000020D9)
		win_const_mgr.add_const('CF_MAX',0x0000000F)
		win_const_mgr.add_const('IF_TYPE_PROP_WIRELESS_P2P',0x0000009D)
		win_const_mgr.add_const('CTRY_MALDIVES',0x000003C0)
		win_const_mgr.add_const('WMDRM_QUERY_DEVICE_CLOCKSTATUS',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_TI_READUNCOMMITTED',0x00000100)
		win_const_mgr.add_const('WINSTA_READSCREEN',0x00000200)
		win_const_mgr.add_const('SERVICE_REDIR_PAUSED',0x00000700)
		win_const_mgr.add_const('ERROR_POLICY_OBJECT_NOT_FOUND',0x0000201B)
		win_const_mgr.add_const('TMT_GRADIENTINACTIVECAPTION',0x0000065D)
		win_const_mgr.add_const('PID_COMPUTERNAME',0x00000005)
		win_const_mgr.add_const('RPC_S_INVALID_AUTH_IDENTITY',0x000006D5)
		win_const_mgr.add_const('RTCEF_PRESENCE_PROPERTY',0x00020000)
		win_const_mgr.add_const('D3DDEVCAPS_TEXTURESYSTEMMEMORY',0x00000100)
		win_const_mgr.add_const('STATE_SYSTEM_FOCUSABLE',0x00100000)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_COVER',0x00000021)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_CONNECT_HTTP',0x00000004)
		win_const_mgr.add_const('ACTRL_DS_DELETE_TREE',0x00000040)
		win_const_mgr.add_const('COD_MINOR_BIT_OFFSET',0x00000002)
		win_const_mgr.add_const('NDW_INSTALLFLAG_HARDWAREALLREADYIN',0x00000002)
		win_const_mgr.add_const('MD_ERROR_INVALID_VERSION',0x800CC802)
		win_const_mgr.add_const('IMPLINK_HIGHEXPER',0x0000009E)
		win_const_mgr.add_const('SHOP_FILEPATH',0x00000002)
		win_const_mgr.add_const('PGK_MENU',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_IC_SENSITIVE',0x00000004)
		win_const_mgr.add_const('PERF_COUNTER_ELAPSED',0x00040000)
		win_const_mgr.add_const('ELF_DISABLEUPDATENOW',0x00000002)
		win_const_mgr.add_const('TTFCFP_DELTA',0x00000002)
		win_const_mgr.add_const('CBS_OEMCONVERT',0x00000080)
		win_const_mgr.add_const('ERROR_WAKE_SYSTEM',0x000002DA)
		win_const_mgr.add_const('COD_LAN_ACCESS_17_USED',0x00000001)
		win_const_mgr.add_const('RIDEV_NOLEGACY',0x00000030)
		win_const_mgr.add_const('MD_LFHINT_NT2',0x00000002)
		win_const_mgr.add_const('GMEM_ZEROINIT',0x00000040)
		win_const_mgr.add_const('ERR_TSTDUP',0x0000005C)
		win_const_mgr.add_const('LINEERR_INVALMESSAGEID',0x80000030)
		win_const_mgr.add_const('ENM_UPDATE',0x00000002)
		win_const_mgr.add_const('CSIDL_COMMON_TEMPLATES',0x00000002)
		win_const_mgr.add_const('PPP_LCP_SSHF',0x00000008)
		win_const_mgr.add_const('VK_NONAME',0x000000FC)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_SYSTEMCALL',0x00000080)
		win_const_mgr.add_const('NRC_DUPNAME',0x00000000)
		win_const_mgr.add_const('NDW_INSTALLFLAG_EXPRESSINTRO',0x00000400)
		win_const_mgr.add_const('DM_PROMPT',0x00000004)
		win_const_mgr.add_const('VOS_OS216_PM16',0x00020002)
		win_const_mgr.add_const('IF_TYPE_IBM370PARCHAN',0x00000048)
		win_const_mgr.add_const('CACHE_ENTRY_EXPTIME_FC',0x00000080)
		win_const_mgr.add_const('ERROR_UNABLE_TO_REMOVE_REPLACED',0x00000497)
		win_const_mgr.add_const('MSGF_MENU',0x00000002)
		win_const_mgr.add_const('CMM_WIN_VERSION',0x00000000)
		win_const_mgr.add_const('PHONE_STATE',0x00000012)
		win_const_mgr.add_const('MIDI_CACHE_QUERY',0x00000003)
		win_const_mgr.add_const('ERROR_ILLEGAL_CHARACTER',0x00000246)
		win_const_mgr.add_const('ACTRL_ACCESS_PROTECTED',0x00000001)
		win_const_mgr.add_const('VK_OEM_FJ_ROYA',0x00000096)
		win_const_mgr.add_const('ACCESS_MAX_MS_ACE_TYPE',0x00000008)
		win_const_mgr.add_const('SUBLANG_ESTONIAN_ESTONIA',0x00000001)
		win_const_mgr.add_const('LANG_SERBIAN_NEUTRAL',0x00000007)
		win_const_mgr.add_const('DIF_REGISTERDEVICE',0x00000019)
		win_const_mgr.add_const('ML_SHELL_LANGUAGE',0x00000004)
		win_const_mgr.add_const('SCHEME_UPDATE',0x00000020)
		win_const_mgr.add_const('HTTP_LOG_FIELD_SERVER_PORT',0x00008000)
		win_const_mgr.add_const('DBPARAMTYPE_INPUT',0x00000001)
		win_const_mgr.add_const('DBFLAGS_CHECKPOINTDEPTH60MB',0x00000020)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_MINIPORT_ADD_DEVICE_REGISTRATION_ATTRIBUTES',0x000000A4)
		win_const_mgr.add_const('EN_HSCROLL',0x00000601)
		win_const_mgr.add_const('FILE_DEVICE_INPORT_PORT',0x00000000)
		win_const_mgr.add_const('TCIF_TEXT',0x00000001)
		win_const_mgr.add_const('INTERNET_OPEN_TYPE_DIRECT',0x00000001)
		win_const_mgr.add_const('MCI_VCR_PLAY_SCAN',0x00040000)
		win_const_mgr.add_const('DS_SCHEMA_GUID_CLASS',0x00000003)
		win_const_mgr.add_const('BITS_MC_FATAL_IGD_ERROR',0x80194009)
		win_const_mgr.add_const('DV_NTSCPAL',0x00200000)
		win_const_mgr.add_const('OS_PROFESSIONAL',0x00000014)
		win_const_mgr.add_const('DEBUG_BREAK_WRITE',0x00000002)
		win_const_mgr.add_const('OID_IP6_OFFLOAD_STATS',0xFC01020A)
		win_const_mgr.add_const('SFGAO_LINK',0x00010000)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_RANGE',0x00000035)
		win_const_mgr.add_const('DDSCAPS2_RTPATCHES',0x01000000)
		win_const_mgr.add_const('MD_ERROR_SUB404_DENIED_BY_POLICY',0x00000002)
		win_const_mgr.add_const('CLTYPE_LEN',0x0000000C)
		win_const_mgr.add_const('GCS_VERBICONW',0x00000014)
		win_const_mgr.add_const('VIDEO_CONFIGURE_MIN',0x00000040)
		win_const_mgr.add_const('URL_ESCAPE_PERCENT',0x00001000)
		win_const_mgr.add_const('SM_CXMINTRACK',0x00000022)
		win_const_mgr.add_const('SUBLANG_SERBIAN_CYRILLIC',0x00000003)
		win_const_mgr.add_const('PFA_LEFT',0x00000001)
		win_const_mgr.add_const('PORT_POP2',0x0000006D)
		win_const_mgr.add_const('PORT_POP3',0x0000006E)
		win_const_mgr.add_const('BLACK_PEN',0x00000007)
		win_const_mgr.add_const('ERROR_DS_NAME_VALUE_TOO_LONG',0x0000209D)
		win_const_mgr.add_const('WM_COMMNOTIFY',0x00000044)
		win_const_mgr.add_const('WEBPOST_ERROR_LAST',0x400421FF)
		win_const_mgr.add_const('SQL_NOSCAN',0x00000002)
		win_const_mgr.add_const('MD_SERVER_CONFIG_SSL_128',0x00000002)
		win_const_mgr.add_const('MCI_DGV_STATUS_VIDEO_SRC_NUM',0x00000401)
		win_const_mgr.add_const('IMGBITS_MASK',0x0E000000)
		win_const_mgr.add_const('PORT_CISCOSYS',0x00000084)
		win_const_mgr.add_const('SENSITIVITY_PROP_PERSONAL',0x00000001)
		win_const_mgr.add_const('D3DPRASTERCAPS_WFOG',0x00100000)
		win_const_mgr.add_const('PCMCIA_DEF_MIN_REGION',0x00010000)
		win_const_mgr.add_const('DSLFLAG_MISMATCHED_DBG',0x00000002)
		win_const_mgr.add_const('RTM_NEXTHOP_CHANGE_NEW',0x00000001)
		win_const_mgr.add_const('SQL_SR_INSERT_TABLE',0x00000100)
		win_const_mgr.add_const('IDS_CAP_STAT_LIVE_MODE',0x000001F4)
		win_const_mgr.add_const('NETE_ENCRYPT_REQ',0x00000013)
		win_const_mgr.add_const('EMR_POLYPOLYGON',0x00000008)
		win_const_mgr.add_const('DIB_PAL_COLORS',0x00000001)
		win_const_mgr.add_const('DB_IN',0x00000001)
		win_const_mgr.add_const('DEBUG_STATUS_NO_CHANGE',0x00000000)
		win_const_mgr.add_const('DNS_TKEY_MODE_GSS',0x00000003)
		win_const_mgr.add_const('OID_FDDI_LONG_CURRENT_ADDR',0x03010102)
		win_const_mgr.add_const('HORZSIZE',0x00000004)
		win_const_mgr.add_const('CB_GETCOMBOBOXINFO',0x00000164)
		win_const_mgr.add_const('DFCS_BUTTONRADIO',0x00000004)
		win_const_mgr.add_const('ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED',0x000020EA)
		win_const_mgr.add_const('DRM_ACTIVATE_DELAYED',0x00000040)
		win_const_mgr.add_const('CHANGER_CLEANER_AUTODISMOUNT',0x80000004)
		win_const_mgr.add_const('LWA_ALPHA',0x00000002)
		win_const_mgr.add_const('ERROR_DS_DRA_BAD_NC',0x000020F8)
		win_const_mgr.add_const('WMDM_E_CANTOPEN_PMSN_SERVICE_PIPE',0x80045013)
		win_const_mgr.add_const('MF_GRAYED',0x00000001)
		win_const_mgr.add_const('MCI_DGV_REALIZE_NORM',0x00010000)
		win_const_mgr.add_const('KSPIN_FLAG_DISTINCT_TRAILING_EDGE',0x00000200)
		win_const_mgr.add_const('GESTURE_SQUIGGLE',0x00000000)
		win_const_mgr.add_const('TA_BASELINE',0x00000018)
		win_const_mgr.add_const('DM_LOGPIXELS',0x00020000)
		win_const_mgr.add_const('SDP_ATTRIB_PAN_NET_ACCESS_TYPE',0x0000030B)
		win_const_mgr.add_const('DEVPROP_TYPE_EMPTY',0x00000000)
		win_const_mgr.add_const('EDITF_ATTRIBUTEEKU',0x00008000)
		win_const_mgr.add_const('E_FILTER_SCRIPTLABEL',0x80100010)
		win_const_mgr.add_const('WIA_IPC_AUDIO_AVAILABLE',0x00001405)
		win_const_mgr.add_const('WINHTTP_QUERY_IF_MODIFIED_SINCE',0x00000020)
		win_const_mgr.add_const('NRB_ILLEGAL_REQUEST',0x00000001)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_SECURITYFIX_UNINSTALL',0x00000015)
		win_const_mgr.add_const('EXCEPTION_DEBUG_EVENT',0x00000001)
		win_const_mgr.add_const('RPC_S_INVALID_TIMEOUT',0x000006AD)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_SA_DELETED',0x000035EF)
		win_const_mgr.add_const('CR_PROP_PRODUCTVERSION',0x00000002)
		win_const_mgr.add_const('LINE_GENERATE',0x00000007)
		win_const_mgr.add_const('SPDIT_CLASSDRIVER',0x00000001)
		win_const_mgr.add_const('RPC_S_NOT_LISTENING',0x000006B3)
		win_const_mgr.add_const('KSAC3_SERVICE_VISUALLY_IMPAIRED',0x00000002)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_CONNECT_FTP',0x00000002)
		win_const_mgr.add_const('OBM_OLD_DNARROW',0x00007FFC)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_ADD_CHAIN_NO_ROOT',0x00000002)
		win_const_mgr.add_const('SHI1005_FLAGS_RESTRICT_EXCLUSIVE_OPENS',0x00000100)
		win_const_mgr.add_const('IDM_TRIED_MERGECELLS',0x00000012)
		win_const_mgr.add_const('DE_E_FILTER_SCRIPTTEXTAREA',0x80100020)
		win_const_mgr.add_const('TPR_MIC',0x00000004)
		win_const_mgr.add_const('SMART_SHORT_SELFTEST_CAPTIVE',0x00000081)
		win_const_mgr.add_const('RAS_EAP_FLAG_HOSTED_IN_PEAP',0x00000100)
		win_const_mgr.add_const('TMT_SCROLLBARWIDTH',0x000004B2)
		win_const_mgr.add_const('NETERR_RING_STATUS_REMOTE_RECEIVED',0x00000200)
		win_const_mgr.add_const('PID_TITLE',0x00000002)
		win_const_mgr.add_const('SCARD_READER_TYPE_PCMCIA',0x00000040)
		win_const_mgr.add_const('OID_FDDI_LONG_PERMANENT_ADDR',0x03010101)
		win_const_mgr.add_const('PDH_PLA_VALIDATION_WARNING',0x80000BF3)
		win_const_mgr.add_const('VK_XBUTTON2',0x00000006)
		win_const_mgr.add_const('SES_NOIME',0x00000080)
		win_const_mgr.add_const('WIA_IPA_DEPTH',0x00001008)
		win_const_mgr.add_const('SPSVCINST_CLOBBER_SECURITY',0x00000400)
		win_const_mgr.add_const('SHI1005_FLAGS_ACCESS_BASED_DIRECTORY_ENUM',0x00000800)
		win_const_mgr.add_const('DMPAPER_B4',0x0000000C)
		win_const_mgr.add_const('WRITE_WATCH_FLAG_RESET',0x00000001)
		win_const_mgr.add_const('BCRYPT_SUPPORTED_PAD_PKCS1_SIG',0x00000004)
		win_const_mgr.add_const('SYMF_THUNK',0x00002000)
		win_const_mgr.add_const('PLATFORM_UNKNOWN',0x00000000)
		win_const_mgr.add_const('MD_APP_POOL_RECYCLE_CONFIG_CHANGE',0x00000040)
		win_const_mgr.add_const('FILE_ACTION_RENAMED_OLD_NAME',0x00000004)
		win_const_mgr.add_const('HFRMREG_LOCAL',0x00000001)
		win_const_mgr.add_const('ARCONTENT_PHASE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('DDSCAPS3_CREATESHAREDRESOURCE',0x00002000)
		win_const_mgr.add_const('ERROR_DS_INIT_FAILURE',0x00002154)
		win_const_mgr.add_const('RPC_X_BAD_STUB_DATA',0x000006F7)
		win_const_mgr.add_const('CBENF_KILLFOCUS',0x00000001)
		win_const_mgr.add_const('ADS_SERVICE_ERROR_IGNORE',0x00000000)
		win_const_mgr.add_const('MOD_SHIFT',0x00000004)
		win_const_mgr.add_const('SHCNE_MEDIAINSERTED',0x00000020)
		win_const_mgr.add_const('SV_USERPATH_PARMNUM',0x00000070)
		win_const_mgr.add_const('VFT2_DRV_COMM',0x0000000A)
		win_const_mgr.add_const('HELP_SETINDEX',0x00000005)
		win_const_mgr.add_const('ERROR_SUCCESS_REBOOT_REQUIRED',0x00000BC2)
		win_const_mgr.add_const('NS_NBP',0x00000014)
		win_const_mgr.add_const('ERROR_LM_CROSS_ENCRYPTION_REQUIRED',0x0000056E)
		win_const_mgr.add_const('LVSIL_GROUPHEADER',0x00000003)
		win_const_mgr.add_const('NS_WRQ',0x00000032)
		win_const_mgr.add_const('SRRF_RT_REG_MULTI_SZ',0x00000020)
		win_const_mgr.add_const('ERROR_INVALID_PRINT_MONITOR',0x00000BBF)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_WANT_SID_PATH',0x00000010)
		win_const_mgr.add_const('ICEE_CREATE_MACHINE_IA64',0x00000200)
		win_const_mgr.add_const('SETUP_SUSPEND_FLAG',0x00000004)
		win_const_mgr.add_const('PORT_NETRJS1',0x00000047)
		win_const_mgr.add_const('PORT_NETRJS2',0x00000048)
		win_const_mgr.add_const('SQL_API_SQLDRIVERS',0x00000047)
		win_const_mgr.add_const('PORT_NETRJS4',0x0000004A)
		win_const_mgr.add_const('SQL_ISV_TABLE_CONSTRAINTS',0x00008000)
		win_const_mgr.add_const('RP_DSN_SENT_EXPANDED',0x00008040)
		win_const_mgr.add_const('MCI_DGV_SET_FILEFORMAT',0x00080000)
		win_const_mgr.add_const('WABOBJECT_ME_NEW',0x00000001)
		win_const_mgr.add_const('VFFF_ISSHAREDFILE',0x00000001)
		win_const_mgr.add_const('DDOVER_SHOW',0x00004000)
		win_const_mgr.add_const('TMT_TEXTSHADOWOFFSET',0x00000D4A)
		win_const_mgr.add_const('FEI_NOT_FAX_CALL',0x00000000)
		win_const_mgr.add_const('SRCINFO_PATH',0x00000001)
		win_const_mgr.add_const('SUBLANG_SPANISH_COLOMBIA',0x00000009)
		win_const_mgr.add_const('DNS_QUERY_WIRE_ONLY',0x00000100)
		win_const_mgr.add_const('WMDM_LOG_NOTIMESTAMP',0x00000010)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_USER_ENTERED_UPLEVEL_SCOPE',0x00000100)
		win_const_mgr.add_const('PAN_XHEIGHT_DUCKING_SMALL',0x00000005)
		win_const_mgr.add_const('PXE_TRACE_FATAL',0x00100000)
		win_const_mgr.add_const('ERROR_REMOTE_STORAGE_MEDIA_ERROR',0x00001100)
		win_const_mgr.add_const('ERROR_INVALID_SERVICE_ACCOUNT',0x00000421)
		win_const_mgr.add_const('TMT_MINSIZE5',0x00000D50)
		win_const_mgr.add_const('RENDBIND_DEFAULTCREDENTIALS',0x00000000)
		win_const_mgr.add_const('TMT_MINSIZE3',0x00000D4E)
		win_const_mgr.add_const('TMT_MINSIZE2',0x00000D4D)
		win_const_mgr.add_const('TMT_MINSIZE1',0x00000D4C)
		win_const_mgr.add_const('CDN_FIRST',0x00000000)
		win_const_mgr.add_const('DDF_UPDATE',0x00000002)
		win_const_mgr.add_const('SUBLANG_MONGOLIAN_CYRILLIC_MONGOLIA',0x00000001)
		win_const_mgr.add_const('WSA_QOS_ESERVICETYPE',0x00002B08)
		win_const_mgr.add_const('CERT_KEY_CERT_SIGN_KEY_USAGE',0x00000004)
		win_const_mgr.add_const('AUTHZ_SKIP_TOKEN_GROUPS',0x00000002)
		win_const_mgr.add_const('ERROR_CLUSTER_RHS_FAILED_INITIALIZATION',0x0000172B)
		win_const_mgr.add_const('APPCOMMAND_UNDO',0x00000022)
		win_const_mgr.add_const('DDSCAPS_OFFSCREENPLAIN',0x00000040)
		win_const_mgr.add_const('ERROR_DIR_EFS_DISALLOWED',0x0000177A)
		win_const_mgr.add_const('ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE',0x0000030D)
		win_const_mgr.add_const('IF_MAX_STRING_SIZE',0x00000100)
		win_const_mgr.add_const('PF_COMPARE64_EXCHANGE128',0x0000000F)
		win_const_mgr.add_const('PDH_CSTATUS_NO_COUNTER',0xC0000BB9)
		win_const_mgr.add_const('MQMSG_AUTHENTICATED_SIG20',0x00000003)
		win_const_mgr.add_const('ELEMENT_STATUS_FULL',0x00000001)
		win_const_mgr.add_const('SQL_CURSOR_SENSITIVITY',0x00002711)
		win_const_mgr.add_const('LVS_TYPEMASK',0x00000003)
		win_const_mgr.add_const('SID_RECOMMENDED_SUB_AUTHORITIES',0x00000001)
		win_const_mgr.add_const('DN_BAD_PARTIAL',0x00400000)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_RELEASEEXCLUSIVEACCESS',0x00000103)
		win_const_mgr.add_const('GROUPIDMASK',0x00008000)
		win_const_mgr.add_const('TMT_TOCOLOR4',0x000007D9)
		win_const_mgr.add_const('NDIS_ETH_TYPE_IPV6',0x00000086)
		win_const_mgr.add_const('NDIS_ETH_TYPE_IPV4',0x00000800)
		win_const_mgr.add_const('SUBLANG_TSWANA_SOUTH_AFRICA',0x00000001)
		win_const_mgr.add_const('CRYPT_PUBKEY_ALG_OID_GROUP_ID',0x00000003)
		win_const_mgr.add_const('DS_REPSYNC_WRITEABLE',0x00000002)
		win_const_mgr.add_const('MPEGLAYER3_WFX_EXTRA_BYTES',0x0000000C)
		win_const_mgr.add_const('WIA_IPS_PAGE_SIZE',0x00000C19)
		win_const_mgr.add_const('SSRVACTION_TRACE',0x00000001)
		win_const_mgr.add_const('TME_LEAVE',0x00000002)
		win_const_mgr.add_const('CM_PROB_OUT_OF_MEMORY',0x00000003)
		win_const_mgr.add_const('SHGDFIL_FINDDATA',0x00000001)
		win_const_mgr.add_const('ILC_HIGHQUALITYSCALE',0x00020000)
		win_const_mgr.add_const('PHONEPRIVILEGE_MONITOR',0x00000001)
		win_const_mgr.add_const('SERIAL_IOC_FCR_RCVR_TRIGGER_MSB',0x00000080)
		win_const_mgr.add_const('SCARD_RESET_CARD',0x00000001)
		win_const_mgr.add_const('MDMVOLFLAG_MEDIUM',0x00000002)
		win_const_mgr.add_const('LINEERR_INVALDIALPARAMS',0x80000025)
		win_const_mgr.add_const('TVHT_NOWHERE',0x00000001)
		win_const_mgr.add_const('CERT_FIRST_USER_PROP_ID',0x00008000)
		win_const_mgr.add_const('DF_IMPERSONATION',0x80000000)
		win_const_mgr.add_const('GMEM_DISCARDED',0x00004000)
		win_const_mgr.add_const('DS_TRY_NEXTCLOSEST_SITE',0x00040000)
		win_const_mgr.add_const('MAXIMUM_SEQUENCE',0xFFFFFFFFFFFFFFFF)
		win_const_mgr.add_const('FACILITY_EAP_MESSAGE',0x00000842)
		win_const_mgr.add_const('STGM_OUTPUT',0x00008000)
		win_const_mgr.add_const('ERROR_AUTHIP_FAILURE',0x000005BD)
		win_const_mgr.add_const('MD_NOTIFY_URL_MAP',0x00001000)
		win_const_mgr.add_const('CHANNEL_RC_OK',0x00000000)
		win_const_mgr.add_const('KS_TVAUDIO_MODE_LANG_A',0x00000010)
		win_const_mgr.add_const('KS_TVAUDIO_MODE_LANG_C',0x00000040)
		win_const_mgr.add_const('KS_TVAUDIO_MODE_LANG_B',0x00000020)
		win_const_mgr.add_const('CC_INTERIORS',0x00000080)
		win_const_mgr.add_const('HKL_NEXT',0x00000001)
		win_const_mgr.add_const('CC_STYLED',0x00000020)
		win_const_mgr.add_const('GESTURE_LEFT_DOWN',0x00000000)
		win_const_mgr.add_const('DDOVER_ALPHADESTCONSTOVERRIDE',0x00000002)
		win_const_mgr.add_const('SQL_STILL_EXECUTING',0x00000002)
		win_const_mgr.add_const('WIA_IPA_PIXELS_PER_LINE',0x00001010)
		win_const_mgr.add_const('DEBUG_MANSTR_NONE',0x00000000)
		win_const_mgr.add_const('PSR_MBZ1',0x00000010)
		win_const_mgr.add_const('PSR_MBZ0',0x00000006)
		win_const_mgr.add_const('PSR_MBZ3',0x0000002E)
		win_const_mgr.add_const('MF_COMPONENT_LS_CERT_REVOKED',0x00040000)
		win_const_mgr.add_const('ERROR_CLUSTER_NO_QUORUM',0x00001725)
		win_const_mgr.add_const('KSEVENTF_EVENT_HANDLE',0x00000001)
		win_const_mgr.add_const('UPDP_CHECK_DRIVERSTORE',0x00000004)
		win_const_mgr.add_const('WINHTTP_OPTION_AUTOLOGON_POLICY',0x0000004D)
		win_const_mgr.add_const('PHOTO_GAINCONTROL_NONE',0x00000000)
		win_const_mgr.add_const('OID_GEN_RECEIVE_BUFFER_SPACE',0x00010109)
		win_const_mgr.add_const('V86FLAGS_AUXCARRY',0x00000010)
		win_const_mgr.add_const('AMDDS_YUVOFF',0x00000020)
		win_const_mgr.add_const('FWP_OPTION_VALUE_DENY_MULTICAST_STATE',0x00000001)
		win_const_mgr.add_const('WM_STYLECHANGING',0x0000007C)
		win_const_mgr.add_const('PTE_EXECUTE_MASK',0x00000200)
		win_const_mgr.add_const('DNS_ERROR_NAME_NOT_IN_ZONE',0x000025EA)
		win_const_mgr.add_const('TMT_TOCOLOR3',0x000007D8)
		win_const_mgr.add_const('KRB_NT_SRV_HST',0x00000003)
		win_const_mgr.add_const('LPV_REJECT',0x0000FFFF)
		win_const_mgr.add_const('MM_SUBMENUSHAVEIDS',0x00000002)
		win_const_mgr.add_const('LDAP_API_FEATURE_VIRTUAL_LIST_VIEW',0x000003E9)
		win_const_mgr.add_const('SQL_DOUBLE',0x00000008)
		win_const_mgr.add_const('SQL_ASYNC_ENABLE_OFF',0x00000000)
		win_const_mgr.add_const('ISDB_DCT_PID',0x00000017)
		win_const_mgr.add_const('IMAGE_REL_PPC_BRTAKEN',0x00000200)
		win_const_mgr.add_const('ILR_DEFAULT',0x00000000)
		win_const_mgr.add_const('PSR_ID',0x00000025)
		win_const_mgr.add_const('PSR_IC',0x0000000D)
		win_const_mgr.add_const('MCI_DGV_FF_RDIB',0x00004003)
		win_const_mgr.add_const('MD_ACCESS_SSL',0x00000008)
		win_const_mgr.add_const('DBPROPVAL_BO_NOINDEXUPDATE',0x00000001)
		win_const_mgr.add_const('IF_TYPE_HDSL2',0x000000A8)
		win_const_mgr.add_const('ERROR_INSTALL_SUSPEND',0x00000644)
		win_const_mgr.add_const('DEBUG_ENGOPT_DISALLOW_SHELL_COMMANDS',0x00001000)
		win_const_mgr.add_const('FR_HIDEWHOLEWORD',0x00010000)
		win_const_mgr.add_const('CONFIGFLAG_FINISHINSTALL_UI',0x00010000)
		win_const_mgr.add_const('D3DPTEXTURECAPS_CUBEMAP_POW2',0x00020000)
		win_const_mgr.add_const('FKF_INDICATOR',0x00000020)
		win_const_mgr.add_const('PSR_IT',0x00000024)
		win_const_mgr.add_const('PSR_IS',0x00000022)
		win_const_mgr.add_const('OBM_LFARROWD',0x00007FE4)
		win_const_mgr.add_const('D3DPSHADECAPS_ALPHAGOURAUDBLEND',0x00004000)
		win_const_mgr.add_const('ERROR_NOINTERFACE',0x00000278)
		win_const_mgr.add_const('DRM_SERVICE_TYPE_ACTIVATION',0x00000001)
		win_const_mgr.add_const('DDL_POSTMSGS',0x00002000)
		win_const_mgr.add_const('MAPI_EXTENDED',0x00000020)
		win_const_mgr.add_const('CRYPT_OAEP',0x00000040)
		win_const_mgr.add_const('ACM_FORMATENUMF_OUTPUT',0x01000000)
		win_const_mgr.add_const('ERROR_INVALID_SHOWWIN_COMMAND',0x000005A9)
		win_const_mgr.add_const('XINPUT_GAMEPAD_Y',0x00008000)
		win_const_mgr.add_const('XINPUT_GAMEPAD_X',0x00004000)
		win_const_mgr.add_const('SCHEMADEF_VERSION',0x00000001)
		win_const_mgr.add_const('DM_NUP',0x00000040)
		win_const_mgr.add_const('MSIMHOSTEVENTS_DISPID_ONCLICKUSERNOTIFY',0x0000000F)
		win_const_mgr.add_const('PP_DELETEKEY',0x00000018)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_REQUEST_SENT',0x00000020)
		win_const_mgr.add_const('AE_BADPW',0x00000001)
		win_const_mgr.add_const('IME_CMODE_HANJACONVERT',0x00000040)
		win_const_mgr.add_const('XINPUT_GAMEPAD_B',0x00002000)
		win_const_mgr.add_const('TRUSTERROR_STEP_FINAL_UIPROV',0x00000025)
		win_const_mgr.add_const('DBCOMPUTEMODE_COMPUTED',0x00000001)
		win_const_mgr.add_const('PSP_HASHELP',0x00000020)
		win_const_mgr.add_const('AM_QUERY_DECODER_DXVA_1_SUPPORT',0x00000002)
		win_const_mgr.add_const('WSAECONNABORTED',0x00002745)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_PHYSICALDISK',0x0000000B)
		win_const_mgr.add_const('CLFS_FLAG_MINIFILTER_LEVEL',0x00000100)
		win_const_mgr.add_const('HTTP_FLUSH_RESPONSE_FLAG_RECURSIVE',0x00000001)
		win_const_mgr.add_const('LVS_EX_LABELTIP',0x00004000)
		win_const_mgr.add_const('MAPI_PREFIX',0x0000002A)
		win_const_mgr.add_const('ERROR_CTX_PD_NOT_FOUND',0x00001B5B)
		win_const_mgr.add_const('SSPROP_SQLXMLXPROGID',0x00000004)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_MAX',0x00000018)
		win_const_mgr.add_const('TSF_COPY_LOCALIZED_NAME',0x00000200)
		win_const_mgr.add_const('SQL_CA1_SELECT_FOR_UPDATE',0x00008000)
		win_const_mgr.add_const('DDSD_CKDESTBLT',0x00004000)
		win_const_mgr.add_const('IT_MSG_DATA_HEADER',0x00000001)
		win_const_mgr.add_const('CR_INVALID_MACHINENAME',0x0000002F)
		win_const_mgr.add_const('SUBLANG_KANNADA_INDIA',0x00000001)
		win_const_mgr.add_const('RPC_FW_IF_FLAG_DCOM',0x00000001)
		win_const_mgr.add_const('ED_TOP',0x00000001)
		win_const_mgr.add_const('LOCALE_SMONTHNAME8',0x0000003F)
		win_const_mgr.add_const('MIN_GOPHER_ATTRIBUTE_LENGTH',0x00000100)
		win_const_mgr.add_const('SNMP_AUTHAPI_INVALID_VERSION',0x0000001E)
		win_const_mgr.add_const('CTRY_FAEROE_ISLANDS',0x0000012A)
		win_const_mgr.add_const('WM_SETFONT',0x00000030)
		win_const_mgr.add_const('CDO_E_NOT_ALL_DELETED',0x80040223)
		win_const_mgr.add_const('SQL_COLUMN_UPDATABLE',0x0000000A)
		win_const_mgr.add_const('NFS_ALL',0x00000010)
		win_const_mgr.add_const('DMTT_DOWNLOAD',0x00000002)
		win_const_mgr.add_const('SUPPORTS_REMOTE_ADMIN_PROTOCOL',0x00000002)
		win_const_mgr.add_const('LINEERR_CALLUNAVAIL',0x80000005)
		win_const_mgr.add_const('MD_SERVER_COMMAND_STOP',0x00000002)
		win_const_mgr.add_const('ERROR_NOT_ALL_ASSIGNED',0x00000514)
		win_const_mgr.add_const('VER_SUITE_SMALLBUSINESS',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_OUT_OF_MEMORY',0x00003623)
		win_const_mgr.add_const('BKMODE_LAST',0x00000002)
		win_const_mgr.add_const('SQL_SP_MATCH_PARTIAL',0x00000010)
		win_const_mgr.add_const('SQL_DIAG_CREATE_SCHEMA',0x00000040)
		win_const_mgr.add_const('MIDI_IO_STATUS',0x00000020)
		win_const_mgr.add_const('DBT_VOLLOCKLOCKRELEASED',0x00008045)
		win_const_mgr.add_const('CDO_E_ARGUMENT1',0x80044000)
		win_const_mgr.add_const('D3DPRESENT_INTERVAL_IMMEDIATE',0x80000000)
		win_const_mgr.add_const('TASK_SATURDAY',0x00000040)
		win_const_mgr.add_const('CDO_E_ARGUMENT2',0x80044001)
		win_const_mgr.add_const('CDO_E_ARGUMENT5',0x80044004)
		win_const_mgr.add_const('ADO_MINOR',0x00000000)
		win_const_mgr.add_const('D3DLOCK_NOOVERWRITE',0x00001000)
		win_const_mgr.add_const('TRUSTERROR_STEP_SIP',0x00000003)
		win_const_mgr.add_const('ERROR_FULLSCREEN_MODE',0x000003EF)
		win_const_mgr.add_const('OID_TAPI_MONITOR_DIGITS',0x07030124)
		win_const_mgr.add_const('FILEOP_NEWPATH',0x00000004)
		win_const_mgr.add_const('BSF_QUERY',0x00000001)
		win_const_mgr.add_const('DISPLAY_DEVICE_TS_COMPATIBLE',0x00200000)
		win_const_mgr.add_const('INDEX_GUID_INKWORD',0x0000000A)
		win_const_mgr.add_const('RCRED_STATUS_UNKNOWN_ISSUER',0x00000002)
		win_const_mgr.add_const('SV_SESSREQS_PARMNUM',0x000001A1)
		win_const_mgr.add_const('LINE_PROXYSTATUS',0x0000001F)
		win_const_mgr.add_const('DOT11_PSD_IE_MAX_DATA_SIZE',0x000000F0)
		win_const_mgr.add_const('ATA_FLAGS_USE_DMA',0x00000001)
		win_const_mgr.add_const('PTE_PFN_LEN',0x00000018)
		win_const_mgr.add_const('MCI_RESERVE',0x00000872)
		win_const_mgr.add_const('ERROR_TRAY_MALFUNCTION',0x00000010)
		win_const_mgr.add_const('LINETERMMODE_BUTTONS',0x00000001)
		win_const_mgr.add_const('RTM_ENUM_OWN_ROUTES',0x00010000)
		win_const_mgr.add_const('OLEUI_ERR_FINDTEMPLATEFAILURE',0x0000006E)
		win_const_mgr.add_const('ERROR_EAS_NOT_SUPPORTED',0x0000011A)
		win_const_mgr.add_const('MAXIMUM_SMARTCARD_READERS',0x0000000A)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_DO_COMPLETE_FIRST',0x00000200)
		win_const_mgr.add_const('ADS_PRINTER_NO_TONER',0x00040000)
		win_const_mgr.add_const('PID_SUBJECT',0x00000003)
		win_const_mgr.add_const('CDO_E_LOGON_FAILURE',0x80040217)
		win_const_mgr.add_const('LBS_WANTKEYBOARDINPUT',0x00000400)
		win_const_mgr.add_const('WINHTTP_OPTION_PASSWORD',0x00001001)
		win_const_mgr.add_const('DEBUG_END_ACTIVE_TERMINATE',0x00000001)
		win_const_mgr.add_const('MMIO_GLOBALPROC',0x10000000)
		win_const_mgr.add_const('CERT_CHAIN_ENABLE_SHARE_STORE',0x00000020)
		win_const_mgr.add_const('IP_FRAGOFF_SHIFT',0x00000003)
		win_const_mgr.add_const('LINEDISCONNECTMODE_NODIALTONE',0x00001000)
		win_const_mgr.add_const('OPTION_SERVER_IDENTIFIER',0x00000036)
		win_const_mgr.add_const('FL_UFI_MEMORYFONT',0x00000004)
		win_const_mgr.add_const('OID_FDDI_PORT_INDEX',0x03030267)
		win_const_mgr.add_const('CLFS_MAX_CONTAINER_INFO',0x00000100)
		win_const_mgr.add_const('OID_GEN_MEDIA_CONNECT_STATUS',0x00010114)
		win_const_mgr.add_const('MIXERLINE_LINEF_ACTIVE',0x00000001)
		win_const_mgr.add_const('SQLBIGBINARY',0x00000000)
		win_const_mgr.add_const('BIF_SHAREABLE',0x00008000)
		win_const_mgr.add_const('WM_HELP',0x00000053)
		win_const_mgr.add_const('SPQ_SCAN_FILE_PRESENCE',0x00000001)
		win_const_mgr.add_const('SV_GUESTACC_PARMNUM',0x00000198)
		win_const_mgr.add_const('RDW_UPDATENOW',0x00000100)
		win_const_mgr.add_const('NRC_INVADDRESS',0x00000039)
		win_const_mgr.add_const('USHORT_ERROR',0x00000000)
		win_const_mgr.add_const('DMPAPER_ENV_INVITE',0x0000002F)
		win_const_mgr.add_const('ERROR_SYMLINK_NOT_SUPPORTED',0x000005B8)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_STATE_CHANGE',0x00004000)
		win_const_mgr.add_const('OPTION_BROADCAST_ADDRESS',0x0000001C)
		win_const_mgr.add_const('SP_SERIALCOMM',0x00000001)
		win_const_mgr.add_const('IMAGE_SCN_MEM_LOCKED',0x00040000)
		win_const_mgr.add_const('DNS_RCLASS_INTERNET',0x00000100)
		win_const_mgr.add_const('PROCESSOR_INTEL_386',0x00000182)
		win_const_mgr.add_const('CRED_MAX_VALUE_SIZE',0x00000100)
		win_const_mgr.add_const('WIA_PAGE_DIN_4B',0x00000035)
		win_const_mgr.add_const('S_STACCATO',0x00000002)
		win_const_mgr.add_const('MC_CAPS_DISPLAY_AREA_POSITION',0x00000080)
		win_const_mgr.add_const('PHOTO_EXPOSUREPROGRAM_MANUAL',0x00000001)
		win_const_mgr.add_const('PIR_STATUS_TABLE_REGISTRY',0x00000000)
		win_const_mgr.add_const('TRUSTERROR_STEP_FINAL_CERTCHKPROV',0x00000023)
		win_const_mgr.add_const('IPX_MAX_ADAPTER_NUM',0x0000400D)
		win_const_mgr.add_const('RTL_RUN_ONCE_CTX_RESERVED_BITS',0x00000002)
		win_const_mgr.add_const('OID_802_5_TOKEN_ERRORS',0x02020206)
		win_const_mgr.add_const('PRIVACY_URLHASCOMPACTPOLICY',0x00020000)
		win_const_mgr.add_const('BS_PUSHLIKE',0x00001000)
		win_const_mgr.add_const('IDM_REMOVEFORMAT',0x000008B6)
		win_const_mgr.add_const('HH_RESET_IT_FILTER',0x00000017)
		win_const_mgr.add_const('SORT_GEORGIAN_MODERN',0x00000001)
		win_const_mgr.add_const('PORT_EMFISDATA',0x0000008C)
		win_const_mgr.add_const('ADS_JOB_DELETED',0x00000100)
		win_const_mgr.add_const('DI_GENERALPAGE_ADDED',0x00001000)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_NAME_RESOLVED',0x00000002)
		win_const_mgr.add_const('IS_IA',0x00000001)
		win_const_mgr.add_const('MD_ERROR_SUB404_DENIED_BY_MIMEMAP',0x00000003)
		win_const_mgr.add_const('SPI_SETWHEELSCROLLCHARS',0x0000006D)
		win_const_mgr.add_const('SQL_AD_DROP_DOMAIN_DEFAULT',0x00000010)
		win_const_mgr.add_const('CRYPT_ALL_FUNCTIONS',0x00000001)
		win_const_mgr.add_const('SQL_CODE_DAY_TO_MINUTE',0x00000009)
		win_const_mgr.add_const('JPEG_Y',0x00000001)
		win_const_mgr.add_const('DCE_C_ERROR_STRING_LEN',0x00000100)
		win_const_mgr.add_const('DEBUG_END_REENTRANT',0x00000003)
		win_const_mgr.add_const('MDPROPVAL_MNF_LINREGVARIANCE',0x00000100)
		win_const_mgr.add_const('DC_PAPERS',0x00000002)
		win_const_mgr.add_const('STI_VERSION_3',0x00000003)
		win_const_mgr.add_const('PAN_PROP_OLD_STYLE',0x00000002)
		win_const_mgr.add_const('FS_JOHAB',0x00200000)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_ALREADY_MEMBER',0x000013C9)
		win_const_mgr.add_const('SM_CYFRAME',0x00000021)
		win_const_mgr.add_const('DB_IMP_LEVEL_DELEGATE',0x00000003)
		win_const_mgr.add_const('SET_POLY_MODE',0x00001008)
		win_const_mgr.add_const('COMMON_LVB_REVERSE_VIDEO',0x00004000)
		win_const_mgr.add_const('DIREG_DEV',0x00000001)
		win_const_mgr.add_const('CACHE_CONFIG_COOKIES_PATHS_FC',0x00000200)
		win_const_mgr.add_const('STATE_SYSTEM_FLOATING',0x00001000)
		win_const_mgr.add_const('CERT_STORE_PROV_SYSTEM_STORE_FLAG',0x00000008)
		win_const_mgr.add_const('PROCESSOR_ALPHA_21064',0x00005248)
		win_const_mgr.add_const('GC_WCH_SIBLING',0x00000001)
		win_const_mgr.add_const('URLACTION_SHELL_VERB',0x00001804)
		win_const_mgr.add_const('ACTCTX_FLAG_PROCESSOR_ARCHITECTURE_VALID',0x00000001)
		win_const_mgr.add_const('WLX_SAS_ACTION_LOGOFF',0x00000004)
		win_const_mgr.add_const('DDCAPS2_CANBOBINTERLEAVED',0x00000010)
		win_const_mgr.add_const('IPX_STATIC_ROUTE_INFO_TYPE',0x00000002)
		win_const_mgr.add_const('DISABLE_STORE_UPDATE',0x0000000F)
		win_const_mgr.add_const('GGO_BITMAP',0x00000001)
		win_const_mgr.add_const('DB_PROT_LEVEL_NONE',0x00000000)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_PVK_FILE',0x00000001)
		win_const_mgr.add_const('CERT_COMPARE_ATTR',0x00000003)
		win_const_mgr.add_const('SPEAKER_LOW_FREQUENCY',0x00000008)
		win_const_mgr.add_const('NCRYPTBUFFER_SSL_HIGHEST_VERSION',0x00000016)
		win_const_mgr.add_const('DEBUG_SYMTYPE_CODEVIEW',0x00000002)
		win_const_mgr.add_const('ERR_INVALID_FILE_TYPE',0xE000000B)
		win_const_mgr.add_const('PRINTER_FONTTYPE',0x00004000)
		win_const_mgr.add_const('OID_TAPI_OPEN',0x07030117)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_SCROLLTO',0x00000490)
		win_const_mgr.add_const('SQL_FN_STR_LTRIM',0x00000008)
		win_const_mgr.add_const('LDAP_OPT_CHASE_REFERRALS',0x00000002)
		win_const_mgr.add_const('MDITILE_ZORDER',0x00000004)
		win_const_mgr.add_const('NTDSCONN_KCC_NO_REASON',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_SQ_QUANTIFIED',0x00000010)
		win_const_mgr.add_const('LCSEX_ANSICREATED',0x00000001)
		win_const_mgr.add_const('CMSG_KEY_AGREE_STATIC_KEY_CHOICE',0x00000002)
		win_const_mgr.add_const('PAN_CONTRAST_MEDIUM_LOW',0x00000005)
		win_const_mgr.add_const('SAFER_LEVELID_NORMALUSER',0x00020000)
		win_const_mgr.add_const('ACMFORMATCHOOSE_STYLEF_INITTOWFXSTRUCT',0x00000040)
		win_const_mgr.add_const('FE_FONTSMOOTHINGORIENTATIONRGB',0x00000001)
		win_const_mgr.add_const('WINWATCHNOTIFY_START',0x00000000)
		win_const_mgr.add_const('KERB_LOGON_FLAG_ALLOW_EXPIRED_TICKET',0x00000001)
		win_const_mgr.add_const('STREAM_FLAGS_DISALLOW_ABSOLUTE_PATH',0x00000002)
		win_const_mgr.add_const('SQL_OSC_MINIMUM',0x00000000)
		win_const_mgr.add_const('MCI_DGV_PUT_CLIENT',0x00400000)
		win_const_mgr.add_const('FACILITY_ACPI_ERROR_CODE',0x00000014)
		win_const_mgr.add_const('ACMFORMATTAGDETAILS_FORMATTAG_CHARS',0x00000030)
		win_const_mgr.add_const('SQL_STRING_FUNCTIONS',0x00000032)
		win_const_mgr.add_const('CERT_STORE_SAVE_TO_FILENAME_W',0x00000004)
		win_const_mgr.add_const('MAX_ADAPTER_NAME',0x00000080)
		win_const_mgr.add_const('URLACTION_ACTIVEX_MIN',0x00001200)
		win_const_mgr.add_const('DEBUG_DATA_SPACE_CONTROL',0x00000002)
		win_const_mgr.add_const('CAUSE_PU_PROVIDER',0x00000000)
		win_const_mgr.add_const('I24_CLASS',0x00000080)
		win_const_mgr.add_const('META_POLYGON',0x00000324)
		win_const_mgr.add_const('DNS_ERROR_DS_ZONE_ALREADY_EXISTS',0x000025F6)
		win_const_mgr.add_const('WMDM_DEVICECAP_CANPLAY',0x00000001)
		win_const_mgr.add_const('ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS',0x0000212D)
		win_const_mgr.add_const('SO_CONFIRM_NAME',0x0000A003)
		win_const_mgr.add_const('TRUST_TYPE_DCE',0x00000004)
		win_const_mgr.add_const('CF_BITMAP',0x00000002)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_INCOMING_FOREST_TRUST_BUILDERS',0x0000022D)
		win_const_mgr.add_const('WMDM_STORAGECAP_FOLDERLIMITEXISTS',0x00000010)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_TX_ENABLED_RX_DISABLED',0x00000002)
		win_const_mgr.add_const('REG_SECURE_CONNECTION',0x00000001)
		win_const_mgr.add_const('MC_CAPS_RESTORE_FACTORY_DEFAULTS',0x00000400)
		win_const_mgr.add_const('KAGPROP_MAXCOLUMNSININDEX',0x0000000D)
		win_const_mgr.add_const('CHANGER_STATUS_NON_VOLATILE',0x00000010)
		win_const_mgr.add_const('ERROR_NET_OPEN_FAILED',0x0000023A)
		win_const_mgr.add_const('INTERNET_RFC1123_FORMAT',0x00000000)
		win_const_mgr.add_const('CACHE_NOTIFY_URL_SET_STICKY',0x00000010)
		win_const_mgr.add_const('CRED_FLAGS_PASSWORD_FOR_CERT',0x00000001)
		win_const_mgr.add_const('DEBUG_TBINFO_START_OFFSET',0x00000010)
		win_const_mgr.add_const('LDAP_OPT_RETURN_REFS',0x00000004)
		win_const_mgr.add_const('CRYPT_RC2_128BIT_VERSION',0x0000003A)
		win_const_mgr.add_const('SKF_AVAILABLE',0x00000002)
		win_const_mgr.add_const('DEBUG_SYMENT_IS_PARAMETER',0x00000004)
		win_const_mgr.add_const('TMTVS_RESERVEDLOW',0x000186A0)
		win_const_mgr.add_const('ERROR_DS_ALIASED_OBJ_MISSING',0x0000208E)
		win_const_mgr.add_const('C3_FULLWIDTH',0x00000080)
		win_const_mgr.add_const('CERT_SHA1_HASH_PROP_ID',0x00000003)
		win_const_mgr.add_const('ERROR_UNKNOWN_PRODUCT',0x00000645)
		win_const_mgr.add_const('ERROR_EVT_FILTER_ALREADYSCOPED',0x00003AA6)
		win_const_mgr.add_const('CLFS_FLAG_IGNORE_SHARE_ACCESS',0x00000040)
		win_const_mgr.add_const('IDM_FOLLOWLINKN',0x00000859)
		win_const_mgr.add_const('SYNC_HANDLERTYPE_DEVICES',0x00000002)
		win_const_mgr.add_const('ERROR_HIBERNATED',0x000002D6)
		win_const_mgr.add_const('CFE_LINK',0x00000020)
		win_const_mgr.add_const('ERROR_FCB_UNAVAILABLE',0x00000023)
		win_const_mgr.add_const('MD_LOG_TYPE_DISABLED',0x00000000)
		win_const_mgr.add_const('ERROR_NO_MORE_MATCHES',0x00000272)
		win_const_mgr.add_const('GPO_OPEN_READ_ONLY',0x00000002)
		win_const_mgr.add_const('MCI_ANIM_PLAY_SLOW',0x00080000)
		win_const_mgr.add_const('PROCESS_TRACE_MODE_REAL_TIME',0x00000100)
		win_const_mgr.add_const('MAXINCOMINGALLOCSIZEDEFAULT',0x00000040)
		win_const_mgr.add_const('SQL_SNVF_OCTET_LENGTH',0x00000010)
		win_const_mgr.add_const('AVIF_TRUSTCKTYPE',0x00000800)
		win_const_mgr.add_const('DFM_GETDEFSTATICID',0x0000000E)
		win_const_mgr.add_const('D3DTSS_TCI_CAMERASPACENORMAL',0x00010000)
		win_const_mgr.add_const('OFFLOAD_MAX_SAS',0x00000003)
		win_const_mgr.add_const('D3DUSAGE_NPATCHES',0x00000100)
		win_const_mgr.add_const('MD_EXTLOG_HTTP_STATUS',0x00000400)
		win_const_mgr.add_const('FS_LATIN2',0x00000002)
		win_const_mgr.add_const('FS_LATIN1',0x00000001)
		win_const_mgr.add_const('MSG_WAITALL',0x00000008)
		win_const_mgr.add_const('CTRY_NORWAY',0x0000002F)
		win_const_mgr.add_const('DDSCL_FPUPRESERVE',0x00001000)
		win_const_mgr.add_const('SMINIT_DEFAULT',0x00000000)
		win_const_mgr.add_const('INTERNET_OPTION_AUTH_FLAGS',0x00000055)
		win_const_mgr.add_const('LINECALLTREATMENT_RINGBACK',0x00000002)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_19',0x00000013)
		win_const_mgr.add_const('FILE_COMPRESSION_WINLZA',0x00000001)
		win_const_mgr.add_const('VIDEO_CONFIGURE_QUERYSIZE',0x00000001)
		win_const_mgr.add_const('WINHTTP_AUTH_SCHEME_NEGOTIATE',0x00000010)
		win_const_mgr.add_const('IDM_MOVE',0x00000058)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_16',0x00000010)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_17',0x00000011)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_10',0x0000000A)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_11',0x0000000B)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_12',0x0000000C)
		win_const_mgr.add_const('METHOD_BGP4_AS_PATH',0x00000001)
		win_const_mgr.add_const('SC_SCREENSAVE',0x0000F140)
		win_const_mgr.add_const('MFASYNC_CALLBACK_QUEUE_TIMER',0x00000004)
		win_const_mgr.add_const('CF_CONVERTONLY',0x00000100)
		win_const_mgr.add_const('PID_COMMENTS',0x00000006)
		win_const_mgr.add_const('CF_NOVERTFONTS',0x01000000)
		win_const_mgr.add_const('IME_THOTKEY_IME_NONIME_TOGGLE',0x00000070)
		win_const_mgr.add_const('LANG_CZECH',0x00000005)
		win_const_mgr.add_const('SERVICE_STOP_REASON_FLAG_PLANNED',0x40000000)
		win_const_mgr.add_const('DNS_TYPE_AAAA',0x00000001)
		win_const_mgr.add_const('TF_SENTENCEMODE_CONVERSATION',0x00000010)
		win_const_mgr.add_const('IPPORT_TFTP',0x00000045)
		win_const_mgr.add_const('CR_NO_SUCH_DEVNODE',0x0000000D)
		win_const_mgr.add_const('AVISTREAMINFO_DISABLED',0x00000001)
		win_const_mgr.add_const('LINEADDRFEATURE_PICKUPHELD',0x00000100)
		win_const_mgr.add_const('LANG_CATALAN',0x00000003)
		win_const_mgr.add_const('SERVICE_NOTIFY_STOP_PENDING',0x00000004)
		win_const_mgr.add_const('PORT_LPD',0x00000203)
		win_const_mgr.add_const('PSINJECT_BOUNDINGBOX',0x00000009)
		win_const_mgr.add_const('PP_CRYPT_COUNT_KEY_USE',0x00000029)
		win_const_mgr.add_const('DLLVER_BUILD_MASK',0xFFFF0000)
		win_const_mgr.add_const('LINEADDRESSTYPE_SDP',0x00000002)
		win_const_mgr.add_const('ERROR_TOO_MANY_MUXWAITERS',0x00000098)
		win_const_mgr.add_const('GET_FEATURE_FROM_THREAD_INTERNET',0x00000040)
		win_const_mgr.add_const('ETO_PDY',0x00002000)
		win_const_mgr.add_const('JOHAB_CHARSET',0x00000082)
		win_const_mgr.add_const('OFN_NONETWORKBUTTON',0x00020000)
		win_const_mgr.add_const('EVENT_SYSTEM_SWITCHEND',0x00000015)
		win_const_mgr.add_const('DBPROPVAL_BD_INTRANSACTION',0x00000001)
		win_const_mgr.add_const('CSIDL_FLAG_MASK',0x0000FF00)
		win_const_mgr.add_const('ODS_GRAYED',0x00000002)
		win_const_mgr.add_const('PPCF_FORCEQUALIFY',0x00000040)
		win_const_mgr.add_const('SAFER_SCOPEID_USER',0x00000002)
		win_const_mgr.add_const('ELF_SHOWHELP',0x00000001)
		win_const_mgr.add_const('PE_TYPE_APPID',0x00000003)
		win_const_mgr.add_const('CP_SYMBOL',0x0000002A)
		win_const_mgr.add_const('LVS_EX_INFOTIP',0x00000400)
		win_const_mgr.add_const('EVCF_SETTINGSMODE',0x00000020)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONNECT',0x0000000C)
		win_const_mgr.add_const('PS_ALTERNATE',0x00000008)
		win_const_mgr.add_const('CSURL_ADDTOFRESHESTCRL',0x00000004)
		win_const_mgr.add_const('META_ANIMATEPALETTE',0x00000436)
		win_const_mgr.add_const('GESTURE_EXCLAMATION',0x00000000)
		win_const_mgr.add_const('STATE_SYSTEM_HOTTRACKED',0x00000080)
		win_const_mgr.add_const('SCRIPTPROP_DEBUGGER',0x00001100)
		win_const_mgr.add_const('ERROR_DS_CANT_REPLACE_HIDDEN_REC',0x000020E8)
		win_const_mgr.add_const('LINESPECIALINFO_UNAVAIL',0x00000010)
		win_const_mgr.add_const('TAPE_DRIVE_FIXED',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_PROCESS_TERMINATION_REQUESTED',0x00003707)
		win_const_mgr.add_const('SM_RESERVED4',0x0000001B)
		win_const_mgr.add_const('SECBUFFER_KERNEL_MAP',0x20000000)
		win_const_mgr.add_const('THREAD_SUSPEND_RESUME',0x00000002)
		win_const_mgr.add_const('CFE_ITALIC',0x00000002)
		win_const_mgr.add_const('SM_RESERVED3',0x0000001A)
		win_const_mgr.add_const('IMAGE_REL_SH3_SECREL',0x0000000F)
		win_const_mgr.add_const('BG_E_VOLUME_CHANGED',0x8020000E)
		win_const_mgr.add_const('IPPORT_EPMAP',0x00000087)
		win_const_mgr.add_const('SQL_BP_DROP',0x00000004)
		win_const_mgr.add_const('REPL_EXTENT_FILE',0x00000001)
		win_const_mgr.add_const('DN_ROOT_ENUMERATED',0x00000001)
		win_const_mgr.add_const('MD_CERT_NO_USAGE_CHECK',0x00010000)
		win_const_mgr.add_const('ERROR_DS_NTDSCRIPT_SYNTAX_ERROR',0x0000218F)
		win_const_mgr.add_const('BSIS_PRESERVEORDERDURINGLAYOUT',0x00000200)
		win_const_mgr.add_const('IRLMP_SHARP_MODE',0x00000020)
		win_const_mgr.add_const('SQL_SP_ISNOTNULL',0x00000002)
		win_const_mgr.add_const('LINEANSWERMODE_HOLD',0x00000004)
		win_const_mgr.add_const('CONTROLCALLBACK_PREROLL',0x00000001)
		win_const_mgr.add_const('SSTF_NONE',0x00000000)
		win_const_mgr.add_const('SO_KEEPALIVE',0x00000008)
		win_const_mgr.add_const('INTERNET_ERROR_BASE',0x00002EE0)
		win_const_mgr.add_const('SHCNE_UPDATEDIR',0x00001000)
		win_const_mgr.add_const('LVNI_DROPHILITED',0x00000008)
		win_const_mgr.add_const('CBA_SYMBOLS_UNLOADED',0x00000004)
		win_const_mgr.add_const('PGF_SCROLLRIGHT',0x00000008)
		win_const_mgr.add_const('MCI_WAVE_STATUS_SAMPLESPERSEC',0x00004003)
		win_const_mgr.add_const('USN_REASON_NAMED_DATA_OVERWRITE',0x00000010)
		win_const_mgr.add_const('IDC_IO_DISPLAYASICON',0x00000838)
		win_const_mgr.add_const('INTERNET_OPTION_DISABLE_PASSPORT_AUTH',0x00000057)
		win_const_mgr.add_const('D3DDEVCAPS_QUINTICRTPATCHES',0x00200000)
		win_const_mgr.add_const('SUBLANG_ORIYA_INDIA',0x00000001)
		win_const_mgr.add_const('GL_LEVEL_FATAL',0x00000001)
		win_const_mgr.add_const('CPF_COMPLETE',0x00000004)
		win_const_mgr.add_const('IFF_LOOPBACK',0x00000004)
		win_const_mgr.add_const('IDM_SCROLL_TOP',0x0000094D)
		win_const_mgr.add_const('BIF_DONTGOBELOWDOMAIN',0x00000002)
		win_const_mgr.add_const('HDS_FILTERBAR',0x00000100)
		win_const_mgr.add_const('ERROR_CTX_CLIENT_LICENSE_NOT_SET',0x00001B8D)
		win_const_mgr.add_const('WMDM_FILE_ATTR_CANREAD',0x00040000)
		win_const_mgr.add_const('GESTURE_ARROW_LEFT',0x00000000)
		win_const_mgr.add_const('SRCINFO_FLAGS',0x00000004)
		win_const_mgr.add_const('IF_TYPE_MSDSL',0x0000008F)
		win_const_mgr.add_const('LVGMF_BORDERCOLOR',0x00000002)
		win_const_mgr.add_const('NDW_INSTALLFLAG_SKIPCLASSLIST',0x00004000)
		win_const_mgr.add_const('MMIO_FINDCHUNK',0x00000010)
		win_const_mgr.add_const('D3DSP_DCL_USAGEINDEX_MASK',0x00000000)
		win_const_mgr.add_const('DFCS_BUTTON3STATE',0x00000008)
		win_const_mgr.add_const('SRRF_RM_SAFE',0x00020000)
		win_const_mgr.add_const('PFD_DRAW_TO_WINDOW',0x00000004)
		win_const_mgr.add_const('ERROR_CTX_SHADOW_DISABLED',0x00001B8B)
		win_const_mgr.add_const('CERT_ARCHIVED_KEY_HASH_PROP_ID',0x00000041)
		win_const_mgr.add_const('INTERNET_OPTION_CODEPAGE_PATH',0x00000064)
		win_const_mgr.add_const('LANG_BELARUSIAN',0x00000023)
		win_const_mgr.add_const('LINEAGENTSTATEEX_BUSYINCOMING',0x00000008)
		win_const_mgr.add_const('MAPI_PW_ADD_SERVICE_ONLY',0x00000004)
		win_const_mgr.add_const('NDIS_OFFLOAD_SUPPORTED',0x00000001)
		win_const_mgr.add_const('RECOCONF_MEDIUMCONFIDENCE',0x00000000)
		win_const_mgr.add_const('RP_DELIVERED',0x00000110)
		win_const_mgr.add_const('DIRID_PROGRAM_FILES',0x00004026)
		win_const_mgr.add_const('ST_DEFAULT',0x00000000)
		win_const_mgr.add_const('LDAP_OPT_REF_DEREF_CONN_PER_MSG',0x00000094)
		win_const_mgr.add_const('FCT_MERGE',0x00000001)
		win_const_mgr.add_const('LINEDEVSTATE_ROAMMODE',0x00004000)
		win_const_mgr.add_const('SSA_GCP',0x00000200)
		win_const_mgr.add_const('CLUSAPI_NO_ACCESS',0x00000004)
		win_const_mgr.add_const('SCRIPTTEXT_DELAYEXECUTION',0x00000001)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_TOTAL_BYTES',0x00000018)
		win_const_mgr.add_const('SQL_ROLLBACK',0x00000001)
		win_const_mgr.add_const('CF_TEXT',0x00000001)
		win_const_mgr.add_const('MDMSPKRFLAG_ON',0x00000004)
		win_const_mgr.add_const('SNMP_BERAPI_INVALID_LENGTH',0x0000000A)
		win_const_mgr.add_const('ILMCM_CHECKLAYOUTANDTIPENABLED',0x00000001)
		win_const_mgr.add_const('PSH_USECALLBACK',0x00000100)
		win_const_mgr.add_const('BTH_ERROR_UNSUPPORTED_FEATURE_OR_PARAMETER',0x00000011)
		win_const_mgr.add_const('LINEDIALTONEMODE_UNAVAIL',0x00000020)
		win_const_mgr.add_const('CB_SETTOPINDEX',0x00000015)
		win_const_mgr.add_const('TASK_THURSDAY',0x00000010)
		win_const_mgr.add_const('SERVICETYPE_NETWORK_UNAVAILABLE',0x00000004)
		win_const_mgr.add_const('FILE_ATTRIBUTE_HIDDEN',0x00000002)
		win_const_mgr.add_const('SQL_ISV_COLLATIONS',0x00000008)
		win_const_mgr.add_const('WS_EX_RIGHTSCROLLBAR',0x00000000)
		win_const_mgr.add_const('SQL_DDL_INDEX',0x000000AA)
		win_const_mgr.add_const('ERROR_DS_NO_CHAINED_EVAL',0x00002088)
		win_const_mgr.add_const('OI_DEFAULT',0x00000000)
		win_const_mgr.add_const('PSINJECT_DOCSUPPLIEDRES',0x00000006)
		win_const_mgr.add_const('WM_DWMCOLORIZATIONCOLORCHANGED',0x00000320)
		win_const_mgr.add_const('ERROR_UNWIND_CONSOLIDATE',0x000002AC)
		win_const_mgr.add_const('OID_FDDI_IF_IN_UCAST_PKTS',0x03030282)
		win_const_mgr.add_const('INET6_ADDRSTRLEN',0x00000041)
		win_const_mgr.add_const('_SETUPAPI_VER',0x00000410)
		win_const_mgr.add_const('DICS_START',0x00000004)
		win_const_mgr.add_const('DNS_RTYPE_ANY',0x00000000)
		win_const_mgr.add_const('DS_DIRECTORY_SERVICE_6_REQUIRED',0x00080000)
		win_const_mgr.add_const('MDM_X75_DATA_64K',0x00000001)
		win_const_mgr.add_const('LANG_BOSNIAN',0x00000001)
		win_const_mgr.add_const('D3DCAPS2_FULLSCREENGAMMA',0x00020000)
		win_const_mgr.add_const('EVENT_SRCSPEW_END',0x000000C7)
		win_const_mgr.add_const('LVIS_SELECTED',0x00000002)
		win_const_mgr.add_const('SQL_FD_FETCH_FIRST',0x00000002)
		win_const_mgr.add_const('SCS_CAP_SETRECONVERTSTRING',0x00000004)
		win_const_mgr.add_const('CERT_TRUST_PUB_ALLOW_ENTERPRISE_ADMIN_TRUST',0x00000002)
		win_const_mgr.add_const('CSCONTROL_SHUTDOWN',0x00000001)
		win_const_mgr.add_const('ERROR_INSTALL_SOURCE_ABSENT',0x0000064C)
		win_const_mgr.add_const('NTMS_MAXATTR_NAMELEN',0x00000020)
		win_const_mgr.add_const('OBM_BTNCORNERS',0x00007FF6)
		win_const_mgr.add_const('HHT_ONDROPDOWN',0x00002000)
		win_const_mgr.add_const('SECPKG_STATE_DOMAIN_CONTROLLER',0x00000004)
		win_const_mgr.add_const('BEGIN_NESTED_SYSTEM_CHANGE_NORP',0x00000068)
		win_const_mgr.add_const('BUTTON_IMAGELIST_ALIGN_CENTER',0x00000004)
		win_const_mgr.add_const('MCI_FORMAT_HMS',0x00000001)
		win_const_mgr.add_const('LOAD_IGNORE_CODE_AUTHZ_LEVEL',0x00000010)
		win_const_mgr.add_const('EMR_MOVETOEX',0x0000001B)
		win_const_mgr.add_const('PCS_REMOVEDCHAR',0x00000002)
		win_const_mgr.add_const('FWPM_ACTRL_SUBSCRIBE',0x00000200)
		win_const_mgr.add_const('MCI_ESCAPE',0x00000805)
		win_const_mgr.add_const('IDM_PRINTPREVIEW',0x000007D3)
		win_const_mgr.add_const('DEBUG_OUTPUT_SYMBOLS_NO_NAMES',0x00000001)
		win_const_mgr.add_const('KRAF_SAVEBADREQUESTKEY',0x00000002)
		win_const_mgr.add_const('OID_FDDI_MAC_T_PRI2',0x03030236)
		win_const_mgr.add_const('OID_FDDI_MAC_T_PRI3',0x03030237)
		win_const_mgr.add_const('OID_FDDI_MAC_T_PRI0',0x03030234)
		win_const_mgr.add_const('OID_FDDI_MAC_T_PRI1',0x03030235)
		win_const_mgr.add_const('OID_FDDI_MAC_T_PRI6',0x0303023A)
		win_const_mgr.add_const('OID_FDDI_MAC_T_PRI4',0x03030238)
		win_const_mgr.add_const('OID_FDDI_MAC_T_PRI5',0x03030239)
		win_const_mgr.add_const('NTMS_OMIDLABELID_LENGTH',0x000000FF)
		win_const_mgr.add_const('HTTB_RESIZINGBORDER_BOTTOM',0x00000080)
		win_const_mgr.add_const('CBR_2400',0x00000960)
		win_const_mgr.add_const('CRSWPP_INVALID_POSTINFO_FILE',0xC0042201)
		win_const_mgr.add_const('WKSTA_OTH_DOMAINS_PARMNUM',0x00000065)
		win_const_mgr.add_const('MFE_NO_ERROR',0x00000000)
		win_const_mgr.add_const('ULW_OPAQUE',0x00000004)
		win_const_mgr.add_const('MIIM_SUBMENU',0x00000004)
		win_const_mgr.add_const('PIDMSI_PRODUCTION',0x0000000A)
		win_const_mgr.add_const('MD_USER_ISOLATION_BASIC',0x00000001)
		win_const_mgr.add_const('SECBUFFER_ATTRMASK',0xF0000000)
		win_const_mgr.add_const('WKSTA_ERRLOGSZ_PARMNUM',0x0000001B)
		win_const_mgr.add_const('CC_PREVENTFULLOPEN',0x00000004)
		win_const_mgr.add_const('MCI_ANIM_STATUS_FORWARD',0x00004002)
		win_const_mgr.add_const('SO_ACCEPTCONN',0x00000002)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_MOVEBY',0x00000007)
		win_const_mgr.add_const('PHOTO_CONTRAST_NORMAL',0x00000000)
		win_const_mgr.add_const('RIS_INTERFACE_MEDIA_ABSENT',0x00000004)
		win_const_mgr.add_const('CFE_SUPERSCRIPT',0x00020000)
		win_const_mgr.add_const('REG_PROCESS_APPKEY',0x00000001)
		win_const_mgr.add_const('CRYPT_STRING_NOCRLF',0x40000000)
		win_const_mgr.add_const('LMEM_DISCARDABLE',0x00000F00)
		win_const_mgr.add_const('ERROR_SERVER_HAS_OPEN_HANDLES',0x00000713)
		win_const_mgr.add_const('SE_DACL_PRESENT',0x00000004)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_CAN_TEST',0x00004009)
		win_const_mgr.add_const('ESB_DISABLE_RIGHT',0x00000002)
		win_const_mgr.add_const('PHONEERR_NODEVICE',0x90000018)
		win_const_mgr.add_const('CTFMODEBIAS_NAME',0x00000002)
		win_const_mgr.add_const('OLEUI_ERR_HRESOURCEINVALID',0x0000006D)
		win_const_mgr.add_const('MC_SUPPORTED_COLOR_TEMPERATURE_10000K',0x00000040)
		win_const_mgr.add_const('WINEVENT_KEYWORD_RESERVED_57',0x200000000000000)
		win_const_mgr.add_const('ERROR_WRONG_PASSWORD',0x0000052B)
		win_const_mgr.add_const('CAUSE_USER_BUSY',0x00000011)
		win_const_mgr.add_const('CHANNEL_EVENT_TERMINATED',0x00000004)
		win_const_mgr.add_const('IGP_SETCOMPSTR',0x00000014)
		win_const_mgr.add_const('ERROR_FAIL_REBOOT_REQUIRED',0x00000BC9)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_DAYLIGHT',0x00000001)
		win_const_mgr.add_const('FMFOCUS_TREE',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_DISCONNECTED_TIMEOUT',0x00000031)
		win_const_mgr.add_const('IMAGE_REL_MIPS_SECTION',0x0000000A)
		win_const_mgr.add_const('DSDSOF_HASUSERANDSERVERINFO',0x00000001)
		win_const_mgr.add_const('TCS_EX_FLATSEPARATORS',0x00000001)
		win_const_mgr.add_const('CRYPT_DEFAULT_CONTEXT_AUTO_RELEASE_FLAG',0x00000001)
		win_const_mgr.add_const('GL_STOP_LISTENING',0x00000002)
		win_const_mgr.add_const('WINEVENT_KEYWORD_RESERVED_56',0x100000000000000)
		win_const_mgr.add_const('OID_GEN_RCV_OK',0x00020102)
		win_const_mgr.add_const('ASPECTY',0x0000002A)
		win_const_mgr.add_const('ASPECTX',0x00000028)
		win_const_mgr.add_const('ICQUALITY_HIGH',0x00002710)
		win_const_mgr.add_const('THREAD_MODE_BACKGROUND_BEGIN',0x00010000)
		win_const_mgr.add_const('SQL_NC_HIGH',0x00000000)
		win_const_mgr.add_const('CBA_DEFERRED_SYMBOL_LOAD_COMPLETE',0x00000002)
		win_const_mgr.add_const('DBIM_MODEFLAGS',0x00000020)
		win_const_mgr.add_const('ERROR_PATCH_PACKAGE_OPEN_FAILED',0x00000663)
		win_const_mgr.add_const('CRYPT_VERIFY_CERT_SIGN_ISSUER_PUBKEY',0x00000001)
		win_const_mgr.add_const('ERROR_HOOK_NOT_INSTALLED',0x00000597)
		win_const_mgr.add_const('PSD_ENABLEPAGESETUPTEMPLATEHANDLE',0x00020000)
		win_const_mgr.add_const('IDM_EMPTYGLYPHTABLE',0x00000920)
		win_const_mgr.add_const('ERROR_INCORRECT_SIZE',0x000005B6)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_START_TIME',0x00000010)
		win_const_mgr.add_const('IME_CMODE_FULLSHAPE',0x00000008)
		win_const_mgr.add_const('TAPE_DRIVE_TAPE_REMAINING',0x00000200)
		win_const_mgr.add_const('SQL_DIAG_CREATE_DOMAIN',0x00000017)
		win_const_mgr.add_const('STATE_SYSTEM_READONLY',0x00000040)
		win_const_mgr.add_const('IMAGE_SEPARATE_DEBUG_SIGNATURE',0x00004449)
		win_const_mgr.add_const('FACILITY_NAP',0x00000027)
		win_const_mgr.add_const('SP_PARITY',0x00000001)
		win_const_mgr.add_const('IDC_CV_CHANGEICON',0x00000099)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_WINDOWS_BOOT_APPLICATION',0x00000010)
		win_const_mgr.add_const('LINECALLFEATURE_SECURECALL',0x00080000)
		win_const_mgr.add_const('SQL_FN_TD_QUARTER',0x00000040)
		win_const_mgr.add_const('ERROR_DEBUG_ATTACH_FAILED',0x0000024E)
		win_const_mgr.add_const('KSMEDIUM_TYPE_ANYINSTANCE',0x00000000)
		win_const_mgr.add_const('PS_64M',0x00000001)
		win_const_mgr.add_const('IDM_TABLEINSERT',0x00000898)
		win_const_mgr.add_const('ICMODE_INTERNALF_FUNCTION32',0x00008000)
		win_const_mgr.add_const('IMAGE_SCN_MEM_16BIT',0x00020000)
		win_const_mgr.add_const('CRYPT_RC2_40BIT_VERSION',0x000000A0)
		win_const_mgr.add_const('PTE_CACHE_SHIFT',0x00000002)
		win_const_mgr.add_const('VER_EQUAL',0x00000001)
		win_const_mgr.add_const('ISOPROTO_CLTP',0x0000001E)
		win_const_mgr.add_const('CHANNEL_RC_BAD_CHANNEL',0x00000006)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_SECURITY_DESCRIPTOR',0x0000000C)
		win_const_mgr.add_const('CRYPT_IMPORT_KEY',0x00000080)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_GRP_FLOW_RATE',0x00000016)
		win_const_mgr.add_const('WAVE_FORMAT_4S08',0x00000200)
		win_const_mgr.add_const('DNS_RTYPE_IXFR',0x00000000)
		win_const_mgr.add_const('STRM_PAUSED',0x00000008)
		win_const_mgr.add_const('TMT_FRAMESPERSECOND',0x0000097A)
		win_const_mgr.add_const('DC_ICON',0x00000004)
		win_const_mgr.add_const('RESOURCEUSAGE_NOLOCALDEVICE',0x00000004)
		win_const_mgr.add_const('SUBLANG_SANSKRIT_INDIA',0x00000001)
		win_const_mgr.add_const('SCE_LOG_LEVEL_ALWAYS',0x00000000)
		win_const_mgr.add_const('PROCESSOR_PPC_601',0x00000259)
		win_const_mgr.add_const('VIF_CANNOTRENAME',0x00002000)
		win_const_mgr.add_const('CACHE_CONFIG_SYNC_MODE_FC',0x00000080)
		win_const_mgr.add_const('MCI_DGV_FF_AVI',0x00004001)
		win_const_mgr.add_const('CTRY_TATARSTAN',0x00000007)
		win_const_mgr.add_const('ERROR_PROCESS_IN_JOB',0x000002F8)
		win_const_mgr.add_const('SERVICE_REDIR_PRINT_PAUSED',0x00000200)
		win_const_mgr.add_const('MEM_ROTATE',0x00800000)
		win_const_mgr.add_const('ERROR_FILE_CHECKED_OUT',0x000000DC)
		win_const_mgr.add_const('USN_REASON_OBJECT_ID_CHANGE',0x00080000)
		win_const_mgr.add_const('SQL_CODE_HOUR_TO_MINUTE',0x0000000B)
		win_const_mgr.add_const('LINK_STORE_TO_ENGINE_INSTANCE',0x00000001)
		win_const_mgr.add_const('ERROR_DEVICE_IN_USE',0x00000964)
		win_const_mgr.add_const('LVHT_ONITEMSTATEICON',0x00000008)
		win_const_mgr.add_const('PERF_DETAIL_COSTLY',0x00010000)
		win_const_mgr.add_const('LDAP_RES_EXTENDED',0x00000078)
		win_const_mgr.add_const('LCMAP_LINGUISTIC_CASING',0x01000000)
		win_const_mgr.add_const('INTERNET_ERROR_MASK_INSERT_CDROM',0x00000001)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_PORT_CHARACTERISTICS',0x0000009C)
		win_const_mgr.add_const('WAVE_FORMAT_1M08',0x00000001)
		win_const_mgr.add_const('LDAP_INVALID_CMD',0x00000000)
		win_const_mgr.add_const('MCI_WAVE_STATUS_BITSPERSAMPLE',0x00004006)
		win_const_mgr.add_const('SQL_ASYNC_ENABLE',0x00000004)
		win_const_mgr.add_const('SMTO_NOTIMEOUTIFNOTHUNG',0x00000008)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_END_REV_UNKNOWN_FLAG',0x00000100)
		win_const_mgr.add_const('DBSESSIONCOUNTDEFAULT',0x00000014)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_MM_TF',0x0000000A)
		win_const_mgr.add_const('MB_MISCMASK',0x0000C000)
		win_const_mgr.add_const('DDSD_DEPTH',0x00800000)
		win_const_mgr.add_const('ASC_REQ_FRAGMENT_SUPPLIED',0x00002000)
		win_const_mgr.add_const('IF_TYPE_G703_2MB',0x00000043)
		win_const_mgr.add_const('PP_CHANGE_PASSWORD',0x00000007)
		win_const_mgr.add_const('WT_EXECUTEINPERSISTENTTHREAD',0x00000080)
		win_const_mgr.add_const('CERT_ALT_NAME_RFC822_NAME',0x00000002)
		win_const_mgr.add_const('SUBLANG_FRENCH',0x00000001)
		win_const_mgr.add_const('PAN_PROP_EVEN_WIDTH',0x00000004)
		win_const_mgr.add_const('PIPE_TYPE_MESSAGE',0x00000004)
		win_const_mgr.add_const('GL_ID_PRIVATE_FIRST',0x00008000)
		win_const_mgr.add_const('PPP_CCP_ENCRYPTION40BIT',0x00000020)
		win_const_mgr.add_const('PXE_BA_IGNORE',0x00000003)
		win_const_mgr.add_const('HTTP_STATUS_CONTINUE',0x00000064)
		win_const_mgr.add_const('ERROR_BAD_PROVIDER',0x000004B4)
		win_const_mgr.add_const('VP_FLAGS_BRIGHTNESS',0x00000040)
		win_const_mgr.add_const('OID_WAN_PERMANENT_ADDRESS',0x04010101)
		win_const_mgr.add_const('DNS_ERROR_RCODE_BADKEY',0x00002339)
		win_const_mgr.add_const('RPC_S_NOT_ALL_OBJS_EXPORTED',0x00000783)
		win_const_mgr.add_const('CDN_LAST',0x00000000)
		win_const_mgr.add_const('PD_RETURNDC',0x00000100)
		win_const_mgr.add_const('LINEPROXYREQUEST_CREATEAGENT',0x00000009)
		win_const_mgr.add_const('ISC_RET_CONNECTION',0x00000800)
		win_const_mgr.add_const('HDF_CHECKBOX',0x00000040)
		win_const_mgr.add_const('IF_TYPE_PPP',0x00000017)
		win_const_mgr.add_const('TCP_NOSYNRETRIES',0x00000009)
		win_const_mgr.add_const('TH32CS_SNAPTHREAD',0x00000004)
		win_const_mgr.add_const('UCSCHAR_INVALID_CHARACTER',0x00000000)
		win_const_mgr.add_const('FOF_NORECURSION',0x00001000)
		win_const_mgr.add_const('ERROR_INVALID_KEYBOARD_HANDLE',0x000005B1)
		win_const_mgr.add_const('INTERNET_OPTION_ACTIVATE_WORKER_THREADS',0x0000005C)
		win_const_mgr.add_const('DXVA_STATUS_REPORTING_FUNCTION',0x00000007)
		win_const_mgr.add_const('BCP_FMT_COLLATION_ID',0x00000007)
		win_const_mgr.add_const('X3_D_WH_SIZE_X',0x00000003)
		win_const_mgr.add_const('PROPTYPE_MASK',0x00000000)
		win_const_mgr.add_const('KSEVENTF_EVENT_OBJECT',0x00000004)
		win_const_mgr.add_const('RECOFLAG_PREFIXOK',0x00000008)
		win_const_mgr.add_const('WPWIZ_ERROR_INIT_FAILED',0xC0042003)
		win_const_mgr.add_const('CSIDL_HISTORY',0x00000022)
		win_const_mgr.add_const('MAPI_NOW',0x00000010)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_TOTALSECTORS',0x00000108)
		win_const_mgr.add_const('MCI_STATUS_CURRENT_TRACK',0x00000008)
		win_const_mgr.add_const('ERROR_SXS_ASSEMBLY_NOT_FOUND',0x000036B3)
		win_const_mgr.add_const('PRIMARY_CRED_INTERACTIVE_SMARTCARD_LOGON',0x00000040)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_ALL',0x000000FF)
		win_const_mgr.add_const('SFVS_SELECT_INVERT',0x00000002)
		win_const_mgr.add_const('RBBIM_BACKGROUND',0x00000080)
		win_const_mgr.add_const('ERROR_AUDIT_FAILED',0x0000025E)
		win_const_mgr.add_const('STATUS_SEVERITY_COFAIL',0x00000003)
		win_const_mgr.add_const('SNMPAPI_ENTITY_UNKNOWN',0x00000006)
		win_const_mgr.add_const('NDR_DEFAULT_CORR_CACHE_SIZE',0x00000190)
		win_const_mgr.add_const('WINCODEC_SDK_VERSION',0x00000236)
		win_const_mgr.add_const('FACILITY_MSMQ',0x0000000E)
		win_const_mgr.add_const('FRS_ERR_CHILD_TO_PARENT_COMM',0x00001F4B)
		win_const_mgr.add_const('SF_NOTIFY_URL_MAP',0x00001000)
		win_const_mgr.add_const('DPNHREGISTERPORTS_TCP',0x00000001)
		win_const_mgr.add_const('INTERNET_FLAG_HYPERLINK',0x00000400)
		win_const_mgr.add_const('COMP_TYPE_MAX',0x00000004)
		win_const_mgr.add_const('FLG_PROFITEM_CURRENTUSER',0x00000001)
		win_const_mgr.add_const('TAPE_RETURN_ENV_INFO',0x00000001)
		win_const_mgr.add_const('DI_NODI_DEFAULTACTION',0x00200000)
		win_const_mgr.add_const('MSIM_DISPID_ON_NM_INVITERECEIVED',0x00000E13)
		win_const_mgr.add_const('DBC_HIDE',0x00000000)
		win_const_mgr.add_const('SUBLANG_UIGHUR_PRC',0x00000001)
		win_const_mgr.add_const('SBM_GETRANGE',0x000000E3)
		win_const_mgr.add_const('CM_INSTALL_STATE_FAILED_INSTALL',0x00000002)
		win_const_mgr.add_const('CERT_REGISTRY_STORE_ROAMING_FLAG',0x00040000)
		win_const_mgr.add_const('ERROR_INVALID_SEGMENT_NUMBER',0x000000B4)
		win_const_mgr.add_const('SV_AUTOSHAREWKS_PARMNUM',0x0000024F)
		win_const_mgr.add_const('SPMODE_FLUSH',0x00000010)
		win_const_mgr.add_const('ICMF_CHOOSE_PREVIEW',0x00000004)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_NO_ADDING_CHANNELS',0x00001D00)
		win_const_mgr.add_const('PERF_DETAIL_ADVANCED',0x000000C8)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_CURRENTMEDIATYPE',0x00000105)
		win_const_mgr.add_const('CERT_TRUST_PUB_ALLOW_MACHINE_ADMIN_TRUST',0x00000001)
		win_const_mgr.add_const('MK_CONTROL',0x00000008)
		win_const_mgr.add_const('D3DPBLENDCAPS_BOTHINVSRCALPHA',0x00001000)
		win_const_mgr.add_const('USN_PAGE_SIZE',0x00001000)
		win_const_mgr.add_const('NET_DFS_SETDC_FLAGS',0x00000000)
		win_const_mgr.add_const('WINHTTP_FLAG_SECURE',0x00800000)
		win_const_mgr.add_const('WHDR_DONE',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_MR_SUPPORTED',0x00000001)
		win_const_mgr.add_const('MAPIFORM_OS_WINNT_40',0x00000005)
		win_const_mgr.add_const('SP_BACKUP_SPECIAL',0x00000004)
		win_const_mgr.add_const('IF_TYPE_CES',0x00000085)
		win_const_mgr.add_const('OID_TCP_TASK_IPSEC_DELETE_SA',0xFC010203)
		win_const_mgr.add_const('MF_MEDIATYPE_EQUAL_FORMAT_TYPES',0x00000002)
		win_const_mgr.add_const('NOM_BT3',0x00000400)
		win_const_mgr.add_const('NOM_BT0',0x00000040)
		win_const_mgr.add_const('NOM_BT1',0x00000100)
		win_const_mgr.add_const('NOM_BT6',0x00002000)
		win_const_mgr.add_const('NOM_BT7',0x00004000)
		win_const_mgr.add_const('NOM_BT4',0x00000800)
		win_const_mgr.add_const('NOM_BT5',0x00001000)
		win_const_mgr.add_const('MOUSEEVENTF_LEFTUP',0x00000004)
		win_const_mgr.add_const('SAFER_POLICY_UIFLAGS_HIDDEN',0x00000004)
		win_const_mgr.add_const('WIA_DPS_SCAN_AHEAD_PAGES',0x00000C16)
		win_const_mgr.add_const('SECBUFFER_TARGET',0x0000000D)
		win_const_mgr.add_const('TCP_PROTOCOL_UUID16',0x00000004)
		win_const_mgr.add_const('WIA_INTENT_BEST_PREVIEW',0x00040000)
		win_const_mgr.add_const('PSWIZB_DISABLEDFINISH',0x00000008)
		win_const_mgr.add_const('PIDSI_AUTHOR',0x00000004)
		win_const_mgr.add_const('EC_OPEN_ALWAYS',0x00000000)
		win_const_mgr.add_const('WAVE_FORMAT_DRM',0x00000009)
		win_const_mgr.add_const('POWER_LEVEL_USER_NOTIFY_TEXT',0x00000001)
		win_const_mgr.add_const('CERT_VALIDITY_MASK_TRUST',0x00000000)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_TREE_PARENT',0x00400000)
		win_const_mgr.add_const('NUMPENS',0x00000012)
		win_const_mgr.add_const('MAX_INF_SECTION_NAME_LENGTH',0x000000FF)
		win_const_mgr.add_const('IMGANIM_MASK',0x10000000)
		win_const_mgr.add_const('ABS_ALWAYSONTOP',0x00000002)
		win_const_mgr.add_const('MD_APP_POOL_RECYCLE_MEMORY',0x00000008)
		win_const_mgr.add_const('ICM_UNREGISTERICMATCHER',0x00000006)
		win_const_mgr.add_const('NFS_BUTTON',0x00000008)
		win_const_mgr.add_const('SECPKG_ATTR_PASSWORD_EXPIRY',0x00000008)
		win_const_mgr.add_const('HHWIN_BUTTON_TOC_PREV',0x00000001)
		win_const_mgr.add_const('AGP_FLAG_SPECIAL_TARGET',0x000FFFFF)
		win_const_mgr.add_const('CFM_LCID',0x02000000)
		win_const_mgr.add_const('SNMP_ERROR_GENERR',0x00000005)
		win_const_mgr.add_const('IDTB_OPTIONS',0x000000D0)
		win_const_mgr.add_const('LBS_USETABSTOPS',0x00000080)
		win_const_mgr.add_const('AUXCAPS_LRVOLUME',0x00000002)
		win_const_mgr.add_const('SYSTEM_CACHE_ALIGNMENT_SIZE',0x00000080)
		win_const_mgr.add_const('OPTION_OK_TO_OVERLAY',0x00000034)
		win_const_mgr.add_const('CERT_TRUST_CTL_IS_NOT_TIME_VALID',0x00020000)
		win_const_mgr.add_const('D3DCAPS2_CANAUTOGENMIPMAP',0x40000000)
		win_const_mgr.add_const('EXTENSION_ORIGIN_ADMIN',0x00030000)
		win_const_mgr.add_const('EMARCH_ENC_I17_IC_VAL_POS_X',0x00000015)
		win_const_mgr.add_const('D3DPMISCCAPS_FOGVERTEXCLAMPED',0x00100000)
		win_const_mgr.add_const('IPX_GETNETINFO_NORIP',0x00004009)
		win_const_mgr.add_const('WMDM_STORAGE_IS_DEFAULT',0x08000000)
		win_const_mgr.add_const('PROCESS_HEAP_ENTRY_BUSY',0x00000004)
		win_const_mgr.add_const('DFM_INVOKECOMMANDEX',0x0000000C)
		win_const_mgr.add_const('DM_PANNINGHEIGHT',0x10000000)
		win_const_mgr.add_const('MQ_ACTION_PEEK_CURRENT',0x80000000)
		win_const_mgr.add_const('PROCESS_SET_SESSIONID',0x00000004)
		win_const_mgr.add_const('LINECALLREASON_REDIRECT',0x00000040)
		win_const_mgr.add_const('QUERY_DEEP',0x00000001)
		win_const_mgr.add_const('F_NOFILE',0x00000001)
		win_const_mgr.add_const('OLEVERB_PRIMARY',0x00000000)
		win_const_mgr.add_const('ERROR_ACCESS_DENIED',0x00000005)
		win_const_mgr.add_const('SQL_FETCH_RESUME',0x00000007)
		win_const_mgr.add_const('CMC_OTHER_INFO_PEND_CHOICE',0x00000002)
		win_const_mgr.add_const('PRIMARY_CRED_CACHED_LOGON',0x00000008)
		win_const_mgr.add_const('META_PIE',0x0000081A)
		win_const_mgr.add_const('BCPODBC',0x00000007)
		win_const_mgr.add_const('SUBLANG_SPANISH_NICARAGUA',0x00000013)
		win_const_mgr.add_const('FILTER_NORMAL_ACCOUNT',0x00000002)
		win_const_mgr.add_const('D3DSTENCILCAPS_REPLACE',0x00000004)
		win_const_mgr.add_const('WS_EX_COMPOSITED',0x02000000)
		win_const_mgr.add_const('IMPORTANCE_LOW_SET',0x00000001)
		win_const_mgr.add_const('MUI_COMPLEX_SCRIPT_FILTER',0x00000200)
		win_const_mgr.add_const('MIM_APPLYTOSUBMENUS',0x80000000)
		win_const_mgr.add_const('QS_RAWINPUT',0x00000400)
		win_const_mgr.add_const('SPCRP_DEVTYPE',0x00000019)
		win_const_mgr.add_const('SYNCHRONIZE',0x00100000)
		win_const_mgr.add_const('RDW_ALLCHILDREN',0x00000080)
		win_const_mgr.add_const('AF_CLUSTER',0x00000018)
		win_const_mgr.add_const('DCBA_FACEUPCENTER',0x00000001)
		win_const_mgr.add_const('SQL_FN_TD_MONTH',0x00000020)
		win_const_mgr.add_const('FILE_SHARE_DELETE',0x00000004)
		win_const_mgr.add_const('MQSEC_WRITE_MESSAGE',0x00000004)
		win_const_mgr.add_const('PT_ROAMING',0x00000002)
		win_const_mgr.add_const('RPC_CONTEXT_HANDLE_SERIALIZE',0x10000000)
		win_const_mgr.add_const('TVHT_ONITEMSTATEICON',0x00000040)
		win_const_mgr.add_const('CAL_SSHORTDATE',0x00000005)
		win_const_mgr.add_const('ICDRAW_PREROLL',0x20000000)
		win_const_mgr.add_const('CFM_STRIKEOUT',0x00000008)
		win_const_mgr.add_const('TOKEN_ADJUST_DEFAULT',0x00000080)
		win_const_mgr.add_const('SQL_SVE_COALESCE',0x00000004)
		win_const_mgr.add_const('MCI_DGV_PLAY_REPEAT',0x00010000)
		win_const_mgr.add_const('FILESYSTEM_STATISTICS_TYPE_NTFS',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_STATIC',0x00000003)
		win_const_mgr.add_const('TTI_INFO',0x00000001)
		win_const_mgr.add_const('SECBUFFER_READONLY_WITH_CHECKSUM',0x10000000)
		win_const_mgr.add_const('KS_VIDEOSTREAM_NABTS',0x00000020)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_SEND',0x0000002F)
		win_const_mgr.add_const('SCRIPTPROP_JITDEBUG',0x00001101)
		win_const_mgr.add_const('INTERNET_COOKIE_IS_SESSION',0x00000002)
		win_const_mgr.add_const('ERROR_MALFORMED_SUBSTITUTION_STRING',0x0000370E)
		win_const_mgr.add_const('MM_PC_JOYSTICK',0x0000000C)
		win_const_mgr.add_const('DISPID_EXECCOMMAND',0x00000002)
		win_const_mgr.add_const('PERF_INVERSE_COUNTER',0x01000000)
		win_const_mgr.add_const('SQL_API_SQLGETDIAGFIELD',0x000003F2)
		win_const_mgr.add_const('HTTP_MAJOR_VERSION',0x00000001)
		win_const_mgr.add_const('ERROR_NO_TRUST_LSA_SECRET',0x000006FA)
		win_const_mgr.add_const('PRINTER_ENUM_LOCAL',0x00000002)
		win_const_mgr.add_const('EMR_CREATECOLORSPACEW',0x0000007A)
		win_const_mgr.add_const('CLUSAPI_VERSION',0x00000600)
		win_const_mgr.add_const('PAN_PROP_MONOSPACED',0x00000009)
		win_const_mgr.add_const('MAXSTRETCHBLTMODE',0x00000004)
		win_const_mgr.add_const('D3DPBLENDCAPS_BOTHSRCALPHA',0x00000800)
		win_const_mgr.add_const('AE_NETLOGON',0x0000000E)
		win_const_mgr.add_const('EXCEPTION_NONCONTINUABLE',0x00000001)
		win_const_mgr.add_const('SHGFI_DISPLAYNAME',0x00000200)
		win_const_mgr.add_const('ISO_FORCE_DISCONNECTED',0x00000001)
		win_const_mgr.add_const('GL_ID_INPUTRADICAL',0x00000025)
		win_const_mgr.add_const('DDSCAPS2_HINTANTIALIASING',0x00000100)
		win_const_mgr.add_const('LB_INITSTORAGE',0x000001A8)
		win_const_mgr.add_const('FRS_ERR_PARENT_TO_CHILD_COMM',0x00001F4C)
		win_const_mgr.add_const('RESTORE_TYPE_ONLINE',0x00000002)
		win_const_mgr.add_const('PID_TEMPLATE',0x00000007)
		win_const_mgr.add_const('WINHTTP_QUERY_PROXY_AUTHENTICATE',0x00000029)
		win_const_mgr.add_const('FPS_UNAVAILABLE',0x20000020)
		win_const_mgr.add_const('OBM_RESTORE',0x00007FEB)
		win_const_mgr.add_const('INTERNET_COOKIE_IS_LEGACY',0x00000800)
		win_const_mgr.add_const('DM_ICMINTENT',0x01000000)
		win_const_mgr.add_const('GPT_BASIC_DATA_ATTRIBUTE_SHADOW_COPY',0x2000000000000000)
		win_const_mgr.add_const('KERB_ETYPE_RSA_MD5_CMS',0x0000000A)
		win_const_mgr.add_const('LM20_SNLEN',0x0000000F)
		win_const_mgr.add_const('EXCHIVERB_REPLYTOFOLDER',0x0000006C)
		win_const_mgr.add_const('TIMEMEDIAPLAYER_OFFSET',0x00000800)
		win_const_mgr.add_const('X3_OPCODE_INST_WORD_POS_X',0x0000001C)
		win_const_mgr.add_const('ERROR_NO_SUCH_USER',0x00000525)
		win_const_mgr.add_const('MD_ERROR_SUB401_URLAUTH_POLICY',0x00000007)
		win_const_mgr.add_const('ERROR_CHILD_WINDOW_MENU',0x0000059C)
		win_const_mgr.add_const('MCI_SEQ_OFFSET',0x000004C0)
		win_const_mgr.add_const('IDM_PEERHITTESTSAMEINEDIT',0x00000977)
		win_const_mgr.add_const('DTT_BORDERSIZE',0x00000001)
		win_const_mgr.add_const('MD_DIMTYPE_OTHER',0x00000003)
		win_const_mgr.add_const('SQL_ISV_TABLES',0x00020000)
		win_const_mgr.add_const('IMAGE_BITMAP',0x00000000)
		win_const_mgr.add_const('FR_ENABLETEMPLATEHANDLE',0x00002000)
		win_const_mgr.add_const('AVIF_ISINTERLEAVED',0x00000100)
		win_const_mgr.add_const('DIGCDP_FLAG_REMOTE_ADVANCED',0x00000004)
		win_const_mgr.add_const('LVGS_FOCUSED',0x00000010)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_NONE',0x00000000)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_DCOM_USERS',0x00000232)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_MM_EXPIRED',0x0000363D)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_ENVIRONMENT',0x00000000)
		win_const_mgr.add_const('SHTDN_REASON_MAJOR_LEGACY_API',0x00070000)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYARITHSTRETCHYN',0x00000008)
		win_const_mgr.add_const('PDERR_NODEFAULTPRN',0x00001008)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_DC_DEMOTION',0x00000022)
		win_const_mgr.add_const('PDH_LOGSVC_NOT_OPENED',0xC0000BD9)
		win_const_mgr.add_const('HHWIN_BUTTON_NOTES',0x00000001)
		win_const_mgr.add_const('MAPI_E_INVALID_SESSION',0x00000013)
		win_const_mgr.add_const('DMPAPER_P32K',0x0000005E)
		win_const_mgr.add_const('DBPARAMTYPE_RETURNVALUE',0x00000004)
		win_const_mgr.add_const('RPC_S_NO_MORE_BINDINGS',0x0000070E)
		win_const_mgr.add_const('CR_PROP_TEMPLATES',0x0000001D)
		win_const_mgr.add_const('DS_REPSYNC_NO_DISCARD',0x00000080)
		win_const_mgr.add_const('FACILITY_NS',0x0000000D)
		win_const_mgr.add_const('OS_WIN2000ORGREATER',0x00000007)
		win_const_mgr.add_const('SSRVOPT_GETPATH',0x00000040)
		win_const_mgr.add_const('DNS_RCLASS_ANY',0x00000000)
		win_const_mgr.add_const('OID_IRDA_EXTRA_RCV_BOFS',0x0A010200)
		win_const_mgr.add_const('WM_TABLET_MAXOFFSET',0x00000020)
		win_const_mgr.add_const('CERT_SUBJECT_INFO_ACCESS_PROP_ID',0x00000050)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_NOEXTERNALCALLS',0x10000000)
		win_const_mgr.add_const('BTH_MFG_ROHDE_SCHWARZ',0x00000019)
		win_const_mgr.add_const('MD_GLOBAL_BINSCHEMATIMESTAMP',0x00002707)
		win_const_mgr.add_const('SCH_CRED_MAX_STORE_NAME_SIZE',0x00000080)
		win_const_mgr.add_const('ERROR_BAD_PATHNAME',0x000000A1)
		win_const_mgr.add_const('SOCKET_INFO_CONNECTION_ENCRYPTED',0x00000002)
		win_const_mgr.add_const('TBS_NOTICKS',0x00000010)
		win_const_mgr.add_const('DNS_ERROR_INVALID_TYPE',0x0000254F)
		win_const_mgr.add_const('PORT_ENTOMB',0x00000307)
		win_const_mgr.add_const('LOCALE_SENGCURRNAME',0x00001007)
		win_const_mgr.add_const('AUDIT_QUERY_MISC_POLICY',0x00000040)
		win_const_mgr.add_const('CRED_TI_USERNAME_TARGET',0x00000008)
		win_const_mgr.add_const('DPNHADDRESSTYPE_LOCALFIREWALL',0x00000008)
		win_const_mgr.add_const('DMPAPER_DBL_JAPANESE_POSTCARD_ROTATED',0x00000052)
		win_const_mgr.add_const('ERROR_CANT_RESOLVE_FILENAME',0x00000781)
		win_const_mgr.add_const('IIS_MD_UT_END_RESERVED',0x000007D0)
		win_const_mgr.add_const('WKSTA_CHARTIME_PARMNUM',0x0000000B)
		win_const_mgr.add_const('CRLF_IGNORE_INVALID_POLICIES',0x00000010)
		win_const_mgr.add_const('LINEAGENTFEATURE_GETAGENTGROUP',0x00000020)
		win_const_mgr.add_const('DDLOCK_HASVOLUMETEXTUREBOXRECT',0x00008000)
		win_const_mgr.add_const('TLS1_ALERT_BAD_RECORD_MAC',0x00000014)
		win_const_mgr.add_const('ERROR_CTX_SHADOW_INVALID',0x00001B8A)
		win_const_mgr.add_const('INTERNET_STATUS_INTERMEDIATE_RESPONSE',0x00000078)
		win_const_mgr.add_const('DT_NOPREFIX',0x00000800)
		win_const_mgr.add_const('PRF_CHILDREN',0x00000010)
		win_const_mgr.add_const('DBPROP_CI_CATALOG_NAME',0x00000002)
		win_const_mgr.add_const('DISPLAYDIB_MODE',0x0000000F)
		win_const_mgr.add_const('TIME_NOMINUTESORSECONDS',0x00000001)
		win_const_mgr.add_const('MAX_GOPHER_SELECTOR_TEXT',0x00000100)
		win_const_mgr.add_const('SPQ_FLAG_VALID',0x0000000F)
		win_const_mgr.add_const('IMAGE_REL_I386_REL32',0x00000014)
		win_const_mgr.add_const('ANY_DEST_ADDR',0xFFFFFFFF)
		win_const_mgr.add_const('PORT_PRTSERVER',0x00000023)
		win_const_mgr.add_const('FILE_DEVICE_FILE_SYSTEM',0x00000009)
		win_const_mgr.add_const('CLFS_SCAN_BUFFERED',0x00000020)
		win_const_mgr.add_const('PHONEFEATURE_SETDISPLAY',0x00010000)
		win_const_mgr.add_const('HHWIN_PROP_NOTB_TEXT',0x00000001)
		win_const_mgr.add_const('ERROR_INVALID_QUOTA_LOWER',0x00000223)
		win_const_mgr.add_const('SERIAL_IOC_FCR_RCVR_RESET',0x00000002)
		win_const_mgr.add_const('ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND',0x00003A9B)
		win_const_mgr.add_const('MD_AUTH_CHANGE_DISABLE',0x00000002)
		win_const_mgr.add_const('JOB_STATUS_PRINTED',0x00000080)
		win_const_mgr.add_const('VER_SERVER_NT',0x80000000)
		win_const_mgr.add_const('JOB_OBJECT_QUERY',0x00000004)
		win_const_mgr.add_const('PSR_DD',0x00000027)
		win_const_mgr.add_const('SE_ERR_DDEFAIL',0x0000001D)
		win_const_mgr.add_const('BDIF_PERSONAL',0x00000010)
		win_const_mgr.add_const('MAXINCOMINGMESSAGESIZEDEFAULT',0x00000040)
		win_const_mgr.add_const('IDM_NEW_TOPLEVELWINDOW',0x00001B8A)
		win_const_mgr.add_const('KSPIN_FLAG_DO_NOT_INITIATE_PROCESSING',0x00000010)
		win_const_mgr.add_const('MKF_RIGHTBUTTONDOWN',0x02000000)
		win_const_mgr.add_const('PIDISM_WATCH',0x00000001)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_SERVICEPACK',0x00000000)
		win_const_mgr.add_const('ERROR_DS_CANT_DELETE_DSA_OBJ',0x00002094)
		win_const_mgr.add_const('SND_SYNC',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_TRY_AGAIN_LATER',0x00002552)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_WMI',0x00000012)
		win_const_mgr.add_const('WIA_PROPPAGE_DEVICE_GENERAL',0x00000004)
		win_const_mgr.add_const('PDH_INVALID_SQL_LOG_FORMAT',0xC0000BF5)
		win_const_mgr.add_const('PSINJECT_BEGINSTREAM',0x00000001)
		win_const_mgr.add_const('IFS_IFM',0x00000000)
		win_const_mgr.add_const('MCI_SEQ_STATUS_TEMPO',0x00004002)
		win_const_mgr.add_const('CF_ACCEPT',0x00000000)
		win_const_mgr.add_const('SQL_API_SQLSTATISTICS',0x00000035)
		win_const_mgr.add_const('MD_CPU_ENABLE_TERMINATED_PROCS',0x00000080)
		win_const_mgr.add_const('SMC_SHCHANGENOTIFY',0x0000002E)
		win_const_mgr.add_const('MFOUTPUTATTRIBUTE_BUS',0x00000020)
		win_const_mgr.add_const('DS_REPSYNCALL_DO_NOT_SYNC',0x00000008)
		win_const_mgr.add_const('MCI_SEQ_SET_PORT',0x00020000)
		win_const_mgr.add_const('FEI_ROUTING',0x00000010)
		win_const_mgr.add_const('CB_GETDROPPEDCONTROLRECT',0x00000152)
		win_const_mgr.add_const('OID_GEN_PORT_STATE',0x0001020E)
		win_const_mgr.add_const('DBPARAMTYPE_OUTPUT',0x00000003)
		win_const_mgr.add_const('ERROR_INVALID_PASSWORD',0x00000056)
		win_const_mgr.add_const('DEVICE_STATEMASK_ALL',0x00000000)
		win_const_mgr.add_const('CRYPT_VERIFY_CERT_SIGN_ISSUER_CHAIN',0x00000003)
		win_const_mgr.add_const('DI_SHOWCLASS',0x00000004)
		win_const_mgr.add_const('REG_HIVE_SINGLE_LOG',0x00000200)
		win_const_mgr.add_const('WMS_CONTAINER_LAST_ENTRY_IN_PLAYLIST',0x00000800)
		win_const_mgr.add_const('UDS_ARROWKEYS',0x00000020)
		win_const_mgr.add_const('LINE_REMOVE',0x00000019)
		win_const_mgr.add_const('D3DPTEXTURECAPS_ALPHAPALETTE',0x00000080)
		win_const_mgr.add_const('ERROR_INVALID_ACCEL_HANDLE',0x0000057B)
		win_const_mgr.add_const('LUP_RETURN_NAME',0x00000010)
		win_const_mgr.add_const('NUM_CUSTOM_COLORS',0x00000010)
		win_const_mgr.add_const('MDAXIS_PAGES',0x00000002)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_205',0x801900CD)
		win_const_mgr.add_const('SECPKG_FLAG_DELEGATION',0x00020000)
		win_const_mgr.add_const('LANG_LATVIAN',0x00000026)
		win_const_mgr.add_const('GM_LAST',0x00000002)
		win_const_mgr.add_const('TVHT_BELOW',0x00000200)
		win_const_mgr.add_const('SCARD_E_NO_KEY_CONTAINER',0x80100030)
		win_const_mgr.add_const('IDD_LINKPROPS',0x0000044E)
		win_const_mgr.add_const('PID_FIRST_USABLE',0x00000002)
		win_const_mgr.add_const('WNODE_FLAG_EVENT_ITEM',0x00000008)
		win_const_mgr.add_const('FILEOP_ABORT',0x00000000)
		win_const_mgr.add_const('ASC_RET_CALL_LEVEL',0x00002000)
		win_const_mgr.add_const('ISCSI_SECURITY_FLAG_TRANSPORT_MODE_PREFERRED',0x00000020)
		win_const_mgr.add_const('ISCSI_LOGIN_OPTIONS_HEADER_DIGEST',0x00000001)
		win_const_mgr.add_const('WINHTTP_ENABLE_PASSPORT_KEYRING',0x40000000)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_200',0x801900C8)
		win_const_mgr.add_const('TF_IPP_CAPS_COMLESSSUPPORT',0x00000008)
		win_const_mgr.add_const('DLCTL_SILENT',0x40000000)
		win_const_mgr.add_const('MCI_SYSINFO',0x00000810)
		win_const_mgr.add_const('PST_PC_MULTIPLE_REPOSITORIES',0x00000010)
		win_const_mgr.add_const('DTR_IO_PORT_INDEX',0x00000005)
		win_const_mgr.add_const('SKF_AUDIBLEFEEDBACK',0x00000040)
		win_const_mgr.add_const('MSV1_0_ALLOW_SERVER_TRUST_ACCOUNT',0x00000020)
		win_const_mgr.add_const('MEM_16K',0x00004000)
		win_const_mgr.add_const('ACL_REVISION3',0x00000003)
		win_const_mgr.add_const('OWNER_SECURITY_INFORMATION',0x00000001)
		win_const_mgr.add_const('MDPROPVAL_FS_GENERATED_COLUMN',0x00000002)
		win_const_mgr.add_const('OID_GEN_PHYSICAL_MEDIUM',0x00010202)
		win_const_mgr.add_const('MEM_16M',0x01000000)
		win_const_mgr.add_const('D3DCREATE_MIXED_VERTEXPROCESSING',0x00000080)
		win_const_mgr.add_const('ERROR_INVALID_PRINTER_COMMAND',0x0000070B)
		win_const_mgr.add_const('WMS_STREAM_SHARING_BANDWIDTH',0x0000000A)
		win_const_mgr.add_const('BDR_SUNKENOUTER',0x00000002)
		win_const_mgr.add_const('DISPID_COLLECTION_MAX',0x002DC6BF)
		win_const_mgr.add_const('DISKQUOTA_LOGFLAG_USER_LIMIT',0x00000002)
		win_const_mgr.add_const('FACILITY_COMMONLOG',0x0000001A)
		win_const_mgr.add_const('SVSI_CHECK',0x00000100)
		win_const_mgr.add_const('DDSCAPS2_EXTENDEDFORMATPRIMARY',0x40000000)
		win_const_mgr.add_const('MHDR_PREPARED',0x00000002)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_CURRENTMEDIATYPE',0x0000010B)
		win_const_mgr.add_const('INTERNET_OPTION_SEND_TIMEOUT',0x00000005)
		win_const_mgr.add_const('D3DFVF_XYZRHW',0x00000004)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYSHRINKX',0x00080000)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYSHRINKY',0x00200000)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_HOLD',0x00000004)
		win_const_mgr.add_const('SPDRP_REMOVAL_POLICY',0x0000001F)
		win_const_mgr.add_const('WIA_IPA_UPLOAD_ITEM_SIZE',0x0000101E)
		win_const_mgr.add_const('ERROR_CLUSTER_INVALID_STRING_TERMINATION',0x0000171C)
		win_const_mgr.add_const('LINEDIALTONEMODE_INTERNAL',0x00000004)
		win_const_mgr.add_const('ERROR_SPECIAL_USER',0x0000055D)
		win_const_mgr.add_const('CRYPT_STRING_BASE64X509CRLHEADER',0x00000009)
		win_const_mgr.add_const('ERROR_DS_DRA_REPL_PENDING',0x0000211D)
		win_const_mgr.add_const('ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN',0x0000219B)
		win_const_mgr.add_const('DISPID_DDISCMASTER2EVENTS_DEVICEREMOVED',0x00000101)
		win_const_mgr.add_const('SCARD_STATE_UNAWARE',0x00000000)
		win_const_mgr.add_const('ERROR_WMI_TRY_AGAIN',0x0000106B)
		win_const_mgr.add_const('CAL_IYEAROFFSETRANGE',0x00000003)
		win_const_mgr.add_const('COD_MINOR_MASK',0x000000FC)
		win_const_mgr.add_const('WS_CHILD',0x40000000)
		win_const_mgr.add_const('BYTE_MAX',0x00000000)
		win_const_mgr.add_const('LINECALLFEATURE_SENDUSERUSER',0x00100000)
		win_const_mgr.add_const('D3DPS20CAPS_ARBITRARYSWIZZLE',0x00000001)
		win_const_mgr.add_const('ERROR_BAD_TOKEN_TYPE',0x00000545)
		win_const_mgr.add_const('SQL_FN_TD_CURDATE',0x00000002)
		win_const_mgr.add_const('SEC_LARGE_PAGES',0x80000000)
		win_const_mgr.add_const('VER_PRODUCTVERSION_DW',0x06000000)
		win_const_mgr.add_const('OID_WAN_GET_LINK_INFO',0x04010109)
		win_const_mgr.add_const('IPV6_HDRINCL',0x00000002)
		win_const_mgr.add_const('SQL_INITIALLY_IMMEDIATE',0x00000006)
		win_const_mgr.add_const('GDICOMMENT_MULTIFORMATS',0x40000004)
		win_const_mgr.add_const('BATTERY_LIFE_UNKNOWN',0xFFFFFFFF)
		win_const_mgr.add_const('ACMDRIVERDETAILS_SUPPORTF_CONVERTER',0x00000002)
		win_const_mgr.add_const('DT_RASCAMERA',0x00000003)
		win_const_mgr.add_const('TR_ED',0x00000034)
		win_const_mgr.add_const('OBJECT_PUSH_FORMAT_VCARD_3_0',0x00000002)
		win_const_mgr.add_const('ACTION_REVOCATION_DEFAULT_CACHE',0x00020000)
		win_const_mgr.add_const('RTM_NEXTHOP_STATE_DELETED',0x00000001)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_ON_DSTSOCKET',0x00000040)
		win_const_mgr.add_const('CRYPT_NOHASHOID',0x00000001)
		win_const_mgr.add_const('RPC_S_UNSUPPORTED_NAME_SYNTAX',0x000006C9)
		win_const_mgr.add_const('DBPROPVAL_RT_SINGLETHREAD',0x00000004)
		win_const_mgr.add_const('MDPROPVAL_MOQ_MEMBER_MEMBER',0x00000080)
		win_const_mgr.add_const('DSGIF_ISMASK',0x00000000)
		win_const_mgr.add_const('PERF_AGGREGATE_MIN',0x00000003)
		win_const_mgr.add_const('ERROR_NO_TOKEN',0x000003F0)
		win_const_mgr.add_const('SP_COPY_IN_USE_TRY_RENAME',0x04000000)
		win_const_mgr.add_const('DV_DVSD_PAL_FRAMESIZE',0x00023280)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_SLIDE',0x0000001B)
		win_const_mgr.add_const('CTRY_JAPAN',0x00000051)
		win_const_mgr.add_const('WINHTTP_CONNS_PER_SERVER_UNLIMITED',0xFFFFFFFF)
		win_const_mgr.add_const('KSAUDIO_SPEAKER_DIRECTOUT',0x00000000)
		win_const_mgr.add_const('LINEAGENTSTATE_UNAVAIL',0x00000200)
		win_const_mgr.add_const('MD_CPU_NO_ACTION',0x00000000)
		win_const_mgr.add_const('MM_MSFT_ACM_WMAUDIO2',0x00000065)
		win_const_mgr.add_const('MCI_DGV_DELETE_AT',0x00010000)
		win_const_mgr.add_const('WLAN_MAX_PHY_TYPE_NUMBER',0x00000008)
		win_const_mgr.add_const('DIF_FINISHINSTALL_ACTION',0x0000002A)
		win_const_mgr.add_const('SPDIT_NODRIVER',0x00000000)
		win_const_mgr.add_const('FWPM_FILTER_FLAG_DISABLED',0x00000020)
		win_const_mgr.add_const('WINHTTP_QUERY_SERVER',0x00000025)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_OPERATINGSYSTEM',0x00030000)
		win_const_mgr.add_const('POLICY_QOS_ALLOW_LOCAL_ROOT_CERT_STORE',0x00000020)
		win_const_mgr.add_const('CAUSE_VPI_VCI_UNACCEPTABLE',0x0000000A)
		win_const_mgr.add_const('DWM_EC_DISABLECOMPOSITION',0x00000000)
		win_const_mgr.add_const('IP_MULTICAST_IF',0x00000009)
		win_const_mgr.add_const('TRUST_TYPE_UPLEVEL',0x00000002)
		win_const_mgr.add_const('SUBLANG_FRENCH_MONACO',0x00000006)
		win_const_mgr.add_const('WSAENAMETOOLONG',0x0000274F)
		win_const_mgr.add_const('FILE_PERSISTENT_ACLS',0x00000008)
		win_const_mgr.add_const('DISPLAYDIB_DONTLOCKTASK',0x00000200)
		win_const_mgr.add_const('PORT_DAYTIME',0x0000000D)
		win_const_mgr.add_const('WIA_DPC_DIMENSION',0x00000816)
		win_const_mgr.add_const('CMSG_SIGNER_CERT_ID_PARAM',0x00000026)
		win_const_mgr.add_const('DTS_SHORTDATEFORMAT',0x00000000)
		win_const_mgr.add_const('SFGAO_STREAM',0x00400000)
		win_const_mgr.add_const('DFS_VOLUME_STATE_INCONSISTENT',0x00000002)
		win_const_mgr.add_const('OID_802_3_ADD_MULTICAST_ADDRESS',0x01010208)
		win_const_mgr.add_const('DSOP_FILTER_WELL_KNOWN_PRINCIPALS',0x00000008)
		win_const_mgr.add_const('PSBTN_OK',0x00000003)
		win_const_mgr.add_const('SQL_AO_OFF',0x00000000)
		win_const_mgr.add_const('NDIS_PROTOCOL_ID_MAX',0x0000000F)
		win_const_mgr.add_const('RTCEF_SESSION_REFER_STATUS',0x00100000)
		win_const_mgr.add_const('OF_PROMPT',0x00002000)
		win_const_mgr.add_const('WINEVENT_OUTOFCONTEXT',0x00000000)
		win_const_mgr.add_const('SS_GRAYRECT',0x00000005)
		win_const_mgr.add_const('DDSCAPS_MODEX',0x00200000)
		win_const_mgr.add_const('SQL_SDF_CURRENT_TIME',0x00000002)
		win_const_mgr.add_const('SPC_INC_PE_PAGE_HASHES_FLAG',0x00000100)
		win_const_mgr.add_const('HALFTONE',0x00000004)
		win_const_mgr.add_const('LOCALE_NAME_MAX_LENGTH',0x00000055)
		win_const_mgr.add_const('MAPI_FULL_IPM_TREE',0x00000002)
		win_const_mgr.add_const('MODALS_PASSWD_HIST_LEN_PARMNUM',0x00000005)
		win_const_mgr.add_const('SCARD_E_CANT_DISPOSE',0x8010000E)
		win_const_mgr.add_const('KS_AMCONTROL_USED',0x00000001)
		win_const_mgr.add_const('TIMESTATE_OFFSET',0x00001000)
		win_const_mgr.add_const('ICEE_CREATE_FILE_STRIP_RELOCS',0x00000008)
		win_const_mgr.add_const('AF_ATM',0x00000016)
		win_const_mgr.add_const('CRYPTUI_ENABLE_EDITPROPERTIES',0x00000008)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGVIRTUALIZE',0x0000001A)
		win_const_mgr.add_const('RPC_TYPE_STRICT_CONTEXT_HANDLE',0x40000000)
		win_const_mgr.add_const('SE_GROUP_RESOURCE',0x20000000)
		win_const_mgr.add_const('TASK_FLAG_DONT_START_IF_ON_BATTERIES',0x00000040)
		win_const_mgr.add_const('WPWIZ_ERROR_FIRST',0x40042000)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_SECURITYFIX',0x00000012)
		win_const_mgr.add_const('WINEVENT_TASK_NONE',0x00000000)
		win_const_mgr.add_const('HTTP_QUERY_AUTHENTICATION_INFO',0x0000004C)
		win_const_mgr.add_const('PIDASI_STREAM_NAME',0x00000009)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_FRAGMENT_DATA',0x00001000)
		win_const_mgr.add_const('KSDSOUND_BUFFER_CTRL_3D',0x00000001)
		win_const_mgr.add_const('PATCH_OPTION_USE_LZX_BEST',0x00000003)
		win_const_mgr.add_const('TVIF_IMAGE',0x00000002)
		win_const_mgr.add_const('INTERNET_REQFLAG_PASSIVE',0x00000010)
		win_const_mgr.add_const('EXIT_PROCESS_DEBUG_EVENT',0x00000005)
		win_const_mgr.add_const('DMPAPER_PENV_10',0x00000069)
		win_const_mgr.add_const('DFCS_SCROLLCOMBOBOX',0x00000005)
		win_const_mgr.add_const('PNRP_MAX_ENDPOINT_ADDRESSES',0x0000000A)
		win_const_mgr.add_const('CF_NOVECTORFONTS',0x00000800)
		win_const_mgr.add_const('SDP_ATTRIB_IMAGING_SUPPORTED_CAPABILITIES',0x00000310)
		win_const_mgr.add_const('EV_RX80FULL',0x00000400)
		win_const_mgr.add_const('D3DDTCAPS_DEC3N',0x00000080)
		win_const_mgr.add_const('IS_TEXT_UNICODE_SIGNATURE',0x00000008)
		win_const_mgr.add_const('IDM_TRIED_NUDGE_ELEMENT',0x00000002)
		win_const_mgr.add_const('ERROR_INSTALL_REMOTE_DISALLOWED',0x00000668)
		win_const_mgr.add_const('DISPID_IFONTNAMES_COUNT',0x00000001)
		win_const_mgr.add_const('CB_RESETCONTENT',0x0000014B)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_ARCHITECTURE',0x00000007)
		win_const_mgr.add_const('D3DVTXPCAPS_DIRECTIONALLIGHTS',0x00000008)
		win_const_mgr.add_const('LOCALE_IDEFAULTANSICODEPAGE',0x00001004)
		win_const_mgr.add_const('IDC_PS_PASTELINKLIST',0x000001F8)
		win_const_mgr.add_const('D3D10_FLOAT_TO_SRGB_THRESHOLD',0x00000000)
		win_const_mgr.add_const('ARW_STARTMASK',0x00000003)
		win_const_mgr.add_const('GESTURE_DOWN',0x00000000)
		win_const_mgr.add_const('SHGFI_OVERLAYINDEX',0x00000040)
		win_const_mgr.add_const('MCI_DGV_INFO_ITEM',0x00000000)
		win_const_mgr.add_const('STATURLFLAG_ISCACHED',0x00000001)
		win_const_mgr.add_const('PDH_CSTATUS_NEW_DATA',0x00000001)
		win_const_mgr.add_const('OPATH_TOK_QSTRING',0x00000065)
		win_const_mgr.add_const('MAX_IF_TYPE',0x000000C4)
		win_const_mgr.add_const('DNS_FILTERON',0x00000004)
		win_const_mgr.add_const('OID_TAG',0x0000000A)
		win_const_mgr.add_const('VIF_DIFFCODEPG',0x00000010)
		win_const_mgr.add_const('INFINFO_REVERSE_DEFAULT_SEARCH',0x00000004)
		win_const_mgr.add_const('DEVPROP_MASK_TYPEMOD',0x0000F000)
		win_const_mgr.add_const('HH_DISPLAY_TEXT_POPUP',0x0000000E)
		win_const_mgr.add_const('CACHE_E_FIRST',0x80040170)
		win_const_mgr.add_const('OID_802_11_WEP_STATUS',0x0D01011B)
		win_const_mgr.add_const('LPV_DROP_MSG',0x0000FFFD)
		win_const_mgr.add_const('PFD_DOUBLEBUFFER_DONTCARE',0x40000000)
		win_const_mgr.add_const('DRM_EL_REVOCATIONLIST',0x00000400)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CURRENT_SETTINGS_VERSION',0x00000000)
		win_const_mgr.add_const('SCARD_CLASS_POWER_MGMT',0x00000004)
		win_const_mgr.add_const('CDO_E_SMTP_SEND_FAILED',0x80040211)
		win_const_mgr.add_const('DB_LOCAL_EXCLUSIVE',0x00000003)
		win_const_mgr.add_const('IF_TYPE_CHANNEL',0x00000046)
		win_const_mgr.add_const('SPC_EXC_PE_PAGE_HASHES_FLAG',0x00000010)
		win_const_mgr.add_const('DCICOMMAND',0x00000C03)
		win_const_mgr.add_const('ERROR_DS_CANT_FIND_NC_IN_CACHE',0x000020E5)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_YEAR_TO_MONTH',0x00000200)
		win_const_mgr.add_const('CERT_NAME_FRIENDLY_DISPLAY_TYPE',0x00000005)
		win_const_mgr.add_const('PER_USER_AUDIT_SUCCESS_EXCLUDE',0x00000002)
		win_const_mgr.add_const('D3DPMISCCAPS_PERSTAGECONSTANT',0x00008000)
		win_const_mgr.add_const('TAPE_FORMAT',0x00000005)
		win_const_mgr.add_const('LOCALE_SNAME',0x00000005)
		win_const_mgr.add_const('X3_IMM39_1_INST_WORD_X',0x00000002)
		win_const_mgr.add_const('CR_PROP_CRLSTATE',0x00000014)
		win_const_mgr.add_const('WIA_DPS_DOCUMENT_HANDLING_SELECT',0x00000C10)
		win_const_mgr.add_const('KSCREATE_ITEM_NOPARAMETERS',0x00000004)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_32BYTES',0x00600000)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_LOG_GROWTH_INCREMENT_NUM_CONTAINERS',0x00000008)
		win_const_mgr.add_const('STARTF_USEFILLATTRIBUTE',0x00000010)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_SERVICE_T4',0x00000800)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_FILELISTRESYNC',0x00000200)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_SERVICE_T1',0x00000040)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_101',0x80190065)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_WRITEPROTECTSTATUS',0x00000107)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_SERVICE_T2',0x00000080)
		win_const_mgr.add_const('HTTP_ADDREQ_FLAG_ADD',0x20000000)
		win_const_mgr.add_const('PROTOCOLFLAG_NO_PICS_CHECK',0x00000001)
		win_const_mgr.add_const('GCT_SEPARATOR',0x00000008)
		win_const_mgr.add_const('PF_CHANNELS_ENABLED',0x00000010)
		win_const_mgr.add_const('CM_PROB_REINSTALL',0x00000012)
		win_const_mgr.add_const('S_WHITE512',0x00000004)
		win_const_mgr.add_const('ERROR_RESOURCEMANAGER_READ_ONLY',0x00001A33)
		win_const_mgr.add_const('CB_GETLOCALE',0x0000015A)
		win_const_mgr.add_const('AE_NOACCESSPERM',0x00000003)
		win_const_mgr.add_const('SSPROPVAL_USEPROCFORPREP_OFF',0x00000000)
		win_const_mgr.add_const('MSV1_0_SUBAUTH_ACCOUNT_DISABLED',0x00000001)
		win_const_mgr.add_const('STI_DEVICE_CREATE_DATA',0x00000002)
		win_const_mgr.add_const('ACTCTX_FLAG_SOURCE_IS_ASSEMBLYREF',0x00000040)
		win_const_mgr.add_const('DISPID_SETPERERRSTATE',0x00000016)
		win_const_mgr.add_const('ATMPROTO_AALUSER',0x00000000)
		win_const_mgr.add_const('SQL_SP_QUANTIFIED_COMPARISON',0x00002000)
		win_const_mgr.add_const('CACHE_S_LAST',0x0004017F)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_RECORDER',0x00000100)
		win_const_mgr.add_const('WSAEOPNOTSUPP',0x0000273D)
		win_const_mgr.add_const('TAPIMAXCALLEDPARTYSIZE',0x00000028)
		win_const_mgr.add_const('PRINTER_STATUS_PAPER_OUT',0x00000010)
		win_const_mgr.add_const('D3DCAPS3_COPY_TO_SYSTEMMEM',0x00000200)
		win_const_mgr.add_const('ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE',0x00001702)
		win_const_mgr.add_const('CERT_TRUST_PUB_CHECK_PUBLISHER_REV_FLAG',0x00000100)
		win_const_mgr.add_const('LOCKP_FAIL_WRITES',0x00000000)
		win_const_mgr.add_const('DMO_E_INVALIDSTREAMINDEX',0x80040201)
		win_const_mgr.add_const('TAPE_DRIVE_SELECT',0x00000002)
		win_const_mgr.add_const('SQL_DI_DROP_INDEX',0x00000002)
		win_const_mgr.add_const('TF_COMMANDING_ENABLED',0x00000004)
		win_const_mgr.add_const('FDTF_LONGDATE',0x00000004)
		win_const_mgr.add_const('MCI_SEEK_TO_END',0x00000200)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYMIRRORUPDOWN',0x10000000)
		win_const_mgr.add_const('NTDSSITELINK_OPT_DISABLE_COMPRESSION',0x00000001)
		win_const_mgr.add_const('FLG_INI2REG_64BITKEY',0x00001000)
		win_const_mgr.add_const('DNOBJECT_PHONE',0x0000001D)
		win_const_mgr.add_const('LVGS_NORMAL',0x00000000)
		win_const_mgr.add_const('ENCAPSULATED_POSTSCRIPT',0x00001014)
		win_const_mgr.add_const('OCR_NO',0x00007F88)
		win_const_mgr.add_const('PRINTER_CHANGE_PRINT_PROCESSOR',0x07000000)
		win_const_mgr.add_const('PDH_LOG_OPT_CIRCULAR',0x02000000)
		win_const_mgr.add_const('ERROR_NOT_JOINED',0x00000088)
		win_const_mgr.add_const('EMR_STRETCHBLT',0x0000004D)
		win_const_mgr.add_const('SQL_CATALOG_NAME',0x00002713)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_R4000',0x00000166)
		win_const_mgr.add_const('FVSIF_NEWFILE',0x80000000)
		win_const_mgr.add_const('OID_FDDI_PORT_CONNECTION_CAPABILITIES',0x03030266)
		win_const_mgr.add_const('VIDEO_CONFIGURE_CURRENT',0x00000010)
		win_const_mgr.add_const('IDM_TRIED_BROWSEMODE',0x0000001D)
		win_const_mgr.add_const('GD_CURSOR',0x0000000C)
		win_const_mgr.add_const('MCI_VCR_SET_PAUSE_TIMEOUT',0x08000000)
		win_const_mgr.add_const('ERROR_HANDLE_DISK_FULL',0x00000027)
		win_const_mgr.add_const('SERVICE_NOTIFY_PAUSE_PENDING',0x00000020)
		win_const_mgr.add_const('CTL_V1',0x00000000)
		win_const_mgr.add_const('SURFACE_LOCK_WAIT',0x00000004)
		win_const_mgr.add_const('SB_LINEDOWN',0x00000001)
		win_const_mgr.add_const('CERT_SECTION_TYPE_ANY',0x000000FF)
		win_const_mgr.add_const('PHONEFEATURE_GETDISPLAY',0x00000004)
		win_const_mgr.add_const('RBS_VERTICALGRIPPER',0x00004000)
		win_const_mgr.add_const('WIA_DPS_VERTICAL_BED_REGISTRATION',0x00000C08)
		win_const_mgr.add_const('PGN_LAST',0x00000000)
		win_const_mgr.add_const('RF_INFORMATION_ONLY',0x02000000)
		win_const_mgr.add_const('FWPS_RIGHT_ACTION_WRITE',0x00000001)
		win_const_mgr.add_const('SBN_LAST',0x00000000)
		win_const_mgr.add_const('DIF_NEWDEVICEWIZARD_PREANALYZE',0x0000001C)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_ROLLBACK_SAVEPOINT',0x00800000)
		win_const_mgr.add_const('MUTANT_QUERY_STATE',0x00000001)
		win_const_mgr.add_const('RP_VOLATILE_FLAGS_MASK',0xF0000000)
		win_const_mgr.add_const('DDBD_24',0x00000000)
		win_const_mgr.add_const('SCHANNEL_SECRET_TYPE_CAPI',0x00000001)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_JOB_TIME',0x00000004)
		win_const_mgr.add_const('PHONESTATE_MONITORS',0x00000010)
		win_const_mgr.add_const('NOM_BT8',0x00008000)
		win_const_mgr.add_const('CF_HDROP',0x0000000F)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_THREAD',0x00000002)
		win_const_mgr.add_const('MUTZ_NOSAVEDFILECHECK',0x00000001)
		win_const_mgr.add_const('EM_GETRECT',0x000000B2)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_REFQUAD',0x00000002)
		win_const_mgr.add_const('CSIDL_SYSTEMX86',0x00000029)
		win_const_mgr.add_const('WINHTTP_OPTION_RECEIVE_RESPONSE_TIMEOUT',0x00000007)
		win_const_mgr.add_const('SECURITY_CREATOR_OWNER_RID',0x00000000)
		win_const_mgr.add_const('OID_ATM_HW_CURRENT_ADDRESS',0x08010104)
		win_const_mgr.add_const('DEBUG_FILTER_SECOND_CHANCE_BREAK',0x00000001)
		win_const_mgr.add_const('PDH_PLA_ERROR_NAME_TOO_LONG',0xC0000BF4)
		win_const_mgr.add_const('ERROR_NO_SUPPORTING_DRIVES',0x000010F3)
		win_const_mgr.add_const('BEGIN_SYSTEM_CHANGE',0x00000064)
		win_const_mgr.add_const('CRLF_USE_XCHG_CERT_TEMPLATE',0x00004000)
		win_const_mgr.add_const('FWPM_NET_EVENT_FLAG_LOCAL_PORT_SET',0x00000008)
		win_const_mgr.add_const('IDM_TRUSTAPPCACHE',0x00000979)
		win_const_mgr.add_const('MQMSG_SENDERID_TYPE_SID',0x00000001)
		win_const_mgr.add_const('IDD_LINKSOURCEUNAVAILABLE',0x000003FC)
		win_const_mgr.add_const('CBES_EX_NOEDITIMAGEINDENT',0x00000002)
		win_const_mgr.add_const('WPC_WEB',0x00000018)
		win_const_mgr.add_const('OID_FDDI_MAC_FRAME_CT',0x0303023B)
		win_const_mgr.add_const('KS_NABTS_GROUPID_ORIGINAL_CONTENT_BASE',0x00000800)
		win_const_mgr.add_const('PXE_CALLBACK_SERVICE_CONTROL',0x00000002)
		win_const_mgr.add_const('ICC_STANDARD_CLASSES',0x00004000)
		win_const_mgr.add_const('ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED',0x00000BCB)
		win_const_mgr.add_const('INTERNET_DIAL_SHOW_OFFLINE',0x00004000)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_DIAMOND',0x0000000F)
		win_const_mgr.add_const('V86FLAGS_RESUME',0x00010000)
		win_const_mgr.add_const('OPATH_TOK_ERROR',0x00000001)
		win_const_mgr.add_const('SV_ENABLEWFW311DIRECTIPX_PARMNUM',0x0000023E)
		win_const_mgr.add_const('MINIDUMP_THREAD_INFO_ERROR_THREAD',0x00000001)
		win_const_mgr.add_const('SQL_QU_DML_STATEMENTS',0x00000001)
		win_const_mgr.add_const('WSANO_DATA',0x00002AFC)
		win_const_mgr.add_const('DISPLAY_DEVICE_DISCONNECT',0x02000000)
		win_const_mgr.add_const('ERROR_DS_INVALID_ROLE_OWNER',0x000020AE)
		win_const_mgr.add_const('URLACTION_DOWNLOAD_SIGNED_ACTIVEX',0x00001001)
		win_const_mgr.add_const('SAFE_PARTIAL',0x00000001)
		win_const_mgr.add_const('MFSESSIONCAP_START',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLSPECIALCOLUMNS',0x00000034)
		win_const_mgr.add_const('SQL_OSCC_NOT_COMPLIANT',0x00000000)
		win_const_mgr.add_const('HTTP_QUERY_FLAG_SYSTEMTIME',0x40000000)
		win_const_mgr.add_const('LINEDISCONNECTMODE_DONOTDISTURB',0x00040000)
		win_const_mgr.add_const('WINHTTP_OPTION_CLIENT_CERT_ISSUER_LIST',0x0000005E)
		win_const_mgr.add_const('ODS_NOACCEL',0x00000100)
		win_const_mgr.add_const('GCP_SYMSWAPOFF',0x00800000)
		win_const_mgr.add_const('TXTLOG_TAB_1',0x00080000)
		win_const_mgr.add_const('SPECIAL_DOBJ_MAX',0x00000000)
		win_const_mgr.add_const('WM_CAPTURECHANGED',0x00000215)
		win_const_mgr.add_const('ERROR_DS_DRA_RPC_CANCELLED',0x00002107)
		win_const_mgr.add_const('SERVICE_NOT_PAUSABLE',0x00000000)
		win_const_mgr.add_const('KSMETHOD_TYPE_SETSUPPORT',0x00000100)
		win_const_mgr.add_const('TTI_ERROR',0x00000003)
		win_const_mgr.add_const('SF_RTFNOOBJS',0x00000003)
		win_const_mgr.add_const('EVENTLOG_WARNING_TYPE',0x00000002)
		win_const_mgr.add_const('EVENT_TRACE_FILE_MODE_PREALLOCATE',0x00000020)
		win_const_mgr.add_const('XP_GUARANTEED_DELIVERY',0x00000002)
		win_const_mgr.add_const('CI_PROVIDER_MSSEARCH',0x00000001)
		win_const_mgr.add_const('WLX_SAS_ACTION_PWD_CHANGED',0x00000006)
		win_const_mgr.add_const('IPX_GLOBAL_INFO_TYPE',0x00000009)
		win_const_mgr.add_const('ERROR_FULL_BACKUP',0x00000FA4)
		win_const_mgr.add_const('WIA_DPC_PAN_POSITION',0x0000080C)
		win_const_mgr.add_const('DO_NOT_VIRTUALIZE_STORAGES_AS_DEVICES',0x00000001)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_NOERROR',0x00000000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_SIG',0x00003633)
		win_const_mgr.add_const('MNGOF_BOTTOMGAP',0x00000002)
		win_const_mgr.add_const('WIA_DIP_DEV_ID',0x00000002)
		win_const_mgr.add_const('NSTYPE_DYNAMIC',0x00000002)
		win_const_mgr.add_const('EN_CORRECTTEXT',0x00000705)
		win_const_mgr.add_const('DIF_SELECTBESTCOMPATDRV',0x00000017)
		win_const_mgr.add_const('USN_REASON_DATA_OVERWRITE',0x00000001)
		win_const_mgr.add_const('WS_MINIMIZEBOX',0x00020000)
		win_const_mgr.add_const('EXTENSION_ORIGIN_REQUEST',0x00010000)
		win_const_mgr.add_const('IDM_CENTERHORIZONTALLY',0x0000000C)
		win_const_mgr.add_const('MC_CAPS_BRIGHTNESS',0x00000002)
		win_const_mgr.add_const('BS_TEXT',0x00000000)
		win_const_mgr.add_const('CAUSE_PU_USER',0x00000008)
		win_const_mgr.add_const('SQL_PT_PROCEDURE',0x00000001)
		win_const_mgr.add_const('INDEX_GUID_TEXTWORD',0x0000000B)
		win_const_mgr.add_const('DMPAPER_PENV_1_ROTATED',0x0000006D)
		win_const_mgr.add_const('SIO_GET_NUMBER_OF_ATM_DEVICES',0x50160001)
		win_const_mgr.add_const('JOY_BUTTON1CHG',0x00000100)
		win_const_mgr.add_const('POLLRDBAND',0x00000200)
		win_const_mgr.add_const('DN_MANUAL',0x00000010)
		win_const_mgr.add_const('CB_DELETESTRING',0x00000144)
		win_const_mgr.add_const('LOCALE_IDIGITS',0x00000011)
		win_const_mgr.add_const('CR_FLG_FORCETELETEX',0x00000001)
		win_const_mgr.add_const('DDCAPS2_TEXMANINNONLOCALVIDMEM',0x01000000)
		win_const_mgr.add_const('DBT_DEVTYP_DEVNODE',0x00000001)
		win_const_mgr.add_const('CERT_RDN_ENABLE_UTF8_UNICODE_FLAG',0x20000000)
		win_const_mgr.add_const('CDO_E_PROP_READONLY',0x80040227)
		win_const_mgr.add_const('OF_SET',0x00000001)
		win_const_mgr.add_const('IMAGE_SCN_LNK_OTHER',0x00000100)
		win_const_mgr.add_const('ATM_NSAP',0x00000002)
		win_const_mgr.add_const('MC_SUPPORTED_COLOR_TEMPERATURE_4000K',0x00000001)
		win_const_mgr.add_const('MCI_VCR_STATUS_INDEX_ON',0x0000400E)
		win_const_mgr.add_const('NRC_BADDR',0x00000007)
		win_const_mgr.add_const('CCHCCDESC',0x00000020)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_SQL_LANGUAGES',0x00000000)
		win_const_mgr.add_const('JOY_POVFORWARD',0x00000000)
		win_const_mgr.add_const('SSRVOPT_CALLBACK',0x00000001)
		win_const_mgr.add_const('WM_MOUSEWHEEL',0x0000020A)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_GRP_SUM_PEAK_RATE',0x0000002E)
		win_const_mgr.add_const('WNNC_SPEC_VERSION',0x00000001)
		win_const_mgr.add_const('DS_ROLE_INFRASTRUCTURE_OWNER',0x00000004)
		win_const_mgr.add_const('NDIS_RING_SOFT_ERROR',0x00002000)
		win_const_mgr.add_const('ICDECOMPRESS_PREROLL',0x20000000)
		win_const_mgr.add_const('SAMPLE_SEQ_CONTENT_UNKNOWN',0x00000000)
		win_const_mgr.add_const('WMIGUID_NOTIFICATION',0x00000004)
		win_const_mgr.add_const('PDH_SQL_FETCH_FAILED',0xC0000BE3)
		win_const_mgr.add_const('CRED_TYPE_DOMAIN_PASSWORD',0x00000002)
		win_const_mgr.add_const('SNMP_GENERICTRAP_ENTERSPECIFIC',0x00000006)
		win_const_mgr.add_const('LANG_ESTONIAN',0x00000025)
		win_const_mgr.add_const('FOF_NOCONFIRMATION',0x00000010)
		win_const_mgr.add_const('MDPROPVAL_MJC_SINGLECUBE',0x00000001)
		win_const_mgr.add_const('SQL_CONVERT_BINARY',0x00000036)
		win_const_mgr.add_const('KSPIN_FLAG_ENFORCE_FIFO',0x00000080)
		win_const_mgr.add_const('MSIM_DISPID_ONFINDRESULT',0x00000E0A)
		win_const_mgr.add_const('DC_PRINTRATE',0x0000001A)
		win_const_mgr.add_const('SQL_SFKD_SET_DEFAULT',0x00000004)
		win_const_mgr.add_const('IASSEMBLYCACHE_INSTALL_FLAG_REFRESH',0x00000001)
		win_const_mgr.add_const('LINETRANSLATEOPTION_CARDOVERRIDE',0x00000001)
		win_const_mgr.add_const('ENABLE_DISABLE_AUTOSAVE',0x000000D2)
		win_const_mgr.add_const('SV_TYPE_DOMAIN_MEMBER',0x00000100)
		win_const_mgr.add_const('CRYPT_OID_DISABLE_SEARCH_DS_FLAG',0x80000000)
		win_const_mgr.add_const('LINEFORWARDMODE_NOANSWINTERNAL',0x00000200)
		win_const_mgr.add_const('JOY_CAL_READRONLY',0x02000000)
		win_const_mgr.add_const('DDOVERZ_SENDTOFRONT',0x00000000)
		win_const_mgr.add_const('DFCS_CHECKED',0x00000400)
		win_const_mgr.add_const('WKSTA_LANROOT_PARMNUM',0x00000007)
		win_const_mgr.add_const('PSR_MC',0x00000023)
		win_const_mgr.add_const('ICCOMPRESSFRAMES_PADDING',0x00000001)
		win_const_mgr.add_const('ELEMENT_STATUS_SVALID',0x00800000)
		win_const_mgr.add_const('BG_E_ERROR_CONTEXT_REMOTE_APPLICATION',0x8020001E)
		win_const_mgr.add_const('DDSCL_FULLSCREEN',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_CB_NON_NULL',0x00000002)
		win_const_mgr.add_const('ERROR_INVALID_TARGET_HANDLE',0x00000072)
		win_const_mgr.add_const('METADATA_INSERT_PATH',0x00000040)
		win_const_mgr.add_const('MCI_DGV_METHOD_DIRECT',0x00000000)
		win_const_mgr.add_const('SV_OPENFILES_PARMNUM',0x0000019E)
		win_const_mgr.add_const('ILIF_LOWQUALITY',0x00000002)
		win_const_mgr.add_const('LINETRANSLATERESULT_INTOLLLIST',0x00000010)
		win_const_mgr.add_const('MD_MAX_CHANGE_ENTRIES',0x00000064)
		win_const_mgr.add_const('PUBLICKEYBLOB',0x00000006)
		win_const_mgr.add_const('ES_WANTRETURN',0x00001000)
		win_const_mgr.add_const('ERROR_LOG_MULTIPLEXED',0x000019E6)
		win_const_mgr.add_const('CMSG_SP3_COMPATIBLE_ENCRYPT_FLAG',0x80000000)
		win_const_mgr.add_const('DVB_SIT_PID',0x0000001F)
		win_const_mgr.add_const('XECI_REQWIZARD',0x00000003)
		win_const_mgr.add_const('SPI_SETCURSORSHADOW',0x0000101B)
		win_const_mgr.add_const('MCI_VCR_STATUS_TIME_MODE',0x0000401A)
		win_const_mgr.add_const('WS_EX_TRANSPARENT',0x00000020)
		win_const_mgr.add_const('OID_FDDI_MAC_FRAME_STATUS_FUNCTIONS',0x0303021F)
		win_const_mgr.add_const('LCRED_CRED_EXISTS',0x00000001)
		win_const_mgr.add_const('HANGUP_PENDING',0x00000004)
		win_const_mgr.add_const('LINECALLFEATURE_ADDTOCONF',0x00000002)
		win_const_mgr.add_const('PAN_WEIGHT_INDEX',0x00000002)
		win_const_mgr.add_const('PERF_ADD_COUNTER',0x00000001)
		win_const_mgr.add_const('WLAN_API_VERSION_2_0',0x00000002)
		win_const_mgr.add_const('CERT_CHAIN_CACHE_END_CERT',0x00000001)
		win_const_mgr.add_const('SPI_SETBEEP',0x00000002)
		win_const_mgr.add_const('IDM_PROPERTIES',0x0000001C)
		win_const_mgr.add_const('BCRYPT_ECDH_PUBLIC_P256_MAGIC',0x314B4345)
		win_const_mgr.add_const('FWPM_SUBSCRIPTION_FLAG_NOTIFY_ON_ADD',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_CANNOT_FIND_ROOT_HINTS',0x0000255C)
		win_const_mgr.add_const('SO_DEBUG',0x00000001)
		win_const_mgr.add_const('PIDDSI_HEADINGPAIR',0x0000000C)
		win_const_mgr.add_const('RPC_C_BINDING_DEFAULT_TIMEOUT',0x00000005)
		win_const_mgr.add_const('VIF_CANNOTDELETECUR',0x00004000)
		win_const_mgr.add_const('NDW_INSTALLFLAG_CI_PICKED_OEM',0x00008000)
		win_const_mgr.add_const('HTTP_STATUS_URI_TOO_LONG',0x0000019E)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_PORT_STATE',0x0000009D)
		win_const_mgr.add_const('TRANSACTION_MANAGER_CORRUPT_FOR_RECOVERY',0x00000010)
		win_const_mgr.add_const('CCF_NOTEXT',0x00000001)
		win_const_mgr.add_const('WMDM_GET_FORMAT_SUPPORT_VIDEO',0x00000002)
		win_const_mgr.add_const('OID_TCP_SAN_SUPPORT',0xFC010204)
		win_const_mgr.add_const('INTERNET_CACHE_FLAG_ADD_FILENAME_ONLY',0x00000800)
		win_const_mgr.add_const('SET_MIRROR_MODE',0x0000100E)
		win_const_mgr.add_const('PRJOB_QS_PRINTING',0x00000003)
		win_const_mgr.add_const('WS_EX_RIGHT',0x00001000)
		win_const_mgr.add_const('PDH_LOG_TYPE_SQL',0x00000007)
		win_const_mgr.add_const('CMS_DISABLEICM',0x00000001)
		win_const_mgr.add_const('WM_ERASEBKGND',0x00000014)
		win_const_mgr.add_const('SHGFI_SELECTED',0x00010000)
		win_const_mgr.add_const('ERROR_INSTRUCTION_MISALIGNMENT',0x00000225)
		win_const_mgr.add_const('GESTURE_CIRCLE_LINE_VERT',0x00000000)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_FLAG10',0x00000400)
		win_const_mgr.add_const('UNICODE_NOCHAR',0x0000FFFF)
		win_const_mgr.add_const('PHONEFEATURE_SETDATA',0x00008000)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_NOT_FOUND',0x000013B2)
		win_const_mgr.add_const('RTUTILS_MAX_PROTOCOL_NAME_LEN',0x00000028)
		win_const_mgr.add_const('ACM_FORMATTAGDETAILSF_QUERYMASK',0x0000000F)
		win_const_mgr.add_const('WM_NCDESTROY',0x00000082)
		win_const_mgr.add_const('WIA_PLANAR',0x00000001)
		win_const_mgr.add_const('ERROR_EOM_OVERFLOW',0x00000469)
		win_const_mgr.add_const('OID_PNP_SET_POWER',0xFD010101)
		win_const_mgr.add_const('LVIF_INDENT',0x00000010)
		win_const_mgr.add_const('DOT11_FLAGS_80211G_DSSS_OFDM',0x00000010)
		win_const_mgr.add_const('RPC_S_NO_ENDPOINT_FOUND',0x000006AC)
		win_const_mgr.add_const('DMPAPER_B4_JIS_ROTATED',0x0000004F)
		win_const_mgr.add_const('DDSCL_ALLOWREBOOT',0x00000002)
		win_const_mgr.add_const('LOCKP_ALLOW_MEM_MAPPING',0x00000000)
		win_const_mgr.add_const('MSIM_DISPID_ONTEXTRECEIVED',0x00000E06)
		win_const_mgr.add_const('EMR_POLYGON16',0x00000056)
		win_const_mgr.add_const('PROFILE_MEMBUFFER',0x00000002)
		win_const_mgr.add_const('PERF_ATTRIB_NO_GROUP_SEPARATOR',0x00000004)
		win_const_mgr.add_const('SQLVARCHAR',0x00000027)
		win_const_mgr.add_const('DEBUG_EVENT_UNLOAD_MODULE',0x00000080)
		win_const_mgr.add_const('PORT_AED512',0x00000095)
		win_const_mgr.add_const('CMS_SETMONITORPROFILE',0x00000010)
		win_const_mgr.add_const('CRYPT_WRITE',0x00000010)
		win_const_mgr.add_const('OCSP_BASIC_BY_NAME_RESPONDER_ID',0x00000001)
		win_const_mgr.add_const('ERROR_LOGON_SERVER_CONFLICT',0x00000238)
		win_const_mgr.add_const('CLIPBRD_S_LAST',0x000401DF)
		win_const_mgr.add_const('RQ_SEND_RESPONSE',0x20000000)
		win_const_mgr.add_const('TA_TOP',0x00000000)
		win_const_mgr.add_const('DIALOPTION_BILLING',0x00000040)
		win_const_mgr.add_const('REG_OPTION_NON_VOLATILE',0x00000000)
		win_const_mgr.add_const('CHANGER_CLEANER_SLOT',0x00000040)
		win_const_mgr.add_const('DEFAULT_SNMPTRAP_PORT_UDP',0x000000A2)
		win_const_mgr.add_const('CHANNEL_FLAG_RESUME',0x00000040)
		win_const_mgr.add_const('DSBI_HASCREDENTIALS',0x00200000)
		win_const_mgr.add_const('OPTION_SUBNET_MASK',0x00000001)
		win_const_mgr.add_const('OID_FDDI_MAC_AVAILABLE_PATHS',0x03030223)
		win_const_mgr.add_const('DDCOLOR_HUE',0x00000004)
		win_const_mgr.add_const('MPR_INTERFACE_ADMIN_DISABLED',0x00000002)
		win_const_mgr.add_const('BATTERY_CAPACITY_RELATIVE',0x40000000)
		win_const_mgr.add_const('TMT_BORDERTYPE',0x00000FA2)
		win_const_mgr.add_const('ATSC_STT_TID',0x000000CD)
		win_const_mgr.add_const('KEY_WOW64_64KEY',0x00000100)
		win_const_mgr.add_const('SQL_DIAG_DROP_CHARACTER_SET',0x00000019)
		win_const_mgr.add_const('AVICOMPRESSF_VALID',0x00000008)
		win_const_mgr.add_const('WMDM_LOG_SEV_WARN',0x00000002)
		win_const_mgr.add_const('ITR_PAL_INDEX',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_AM_TOKEN',0x00000009)
		win_const_mgr.add_const('DTRESULTPROB',0x00000002)
		win_const_mgr.add_const('IDM_JUSTIFYLEFT',0x0000003B)
		win_const_mgr.add_const('MQMSG_TRACE_NONE',0x00000000)
		win_const_mgr.add_const('ERROR_DS_COUNTING_AB_INDICES_FAILED',0x000020EC)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_REMOTE_DESKTOP_USERS',0x0000022B)
		win_const_mgr.add_const('EM_GETLINE',0x000000C4)
		win_const_mgr.add_const('WINHTTP_ACCESS_TYPE_DEFAULT_PROXY',0x00000000)
		win_const_mgr.add_const('INTERNET_ERROR_MASK_NEED_MSN_SSPI_PKG',0x00000000)
		win_const_mgr.add_const('NTM_BOLD',0x00000020)
		win_const_mgr.add_const('SSF_ICONSONLY',0x01000000)
		win_const_mgr.add_const('CRYPT_MACHINE_DEFAULT',0x00000001)
		win_const_mgr.add_const('SBSP_TRUSTFIRSTDOWNLOAD',0x01000000)
		win_const_mgr.add_const('MAX_LINE_LEN',0x00000400)
		win_const_mgr.add_const('DNOBJECT_NICE',0x00000013)
		win_const_mgr.add_const('RCRED_CRED_EXISTS',0x00000001)
		win_const_mgr.add_const('D3DVS20_MIN_NUMTEMPS',0x0000000C)
		win_const_mgr.add_const('MDTREEOP_PARENT',0x00000004)
		win_const_mgr.add_const('DDBLTFX_ROTATE90',0x00000040)
		win_const_mgr.add_const('ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT',0x00001A9B)
		win_const_mgr.add_const('RPC_C_SECURITY_QOS_VERSION',0x00000001)
		win_const_mgr.add_const('VK_DBE_SBCSCHAR',0x00000000)
		win_const_mgr.add_const('LVS_EX_TRANSPARENTSHADOWTEXT',0x00800000)
		win_const_mgr.add_const('SPDRP_LOWERFILTERS',0x00000012)
		win_const_mgr.add_const('DDFXCAPS_BLTSHRINKXN',0x00000800)
		win_const_mgr.add_const('SHPWHF_USEMRU',0x00000008)
		win_const_mgr.add_const('WIA_INTENT_MAXIMIZE_QUALITY',0x00020000)
		win_const_mgr.add_const('FILE_READ_ATTRIBUTES',0x00000080)
		win_const_mgr.add_const('SPMODE_MULTISTOP',0x00004000)
		win_const_mgr.add_const('LOCALE_ICURRENCY',0x0000001B)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_ZEROS_SUBNETBC',0x00002000)
		win_const_mgr.add_const('HTTB_RESIZINGBORDER_TOP',0x00000020)
		win_const_mgr.add_const('WT_TRUSTDBDIALOG_NO_UI_FLAG',0x00000001)
		win_const_mgr.add_const('MCI_OVLY_GETDEVCAPS_CAN_FREEZE',0x00004002)
		win_const_mgr.add_const('JS_PAUSED',0x00000008)
		win_const_mgr.add_const('DNS_INFO_NO_RECORDS',0x0000251D)
		win_const_mgr.add_const('SQL_UP_OFF',0x00000000)
		win_const_mgr.add_const('GESTURE_CHEVRON_UP',0x00000000)
		win_const_mgr.add_const('PORT_DLS',0x000000C5)
		win_const_mgr.add_const('SP_FLAG_CABINETCONTINUATION',0x00000800)
		win_const_mgr.add_const('SQL_CS_DEFAULT_CHARACTER_SET',0x00000004)
		win_const_mgr.add_const('INTERNET_OPTION_SETTINGS_CHANGED',0x00000027)
		win_const_mgr.add_const('DS_REPL_NBR_FULL_SYNC_NEXT_PACKET',0x00020000)
		win_const_mgr.add_const('QUOTA_LIMITS_USE_DEFAULT_LIMITS',0x00000010)
		win_const_mgr.add_const('DS_AVOID_SELF',0x00004000)
		win_const_mgr.add_const('PHONESTATE_SPEAKERHOOKSWITCH',0x00001000)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME11',0x00000002)
		win_const_mgr.add_const('DEVPROP_TYPE_SECURITY_DESCRIPTOR',0x00000013)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME13',0x00000002)
		win_const_mgr.add_const('SPQ_FLAG_DO_SHUFFLEMOVE',0x00000008)
		win_const_mgr.add_const('DEBUG_CSS_ALL',0x00000000)
		win_const_mgr.add_const('SO_TYPE',0x00001008)
		win_const_mgr.add_const('SUBLANG_TAJIK_TAJIKISTAN',0x00000001)
		win_const_mgr.add_const('SV_ALERTSCHEDULE_PARMNUM',0x00000223)
		win_const_mgr.add_const('ERROR_CSCSHARE_OFFLINE',0x000004EE)
		win_const_mgr.add_const('WIA_PROP_SYNC_REQUIRED',0x00000004)
		win_const_mgr.add_const('CRYPTPROTECTMEMORY_SAME_PROCESS',0x00000000)
		win_const_mgr.add_const('MEM_LARGE_PAGES',0x20000000)
		win_const_mgr.add_const('TVHT_ONITEMRIGHT',0x00000020)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_REFLONGNB',0x00000010)
		win_const_mgr.add_const('DMICM_CONTRAST',0x00000002)
		win_const_mgr.add_const('HTTP_QUERY_WARNING',0x00000043)
		win_const_mgr.add_const('BFFM_INITIALIZED',0x00000001)
		win_const_mgr.add_const('DM_ICMMETHOD',0x00800000)
		win_const_mgr.add_const('WIA_IPS_INVERT',0x00001810)
		win_const_mgr.add_const('DNPROTO_RAW',0x000000FF)
		win_const_mgr.add_const('MCI_ANIM_INFO_TEXT',0x00010000)
		win_const_mgr.add_const('SCHEDULE_BANDWIDTH',0x00000001)
		win_const_mgr.add_const('WMDM_RIGHTS_PLAY_ON_PC',0x00000001)
		win_const_mgr.add_const('CVT_HOURS',0x0000003C)
		win_const_mgr.add_const('TBSTYLE_REGISTERDROP',0x00004000)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_SCHEMATA',0x00000003)
		win_const_mgr.add_const('ERROR_REC_NON_EXISTENT',0x00000FA5)
		win_const_mgr.add_const('PFS_EC_SIZE',0x00000006)
		win_const_mgr.add_const('INDEX_GUID_GUIDE',0x00000001)
		win_const_mgr.add_const('SQLAOPMAX',0x00000052)
		win_const_mgr.add_const('SUPPORTS_UNICODE',0x00000010)
		win_const_mgr.add_const('CRYPT_OID_INFO_OID_GROUP_BIT_LEN_MASK',0x0FFF0000)
		win_const_mgr.add_const('IEIFLAG_SCREEN',0x00000020)
		win_const_mgr.add_const('OID_FDDI_SHORT_PERMANENT_ADDR',0x03010105)
		win_const_mgr.add_const('DWN_FORCEDITHER',0x00000080)
		win_const_mgr.add_const('HTLEFT',0x0000000A)
		win_const_mgr.add_const('MDPROPVAL_VISUAL_MODE_VISUAL_OFF',0x00000002)
		win_const_mgr.add_const('PF_ALPHA_BYTE_INSTRUCTIONS',0x00000005)
		win_const_mgr.add_const('NETE_NORESOURCE',0x00000008)
		win_const_mgr.add_const('CERT_TRUST_HAS_EXACT_MATCH_ISSUER',0x00000001)
		win_const_mgr.add_const('SPINST_BITREG',0x00000020)
		win_const_mgr.add_const('CREDUI_MAX_MESSAGE_LENGTH',0x00007FFF)
		win_const_mgr.add_const('SHTDN_REASON_FLAG_CLEAN_UI',0x04000000)
		win_const_mgr.add_const('CM_REGISTER_DEVICE_DRIVER_STATIC',0x00000000)
		win_const_mgr.add_const('OBM_DNARROWD',0x00007FE6)
		win_const_mgr.add_const('DS_REPL_NBR_NO_CHANGE_NOTIFICATIONS',0x20000000)
		win_const_mgr.add_const('RTCEF_CLIENT',0x00000001)
		win_const_mgr.add_const('SMC_DEMOTE',0x00000011)
		win_const_mgr.add_const('CHANNEL_RC_NOT_IN_VIRTUALCHANNELENTRY',0x0000000F)
		win_const_mgr.add_const('POLLERR',0x00000001)
		win_const_mgr.add_const('WIA_PAGE_ISO_B3',0x00000014)
		win_const_mgr.add_const('LINEERR_INUSE',0x8000000F)
		win_const_mgr.add_const('SERVICE_UNINSTALL_PENDING',0x00000002)
		win_const_mgr.add_const('SQL_INTERVAL_DAY',0x00000064)
		win_const_mgr.add_const('IMAGE_REL_I386_DIR32',0x00000006)
		win_const_mgr.add_const('RPC_C_AUTHN_GSS_SCHANNEL',0x0000000E)
		win_const_mgr.add_const('FACILITY_ITF',0x00000004)
		win_const_mgr.add_const('DSGIF_ISNORMAL',0x00000000)
		win_const_mgr.add_const('ERROR_CLUSTER_IPADDR_IN_USE',0x000013C1)
		win_const_mgr.add_const('RPC_C_AUTHN_WINNT',0x0000000A)
		win_const_mgr.add_const('MIXER_GETLINECONTROLSF_ALL',0x00000000)
		win_const_mgr.add_const('CAUSE_LOC_PRIVATE_LOCAL',0x00000001)
		win_const_mgr.add_const('PDCAP_S1_SUPPORTED',0x00020000)
		win_const_mgr.add_const('PRINTER_CHANGE_SET_PRINTER',0x00000002)
		win_const_mgr.add_const('KSNODEPIN_AEC_CAPTURE_OUT',0x00000003)
		win_const_mgr.add_const('DSROLE_PRIMARY_DS_RUNNING',0x00000001)
		win_const_mgr.add_const('SAMPLE_SEQ_PICTURE_HEADER',0x00000003)
		win_const_mgr.add_const('CRYPT_MODE_CFB',0x00000004)
		win_const_mgr.add_const('ICM_LEVEL2_5',0x00000003)
		win_const_mgr.add_const('LANG_FARSI',0x00000029)
		win_const_mgr.add_const('WM_NCXBUTTONDBLCLK',0x000000AD)
		win_const_mgr.add_const('EVENT_SYSTEM_MINIMIZESTART',0x00000016)
		win_const_mgr.add_const('SQL_FN_STR_LOCATE_2',0x00010000)
		win_const_mgr.add_const('DSSI_READ_ONLY',0x00000001)
		win_const_mgr.add_const('WMIGUID_SET',0x00000002)
		win_const_mgr.add_const('MF_COMPONENT_CERT_REVOKED',0x00008000)
		win_const_mgr.add_const('IDD_DYNAWIZ_SELECT_NEXTPAGE',0x00002712)
		win_const_mgr.add_const('BCRYPT_PUBLIC_KEY_FLAG',0x00000001)
		win_const_mgr.add_const('CACHEGROUP_ATTRIBUTE_FLAG',0x00000002)
		win_const_mgr.add_const('E_PRINTCAPABILITIES_FORMAT',0x80040004)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_DECRYPT',0x0000362B)
		win_const_mgr.add_const('EVENT_E_FIRST',0x80040200)
		win_const_mgr.add_const('__SAL_H_FULL_VER',0x08590127)
		win_const_mgr.add_const('CPS_COMPLETE',0x00000001)
		win_const_mgr.add_const('SID_MAX_SUB_AUTHORITIES',0x0000000F)
		win_const_mgr.add_const('D3DDEVCAPS_CANBLTSYSTONONLOCAL',0x00020000)
		win_const_mgr.add_const('D3DTEXOPCAPS_MULTIPLYADD',0x01000000)
		win_const_mgr.add_const('CRYPT_OID_INFO_PUBKEY_SIGN_KEY_FLAG',0x80000000)
		win_const_mgr.add_const('MQ_ACTION_RECEIVE',0x00000000)
		win_const_mgr.add_const('CRYPT_NEWKEYSET',0x00000008)
		win_const_mgr.add_const('MAX_DEINTERLACE_SURFACES',0x00000020)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_LANGUAGE',0x00000006)
		win_const_mgr.add_const('SECPKG_FLAG_RESTRICTED_TOKENS',0x00080000)
		win_const_mgr.add_const('ERROR_UNDEFINED_CHARACTER',0x00000247)
		win_const_mgr.add_const('MCI_VCR_STATUS_INDEX',0x0000400F)
		win_const_mgr.add_const('USN_REASON_INDEXABLE_CHANGE',0x00004000)
		win_const_mgr.add_const('PRIVACY_TYPE_THIRD_PARTY',0x00000001)
		win_const_mgr.add_const('DSF_TWAIN_DEVICES',0x00000010)
		win_const_mgr.add_const('STD_PROPERTIES',0x0000000A)
		win_const_mgr.add_const('DFCS_CAPTIONMIN',0x00000001)
		win_const_mgr.add_const('SIMPLEBLOB',0x00000001)
		win_const_mgr.add_const('DISPID_RESETFIRSTBOOTMODE',0x00000001)
		win_const_mgr.add_const('BTH_ERROR_CONNECTION_TIMEOUT',0x00000008)
		win_const_mgr.add_const('GL_ID_INPUTCODE',0x00000026)
		win_const_mgr.add_const('FPSR_I2',0x0000002C)
		win_const_mgr.add_const('FPSR_I3',0x00000039)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_DIRECTED_CTRL',0x00800000)
		win_const_mgr.add_const('IME_PROP_AT_CARET',0x00010000)
		win_const_mgr.add_const('DDSD_CKSRCBLT',0x00010000)
		win_const_mgr.add_const('KSDSOUND_3D_MODE_NORMAL',0x00000000)
		win_const_mgr.add_const('LVHT_BELOW',0x00000010)
		win_const_mgr.add_const('PHOTO_PROGRAMMODE_SHUTTER',0x00000004)
		win_const_mgr.add_const('FPSR_ID',0x00000005)
		win_const_mgr.add_const('TIME_NOSECONDS',0x00000002)
		win_const_mgr.add_const('TABLET_ENABLE_FLICKLEARNINGMODE',0x00040000)
		win_const_mgr.add_const('SQL_OV_ODBC3',0x00000003)
		win_const_mgr.add_const('SQL_OV_ODBC2',0x00000002)
		win_const_mgr.add_const('MIB_IF_TYPE_TOKENRING',0x00000009)
		win_const_mgr.add_const('RPC_X_INVALID_ES_ACTION',0x00000723)
		win_const_mgr.add_const('IDM_SAVEAS',0x00000047)
		win_const_mgr.add_const('TLS1_ALERT_INTERNAL_ERROR',0x00000050)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_SERVICES',0x80800000)
		win_const_mgr.add_const('MCI_DGV_FF_JFIF',0x00004006)
		win_const_mgr.add_const('CMSG_BARE_CONTENT_FLAG',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_IGNORE_OFFLINE',0x0000004D)
		win_const_mgr.add_const('CLCTL_USER_MASK',0x00000001)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_MEDIACONTROL',0x00000008)
		win_const_mgr.add_const('DCM_FLAGS_CTFMON',0x00000002)
		win_const_mgr.add_const('CRL_REASON_UNUSED_FLAG',0x00000080)
		win_const_mgr.add_const('GMEM_MODIFY',0x00000080)
		win_const_mgr.add_const('PID_NETRESOURCE',0x00000001)
		win_const_mgr.add_const('CRED_FLAGS_PROMPT_NOW',0x00000002)
		win_const_mgr.add_const('ERROR_DS_CANT_MOVE_DELETED_OBJECT',0x00002129)
		win_const_mgr.add_const('CM_DETECT_CRASHED',0x00000002)
		win_const_mgr.add_const('MDFF_BOLD',0x00000001)
		win_const_mgr.add_const('SPI_SETMINIMIZEDMETRICS',0x0000002C)
		win_const_mgr.add_const('CB_SETEXTENDEDUI',0x00000155)
		win_const_mgr.add_const('REPLACEFILE_WRITE_THROUGH',0x00000001)
		win_const_mgr.add_const('SPI_GETDROPSHADOW',0x00001024)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_ATTRIBUTES',0x0000000D)
		win_const_mgr.add_const('GL_RSCA_QUERY',0x00001000)
		win_const_mgr.add_const('IMC_SETCOMPOSITIONWINDOW',0x0000000C)
		win_const_mgr.add_const('WLX_DLG_INPUT_TIMEOUT',0x00000066)
		win_const_mgr.add_const('WINHTTP_AUTO_DETECT_TYPE_DHCP',0x00000001)
		win_const_mgr.add_const('EVENT_ENABLE_PROPERTY_TS_ID',0x00000002)
		win_const_mgr.add_const('MMIO_REMOVEPROC',0x00020000)
		win_const_mgr.add_const('IPSEC_POLICY_FLAG_NAT_ENCAP_ALLOW_PEER_BEHIND_NAT',0x00000010)
		win_const_mgr.add_const('SECTION_MAP_EXECUTE_EXPLICIT',0x00000020)
		win_const_mgr.add_const('SCESTATUS_ALREADY_RUNNING',0x0000000D)
		win_const_mgr.add_const('SQL_CT_COLUMN_DEFAULT',0x00000400)
		win_const_mgr.add_const('ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE',0x000036DD)
		win_const_mgr.add_const('MDMSPKR_OFF',0x00000000)
		win_const_mgr.add_const('CLCTL_MODIFY_MASK',0x00000001)
		win_const_mgr.add_const('MM_SNDBLST_MIDIOUT',0x00000003)
		win_const_mgr.add_const('VK_RBUTTON',0x00000002)
		win_const_mgr.add_const('OID_FDDI_FRAME_ERRORS',0x03020104)
		win_const_mgr.add_const('SQL_API_SQLTABLEPRIVILEGES',0x00000046)
		win_const_mgr.add_const('LL_INACTIVE',0x00000000)
		win_const_mgr.add_const('CBR_256000',0x0003E800)
		win_const_mgr.add_const('SQL_ATTR_OUTPUT_NTS',0x00002711)
		win_const_mgr.add_const('MK_XBUTTON1',0x00000020)
		win_const_mgr.add_const('EAP_E_EAPHOST_EAPQEC_INACCESSIBLE',0x80420013)
		win_const_mgr.add_const('AM_LOADSTATUS_LOADINGDESCR',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_CONNECT_BACKOFF',0x00000004)
		win_const_mgr.add_const('DN_MAXOBJL',0x00000010)
		win_const_mgr.add_const('WIA_DIP_PNP_ID',0x00000010)
		win_const_mgr.add_const('HTTP_QUERY_RAW_HEADERS',0x00000015)
		win_const_mgr.add_const('USER_MARSHAL_FC_DOUBLE',0x0000000C)
		win_const_mgr.add_const('IDM_JUSTIFYCENTER',0x00000039)
		win_const_mgr.add_const('WT_EXECUTEINTIMERTHREAD',0x00000020)
		win_const_mgr.add_const('FR_NOUPDOWN',0x00000400)
		win_const_mgr.add_const('KAGPROP_CONCURRENCY',0x00000007)
		win_const_mgr.add_const('KSEVENT_TYPE_ENABLE',0x00000001)
		win_const_mgr.add_const('WLX_CREDENTIAL_TYPE_V1_0',0x00000001)
		win_const_mgr.add_const('GL_LEVEL_WARNING',0x00000003)
		win_const_mgr.add_const('SQL_INDEX_ALL',0x00000001)
		win_const_mgr.add_const('BFT_DATABASE_DIRECTORY',0x00000040)
		win_const_mgr.add_const('CRYPT_FORCE_KEY_PROTECTION_HIGH',0x00008000)
		win_const_mgr.add_const('MK_XBUTTON2',0x00000040)
		win_const_mgr.add_const('FACILITY_WIN32',0x00000007)
		win_const_mgr.add_const('SMAE_VALID',0x00000007)
		win_const_mgr.add_const('BLLI_L2_LLC',0x0000000C)
		win_const_mgr.add_const('HICF_MOUSE',0x00000001)
		win_const_mgr.add_const('D3DSHADER_COMPARISON_MASK',0x00000007)
		win_const_mgr.add_const('SQLBIGCHAR',0x00000000)
		win_const_mgr.add_const('WSA_FLAG_OVERLAPPED',0x00000001)
		win_const_mgr.add_const('SQL_NB_ON',0x00000001)
		win_const_mgr.add_const('VIDEO_CONFIGURE_GET',0x00002000)
		win_const_mgr.add_const('SERVICE_SID_TYPE_UNRESTRICTED',0x00000001)
		win_const_mgr.add_const('PGN_FIRST',0x00000000)
		win_const_mgr.add_const('DDFLIP_EVEN',0x00000002)
		win_const_mgr.add_const('ILP_DOWNLEVEL',0x00000001)
		win_const_mgr.add_const('STD_COPY',0x00000001)
		win_const_mgr.add_const('DEBUG_MANRESET_LOAD_DLL',0x00000001)
		win_const_mgr.add_const('PDH_DIALOG_CANCELLED',0x800007D9)
		win_const_mgr.add_const('IDM_ATOMICSELECTION',0x0000095F)
		win_const_mgr.add_const('DBPROPVAL_IN_IGNOREANYNULL',0x00000004)
		win_const_mgr.add_const('RBSTR_CHANGERECT',0x00000001)
		win_const_mgr.add_const('LOCKP_LOCK_FOR_FORMAT',0x00000004)
		win_const_mgr.add_const('TBS_FIXEDLENGTH',0x00000040)
		win_const_mgr.add_const('HELP_KEY',0x00000101)
		win_const_mgr.add_const('EC_SAMPLE_NEEDED',0x00000020)
		win_const_mgr.add_const('UNWIND_HISTORY_TABLE_SIZE',0x0000000C)
		win_const_mgr.add_const('MCI_DGV_WHERE_DESTINATION',0x00040000)
		win_const_mgr.add_const('FILE_DEVICE_SCREEN',0x00000001)
		win_const_mgr.add_const('COD_COMPUTER_MINOR_UNCLASSIFIED',0x00000000)
		win_const_mgr.add_const('MSV1_0_SUBAUTH_ACCOUNT_TYPE',0x00000040)
		win_const_mgr.add_const('F_EXISTCHECK',0x00000013)
		win_const_mgr.add_const('ACM_MPEG_ORIGINALHOME',0x00000004)
		win_const_mgr.add_const('ERROR_CLEANER_SLOT_NOT_SET',0x000010EC)
		win_const_mgr.add_const('LINE_MONITORMEDIA',0x0000000A)
		win_const_mgr.add_const('MCN_FIRST',0x00000000)
		win_const_mgr.add_const('BG_COPY_FILE_SACL',0x00000008)
		win_const_mgr.add_const('MDPROPVAL_MSC_LESSTHAN',0x00000001)
		win_const_mgr.add_const('DEBUG_OUTPUT_IDENTITY_DEFAULT',0x00000000)
		win_const_mgr.add_const('AUTO_PROXY_FLAG_DONT_CACHE_PROXY_RESULT',0x00000010)
		win_const_mgr.add_const('SQL_RE_ON',0x00000001)
		win_const_mgr.add_const('SM_CYFOCUSBORDER',0x00000054)
		win_const_mgr.add_const('SM_CXICONSPACING',0x00000026)
		win_const_mgr.add_const('ASC_REQ_LICENSING',0x00040000)
		win_const_mgr.add_const('CDB2GVF_ISFILESAVE',0x00000002)
		win_const_mgr.add_const('IF_TYPE_COFFEE',0x00000084)
		win_const_mgr.add_const('GD_MAX_RESOURCE',0x0000000F)
		win_const_mgr.add_const('SUBLANG_ARABIC_QATAR',0x00000010)
		win_const_mgr.add_const('SP_COPY_PNPLOCKED',0x02000000)
		win_const_mgr.add_const('ERROR_TXF_METADATA_ALREADY_PRESENT',0x00001AB3)
		win_const_mgr.add_const('SUBLANG_CUSTOM_UNSPECIFIED',0x00000004)
		win_const_mgr.add_const('CERT_VALIDITY_EXTENDED_USAGE_FAILURE',0x00000020)
		win_const_mgr.add_const('MAXLSN',0x7FFFFFFFFFFFFFFF)
		win_const_mgr.add_const('SCARD_STATE_MUTE',0x00000200)
		win_const_mgr.add_const('D3DPTADDRESSCAPS_CLAMP',0x00000004)
		win_const_mgr.add_const('PAN_MIDLINE_STANDARD_TRIMMED',0x00000002)
		win_const_mgr.add_const('SCARD_PROTOCOL_DEFAULT',0x80000000)
		win_const_mgr.add_const('ICW_FULLPRESENT',0x00000001)
		win_const_mgr.add_const('DBT_CONFIGMGAPI32',0x00000022)
		win_const_mgr.add_const('ERROR_DS_OBJECT_BEING_REMOVED',0x00002093)
		win_const_mgr.add_const('DISPID_FONT_SIZE',0x00000002)
		win_const_mgr.add_const('DM_YRESOLUTION',0x00002000)
		win_const_mgr.add_const('PSWIZB_FINISH',0x00000004)
		win_const_mgr.add_const('LINEADDRESSTYPE_EMAILNAME',0x00000004)
		win_const_mgr.add_const('DDBLTFAST_NOCOLORKEY',0x00000000)
		win_const_mgr.add_const('D3DSP_REGNUM_MASK',0x000007FF)
		win_const_mgr.add_const('NETLOGON_CONTROL_UNLOAD_NETLOGON_DLL',0x0000FFFB)
		win_const_mgr.add_const('DEBUG_TYPEOPTS_LONGSTATUS_DISPLAY',0x00000002)
		win_const_mgr.add_const('MAPI_NEW_MESSAGE',0x00000002)
		win_const_mgr.add_const('CC_ROUNDRECT',0x00000100)
		win_const_mgr.add_const('WINHTTP_OPTION_RECEIVE_TIMEOUT',0x00000006)
		win_const_mgr.add_const('OID_GEN_BROADCAST_BYTES_XMIT',0x00020205)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_REWIND',0x00000032)
		win_const_mgr.add_const('ERROR_CTX_NO_OUTBUF',0x00001B60)
		win_const_mgr.add_const('DNOBJECT_DTR',0x0000003F)
		win_const_mgr.add_const('TME_CANCEL',0x80000000)
		win_const_mgr.add_const('IF_TYPE_FRAMERELAY_SERVICE',0x0000002C)
		win_const_mgr.add_const('DFC_BUTTON',0x00000004)
		win_const_mgr.add_const('SQL_QUICK',0x00000000)
		win_const_mgr.add_const('NDIS_RING_REMOVE_RECEIVED',0x00000200)
		win_const_mgr.add_const('AGP_FLAG_NO_8X_RATE',0x00000008)
		win_const_mgr.add_const('REG_NOTIFY_CHANGE_NAME',0x00000001)
		win_const_mgr.add_const('PERF_DISPLAY_NOSHOW',0x40000000)
		win_const_mgr.add_const('HCF_HOTKEYACTIVE',0x00000004)
		win_const_mgr.add_const('ACL_REVISION2',0x00000002)
		win_const_mgr.add_const('EC_SHUTTING_DOWN',0x0000000C)
		win_const_mgr.add_const('KSDSOUND_BUFFER_CTRL_VOLUME',0x00000008)
		win_const_mgr.add_const('SMART_CYL_HI',0x000000C2)
		win_const_mgr.add_const('TXTLOG_POLICY',0x00800000)
		win_const_mgr.add_const('DEBUG_EVENT_EXIT_PROCESS',0x00000020)
		win_const_mgr.add_const('SC_MINIMIZE',0x0000F020)
		win_const_mgr.add_const('KS_VBICAP_PROTECTION_MV_PRESENT',0x00000001)
		win_const_mgr.add_const('KAGPROP_MAXCOLUMNSINSELECT',0x0000000F)
		win_const_mgr.add_const('WMI_GUIDTYPE_EVENT',0x00000003)
		win_const_mgr.add_const('RPC_S_OUT_OF_RESOURCES',0x000006B9)
		win_const_mgr.add_const('WHITEONBLACK',0x00000002)
		win_const_mgr.add_const('OID_FDDI_IF_TYPE',0x0303027A)
		win_const_mgr.add_const('MD_APPPOOL_IDENTITY_TYPE_SPECIFICUSER',0x00000003)
		win_const_mgr.add_const('JOB_STATUS_DELETING',0x00000004)
		win_const_mgr.add_const('FCSM_WEBVIEWTEMPLATE',0x00000002)
		win_const_mgr.add_const('TTS_ALWAYSTIP',0x00000001)
		win_const_mgr.add_const('MCI_WHERE',0x00000843)
		win_const_mgr.add_const('RPC_C_AUTHN_DPA',0x00000011)
		win_const_mgr.add_const('SUBLANG_ENGLISH_CAN',0x00000004)
		win_const_mgr.add_const('PLAINTEXTKEYBLOB',0x00000008)
		win_const_mgr.add_const('IDD_ACMFORMATCHOOSE_BTN_SETNAME',0x00000067)
		win_const_mgr.add_const('MAPI_EXPLICIT_PROFILE',0x00000010)
		win_const_mgr.add_const('IS_TEXT_UNICODE_STATISTICS',0x00000002)
		win_const_mgr.add_const('CMSG_CMS_ENCAPSULATED_CONTENT_FLAG',0x00000040)
		win_const_mgr.add_const('PORT_DN6NLMAUD',0x000000C3)
		win_const_mgr.add_const('TAPE_SELECT_PARTITIONS',0x00000001)
		win_const_mgr.add_const('SKF_RSHIFTLATCHED',0x02000000)
		win_const_mgr.add_const('RAS_EAP_FLAG_LOGON',0x00000004)
		win_const_mgr.add_const('IF_TYPE_LAP_D',0x0000004D)
		win_const_mgr.add_const('CMSG_ATTR_CERT_PARAM',0x00000020)
		win_const_mgr.add_const('INTERNET_FLAG_NO_COOKIES',0x00080000)
		win_const_mgr.add_const('DISPID_DEPTH',0x00000011)
		win_const_mgr.add_const('SPI_GETWINDOWSEXTENSION',0x0000005C)
		win_const_mgr.add_const('WINCODEC_ERR_BASE',0x00002000)
		win_const_mgr.add_const('SAMPLE_SEQ_SEQUENCE_HEADER',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_TRANS',0x00003608)
		win_const_mgr.add_const('LSA_MODE_MANDATORY_ACCESS',0x00000004)
		win_const_mgr.add_const('PIDDSI_MMCLIPCOUNT',0x0000000A)
		win_const_mgr.add_const('SBM_SETRANGE',0x000000E2)
		win_const_mgr.add_const('ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP',0x00001706)
		win_const_mgr.add_const('SCARD_STATE_IGNORE',0x00000001)
		win_const_mgr.add_const('SQL_ISV_REFERENTIAL_CONSTRAINTS',0x00001000)
		win_const_mgr.add_const('AM_AC3_SERVICE_MAIN_AUDIO',0x00000000)
		win_const_mgr.add_const('WIA_DATA_RAW_BGR',0x00000007)
		win_const_mgr.add_const('LVNI_SELECTED',0x00000002)
		win_const_mgr.add_const('BAUD_115200',0x00020000)
		win_const_mgr.add_const('MB_SERVICE_NOTIFICATION',0x00040000)
		win_const_mgr.add_const('IS_TEXT_UNICODE_NOT_ASCII_MASK',0x0000F000)
		win_const_mgr.add_const('OID_GEN_CO_BYTES_XMIT_OUTSTANDING',0x00020221)
		win_const_mgr.add_const('WM_MBUTTONDOWN',0x00000207)
		win_const_mgr.add_const('LINEINITIALIZEEXOPTION_USEEVENT',0x00000002)
		win_const_mgr.add_const('WPSTYLE_MAX',0x00000003)
		win_const_mgr.add_const('SECURITY_MIN_NEVER_FILTERED',0x000003E8)
		win_const_mgr.add_const('ABM_WINDOWPOSCHANGED',0x00000009)
		win_const_mgr.add_const('LANG_KOREAN',0x00000012)
		win_const_mgr.add_const('LINEAGENTSTATE_WORKINGAFTERCALL',0x00000080)
		win_const_mgr.add_const('DISPID_FONT_WEIGHT',0x00000007)
		win_const_mgr.add_const('SI_EDIT_EFFECTIVE',0x00020000)
		win_const_mgr.add_const('DISK_BINNING',0x00000003)
		win_const_mgr.add_const('GCPCLASS_POSTBOUNDLTR',0x00000020)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATAEVENTARGS_CURRENTACTION',0x00000303)
		win_const_mgr.add_const('PARMNUM_ALL',0x00000000)
		win_const_mgr.add_const('ERROR_DS_NONEXISTENT_POSS_SUP',0x000020C6)
		win_const_mgr.add_const('ID_BROWSE_ADDCONTROL',0x00000003)
		win_const_mgr.add_const('OID_GEN_BROADCAST_BYTES_RCV',0x0002020B)
		win_const_mgr.add_const('FLG_BITREG_32BITKEY',0x00004000)
		win_const_mgr.add_const('WS_BORDER',0x00800000)
		win_const_mgr.add_const('SQL_SENSITIVE',0x00000002)
		win_const_mgr.add_const('IO_ALIAS_10_BIT_DECODE',0x00000004)
		win_const_mgr.add_const('DNS_TYPE_NSAPPTR',0x00000017)
		win_const_mgr.add_const('PHOTO_SHARPNESS_SOFT',0x00000001)
		win_const_mgr.add_const('IDANI_OPEN',0x00000001)
		win_const_mgr.add_const('STN_DISABLE',0x00000003)
		win_const_mgr.add_const('LINEGATHERTERM_FIRSTTIMEOUT',0x00000004)
		win_const_mgr.add_const('REO_BELOWBASELINE',0x00000002)
		win_const_mgr.add_const('CERT_CROSS_CERT_DIST_POINTS_PROP_ID',0x00000017)
		win_const_mgr.add_const('ACM_FORMATSUGGESTF_WBITSPERSAMPLE',0x00080000)
		win_const_mgr.add_const('DISKQUOTA_FILESTATE_REBUILDING',0x00000200)
		win_const_mgr.add_const('SPDRP_LOCATION_INFORMATION',0x0000000D)
		win_const_mgr.add_const('FOREGROUND_INTENSITY',0x00000008)
		win_const_mgr.add_const('WMDM_DEVICECAP_CANSTOP',0x00000040)
		win_const_mgr.add_const('MUI_THREAD_LANGUAGES',0x00000040)
		win_const_mgr.add_const('LBS_DISABLENOSCROLL',0x00001000)
		win_const_mgr.add_const('SV_IRPSTACKSIZE_PARMNUM',0x000001FC)
		win_const_mgr.add_const('MCS_NOTRAILINGDATES',0x00000040)
		win_const_mgr.add_const('VS_FF_PRIVATEBUILD',0x00000008)
		win_const_mgr.add_const('SQL_IS_OFF',0x00000000)
		win_const_mgr.add_const('SBSP_REDIRECT',0x40000000)
		win_const_mgr.add_const('WIA_PAGE_ISO_A5',0x0000000B)
		win_const_mgr.add_const('IF_CONNECTION_DEDICATED',0x00000001)
		win_const_mgr.add_const('C2_ARABICNUMBER',0x00000006)
		win_const_mgr.add_const('ISCSI_LOGIN_OPTIONS_AUTH_TYPE',0x00000080)
		win_const_mgr.add_const('PRIORITY_PROP_HIGH',0x00000002)
		win_const_mgr.add_const('WIA_PAGE_ISO_A3',0x0000000A)
		win_const_mgr.add_const('CDS_GLOBAL',0x00000008)
		win_const_mgr.add_const('MD_SERVER_COMMAND_CONTINUE',0x00000004)
		win_const_mgr.add_const('LOCALSTATE_PUBLISHED',0x00000002)
		win_const_mgr.add_const('EMR_SETICMMODE',0x00000062)
		win_const_mgr.add_const('MD_ERROR_SUB401_LOGON_ACL',0x00000003)
		win_const_mgr.add_const('TCS_FORCELABELLEFT',0x00000020)
		win_const_mgr.add_const('WIA_PAGE_ISO_A1',0x00000008)
		win_const_mgr.add_const('ERROR_CHECKOUT_REQUIRED',0x000000DD)
		win_const_mgr.add_const('SQL_CO_FIREHOSE_AF',0x00000004)
		win_const_mgr.add_const('ERROR_ADDRESS_NOT_ASSOCIATED',0x000004CC)
		win_const_mgr.add_const('PC_NOCOLLAPSE',0x00000004)
		win_const_mgr.add_const('TYMED_MULTIPAGE_CALLBACK',0x00000200)
		win_const_mgr.add_const('OID_FDDI_MAC_LOST_CT',0x03030240)
		win_const_mgr.add_const('ERROR_TIMEOUT',0x000005B4)
		win_const_mgr.add_const('CQPM_HANDLERSPECIFIC',0x10000000)
		win_const_mgr.add_const('CHANGER_TO_TRANSPORT',0x00000001)
		win_const_mgr.add_const('ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC',0x0000219C)
		win_const_mgr.add_const('X3_IMM20_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('HELP_CONTEXTPOPUP',0x00000008)
		win_const_mgr.add_const('PIPE_WAIT',0x00000000)
		win_const_mgr.add_const('ES_UPPERCASE',0x00000008)
		win_const_mgr.add_const('SND_ALIAS_START',0x00000000)
		win_const_mgr.add_const('CAUSE_LOC_INTERNATIONAL_NETWORK',0x00000007)
		win_const_mgr.add_const('KERB_RETRIEVE_TICKET_DONT_USE_CACHE',0x00000001)
		win_const_mgr.add_const('PGF_SCROLLUP',0x00000001)
		win_const_mgr.add_const('TCI_SRCFONTSIG',0x00000003)
		win_const_mgr.add_const('SP_PROT_UNI_CLIENT',0x80000000)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INVALID_STANDALONE',0x000036F6)
		win_const_mgr.add_const('SB_LEFT',0x00000006)
		win_const_mgr.add_const('BG_E_PEERCACHING_DISABLED',0x80200047)
		win_const_mgr.add_const('CONFIGFLAG_SUPPRESS_SURPRISE',0x00004000)
		win_const_mgr.add_const('PHONESTATE_CAPSCHANGE',0x00400000)
		win_const_mgr.add_const('MCI_SET_AUDIO_LEFT',0x00000001)
		win_const_mgr.add_const('CLUS_HYBRID_QUORUM',0x00000400)
		win_const_mgr.add_const('USER_TRUSTED_TO_AUTHENTICATE_FOR_DELEGATION',0x00040000)
		win_const_mgr.add_const('CPS_CANCEL',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_BASED_HIGHLOW',0x00000003)
		win_const_mgr.add_const('LC_POLYLINE',0x00000002)
		win_const_mgr.add_const('SCRIPT_DIGITSUBSTITUTE_TRADITIONAL',0x00000003)
		win_const_mgr.add_const('WM_SETREDRAW',0x0000000B)
		win_const_mgr.add_const('PFM_NUMBERING',0x00000020)
		win_const_mgr.add_const('AE_CONNSTART',0x00000004)
		win_const_mgr.add_const('IDC_LP_CHANGESOURCE',0x000003F7)
		win_const_mgr.add_const('CPIOD_PEEK',0x40000000)
		win_const_mgr.add_const('LGRPID_TURKIC',0x00000006)
		win_const_mgr.add_const('AUTH_REQ_ALLOW_FORWARDABLE',0x00000001)
		win_const_mgr.add_const('MAX_CO_PASSWORD_LENGTH',0x00000010)
		win_const_mgr.add_const('TLS1_ALERT_DECOMPRESSION_FAIL',0x0000001E)
		win_const_mgr.add_const('DISPID_SETPHISHINGFILTERSTATUS',0x0000011A)
		win_const_mgr.add_const('IME_SETCONVERSIONWINDOW',0x00000008)
		win_const_mgr.add_const('MS_PPM_SOFTWARE_ALL',0x00000001)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_IS_TOPL_DETECT_STALE_DISABLED',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_LEFT',0x00200000)
		win_const_mgr.add_const('WN_SERVICE_CLASS',0x00000008)
		win_const_mgr.add_const('RASLCPAD_CHAP_MS',0x00000080)
		win_const_mgr.add_const('CERT_NAME_DNS_TYPE',0x00000006)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_NIC',0x0000000D)
		win_const_mgr.add_const('INTERNET_OPTION_CONNECT_TIMEOUT',0x00000002)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_SYSTEMSPEED',0x00000029)
		win_const_mgr.add_const('WM_GETHOTKEY',0x00000033)
		win_const_mgr.add_const('DOT11_RECV_FLAG_RAW_PACKET_FCS_FAILURE',0x00000002)
		win_const_mgr.add_const('DFCS_SCROLLSIZEGRIPRIGHT',0x00000010)
		win_const_mgr.add_const('DTR_CONTROL_HANDSHAKE',0x00000002)
		win_const_mgr.add_const('ISC_RET_EXTENDED_ERROR',0x00004000)
		win_const_mgr.add_const('NDIS_PNP_WAKE_UP_LINK_CHANGE',0x00000004)
		win_const_mgr.add_const('TRACE_VS_EVENT_ON',0x00000002)
		win_const_mgr.add_const('CRYPT_GET_URL_FROM_PROPERTY',0x00000001)
		win_const_mgr.add_const('ERROR_WAS_UNLOCKED',0x000002CB)
		win_const_mgr.add_const('CHINESEBIG5_CHARSET',0x00000088)
		win_const_mgr.add_const('SCARD_PROVIDER_CSP',0x00000002)
		win_const_mgr.add_const('SNMP_MEM_ALLOC_ERROR',0x00000001)
		win_const_mgr.add_const('DMPAPER_DSHEET',0x00000019)
		win_const_mgr.add_const('MAPI_NEW_SESSION',0x00000002)
		win_const_mgr.add_const('CONFIGFLAG_OKREMOVEROM',0x00000100)
		win_const_mgr.add_const('NDIS_PORT_AUTHENTICATION_PARAMETERS_REVISION_1',0x00000001)
		win_const_mgr.add_const('VCAPS_SRC_CAN_CLIP',0x00000002)
		win_const_mgr.add_const('SPFILENOTIFY_STARTBACKUP',0x00000015)
		win_const_mgr.add_const('DE_E_FILTER_SCRIPTLISTING',0x80100008)
		win_const_mgr.add_const('SQL_CD_TRUE',0x00000001)
		win_const_mgr.add_const('HSR_INITIATE',0x00000008)
		win_const_mgr.add_const('FAX_ERR_END',0x00001B65)
		win_const_mgr.add_const('FACILITY_HTTP',0x00000019)
		win_const_mgr.add_const('WSAEINTR',0x00002714)
		win_const_mgr.add_const('DPNHCAPSFLAG_NOTALLSUPPORTACTIVENOTIFY',0x00000010)
		win_const_mgr.add_const('FILE_DEVICE_WAVE_OUT',0x00000026)
		win_const_mgr.add_const('RPC_PROTSEQ_NMP',0x00000002)
		win_const_mgr.add_const('SPFILENOTIFY_FILEEXTRACTED',0x00000013)
		win_const_mgr.add_const('NUMBER_OF_PERFMON_REGISTER_PAIRS',0x00000004)
		win_const_mgr.add_const('ACMFILTERCHOOSE_STYLEF_CONTEXTHELP',0x00000080)
		win_const_mgr.add_const('IRTIR_TASK_SUSPENDED',0x00000002)
		win_const_mgr.add_const('LDAP_OPT_CACHE_STRATEGY',0x00000000)
		win_const_mgr.add_const('SERVICE_CONTROL_NETBINDENABLE',0x00000009)
		win_const_mgr.add_const('DONT_RESOLVE_DLL_REFERENCES',0x00000001)
		win_const_mgr.add_const('COD_MAJOR_IMAGING',0x00000006)
		win_const_mgr.add_const('DBPROPVAL_BI_CROSSROWSET',0x00000001)
		win_const_mgr.add_const('SECBUFFER_DATA',0x00000001)
		win_const_mgr.add_const('DS_GC_FLAG',0x00000004)
		win_const_mgr.add_const('SQL_FLOAT',0x00000006)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNCLOSEDCOMMENT',0x000036EF)
		win_const_mgr.add_const('SCESTATUS_SERVICE_NOT_SUPPORT',0x0000000E)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_WORK_OFFLINE',0x00000400)
		win_const_mgr.add_const('F_CLOSE',0x00000011)
		win_const_mgr.add_const('HDSIL_STATE',0x00000001)
		win_const_mgr.add_const('ERROR_NO_EFS',0x00001774)
		win_const_mgr.add_const('SV_LOCKVIOLATIONOFFSET_PARMNUM',0x00000238)
		win_const_mgr.add_const('INTERNET_AUTODIAL_FORCE_ONLINE',0x00000001)
		win_const_mgr.add_const('AM_GETDECODERCAP_QUERY_EVR_SUPPORT',0x00000007)
		win_const_mgr.add_const('BCRYPT_CIPHER_OPERATION',0x00000001)
		win_const_mgr.add_const('DFS_STORAGE_STATE_ONLINE',0x00000002)
		win_const_mgr.add_const('L2_NOTIFICATION_SOURCE_WLAN_MSM',0x00000000)
		win_const_mgr.add_const('SPI_GETFOREGROUNDLOCKTIMEOUT',0x00002000)
		win_const_mgr.add_const('DRM_AL_NONSILENT',0x00000001)
		win_const_mgr.add_const('ES_NOOLEDRAGDROP',0x00000008)
		win_const_mgr.add_const('COOKIE_OP_3RD_PARTY',0x00000020)
		win_const_mgr.add_const('IDD_CHANGEICONBROWSE',0x000003F3)
		win_const_mgr.add_const('IDM_BRINGTOFRONT',0x0000000B)
		win_const_mgr.add_const('REFERENCE_WHITE_MAX',0x00002710)
		win_const_mgr.add_const('D3DSTENCILCAPS_KEEP',0x00000001)
		win_const_mgr.add_const('CRYPT_GET_URL_FROM_UNAUTH_ATTRIBUTE',0x00000004)
		win_const_mgr.add_const('ERROR_PATCH_NOT_AVAILABLE',0xC00E4106)
		win_const_mgr.add_const('CRYPT_ALL_PROVIDERS',0x00000002)
		win_const_mgr.add_const('NULLREGION',0x00000001)
		win_const_mgr.add_const('TCP_MAXSEG',0x00000004)
		win_const_mgr.add_const('WM_GETFONT',0x00000031)
		win_const_mgr.add_const('HOTKEYF_CONTROL',0x00000002)
		win_const_mgr.add_const('SQL_TRUE',0x00000001)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_CANDIDATE_LIST_EXHAUSTED',0x00000006)
		win_const_mgr.add_const('SP_COPY_NOOVERWRITE',0x00000008)
		win_const_mgr.add_const('CAUSE_NO_ROUTE_TO_TRANSIT_NETWORK',0x00000002)
		win_const_mgr.add_const('ERROR_CLIENT_SERVER_PARAMETERS_INVALID',0x00000255)
		win_const_mgr.add_const('HTTP_LOG_FIELD_REASON',0x02000000)
		win_const_mgr.add_const('VT_BLOB_PROPSET',0x0000004B)
		win_const_mgr.add_const('SPFILENOTIFY_STARTDELETE',0x00000005)
		win_const_mgr.add_const('ERROR_DS_BAD_ATT_SCHEMA_SYNTAX',0x000020D0)
		win_const_mgr.add_const('RIM_INPUT',0x00000000)
		win_const_mgr.add_const('MCI_DGV_STATUS_KEY_COLOR',0x00004025)
		win_const_mgr.add_const('PRINTER_ENUM_CONTAINER',0x00008000)
		win_const_mgr.add_const('TVS_EDITLABELS',0x00000008)
		win_const_mgr.add_const('WMS_CONTAINER_IS_VBR',0x0000000F)
		win_const_mgr.add_const('SM_CYICON',0x0000000C)
		win_const_mgr.add_const('MEM_64M',0x04000000)
		win_const_mgr.add_const('SUBLANG_MALTESE_MALTA',0x00000001)
		win_const_mgr.add_const('MEM_64K',0x00010000)
		win_const_mgr.add_const('BG_E_INVALID_STATE',0x80200002)
		win_const_mgr.add_const('NSPROTO_SPX',0x000004E8)
		win_const_mgr.add_const('SQL_ACTIVE_STATEMENTS',0x00000001)
		win_const_mgr.add_const('TIME_PERIODIC',0x00000001)
		win_const_mgr.add_const('TOKEN_IMPERSONATE',0x00000004)
		win_const_mgr.add_const('TOKEN_ASSIGN_PRIMARY',0x00000001)
		win_const_mgr.add_const('BG_E_PROXY_BYPASS_LIST_TOO_LARGE',0x80200019)
		win_const_mgr.add_const('WM_QUERYNEWPALETTE',0x0000030F)
		win_const_mgr.add_const('RQ_EXECUTE_REQUEST_HANDLER',0x00000080)
		win_const_mgr.add_const('NETSETUP_JOIN_DC_ACCOUNT',0x00000200)
		win_const_mgr.add_const('RTCEF_USERSEARCH',0x00000800)
		win_const_mgr.add_const('HH_SET_GLOBAL_PROPERTY',0x00000000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_SUPPORTEDWRITESPEEDDESCRIPTORS',0x00000114)
		win_const_mgr.add_const('LINETERMMODE_MEDIABIDIRECT',0x00000080)
		win_const_mgr.add_const('CMB_MASKED',0x00000002)
		win_const_mgr.add_const('ERROR_LOG_RESERVATION_INVALID',0x000019D7)
		win_const_mgr.add_const('DBTF_RESOURCE',0x00000001)
		win_const_mgr.add_const('WIA_DPS_DEVICE_ID',0x00000C2A)
		win_const_mgr.add_const('LINEADDRESSMODE_DIALABLEADDR',0x00000002)
		win_const_mgr.add_const('SCARD_PROTOCOL_OPTIMAL',0x00000000)
		win_const_mgr.add_const('DISPID_NAVIGATECOMPLETE',0x00000065)
		win_const_mgr.add_const('PDH_LOG_OPEN_EXISTING',0x00000004)
		win_const_mgr.add_const('IF_TYPE_ATM_DXI',0x00000069)
		win_const_mgr.add_const('KSPROPERTY_CAMERACONTROL_FLAGS_MANUAL',0x00000000)
		win_const_mgr.add_const('VK_OEM_2',0x000000BF)
		win_const_mgr.add_const('RF_DONTCARE',0x00000001)
		win_const_mgr.add_const('CONTEXT_E_FIRST',0x8004E000)
		win_const_mgr.add_const('MFE_OIF_PRUNED',0x00000005)
		win_const_mgr.add_const('ERROR_CTX_WINSTATIONS_DISABLED',0x00001B94)
		win_const_mgr.add_const('VK_OEM_3',0x000000C0)
		win_const_mgr.add_const('WMDM_FILE_ATTR_FILE',0x00000020)
		win_const_mgr.add_const('ERR_DISK_WRITE_ERROR',0xE0000005)
		win_const_mgr.add_const('LINEERR_INVALPARAM',0x80000032)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_END_OF_STRUCT',0x00000066)
		win_const_mgr.add_const('MIXER_GETLINECONTROLSF_QUERYMASK',0x0000000F)
		win_const_mgr.add_const('GESTURE_SEMICIRCLE_LEFT',0x00000000)
		win_const_mgr.add_const('CDERR_LOADSTRFAILURE',0x00000005)
		win_const_mgr.add_const('AA_A_CREATE',0x00002000)
		win_const_mgr.add_const('CDEF_BYPASS_CLASS_MANAGER',0x00000002)
		win_const_mgr.add_const('NETSCAPE_SIGN_CA_CERT_TYPE',0x00000001)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_COLUMN_PRIVILEGES',0x00000006)
		win_const_mgr.add_const('LINEANSWERMODE_NONE',0x00000001)
		win_const_mgr.add_const('BCPKEEPNULLS',0x00000005)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_INDIRECT_MEMORY',0x00000008)
		win_const_mgr.add_const('TMT_OPACITY',0x0000097E)
		win_const_mgr.add_const('ERROR_ARBITRATION_UNHANDLED',0x000002D3)
		win_const_mgr.add_const('SECPKG_CRED_BOTH',0x00000003)
		win_const_mgr.add_const('MCI_SETVIDEO',0x00000876)
		win_const_mgr.add_const('FWP_ACTION_FLAG_CALLOUT',0x00004000)
		win_const_mgr.add_const('ENUM_SUCCESS',0x00000000)
		win_const_mgr.add_const('FILE_EXECUTE',0x00000020)
		win_const_mgr.add_const('PEER_TO_PEER_NODETYPE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_CONSTRAINT_VIOLATION',0x0000202F)
		win_const_mgr.add_const('THREAD_SET_THREAD_TOKEN',0x00000080)
		win_const_mgr.add_const('SRCLIST_NOBROWSE',0x00000002)
		win_const_mgr.add_const('LVS_EX_SUBITEMIMAGES',0x00000002)
		win_const_mgr.add_const('MAX_INSTRUCTION_LEN',0x00000100)
		win_const_mgr.add_const('PDH_SQL_ROWCOUNT_FAILED',0xC0000BE4)
		win_const_mgr.add_const('CB_LIMITTEXT',0x00000141)
		win_const_mgr.add_const('DBPROPVAL_TI_CURSORSTABILITY',0x00001000)
		win_const_mgr.add_const('DSPROVIDER_ADVANCED',0x00000010)
		win_const_mgr.add_const('ERROR_PASSWORD_EXPIRED',0x00000532)
		win_const_mgr.add_const('IPV6_UNICAST_IF',0x0000001F)
		win_const_mgr.add_const('ELEMENT_STATUS_PVOLTAG',0x10000000)
		win_const_mgr.add_const('MODALS_DOMAIN_ID_PARMNUM',0x00000009)
		win_const_mgr.add_const('AF_ECMA',0x00000008)
		win_const_mgr.add_const('ERROR_SYSTEM_TRACE',0x00000096)
		win_const_mgr.add_const('RASLCPO_3_DES',0x00000010)
		win_const_mgr.add_const('MIXER_GETLINEINFOF_TARGETTYPE',0x00000004)
		win_const_mgr.add_const('DEBUG_STATUS_MASK',0x00000000)
		win_const_mgr.add_const('INTERNET_MAX_PORT_NUMBER_LENGTH',0x00000005)
		win_const_mgr.add_const('LINEAGENTSESSIONSTATUS_STATE',0x00000002)
		win_const_mgr.add_const('TBIF_APPEND',0x00000000)
		win_const_mgr.add_const('C1_SPACE',0x00000008)
		win_const_mgr.add_const('MEDIASINK_CANNOT_MATCH_CLOCK',0x00000002)
		win_const_mgr.add_const('ICMODE_DECOMPRESS',0x00000002)
		win_const_mgr.add_const('ERROR_DS_INTERNAL_FAILURE',0x000020EE)
		win_const_mgr.add_const('DVB_ST_PID_20',0x00000014)
		win_const_mgr.add_const('DISPID_EXPAND',0x00000019)
		win_const_mgr.add_const('DBIMF_NOMARGINS',0x00002000)
		win_const_mgr.add_const('ERROR_RESOURCE_ENUM_USER_STOP',0x00003B02)
		win_const_mgr.add_const('ERROR_CLUSTER_INVALID_REQUEST',0x000013B8)
		win_const_mgr.add_const('ERROR_DS_INSTALL_SCHEMA_MISMATCH',0x00002113)
		win_const_mgr.add_const('MCI_DGV_FF_JPEG',0x00004004)
		win_const_mgr.add_const('DPAS_INSERTAFTER',0x00000004)
		win_const_mgr.add_const('ERRCLASS_INTRN',0x00000004)
		win_const_mgr.add_const('TC_HARDERR',0x00000001)
		win_const_mgr.add_const('MF_TEST_SIGNED_COMPONENT_LOADING',0x01000000)
		win_const_mgr.add_const('PDH_SQL_CONNECT_FAILED',0xC0000BE6)
		win_const_mgr.add_const('CAC_FULL',0x00000000)
		win_const_mgr.add_const('SM_XVIRTUALSCREEN',0x0000004C)
		win_const_mgr.add_const('WIA_DATA_RAW_YUVK',0x00000009)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_ENLIST_PREPREPARE',0x00001000)
		win_const_mgr.add_const('SPI_SETCLIENTAREAANIMATION',0x00001043)
		win_const_mgr.add_const('DBFLAGS_LOGBUFFERSLARGE',0x00000040)
		win_const_mgr.add_const('MD_ERROR_SECURE_CHANNEL_FAILURE',0x800CC806)
		win_const_mgr.add_const('ERROR_TRANSACTION_OBJECT_EXPIRED',0x00001A42)
		win_const_mgr.add_const('DDENUMSURFACES_DOESEXIST',0x00000010)
		win_const_mgr.add_const('VDMEVENT_PM16',0x00000002)
		win_const_mgr.add_const('XP1_MESSAGE_ORIENTED',0x00000008)
		win_const_mgr.add_const('IMAGE_REL_BASED_MIPS_JMPADDR16',0x00000009)
		win_const_mgr.add_const('URL_APPLY_FORCEAPPLY',0x00000008)
		win_const_mgr.add_const('JIFMK_DHP',0x0000FFDE)
		win_const_mgr.add_const('ERROR_CTX_ACCOUNT_RESTRICTION',0x00001B98)
		win_const_mgr.add_const('ISDB_PCAT_TID',0x000000C2)
		win_const_mgr.add_const('JIFMK_DHT',0x0000FFC4)
		win_const_mgr.add_const('HDS_NOSIZING',0x00000800)
		win_const_mgr.add_const('DBG_MODMOVE',0x00000013)
		win_const_mgr.add_const('ISOPROTO_TP1',0x0000001A)
		win_const_mgr.add_const('D3DLINECAPS_ALPHACMP',0x00000008)
		win_const_mgr.add_const('CHECKSUM_MAP_FAILURE',0x00000002)
		win_const_mgr.add_const('TTS_BALLOON',0x00000040)
		win_const_mgr.add_const('SMC_INITMENU',0x00000001)
		win_const_mgr.add_const('VARIANT_NOVALUEPROP',0x00000001)
		win_const_mgr.add_const('ICW_MANUALPRESENT',0x00000002)
		win_const_mgr.add_const('FACILITY_DISPATCH',0x00000002)
		win_const_mgr.add_const('SEC_WINNT_AUTH_IDENTITY_ANSI',0x00000001)
		win_const_mgr.add_const('SHCDF_UPDATEITEM',0x00000001)
		win_const_mgr.add_const('ENUM_E_FIRST',0x800401B0)
		win_const_mgr.add_const('IP_TOS_SHIFT',0x00000001)
		win_const_mgr.add_const('LDAP_MODIFY_CMD',0x00000066)
		win_const_mgr.add_const('MXDCOP_SET_XPSPASSTHRU_MODE',0x00000020)
		win_const_mgr.add_const('MCI_VCR_SETVIDEO_RECORD',0x00010000)
		win_const_mgr.add_const('TSF_NORMAL',0x00000000)
		win_const_mgr.add_const('HIST_BACK',0x00000000)
		win_const_mgr.add_const('WINHTTP_OPTION_CONNECTION_INFO',0x0000005D)
		win_const_mgr.add_const('IME_PROP_UNICODE',0x00080000)
		win_const_mgr.add_const('FILE_ATTRIBUTE_TEMPORARY',0x00000100)
		win_const_mgr.add_const('SCARD_W_CARD_NOT_AUTHENTICATED',0x8010006F)
		win_const_mgr.add_const('CERT_STORE_SHARE_STORE_FLAG',0x00000040)
		win_const_mgr.add_const('SQL_NUMERIC',0x00000002)
		win_const_mgr.add_const('WIA_DIP_SERVER_NAME',0x00000008)
		win_const_mgr.add_const('WINHTTP_DISABLE_COOKIES',0x00000001)
		win_const_mgr.add_const('MD_ERROR_SUB403_SSL_REQUIRED',0x00000004)
		win_const_mgr.add_const('SMINIT_DROPONCONTAINER',0x00000400)
		win_const_mgr.add_const('EM_GETHANDLE',0x000000BD)
		win_const_mgr.add_const('INTERNET_AUTODIAL_FORCE_UNATTENDED',0x00000002)
		win_const_mgr.add_const('UISF_HIDEFOCUS',0x00000001)
		win_const_mgr.add_const('TF_CLUIE_COUNT',0x00000002)
		win_const_mgr.add_const('CSIDL_CONTROLS',0x00000003)
		win_const_mgr.add_const('WIA_DPA_DEVICE_TIME',0x00000404)
		win_const_mgr.add_const('SV_MDLREADSWITCHOVER_PARMNUM',0x0000023A)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_CLOSING',0x00000100)
		win_const_mgr.add_const('PHONESTATE_DISPLAY',0x00000020)
		win_const_mgr.add_const('PCR_ENTRY',0x00000000)
		win_const_mgr.add_const('LINEFEATURE_SETTERMINAL',0x00000020)
		win_const_mgr.add_const('CTRY_SOUTH_KOREA',0x00000052)
		win_const_mgr.add_const('ERROR_EC_CRED_NOT_FOUND',0x00003AEC)
		win_const_mgr.add_const('PAN_SERIF_THIN',0x00000007)
		win_const_mgr.add_const('BI_1632',0x32333631)
		win_const_mgr.add_const('MCI_DGV_SET_STILL',0x00040000)
		win_const_mgr.add_const('MD_CPU_DISABLE_ALL_LOGGING',0x00000000)
		win_const_mgr.add_const('TF_SFT_EXTRAICONSONMINIMIZED',0x00000200)
		win_const_mgr.add_const('LOCALE_SDURATION',0x00000005)
		win_const_mgr.add_const('MDPROPVAL_VISUAL_MODE_DEFAULT',0x00000000)
		win_const_mgr.add_const('SUBSMGRUPDATE_MINIMIZE',0x00000001)
		win_const_mgr.add_const('ERROR_PORT_UNREACHABLE',0x000004D2)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_BIT_FIELD',0x00000012)
		win_const_mgr.add_const('MCGIF_NAME',0x00000004)
		win_const_mgr.add_const('MSDAIPP_MAX_URL_LENGTH',0x00001000)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG4',0x00004000)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG7',0x00007000)
		win_const_mgr.add_const('TTFCFP_FLAGS_COMPRESS',0x00000002)
		win_const_mgr.add_const('LIFF_FORCE_TEXT_FILTER_FALLBACK',0x00000003)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG0',0x00000000)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETAGENTSTATUS',0x00000005)
		win_const_mgr.add_const('CSA_GRAY',0x00000005)
		win_const_mgr.add_const('IP_CURSOR_DOWN',0x00000001)
		win_const_mgr.add_const('BF_ADJUST',0x00002000)
		win_const_mgr.add_const('COMP_TYPE_CFHTML',0x00000004)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG9',0x00009000)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG8',0x00008000)
		win_const_mgr.add_const('SI_RESET',0x00000020)
		win_const_mgr.add_const('REO_INPLACEACTIVE',0x02000000)
		win_const_mgr.add_const('LINECALLREASON_PARKED',0x00002000)
		win_const_mgr.add_const('IS_FULLSCREEN',0x00000002)
		win_const_mgr.add_const('PP_ENUMEX_SIGNING_PROT',0x00000028)
		win_const_mgr.add_const('IDM_COPYBACKGROUND',0x000008D9)
		win_const_mgr.add_const('TMT_TOCOLOR5',0x000007DA)
		win_const_mgr.add_const('TMT_TOCOLOR2',0x000007D7)
		win_const_mgr.add_const('DIRID_SYSTEM_X86',0x00004029)
		win_const_mgr.add_const('TMT_TOCOLOR1',0x000007D6)
		win_const_mgr.add_const('BAUD_7200',0x00000400)
		win_const_mgr.add_const('LBN_DBLCLK',0x00000002)
		win_const_mgr.add_const('RF_REQUIRESSEGMENTATIONBREAKING',0x00020000)
		win_const_mgr.add_const('SO_CONNDATALEN',0x00007004)
		win_const_mgr.add_const('DDE_FAPPSTATUS',0x00000000)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_EBC',0x00000EBC)
		win_const_mgr.add_const('SET_FEATURE_ON_THREAD_TRUSTED',0x00000020)
		win_const_mgr.add_const('SQL_CA1_POSITIONED_UPDATE',0x00002000)
		win_const_mgr.add_const('MDMEASURE_AGGR_VAR',0x00000006)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('LVCDI_GROUP',0x00000001)
		win_const_mgr.add_const('DEFAULT_CHARSET',0x00000001)
		win_const_mgr.add_const('PRINTER_ERROR_WARNING',0x40000000)
		win_const_mgr.add_const('ERROR_CANTSCROLLBACKWARDS',0x00000303)
		win_const_mgr.add_const('MCI_OVLY_WINDOW_DISABLE_STRETCH',0x00200000)
		win_const_mgr.add_const('IDM_TRIED_EDITMODE',0x00000021)
		win_const_mgr.add_const('LOCALE_SENGCOUNTRY',0x00001002)
		win_const_mgr.add_const('LINEADDRFEATURE_SETMEDIACONTROL',0x00000008)
		win_const_mgr.add_const('NETSCAPE_SMIME_CERT_TYPE',0x00000020)
		win_const_mgr.add_const('REPLACE_PRIMARY',0x0000000A)
		win_const_mgr.add_const('MCI_DGV_STATUS_UNSAVED',0x00004017)
		win_const_mgr.add_const('COLOR_ACTIVECAPTION',0x00000002)
		win_const_mgr.add_const('CRYPT_LITTLE_ENDIAN',0x00000001)
		win_const_mgr.add_const('PXE_CALLBACK_RECV_REQUEST',0x00000000)
		win_const_mgr.add_const('SSPROP_DEFERPREPARE',0x0000000D)
		win_const_mgr.add_const('USN_REASON_FILE_DELETE',0x00000200)
		win_const_mgr.add_const('MDM_MASK_HDLCPPP_ML',0x00000003)
		win_const_mgr.add_const('HDN_FIRST',0x00000000)
		win_const_mgr.add_const('KSCREATE_ITEM_FREEONSTOP',0x00000008)
		win_const_mgr.add_const('NCBRECV',0x00000015)
		win_const_mgr.add_const('IMAGE_REL_M32R_ADDR32',0x00000001)
		win_const_mgr.add_const('CLFS_SCAN_INIT',0x00000001)
		win_const_mgr.add_const('ERROR_INVALID_MEDIA_POOL',0x000010CE)
		win_const_mgr.add_const('DBPROPVAL_FU_TABLE',0x00000004)
		win_const_mgr.add_const('XECI_DISABLE',0x00000000)
		win_const_mgr.add_const('DISPID_WINDOWREVOKED',0x000000C9)
		win_const_mgr.add_const('PPP_LCP_CHAP',0x0000C223)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_FILTER',0x00003622)
		win_const_mgr.add_const('VP_CP_CMD_DEACTIVATE',0x00000002)
		win_const_mgr.add_const('MIXERCONTROL_CT_CLASS_SLIDER',0x40000000)
		win_const_mgr.add_const('DIB_RGB_COLORS',0x00000000)
		win_const_mgr.add_const('MD_DIRBROW_SHOW_DATE',0x00000002)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_SETWRITESPEED',0x00000205)
		win_const_mgr.add_const('DMPAPER_P32KBIG',0x0000005F)
		win_const_mgr.add_const('RPC_C_OPT_OPTIMIZE_TIME',0x00000010)
		win_const_mgr.add_const('XA_SWITCH_F_DTC',0x00000001)
		win_const_mgr.add_const('ERROR_CONNECTION_INVALID',0x000004CD)
		win_const_mgr.add_const('HOTKEYF_SHIFT',0x00000001)
		win_const_mgr.add_const('TAPE_SPACE_RELATIVE_BLOCKS',0x00000005)
		win_const_mgr.add_const('DBT_DEVICEARRIVAL',0x00008000)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_REFHI',0x0000000A)
		win_const_mgr.add_const('SERVICE_WIN32_SHARE_PROCESS',0x00000020)
		win_const_mgr.add_const('R2_NOTCOPYPEN',0x00000004)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_GRP_PEAK_RATE',0x0000001A)
		win_const_mgr.add_const('VTBIT_CY',0x00000001)
		win_const_mgr.add_const('URLACTION_HTML_SUBFRAME_NAVIGATE',0x00001607)
		win_const_mgr.add_const('DRIVER_COMPATID_RANK',0x00003FFF)
		win_const_mgr.add_const('SQL_OU_PRIVILEGE_DEFINITION',0x00000010)
		win_const_mgr.add_const('CTRY_AUSTRALIA',0x0000003D)
		win_const_mgr.add_const('CTRY_NETHERLANDS',0x0000001F)
		win_const_mgr.add_const('WMDM_SCP_RIGHTS_DATA',0x00000040)
		win_const_mgr.add_const('MF_COMPONENT_INVALID_ROOT',0x00010000)
		win_const_mgr.add_const('CI_STATE_READING_USNS',0x00004000)
		win_const_mgr.add_const('FAST_TRANSLATE',0x00040000)
		win_const_mgr.add_const('PHONEERR_INIFILECORRUPT',0x90000005)
		win_const_mgr.add_const('SQL_CODE_DAY',0x00000003)
		win_const_mgr.add_const('ERROR_EVENTLOG_CANT_START',0x000005DD)
		win_const_mgr.add_const('DBPROP_MSREMOTE_SERVER',0x00000002)
		win_const_mgr.add_const('WMDM_POWER_CAP_BATTERY',0x00000001)
		win_const_mgr.add_const('ERROR_TRANSACTION_SUPERIOR_EXISTS',0x00001A35)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_TREE',0x0000000A)
		win_const_mgr.add_const('DISPID_DHTMLEDITSCROLLBARS',0x0000000E)
		win_const_mgr.add_const('SELCERT_CERTLIST',0x00000066)
		win_const_mgr.add_const('MPR_INTERFACE_CONNECTION_FAILURE',0x00000004)
		win_const_mgr.add_const('ERROR_MCA_MCCS_VERSION_MISMATCH',0x00003B63)
		win_const_mgr.add_const('OID_GEN_RCV_LINK_SPEED',0x00010285)
		win_const_mgr.add_const('SYSFXUI_DONOTSHOW_SPEAKERFILLING',0x00000040)
		win_const_mgr.add_const('SQL_SSF_UPPER',0x00000004)
		win_const_mgr.add_const('DISPID_SEARCHCOMMAND_RESTORE',0x00000007)
		win_const_mgr.add_const('DATE_USE_ALT_CALENDAR',0x00000004)
		win_const_mgr.add_const('ETW_UINT16_TYPE_VALUE',0x00000006)
		win_const_mgr.add_const('FCW_PROGRESS',0x00000008)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_LOCAL_MCAST',0x00000200)
		win_const_mgr.add_const('SD_RECEIVE',0x00000000)
		win_const_mgr.add_const('ERROR_SUCCESS',0x00000000)
		win_const_mgr.add_const('HTTP_STATUS_OK',0x000000C8)
		win_const_mgr.add_const('CHANNEL_RC_NOT_OPEN',0x0000000A)
		win_const_mgr.add_const('LINEROAMMODE_UNAVAIL',0x00000002)
		win_const_mgr.add_const('PRINTER_ERROR_OUTOFPAPER',0x00000001)
		win_const_mgr.add_const('ICM_QUERY',0x00000003)
		win_const_mgr.add_const('PHONESTATE_HANDSETVOLUME',0x00000400)
		win_const_mgr.add_const('ERROR_EVT_VERSION_TOO_OLD',0x00003ABA)
		win_const_mgr.add_const('DXVA_HIGHLIGHT_BUFFER',0x0000000B)
		win_const_mgr.add_const('PHONEHOOKSWITCHMODE_ONHOOK',0x00000001)
		win_const_mgr.add_const('IPX_SERVICE_FILTER_PERMIT',0x00000001)
		win_const_mgr.add_const('PSNRET_MESSAGEHANDLED',0x00000003)
		win_const_mgr.add_const('SQL_FN_TSI_MINUTE',0x00000004)
		win_const_mgr.add_const('XEPR_REQUESTID',0x00000004)
		win_const_mgr.add_const('SV_MINLINKTHROUGHPUT_PARMNUM',0x00000229)
		win_const_mgr.add_const('CERT_CHAIN_ENABLE_CACHE_AUTO_UPDATE',0x00000010)
		win_const_mgr.add_const('SQL_GB_NOT_SUPPORTED',0x00000000)
		win_const_mgr.add_const('XBUTTON2',0x00000002)
		win_const_mgr.add_const('DVB_BAT_PID',0x00000011)
		win_const_mgr.add_const('STACK_SCRATCH_AREA',0x00000010)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_DATETIME',0x0000001F)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_COMMERCIAL',0x00000001)
		win_const_mgr.add_const('META_OFFSETVIEWPORTORG',0x00000211)
		win_const_mgr.add_const('IP_PRECEDENCE_SHIFT',0x00000005)
		win_const_mgr.add_const('PORT_MSGAUTH',0x0000001F)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_NOTIFY_NAME',0x00000004)
		win_const_mgr.add_const('COD_LAN_MINOR_UNCLASSIFIED',0x00000000)
		win_const_mgr.add_const('BCOB_C',0x00000003)
		win_const_mgr.add_const('PROGRESS_CANCEL',0x00000001)
		win_const_mgr.add_const('CM_CREATE_DEVNODE_PHANTOM',0x00000002)
		win_const_mgr.add_const('SQL_SRVC_VALUE_EXPRESSION',0x00000001)
		win_const_mgr.add_const('PKR_RD',0x00000002)
		win_const_mgr.add_const('PHONEERR_BADDEVICEID',0x90000002)
		win_const_mgr.add_const('BCOB_X',0x00000010)
		win_const_mgr.add_const('RPC_S_CALL_FAILED_DNE',0x000006BF)
		win_const_mgr.add_const('MCI_WAVE_SET_CHANNELS',0x00020000)
		win_const_mgr.add_const('DSPRINT_UPDATE',0x00000002)
		win_const_mgr.add_const('MSIM_LIST_NOREF',0x00000010)
		win_const_mgr.add_const('WNODE_FLAG_PERSIST_EVENT',0x00000400)
		win_const_mgr.add_const('DUPLICATE_SAME_ACCESS',0x00000002)
		win_const_mgr.add_const('SM_MEDIACENTER',0x00000057)
		win_const_mgr.add_const('CBR_300',0x0000012C)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_MEMBER_OF_ENUM',0x00000010)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_OPTION',0x00000485)
		win_const_mgr.add_const('RED_SHIFT',0x00000010)
		win_const_mgr.add_const('SQL_API_SQLALLOCENV',0x00000002)
		win_const_mgr.add_const('DN_MAXNODEL',0x00000007)
		win_const_mgr.add_const('TMT_ANIMATIONBUTTONRECT',0x0000138D)
		win_const_mgr.add_const('CR_PROP_CABACKWARDCROSSCERTSTATE',0x00000026)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_RESPONSE_NONE',0x00000000)
		win_const_mgr.add_const('RTCEF_WATCHER',0x00000200)
		win_const_mgr.add_const('INTERNET_OPEN_TYPE_PRECONFIG_WITH_NO_AUTOPROXY',0x00000004)
		win_const_mgr.add_const('SBSP_EXPLOREMODE',0x00000020)
		win_const_mgr.add_const('SQL_API_SQLDESCRIBEPARAM',0x0000003A)
		win_const_mgr.add_const('CBS_UPPERCASE',0x00002000)
		win_const_mgr.add_const('NTMS_APPLICATIONNAME_LENGTH',0x00000040)
		win_const_mgr.add_const('SQL_QUALIFIER_USAGE',0x0000005C)
		win_const_mgr.add_const('AE_SRVSTART',0x00000000)
		win_const_mgr.add_const('KERB_ETYPE_AES128_CTS_HMAC_SHA1_96',0x00000011)
		win_const_mgr.add_const('PHONEHOOKSWITCHDEV_SPEAKER',0x00000002)
		win_const_mgr.add_const('CFU_UNDERLINEDOUBLEWAVE',0x0000000B)
		win_const_mgr.add_const('ERROR_TRANSACTIONS_NOT_FROZEN',0x00001AB7)
		win_const_mgr.add_const('SUBLANG_FRISIAN_NETHERLANDS',0x00000001)
		win_const_mgr.add_const('CERT_UNICODE_RDN_ERR_INDEX_SHIFT',0x00000016)
		win_const_mgr.add_const('GESTURE_SCRATCHOUT',0x00000000)
		win_const_mgr.add_const('SQL_OPT_TRACE',0x00000068)
		win_const_mgr.add_const('ICM_SET_CALIBRATE_MODE',0x00000002)
		win_const_mgr.add_const('BIF_SHOWSIMILARDRIVERS',0x00000001)
		win_const_mgr.add_const('DBT_QUERYCHANGECONFIG',0x00000017)
		win_const_mgr.add_const('MD_BACKUP_OVERWRITE',0x00000001)
		win_const_mgr.add_const('EXITEVENT_CERTPENDING',0x00000002)
		win_const_mgr.add_const('FMEVENT_HELPMENUITEM',0x0000006B)
		win_const_mgr.add_const('MSV1_0_USER_SESSION_KEY_LENGTH',0x00000010)
		win_const_mgr.add_const('MQSEC_DELETE_MESSAGE',0x00000001)
		win_const_mgr.add_const('MIXER_SETCONTROLDETAILSF_CUSTOM',0x00000001)
		win_const_mgr.add_const('IDB_HIST_NORMAL',0x0000000C)
		win_const_mgr.add_const('SMC_CREATE',0x00000002)
		win_const_mgr.add_const('CRLF_IGNORE_CROSS_CERT_TRUST_ERROR',0x00000100)
		win_const_mgr.add_const('DNS_ERROR_NOT_ALLOWED_ON_RODC',0x00002561)
		win_const_mgr.add_const('CRYPT_KEYID_ALLOC_FLAG',0x00008000)
		win_const_mgr.add_const('MD_CPU_ENABLE_LOGGING',0x80000000)
		win_const_mgr.add_const('PPP_LCP_AES_256',0x00000080)
		win_const_mgr.add_const('RRF_RT_REG_MULTI_SZ',0x00000020)
		win_const_mgr.add_const('ATMPROTO_AAL1',0x00000001)
		win_const_mgr.add_const('ERROR_LOG_METADATA_INCONSISTENT',0x000019D6)
		win_const_mgr.add_const('TR_AR',0x00000009)
		win_const_mgr.add_const('VP_TV_STANDARD_SECAM_K1',0x00002000)
		win_const_mgr.add_const('CMS_SETPRINTERPROFILE',0x00000020)
		win_const_mgr.add_const('SUBLANG_XHOSA_SOUTH_AFRICA',0x00000001)
		win_const_mgr.add_const('LVIF_TEXT',0x00000001)
		win_const_mgr.add_const('DBT_DEVTYP_HANDLE',0x00000006)
		win_const_mgr.add_const('DSBI_RETURNOBJECTCLASS',0x01000000)
		win_const_mgr.add_const('D3DCAPS3_COPY_TO_VIDMEM',0x00000100)
		win_const_mgr.add_const('IDM_JUSTIFYFULL',0x00000032)
		win_const_mgr.add_const('RTM_NUM_CHANGE_TYPES',0x00000003)
		win_const_mgr.add_const('INTERNET_OPTION_CACHE_TIMESTAMPS',0x00000045)
		win_const_mgr.add_const('TMT_CAPTIONBARWIDTH',0x000004B4)
		win_const_mgr.add_const('RESETDEV',0x00000007)
		win_const_mgr.add_const('MSIM_DISPID_ONLOGOFF',0x00000E01)
		win_const_mgr.add_const('MKF_LEFTBUTTONDOWN',0x01000000)
		win_const_mgr.add_const('BAUD_134_5',0x00000004)
		win_const_mgr.add_const('NTDSCONN_OPT_USE_NOTIFY',0x00000001)
		win_const_mgr.add_const('MCI_VCR_LIST_VIDEO_SOURCE',0x00010000)
		win_const_mgr.add_const('NETLOGON_CONTROL_TRANSPORT_NOTIFY',0x00000007)
		win_const_mgr.add_const('FOF_NO_CONNECTED_ELEMENTS',0x00002000)
		win_const_mgr.add_const('WLX_SAS_TYPE_SC_INSERT',0x00000005)
		win_const_mgr.add_const('SETUP_DCOM_SECURITY_UPDATED_FLAG',0x00002000)
		win_const_mgr.add_const('ERROR_IMAGE_NOT_STRIPPED',0x00008800)
		win_const_mgr.add_const('RPC_INTERFACE_HAS_PIPES',0x00000001)
		win_const_mgr.add_const('WINEVENT_LEVEL_ERROR',0x00000002)
		win_const_mgr.add_const('DBPROP_INIT_CACHEAGGRESSIVELY',0x00000003)
		win_const_mgr.add_const('SSM_REFRESH',0x00000002)
		win_const_mgr.add_const('NIF_INFO',0x00000010)
		win_const_mgr.add_const('STRSAFE_NO_TRUNCATION',0x00001000)
		win_const_mgr.add_const('DC_FILEDEPENDENCIES',0x0000000E)
		win_const_mgr.add_const('BTNS_WHOLEDROPDOWN',0x00000080)
		win_const_mgr.add_const('DDLOCK_OKTOSWAP',0x00002000)
		win_const_mgr.add_const('PORT_FTPDATA',0x00000014)
		win_const_mgr.add_const('DISPID_EVPROPS_COUNT',0x00000064)
		win_const_mgr.add_const('PAN_STROKE_GRADUAL_HORZ',0x00000005)
		win_const_mgr.add_const('SCARD_SHARE_DIRECT',0x00000003)
		win_const_mgr.add_const('VPDF_DISABLEPWRSTATUSPOLL',0x00000008)
		win_const_mgr.add_const('VIDCF_COMPRESSFRAMES',0x00000008)
		win_const_mgr.add_const('MCI_VD_STEP_FRAMES',0x00010000)
		win_const_mgr.add_const('IDM_HTMLCONTAIN',0x0000086F)
		win_const_mgr.add_const('USN_REASON_NAMED_DATA_TRUNCATION',0x00000040)
		win_const_mgr.add_const('IDI_SHIELD',0x00007F06)
		win_const_mgr.add_const('GC_WCH_FSELECTED',0x40000000)
		win_const_mgr.add_const('MIB_IF_ADMIN_STATUS_TESTING',0x00000003)
		win_const_mgr.add_const('BCRYPT_ECDSA_PRIVATE_P384_MAGIC',0x34534345)
		win_const_mgr.add_const('SCS_WOW_BINARY',0x00000002)
		win_const_mgr.add_const('ENUM_TYPE_VERSION',0x00000300)
		win_const_mgr.add_const('IRLMP_EXCLUSIVE_MODE',0x00000014)
		win_const_mgr.add_const('URLMON_OPTION_USE_BINDSTRINGCREDS',0x10000008)
		win_const_mgr.add_const('PRF_ERASEBKGND',0x00000008)
		win_const_mgr.add_const('SQL_SSF_TRIM_TRAILING',0x00000080)
		win_const_mgr.add_const('ERROR_SET_POWER_STATE_FAILED',0x00000475)
		win_const_mgr.add_const('SL_MSCH_ZONE',0x0000C000)
		win_const_mgr.add_const('VER_PRODUCTMAJORVERSION',0x00000006)
		win_const_mgr.add_const('RTCRMF_PRESENCE_ROAMING',0x00000004)
		win_const_mgr.add_const('OID_GEN_GET_NETCARD_TIME',0x00020210)
		win_const_mgr.add_const('NABTS_BYTES_PER_LINE',0x00000024)
		win_const_mgr.add_const('SSPROP_FASTLOADOPTIONS',0x00000009)
		win_const_mgr.add_const('DMPAPER_FANFOLD_STD_GERMAN',0x00000028)
		win_const_mgr.add_const('D3DUSAGE_DEPTHSTENCIL',0x00000002)
		win_const_mgr.add_const('ERROR_CANNOT_LOAD_REGISTRY_FILE',0x0000024D)
		win_const_mgr.add_const('HTTP_STATUS_BAD_GATEWAY',0x000001F6)
		win_const_mgr.add_const('CONNECT_COMMANDLINE',0x00000800)
		win_const_mgr.add_const('DXVA_INVERSE_QUANTIZATION_MATRIX_BUFFER',0x00000005)
		win_const_mgr.add_const('BSM_VXDS',0x00000001)
		win_const_mgr.add_const('IO_ALIAS_12_BIT_DECODE',0x00000010)
		win_const_mgr.add_const('MD_WARNING_PATH_NOT_INSERTED',0x000CC807)
		win_const_mgr.add_const('SQL_ATTR_CONNECTION_TIMEOUT',0x00000071)
		win_const_mgr.add_const('PHONEERR_INUSE',0x90000006)
		win_const_mgr.add_const('CAUSE_DESTINATION_OUT_OF_ORDER',0x0000001B)
		win_const_mgr.add_const('MKF_MOUSEMODE',0x80000000)
		win_const_mgr.add_const('MCI_ANIM_WINDOW_DEFAULT',0x00000000)
		win_const_mgr.add_const('FILE_NOTIFY_CHANGE_SIZE',0x00000008)
		win_const_mgr.add_const('CMC_STATUS_SUCCESS',0x00000000)
		win_const_mgr.add_const('WIA_DPC_EFFECT_MODE',0x0000081D)
		win_const_mgr.add_const('STI_TRACE_ERROR',0x00000004)
		win_const_mgr.add_const('LDAP_SCOPE_ONELEVEL',0x00000001)
		win_const_mgr.add_const('ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND',0x00003AB9)
		win_const_mgr.add_const('D3DVTXPCAPS_TEXGEN',0x00000001)
		win_const_mgr.add_const('SQL_FN_STR_REPLACE',0x00000100)
		win_const_mgr.add_const('BCRYPT_ECDSA_PUBLIC_P384_MAGIC',0x33534345)
		win_const_mgr.add_const('KS_VBICAP_PROTECTION_MV_HARDWARE',0x00000002)
		win_const_mgr.add_const('ERROR_SEEK_ON_DEVICE',0x00000084)
		win_const_mgr.add_const('MD_CERT_NO_REVOC_CHECK',0x00000001)
		win_const_mgr.add_const('LINETRANSLATEOPTION_FORCELOCAL',0x00000004)
		win_const_mgr.add_const('DTBG_DRAWSOLID',0x00000002)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_DEFAULT_FILTER_USERS',0x00000040)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME3',0x00000024)
		win_const_mgr.add_const('TVE_COLLAPSERESET',0x00008000)
		win_const_mgr.add_const('IME_RS_SYSTEMMODAL',0x00000013)
		win_const_mgr.add_const('SQL_OAC_LEVEL1',0x00000001)
		win_const_mgr.add_const('SQL_FN_TD_DAYOFWEEK',0x00000008)
		win_const_mgr.add_const('PROPID_PC_BASE',0x000016A8)
		win_const_mgr.add_const('SQL_OAC_LEVEL2',0x00000002)
		win_const_mgr.add_const('DNS_TYPE_EID',0x00000001)
		win_const_mgr.add_const('CERT_CREATE_CONTEXT_NOCOPY_FLAG',0x00000001)
		win_const_mgr.add_const('LINEERR_NOCONFERENCE',0x80000041)
		win_const_mgr.add_const('ERROR_PROCESS_MODE_NOT_BACKGROUND',0x00000193)
		win_const_mgr.add_const('SAFER_POLICY_UIFLAGS_INFORMATION_PROMPT',0x00000001)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME6',0x00000027)
		win_const_mgr.add_const('IDM_BEGINUSERACTION',0x00000980)
		win_const_mgr.add_const('TMT_MINDPI4',0x00000977)
		win_const_mgr.add_const('KP_PUB_EX_LEN',0x0000001C)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME7',0x00000028)
		win_const_mgr.add_const('SAPI_ERROR_BASE',0x00005000)
		win_const_mgr.add_const('WIA_DATA_RAW_CMY',0x0000000A)
		win_const_mgr.add_const('PSBTN_NEXT',0x00000001)
		win_const_mgr.add_const('ERROR_RECEIVE_PARTIAL_EXPEDITED',0x000002C5)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_SENT',0x00000020)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGCLOSE',0x0000001B)
		win_const_mgr.add_const('FLAGS_ERROR_UI_FILTER_FOR_ERRORS',0x00000001)
		win_const_mgr.add_const('TMT_MINDPI3',0x00000976)
		win_const_mgr.add_const('DDSCAPS_RESERVED1',0x00000001)
		win_const_mgr.add_const('CR_FAILURE',0x00000013)
		win_const_mgr.add_const('DDSCAPS_RESERVED3',0x00000400)
		win_const_mgr.add_const('CM_REGISTRY_USER',0x00000100)
		win_const_mgr.add_const('QITIPF_DEFAULT',0x00000000)
		win_const_mgr.add_const('MAXLONG',0x00000007)
		win_const_mgr.add_const('IDM_REMOVEPARAFORMAT',0x000008CD)
		win_const_mgr.add_const('PORT_METAGRAM',0x00000063)
		win_const_mgr.add_const('IDC_UL_METER',0x00000405)
		win_const_mgr.add_const('SMC_NEWITEM',0x00000017)
		win_const_mgr.add_const('CRL_REASON_CESSATION_OF_OPERATION',0x00000005)
		win_const_mgr.add_const('SDP_ATTRIB_PROFILE_SPECIFIC',0x00000200)
		win_const_mgr.add_const('SHFMT_OPT_FULL',0x00000001)
		win_const_mgr.add_const('TSF_USE_FULL_ACCESS',0x00000040)
		win_const_mgr.add_const('ERROR_RESMON_CREATE_FAILED',0x00001399)
		win_const_mgr.add_const('CERT_LDAP_STORE_AREC_EXCLUSIVE_FLAG',0x00020000)
		win_const_mgr.add_const('SCARD_E_CANCELLED',0x80100002)
		win_const_mgr.add_const('LINEERR_INVALREQUESTMODE',0x80000038)
		win_const_mgr.add_const('VIEW_PRIORITY_USEASDEFAULT',0x00000043)
		win_const_mgr.add_const('PROXY_TYPE_PROXY',0x00000002)
		win_const_mgr.add_const('FLG_DELREG_VALUE',0x00000000)
		win_const_mgr.add_const('DXVA_EXECUTE_RETURN_DATA_ERROR_MINOR',0x00000001)
		win_const_mgr.add_const('CSIDL_FONTS',0x00000014)
		win_const_mgr.add_const('MCI_DGV_SAVE_ABORT',0x00020000)
		win_const_mgr.add_const('TSPI_PROC_BASE',0x000001F4)
		win_const_mgr.add_const('VER_ERR_EXCEP_NUM_2',0x00000020)
		win_const_mgr.add_const('DNS_CLASS_INTERNET',0x00000001)
		win_const_mgr.add_const('PRINTER_STATUS_WAITING',0x00002000)
		win_const_mgr.add_const('PORT_OSUNMS',0x000000C0)
		win_const_mgr.add_const('WM_MOUSELEAVE',0x000002A3)
		win_const_mgr.add_const('SCRIPTSTAT_INSTRUCTION_COUNT',0x00000002)
		win_const_mgr.add_const('LVNI_SAMEGROUPONLY',0x00000080)
		win_const_mgr.add_const('PSF_SELECTPASTE',0x00000002)
		win_const_mgr.add_const('PLATFORM_ID_OSF',0x00000258)
		win_const_mgr.add_const('LVFIF_TEXT',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_MIPS_GPREL',0x00000006)
		win_const_mgr.add_const('TXTLOG_DEPTH_DECR',0x00040000)
		win_const_mgr.add_const('AM_DVD_NOT_COPYRIGHTED',0x00000000)
		win_const_mgr.add_const('SW_SHOWDEFAULT',0x0000000A)
		win_const_mgr.add_const('SP_PROT_SSL2_SERVER',0x00000004)
		win_const_mgr.add_const('DDENUMSURFACES_CANBECREATED',0x00000008)
		win_const_mgr.add_const('VHDR_INQUEUE',0x00000004)
		win_const_mgr.add_const('PORT_RFILE',0x000002EE)
		win_const_mgr.add_const('ACMDRIVERDETAILS_SUPPORTF_HARDWARE',0x00000008)
		win_const_mgr.add_const('BG_E_ERROR_CONTEXT_REMOTE_FILE',0x8020000A)
		win_const_mgr.add_const('RTCSI_APPLICATION',0x00000020)
		win_const_mgr.add_const('SYMOPT_FAVOR_COMPRESSED',0x00800000)
		win_const_mgr.add_const('REG_QWORD_LITTLE_ENDIAN',0x0000000B)
		win_const_mgr.add_const('BAUD_1800',0x00000080)
		win_const_mgr.add_const('MSV1_0_TRY_SPECIFIED_DOMAIN_ONLY',0x00000400)
		win_const_mgr.add_const('ERROR_SYSTEM_SHUTDOWN',0x00000281)
		win_const_mgr.add_const('ALINF_UPDHLPDLLS',0x00000010)
		win_const_mgr.add_const('SQL_CCS_COLLATE_CLAUSE',0x00000002)
		win_const_mgr.add_const('HAL_RID',0x00000002)
		win_const_mgr.add_const('MCS_SHORTDAYSOFWEEK',0x00000080)
		win_const_mgr.add_const('WIA_IPS_ORIENTATION',0x0000180C)
		win_const_mgr.add_const('CRL_FIND_ISSUED_BY_BASE_FLAG',0x00000008)
		win_const_mgr.add_const('IDABORT',0x00000003)
		win_const_mgr.add_const('NDIS_802_11_AUTH_REQUEST_AUTH_FIELDS',0x00000000)
		win_const_mgr.add_const('CB_GETCOUNT',0x00000146)
		win_const_mgr.add_const('SQL_CB_DELETE',0x00000000)
		win_const_mgr.add_const('CRL_REASON_REMOVE_FROM_CRL',0x00000008)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_IS_SCHEDULE_HASHING_ENABLED',0x00000001)
		win_const_mgr.add_const('CRYPT_MODE_OFBP',0x00000008)
		win_const_mgr.add_const('ERROR_QUORUMLOG_OPEN_FAILED',0x000013A4)
		win_const_mgr.add_const('IMGDECODE_EVENT_PALETTE',0x00000002)
		win_const_mgr.add_const('TRUST_TYPE_MIT',0x00000003)
		win_const_mgr.add_const('SQL_FN_TD_CURRENT_TIME',0x00040000)
		win_const_mgr.add_const('PPP_CCP_COMPRESSION',0x00000001)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MINFLINEAR',0x00000200)
		win_const_mgr.add_const('MC_CAPS_CONTRAST',0x00000004)
		win_const_mgr.add_const('PRINTER_ENUM_REMOTE',0x00000010)
		win_const_mgr.add_const('LOCALE_IDEFAULTMACCODEPAGE',0x00001011)
		win_const_mgr.add_const('PSD_ENABLEPAGEPAINTHOOK',0x00040000)
		win_const_mgr.add_const('SQL_AF_MAX',0x00000004)
		win_const_mgr.add_const('NDIS_MAC_OPTION_TRANSFERS_NOT_PEND',0x00000004)
		win_const_mgr.add_const('DXVA_BIDIRECTIONAL_AVERAGING_MPEG2_ROUND',0x00000000)
		win_const_mgr.add_const('BLLI_L3_PACKET_512',0x00000009)
		win_const_mgr.add_const('CTRY_COLOMBIA',0x00000039)
		win_const_mgr.add_const('CAL_SABBREVDAYNAME5',0x00000012)
		win_const_mgr.add_const('PSINJECT_PAGEORDER',0x00000007)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_CONNECTING',0x00000004)
		win_const_mgr.add_const('BTH_ERROR_REMOTE_USER_ENDED_CONNECTION',0x00000013)
		win_const_mgr.add_const('AUDIO_CHANNELCOUNT_MONO',0x00000001)
		win_const_mgr.add_const('IITWBC_BREAKTYPE_DATE',0x00000002)
		win_const_mgr.add_const('URLPOLICY_QUERY',0x00000001)
		win_const_mgr.add_const('SQL_CA1_POSITIONED_DELETE',0x00004000)
		win_const_mgr.add_const('SHFMT_OPT_SYSONLY',0x00000002)
		win_const_mgr.add_const('DSOP_FILTER_DOMAIN_LOCAL_GROUPS_DL',0x00000100)
		win_const_mgr.add_const('CTRY_BELARUS',0x00000177)
		win_const_mgr.add_const('LINEREQUESTMODE_DROP',0x00000004)
		win_const_mgr.add_const('SMC_GETOBJECT',0x00000007)
		win_const_mgr.add_const('DDSCAPS2_D3DTEXTUREMANAGE',0x00020000)
		win_const_mgr.add_const('SHGFI_USEFILEATTRIBUTES',0x00000010)
		win_const_mgr.add_const('OID_802_5_CURRENT_RING_STATUS',0x02010106)
		win_const_mgr.add_const('PORT_PCSERVER',0x00000258)
		win_const_mgr.add_const('ERROR_SHARING_PAUSED',0x00000046)
		win_const_mgr.add_const('HTTP_QUERY_URI',0x0000000D)
		win_const_mgr.add_const('ERROR_BAD_UNIT',0x00000014)
		win_const_mgr.add_const('FILE_BEGIN',0x00000000)
		win_const_mgr.add_const('WCS_ALWAYS',0x00200000)
		win_const_mgr.add_const('DISPID_SYNCHRONIZE',0x00000005)
		win_const_mgr.add_const('ALG_SID_HMAC',0x00000009)
		win_const_mgr.add_const('FORMAT_MESSAGE_FROM_STRING',0x00000400)
		win_const_mgr.add_const('FLG_ADDPROPERTY_OVERWRITEONLY',0x00000002)
		win_const_mgr.add_const('PRIVATEOBJECT_CALLID',0x00000002)
		win_const_mgr.add_const('COLOR_NO_TRANSPARENT',0xFFFFFFFF)
		win_const_mgr.add_const('LB_MULTIPLEADDSTRING',0x000001B1)
		win_const_mgr.add_const('INDEX_GUID_ALIGNMENTLEVEL',0x00000003)
		win_const_mgr.add_const('BS_PATTERN8X8',0x00000007)
		win_const_mgr.add_const('IDS_CAP_NO_FRAME_CAP_ERROR',0x000001B2)
		win_const_mgr.add_const('CERT_TRUST_HAS_KEY_MATCH_ISSUER',0x00000002)
		win_const_mgr.add_const('RI_MOUSE_BUTTON_4_DOWN',0x00000040)
		win_const_mgr.add_const('CERT_NAME_URL_TYPE',0x00000007)
		win_const_mgr.add_const('SQL_DRIVER_NAME',0x00000006)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NO_PEER_CERT',0x00003617)
		win_const_mgr.add_const('WT_TRUSTDBDIALOG_WRITE_IEAK_STORE_FLAG',0x00000200)
		win_const_mgr.add_const('PARTITION_ENTRY_UNUSED',0x00000000)
		win_const_mgr.add_const('CO_S_LAST',0x000401FF)
		win_const_mgr.add_const('PIDSI_WORDCOUNT',0x00000000)
		win_const_mgr.add_const('SFVM_REMOVEOBJECT',0x00000006)
		win_const_mgr.add_const('INTERNET_OPTION_SOCKET_SEND_BUFFER_LENGTH',0x0000005E)
		win_const_mgr.add_const('GET_TAPE_DRIVE_INFORMATION',0x00000001)
		win_const_mgr.add_const('DEBUG_MANAGED_DISABLED',0x00000000)
		win_const_mgr.add_const('EC_OLE_EVENT',0x00000018)
		win_const_mgr.add_const('RGB_GAMMA_MIN',0x000009C4)
		win_const_mgr.add_const('USE_LOTS_OF_FORCE',0x00000002)
		win_const_mgr.add_const('PROTO_VENDOR_MS2',0x00003FFF)
		win_const_mgr.add_const('WINSTA_READATTRIBUTES',0x00000002)
		win_const_mgr.add_const('PROTO_VENDOR_MS0',0x00000000)
		win_const_mgr.add_const('PROTO_VENDOR_MS1',0x00000137)
		win_const_mgr.add_const('D3DFVF_NORMAL',0x00000010)
		win_const_mgr.add_const('OID_ATM_RCV_CELLS_DROPPED',0x08020103)
		win_const_mgr.add_const('DISPID_EXPLORERWINDOWREADY',0x000000DD)
		win_const_mgr.add_const('DBTYPE_SQLVARIANT',0x00000090)
		win_const_mgr.add_const('KEY_WOW64_32KEY',0x00000200)
		win_const_mgr.add_const('DIRID_USERPROFILE',0x00000035)
		win_const_mgr.add_const('REVISION_LENGTH',0x00000004)
		win_const_mgr.add_const('OID_TAPI_SET_STATUS_MESSAGES',0x07030122)
		win_const_mgr.add_const('DDPCAPS_PRIMARYSURFACELEFT',0x00000020)
		win_const_mgr.add_const('IF_TYPE_HYPERCHANNEL',0x0000000E)
		win_const_mgr.add_const('SC_DLG_NO_UI',0x00000002)
		win_const_mgr.add_const('NETINFO_DISKRED',0x00000004)
		win_const_mgr.add_const('ERROR_DS_DUP_MAPI_ID',0x000020BC)
		win_const_mgr.add_const('CMF_VERBSONLY',0x00000002)
		win_const_mgr.add_const('ERROR_CANNOT_COPY',0x0000010A)
		win_const_mgr.add_const('DMDITHER_ERRORDIFFUSION',0x00000005)
		win_const_mgr.add_const('MRINFO_TUNNEL_FLAG',0x00000001)
		win_const_mgr.add_const('MD_ERROR_SUB404_FILE_EXTENSION_DENIED',0x00000007)
		win_const_mgr.add_const('END_SYSTEM_CHANGE',0x00000065)
		win_const_mgr.add_const('GCPCLASS_POSTBOUNDRTL',0x00000010)
		win_const_mgr.add_const('DC_SMALLCAP',0x00000002)
		win_const_mgr.add_const('GET_FEATURE_FROM_THREAD',0x00000001)
		win_const_mgr.add_const('RI_MOUSE_BUTTON_5_DOWN',0x00000100)
		win_const_mgr.add_const('RPC_S_INVALID_STRING_UUID',0x000006A9)
		win_const_mgr.add_const('ERROR_SXS_SECTION_NOT_FOUND',0x000036B0)
		win_const_mgr.add_const('NCRYPT_OVERWRITE_KEY_FLAG',0x00000080)
		win_const_mgr.add_const('BLUETOOTH_MAX_PASSKEY_SIZE',0x00000010)
		win_const_mgr.add_const('SPLITSYM_EXTRACT_ALL',0x00000002)
		win_const_mgr.add_const('SEC_IMAGE',0x01000000)
		win_const_mgr.add_const('POLICY_LOOKUP_NAMES',0x00000800)
		win_const_mgr.add_const('SPSVCINST_DELETEEVENTLOGENTRY',0x00000004)
		win_const_mgr.add_const('KERB_ETYPE_DES_CBC_MD4',0x00000002)
		win_const_mgr.add_const('ALINF_DELAYREGISTEROCX',0x00000200)
		win_const_mgr.add_const('PDCAP_WAKE_FROM_D2_SUPPORTED',0x00000040)
		win_const_mgr.add_const('URL_APPLY_DEFAULT',0x00000001)
		win_const_mgr.add_const('DSOBJECT_READONLYPAGES',0x80000000)
		win_const_mgr.add_const('CROSS_CERT_DIST_POINT_ERR_INDEX_SHIFT',0x00000018)
		win_const_mgr.add_const('OPATH_TOK_EOF',0x00000000)
		win_const_mgr.add_const('MFASYNC_CALLBACK_QUEUE_STANDARD',0x00000001)
		win_const_mgr.add_const('CB_MAX_CAB_PATH',0x00000100)
		win_const_mgr.add_const('IF_TYPE_ESCON',0x00000049)
		win_const_mgr.add_const('ENABLE_MOUSE_INPUT',0x00000010)
		win_const_mgr.add_const('DISPID_VIEWPAINTDONE',0x000000D3)
		win_const_mgr.add_const('LINEERR_INVALPASSWORD',0x80000059)
		win_const_mgr.add_const('LGRPID_SIMPLIFIED_CHINESE',0x00000000)
		win_const_mgr.add_const('FMEVENT_SELCHANGE',0x00000068)
		win_const_mgr.add_const('MCI_VCR_STATUS_COUNTER_VALUE',0x00004013)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_SRVQUERYCRED',0x00003620)
		win_const_mgr.add_const('EVENT_SYSTEM_SCROLLINGEND',0x00000013)
		win_const_mgr.add_const('JOY_BUTTON1',0x00000001)
		win_const_mgr.add_const('JOY_BUTTON2',0x00000002)
		win_const_mgr.add_const('JOY_BUTTON3',0x00000004)
		win_const_mgr.add_const('JOY_BUTTON4',0x00000008)
		win_const_mgr.add_const('JOY_BUTTON5',0x00000010)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_FOCUS',0x00000486)
		win_const_mgr.add_const('JOY_BUTTON7',0x00000040)
		win_const_mgr.add_const('JOY_BUTTON8',0x00000080)
		win_const_mgr.add_const('JOY_BUTTON9',0x00000100)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SRC_RIGHT_S',0x00008021)
		win_const_mgr.add_const('USE_DOMAINNAME_PARMNUM',0x00000006)
		win_const_mgr.add_const('IDM_SETCUSTOMCURSOR',0x00000982)
		win_const_mgr.add_const('GD_FONTDIR',0x00000007)
		win_const_mgr.add_const('MIXERCONTROL_CT_SC_LIST_MULTIPLE',0x01000000)
		win_const_mgr.add_const('PRINTER_STATUS_BUSY',0x00000200)
		win_const_mgr.add_const('PHOTO_PHOTOMETRIC_RGB',0x00000002)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_SETTIMEOUT',0x00000494)
		win_const_mgr.add_const('SUBLANG_ARABIC_JORDAN',0x00000000)
		win_const_mgr.add_const('NUM_EISA_RANGES',0x00000004)
		win_const_mgr.add_const('PRIVATEOBJECT_LINE',0x00000003)
		win_const_mgr.add_const('CF_ENABLETEMPLATEHANDLE',0x00000020)
		win_const_mgr.add_const('DSSSF_DSAVAILABLE',0x80000000)
		win_const_mgr.add_const('SDP_ATTRIB_DOCUMENTATION_URL',0x0000000A)
		win_const_mgr.add_const('KSNODEPIN_DEMUX_OUT',0x00000001)
		win_const_mgr.add_const('EMO_EXPAND',0x00000003)
		win_const_mgr.add_const('SI_NETWORK',0x00000003)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_DEF_PEAK_RATE',0x00000019)
		win_const_mgr.add_const('SNMP_LOG_WARNING',0x00000003)
		win_const_mgr.add_const('SCRIPT_ENCODE_NO_ASP_LANGUAGE',0x00000002)
		win_const_mgr.add_const('SERIAL_IOC_FCR_XMIT_RESET',0x00000004)
		win_const_mgr.add_const('WLX_SAS_TYPE_SC_FIRST_READER_ARRIVED',0x00000008)
		win_const_mgr.add_const('HTTP_LOG_FIELD_VERSION',0x00080000)
		win_const_mgr.add_const('SECPKG_ATTR_SUPPORTED_PROTOCOLS',0x00000058)
		win_const_mgr.add_const('REQDISP_USEREQUESTATTRIBUTE',0x00000003)
		win_const_mgr.add_const('BTH_ERROR_INVALID_HCI_PARAMETER',0x00000012)
		win_const_mgr.add_const('JOY_RETURNRAWDATA',0x00000100)
		win_const_mgr.add_const('LINEMEDIAMODE_VOICEVIEW',0x00004000)
		win_const_mgr.add_const('DXVA_PICTURE_DECODING_FUNCTION',0x00000001)
		win_const_mgr.add_const('NRC_PENDING',0x00000000)
		win_const_mgr.add_const('HS_CROSS',0x00000004)
		win_const_mgr.add_const('CSA_DEF',0x00000003)
		win_const_mgr.add_const('ERROR_VOLSNAP_HIBERNATE_READY',0x000002F9)
		win_const_mgr.add_const('WMDRM_LICENSE_TYPE_XML',0x00000001)
		win_const_mgr.add_const('CSTR_GREATER_THAN',0x00000003)
		win_const_mgr.add_const('DISPID_SELECTIONCHANGED',0x000000C8)
		win_const_mgr.add_const('KP_KEYEXCHANGE_PIN',0x00000020)
		win_const_mgr.add_const('HTTP_RECEIVE_REQUEST_ENTITY_BODY_FLAG_FILL_BUFFER',0x00000001)
		win_const_mgr.add_const('FTPWPP_ERROR_LAST',0x400423FF)
		win_const_mgr.add_const('ES_DISPLAY_REQUIRED',0x00000002)
		win_const_mgr.add_const('SBARS_TOOLTIPS',0x00000800)
		win_const_mgr.add_const('RBBIM_HEADERSIZE',0x00000800)
		win_const_mgr.add_const('NETWORK_ALIVE_AOL',0x00000004)
		win_const_mgr.add_const('IMAGE_SCN_CNT_CODE',0x00000020)
		win_const_mgr.add_const('KSPIN_FLAG_DENY_USERMODE_ACCESS',0x80000000)
		win_const_mgr.add_const('ERROR_DATA_LOST_REPAIR',0x00001ABB)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_WCEMIPSV2',0x00000169)
		win_const_mgr.add_const('SQL_LOCK_TYPES',0x0000004E)
		win_const_mgr.add_const('CDERR_STRUCTSIZE',0x00000001)
		win_const_mgr.add_const('D3DTEXOPCAPS_MODULATE4X',0x00000020)
		win_const_mgr.add_const('DDSCAPS_3DDEVICE',0x00002000)
		win_const_mgr.add_const('AD_FLAG_BREAK_BIT',0x00000001)
		win_const_mgr.add_const('CBR_110',0x0000006E)
		win_const_mgr.add_const('ASC_RET_NO_TOKEN',0x01000000)
		win_const_mgr.add_const('BTH_ADDR_IAC_FIRST',0x009E8B00)
		win_const_mgr.add_const('RTM_ENUM_OWN_DESTS',0x01000000)
		win_const_mgr.add_const('HTTP_STATUS_NONE_ACCEPTABLE',0x00000196)
		win_const_mgr.add_const('MD_NOTIFY_SEND_RAW_DATA',0x00000400)
		win_const_mgr.add_const('TF_DISABLE_COMMANDING',0x00000004)
		win_const_mgr.add_const('DISABLE_CPL_FIX',0x00000006)
		win_const_mgr.add_const('ERROR_WAIT_63',0x000002DE)
		win_const_mgr.add_const('ERROR_DS_DRA_ABANDON_SYNC',0x0000210E)
		win_const_mgr.add_const('PROV_INTEL_SEC',0x00000016)
		win_const_mgr.add_const('IF_TYPE_ATM_IMA',0x0000006B)
		win_const_mgr.add_const('MDM_BEARERMODE_ANALOG',0x00000000)
		win_const_mgr.add_const('SCH_CRED_NO_SERVERNAME_CHECK',0x00000004)
		win_const_mgr.add_const('ERROR_CTX_SERVICE_NAME_COLLISION',0x00001B5E)
		win_const_mgr.add_const('SERVICE_STOP_REASON_FLAG_UNPLANNED',0x10000000)
		win_const_mgr.add_const('IDM_TRIED_SEND_TO_BACK',0x00000006)
		win_const_mgr.add_const('MCI_QUALITY_NAME',0x00020000)
		win_const_mgr.add_const('CM_DETECT_NEW_PROFILE',0x00000001)
		win_const_mgr.add_const('TRUSTERROR_STEP_FILEIO',0x00000002)
		win_const_mgr.add_const('SECPKG_OPTIONS_TYPE_SSPI',0x00000002)
		win_const_mgr.add_const('TF_MOD_CONTROL',0x00000002)
		win_const_mgr.add_const('PSR_AC',0x00000003)
		win_const_mgr.add_const('LINECALLPARTYID_BLOCKED',0x00000001)
		win_const_mgr.add_const('CERT_CHAIN_CACHE_ONLY_URL_RETRIEVAL',0x00000004)
		win_const_mgr.add_const('MM_JOY1BUTTONUP',0x000003B7)
		win_const_mgr.add_const('HTTP_STATUS_NOT_MODIFIED',0x00000130)
		win_const_mgr.add_const('SDP_ATTRIB_DI_PRODUCT_ID',0x00000202)
		win_const_mgr.add_const('PORT_CHSHELL',0x00000232)
		win_const_mgr.add_const('REPL_ROLE_BOTH',0x00000003)
		win_const_mgr.add_const('DFS_VOLUME_FLAVOR_STANDALONE',0x00000100)
		win_const_mgr.add_const('FOCUSMETERING_MULTISPOT',0x00000002)
		win_const_mgr.add_const('DFS_STORAGE_FLAVOR_UNUSED2',0x00000300)
		win_const_mgr.add_const('GOPHER_TYPE_SOUND',0x00010000)
		win_const_mgr.add_const('ALG_SID_3DES_112',0x00000009)
		win_const_mgr.add_const('URLPOLICY_LOG_ON_DISALLOW',0x00000080)
		win_const_mgr.add_const('CAL_SSHORTESTDAYNAME4',0x00000034)
		win_const_mgr.add_const('CAL_SSHORTESTDAYNAME5',0x00000035)
		win_const_mgr.add_const('CAL_SSHORTESTDAYNAME6',0x00000036)
		win_const_mgr.add_const('CAL_SSHORTESTDAYNAME7',0x00000037)
		win_const_mgr.add_const('IDM_DELETEWORD',0x0000005C)
		win_const_mgr.add_const('CAL_SSHORTESTDAYNAME1',0x00000031)
		win_const_mgr.add_const('REPLACE_ALTERNATE',0x0000000B)
		win_const_mgr.add_const('DRM_AL_CANCEL',0x00000004)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_LOCATION',0x0000000E)
		win_const_mgr.add_const('KSPROPERTY_MEMBER_FLAG_BASICSUPPORT_MULTICHANNEL',0x00000002)
		win_const_mgr.add_const('STATEBITS_FLAT',0x00000001)
		win_const_mgr.add_const('HTTP_QUERY_EXPIRES',0x0000000A)
		win_const_mgr.add_const('MEM_COMMIT',0x00001000)
		win_const_mgr.add_const('DMBIN_LOWER',0x00000002)
		win_const_mgr.add_const('USE_PAUSED',0x00000001)
		win_const_mgr.add_const('WIA_IPA_ACCESS_RIGHTS',0x00001006)
		win_const_mgr.add_const('SBSP_FEEDNAVIGATION',0x20000000)
		win_const_mgr.add_const('D3DCOMPOSERECTS_MAXNUMRECTS',0x0000FFFF)
		win_const_mgr.add_const('MCMV_YEAR',0x00000001)
		win_const_mgr.add_const('INTERNET_STATUS_CONNECTING_TO_SERVER',0x00000014)
		win_const_mgr.add_const('USER_PRIV_MASK',0x00000003)
		win_const_mgr.add_const('MIDIPROP_GET',0x40000000)
		win_const_mgr.add_const('CRYPT_OWF_REPL_LM_HASH',0x00000001)
		win_const_mgr.add_const('SSF_NONETCRAWLING',0x00100000)
		win_const_mgr.add_const('DN_MAXALIASL',0x00000080)
		win_const_mgr.add_const('DNS_RTYPE_AAAA',0x00000001)
		win_const_mgr.add_const('X3_TMPLT_SIZE_X',0x00000004)
		win_const_mgr.add_const('INTERNET_OPTION_BYPASS_EDITED_ENTRY',0x00000040)
		win_const_mgr.add_const('CERT_BIOMETRIC_SIGNATURE_TYPE',0x00000001)
		win_const_mgr.add_const('TF_IPP_FLAG_SUBSTITUTEDBYINPUTPROCESSOR',0x00000004)
		win_const_mgr.add_const('ERRACT_PANIC',0x00000005)
		win_const_mgr.add_const('OBM_REDUCE',0x00007FED)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_IS_TOPL_MIN_HOPS_DISABLED',0x00000001)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_CONNECTION_CLOSED',0x00000200)
		win_const_mgr.add_const('SPSVCINST_STARTSERVICE',0x00000800)
		win_const_mgr.add_const('CM_GET_DEVICE_INTERFACE_LIST_PRESENT',0x00000000)
		win_const_mgr.add_const('ATMPROTO_AAL5',0x00000005)
		win_const_mgr.add_const('NDIS_WMI_METHOD_HEADER_REVISION_1',0x00000001)
		win_const_mgr.add_const('FILE_DEVICE_INFINIBAND',0x0000003B)
		win_const_mgr.add_const('FL_UFI_DESIGNVECTOR_PFF',0x00000002)
		win_const_mgr.add_const('HTTP_QUERY_VIA',0x00000042)
		win_const_mgr.add_const('TAPE_DRIVE_RELATIVE_BLKS',0x80020000)
		win_const_mgr.add_const('TRACELOG_CREATE_ONDISK',0x00000040)
		win_const_mgr.add_const('D3DSTENCILCAPS_DECR',0x00000080)
		win_const_mgr.add_const('ERROR_DS_BAD_NAME_SYNTAX',0x0000208F)
		win_const_mgr.add_const('FLG_INI2REG_32BITKEY',0x00004000)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_HOTFIX',0x00000011)
		win_const_mgr.add_const('PSINJECT_ENDPAGESETUP',0x00000066)
		win_const_mgr.add_const('KSDSOUND_BUFFER_PRIMARY',0x00000001)
		win_const_mgr.add_const('AT_KEYEXCHANGE',0x00000001)
		win_const_mgr.add_const('KEY_LENGTH_MASK',0xFFFF0000)
		win_const_mgr.add_const('MIIM_ID',0x00000002)
		win_const_mgr.add_const('ETO_NUMERICSLATIN',0x00000800)
		win_const_mgr.add_const('DISK_LOGGING_STOP',0x00000001)
		win_const_mgr.add_const('BS_LEFT',0x00000100)
		win_const_mgr.add_const('KS_NABTS_GROUPID_TELEVISION_STATION_ADVERTISER_BASE',0x00000890)
		win_const_mgr.add_const('FCSM_VIEWID',0x00000001)
		win_const_mgr.add_const('OPATH_TOK_SINGLETON_SYM',0x0000006C)
		win_const_mgr.add_const('FACILITY_PINT_STATUS_CODE',0x000000F0)
		win_const_mgr.add_const('IN4ADDR_LOOPBACKPREFIX_LENGTH',0x00000008)
		win_const_mgr.add_const('MFBYTESTREAM_IS_WRITABLE',0x00000002)
		win_const_mgr.add_const('SM_REMOTESESSION',0x00001000)
		win_const_mgr.add_const('FAULT_INVALID_SEQUENCE_NUMBER',0x00000193)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_NAME',0x0000000B)
		win_const_mgr.add_const('RPC_C_AUTHN_GSS_NEGOTIATE',0x00000009)
		win_const_mgr.add_const('TMT_INACTIVECAPTIONTEXT',0x00000654)
		win_const_mgr.add_const('CONTEXT_MENU_ANCHOR',0x00000005)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_COLOR',0x00004001)
		win_const_mgr.add_const('STDPROP_INDEX_BREAK',0x000000CC)
		win_const_mgr.add_const('POSTSCRIPT_INJECTION',0x00001016)
		win_const_mgr.add_const('TRACE_HEADER_FLAG_USE_TIMESTAMP',0x00000200)
		win_const_mgr.add_const('PDCAP_WAKE_FROM_S2_SUPPORTED',0x00400000)
		win_const_mgr.add_const('LANG_NORWEGIAN',0x00000014)
		win_const_mgr.add_const('PRP',0x00000080)
		win_const_mgr.add_const('ODBC_VS_FLAG_UNICODE_ARG',0x00000001)
		win_const_mgr.add_const('WM_MENUDRAG',0x00000123)
		win_const_mgr.add_const('SECPKG_ATTR_NAMES',0x00000001)
		win_const_mgr.add_const('DDF_0001',0x00000001)
		win_const_mgr.add_const('D3DCREATE_NOWINDOWCHANGES',0x00000800)
		win_const_mgr.add_const('ACMFORMATCHOOSE_STYLEF_ENABLETEMPLATEHANDLE',0x00000020)
		win_const_mgr.add_const('NETLOGON_CONTROL_TRUNCATE_LOG',0x0000FFFD)
		win_const_mgr.add_const('ISR_UI_TRAP',0x00000004)
		win_const_mgr.add_const('IME_ESC_RESERVED_LAST',0x000007FF)
		win_const_mgr.add_const('ERROR_TRANSACTION_NOT_REQUESTED',0x00001A2F)
		win_const_mgr.add_const('DESKTOPHORZRES',0x00000076)
		win_const_mgr.add_const('IMGLOAD_NOTLOADED',0x00100000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGSETINFORMATION',0x00000014)
		win_const_mgr.add_const('KSPROPERTY_TYPE_SERIALIZESET',0x00000800)
		win_const_mgr.add_const('IME_RS_ILLEGAL',0x00000006)
		win_const_mgr.add_const('CS_DISABLE',0x00000002)
		win_const_mgr.add_const('SQL_DESC_ARRAY_SIZE',0x00000014)
		win_const_mgr.add_const('IDM_CELLINSERT',0x0000089A)
		win_const_mgr.add_const('SM_FOCUS_TYPE_UNKNOWN_DOMAIN',0x00000003)
		win_const_mgr.add_const('SQL_INFO_SCHEMA_VIEWS',0x00000095)
		win_const_mgr.add_const('DISPID_FILELISTENUMDONE',0x000000C9)
		win_const_mgr.add_const('DBPROPVAL_IN_DISALLOWNULL',0x00000001)
		win_const_mgr.add_const('PP_PROVTYPE',0x00000010)
		win_const_mgr.add_const('SERVICE_PAUSE_PENDING',0x00000006)
		win_const_mgr.add_const('MWMO_WAITALL',0x00000001)
		win_const_mgr.add_const('PIR_STATUS_ERROR',0x00000000)
		win_const_mgr.add_const('ERROR_DS_NO_DELETED_NAME',0x000020A3)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_KEEPPRINTEDJOBS',0x00000100)
		win_const_mgr.add_const('WTPF_ALLOWONLYPERTRUST',0x00040000)
		win_const_mgr.add_const('DFC_MENU',0x00000002)
		win_const_mgr.add_const('VIEW_E_FIRST',0x80040140)
		win_const_mgr.add_const('NDIS_OFFLOAD_SET_OFF',0x00000002)
		win_const_mgr.add_const('TME_QUERY',0x40000000)
		win_const_mgr.add_const('SYMOPT_INCLUDE_32BIT_MODULES',0x00002000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_SETCALLINGID',0x20000000)
		win_const_mgr.add_const('IDF_CHECKFIRST',0x00000100)
		win_const_mgr.add_const('APPCOMMAND_SEND_MAIL',0x00000029)
		win_const_mgr.add_const('TAPE_SPACE_SEQUENTIAL_SMKS',0x00000009)
		win_const_mgr.add_const('FWPM_CONTEXT_RPC_AUDIT_ENABLED',0x00000001)
		win_const_mgr.add_const('NETSETUP_INSTALL_INVOCATION',0x00040000)
		win_const_mgr.add_const('SFC_SCAN_ALWAYS',0x00000001)
		win_const_mgr.add_const('ERROR_HOST_UNREACHABLE',0x000004D0)
		win_const_mgr.add_const('SUF_BATCHINF',0x00000004)
		win_const_mgr.add_const('ERROR_ONLY_IF_CONNECTED',0x000004E3)
		win_const_mgr.add_const('VER_PRODUCTMINORVERSION',0x00000000)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_SETINTERVAL',0x00000495)
		win_const_mgr.add_const('EVENT_MIN',0x00000001)
		win_const_mgr.add_const('LANG_SYRIAC',0x00000005)
		win_const_mgr.add_const('CPF_MANUAL',0x00000040)
		win_const_mgr.add_const('OLEOBJ_E_FIRST',0x80040180)
		win_const_mgr.add_const('OID_ATM_DIGITAL_BROADCAST_VPIVCI',0x08010206)
		win_const_mgr.add_const('IPX_STANDARD_PACKET_TYPE',0x00000001)
		win_const_mgr.add_const('RTM_CHANGE_TYPE_ALL',0x00000001)
		win_const_mgr.add_const('VIDEO_EXTERNALIN',0x00000001)
		win_const_mgr.add_const('FNERR_INVALIDFILENAME',0x00003002)
		win_const_mgr.add_const('BTH_ERROR_UNKNOWN_HCI_COMMAND',0x00000001)
		win_const_mgr.add_const('ERROR_PRINTER_DRIVER_PACKAGE_IN_USE',0x00000BC7)
		win_const_mgr.add_const('DIF_DESTROYWIZARDDATA',0x00000011)
		win_const_mgr.add_const('TVS_EX_DOUBLEBUFFER',0x00000004)
		win_const_mgr.add_const('IPX_ADAPTER_INFO_TYPE',0x00000007)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2ERASE_RECORDER',0x00000100)
		win_const_mgr.add_const('DNS_TYPE_PX',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLSETDESCFIELD',0x000003F9)
		win_const_mgr.add_const('ABM_QUERYPOS',0x00000002)
		win_const_mgr.add_const('PORT_SURMEAS',0x000000F3)
		win_const_mgr.add_const('USER_LAST_LOGON_PARMNUM',0x0000000F)
		win_const_mgr.add_const('PLATFORM_ID_DOS',0x0000012C)
		win_const_mgr.add_const('EVENTLOG_SEQUENTIAL_READ',0x00000001)
		win_const_mgr.add_const('OID_GEN_MAX_LINK_SPEED',0x00010206)
		win_const_mgr.add_const('VP_CP_TYPE_MACROVISION',0x00000002)
		win_const_mgr.add_const('SECPKG_CALL_ANSI',0x00000002)
		win_const_mgr.add_const('SM_CYMAXTRACK',0x0000003C)
		win_const_mgr.add_const('OPATH_TOK_COLON',0x0000006F)
		win_const_mgr.add_const('INTERNET_MAX_HOST_NAME_LENGTH',0x00000100)
		win_const_mgr.add_const('WIA_PAGE_ISO_B7',0x00000018)
		win_const_mgr.add_const('SVAUD_USERLIST',0x00002000)
		win_const_mgr.add_const('WIA_PAGE_ISO_B5',0x00000016)
		win_const_mgr.add_const('SQL_HANDLE_ENV',0x00000001)
		win_const_mgr.add_const('XP_BANDWIDTH_ALLOCATION',0x00000800)
		win_const_mgr.add_const('WIA_PAGE_ISO_B2',0x00000013)
		win_const_mgr.add_const('WIA_PAGE_ISO_B1',0x00000012)
		win_const_mgr.add_const('WIA_PAGE_ISO_B0',0x00000011)
		win_const_mgr.add_const('D3DPS20_MAX_STATICFLOWCONTROLDEPTH',0x00000004)
		win_const_mgr.add_const('LF32_MOVEABLE',0x00000004)
		win_const_mgr.add_const('DBG_TOOLHELP',0x0000000F)
		win_const_mgr.add_const('WIA_PAGE_ISO_B9',0x0000001A)
		win_const_mgr.add_const('CQPM_INITIALIZE',0x00000001)
		win_const_mgr.add_const('MCI_VCR_FREEZE_INPUT',0x00010000)
		win_const_mgr.add_const('ECOOP_SET',0x00000001)
		win_const_mgr.add_const('MF_RIGHTJUSTIFY',0x00004000)
		win_const_mgr.add_const('MIXERCONTROL_CT_UNITS_PERCENT',0x00050000)
		win_const_mgr.add_const('RTCSI_PHONE_TO_PHONE',0x00000004)
		win_const_mgr.add_const('HTTP_INITIALIZE_SERVER',0x00000001)
		win_const_mgr.add_const('DEBUG_STATUS_STEP_BRANCH',0x00000008)
		win_const_mgr.add_const('TMRESUME',0x08000000)
		win_const_mgr.add_const('PORT_STATUS_TYPE_WARNING',0x00000002)
		win_const_mgr.add_const('STG_TOEND',0xFFFFFFFF)
		win_const_mgr.add_const('DRIVER_HARDWAREID_MASK',0x80000FFF)
		win_const_mgr.add_const('PRINTER_NOTIFY_TYPE',0x00000000)
		win_const_mgr.add_const('D3DPBLENDCAPS_INVSRCCOLOR',0x00000008)
		win_const_mgr.add_const('CRED_TI_DOMAIN_FORMAT_UNKNOWN',0x00000002)
		win_const_mgr.add_const('WPC_SETTINGS_MODIFY',0x00000015)
		win_const_mgr.add_const('DELFLG_IN_USE',0x00000001)
		win_const_mgr.add_const('COPYFILE_SIS_LINK',0x00000001)
		win_const_mgr.add_const('NCRYPT_MAX_PROPERTY_DATA',0x00100000)
		win_const_mgr.add_const('CMSG_ENVELOPED_FLAG',0x00000001)
		win_const_mgr.add_const('HTTP_LOG_FIELD_SITE_NAME',0x00000010)
		win_const_mgr.add_const('CDO_E_NO_DIRECTORIES_SPECIFIED',0x80040231)
		win_const_mgr.add_const('MCI_OVLY_WINDOW_HWND',0x00010000)
		win_const_mgr.add_const('OFN_HIDEREADONLY',0x00000004)
		win_const_mgr.add_const('SERIAL_IOC_FCR_FIFO_ENABLE',0x00000001)
		win_const_mgr.add_const('KAGPROP_NUMERICFUNCTIONS',0x00000011)
		win_const_mgr.add_const('SETDTR',0x00000005)
		win_const_mgr.add_const('BG_E_INVALID_SERVER_RESPONSE',0x8020001B)
		win_const_mgr.add_const('SQL_SCROLLABLE',0x00000001)
		win_const_mgr.add_const('MCI_DGV_STATUS_TINT',0x00004015)
		win_const_mgr.add_const('DC_PRINTERMEM',0x0000001C)
		win_const_mgr.add_const('MAX_REASON_NAME_LEN',0x00000040)
		win_const_mgr.add_const('CFM_STYLE',0x00080000)
		win_const_mgr.add_const('ERROR_SERVICE_DISABLED',0x00000422)
		win_const_mgr.add_const('LINEERR_INVALCALLCOMPLMODE',0x80000017)
		win_const_mgr.add_const('PDH_CSTATUS_NO_OBJECT',0xC0000BB8)
		win_const_mgr.add_const('STI_VERSION_FLAG_MASK',0x00000000)
		win_const_mgr.add_const('ERROR_PATCH_PACKAGE_UNSUPPORTED',0x00000665)
		win_const_mgr.add_const('CLUSCTL_ACCESS_MODE_MASK',0x00000003)
		win_const_mgr.add_const('DSPRINT_UNPUBLISH',0x00000004)
		win_const_mgr.add_const('SQL_AF_COUNT',0x00000002)
		win_const_mgr.add_const('INTERNET_IDENTITY_FLAG_CLEAR_COOKIES',0x00000008)
		win_const_mgr.add_const('AUXCAPS_VOLUME',0x00000001)
		win_const_mgr.add_const('SECURITY_DESCRIPTOR_REVISION1',0x00000001)
		win_const_mgr.add_const('GPO_FLAG_DISABLE',0x00000001)
		win_const_mgr.add_const('WMDM_RIGHTS_NAMEDSERIALIDS',0x00000010)
		win_const_mgr.add_const('LDAP_OPT_PING_KEEP_ALIVE',0x00000036)
		win_const_mgr.add_const('DS_KCC_FLAG_ASYNC_OP',0x00000001)
		win_const_mgr.add_const('IDS_FW',0x0001100B)
		win_const_mgr.add_const('SPI_GETCLIENTAREAANIMATION',0x00001042)
		win_const_mgr.add_const('ATSC_EIT_TID',0x000000CB)
		win_const_mgr.add_const('SQL_DESC_ALLOC_USER',0x00000002)
		win_const_mgr.add_const('PKCS12_EXPORT_RESERVED_MASK',0x00000000)
		win_const_mgr.add_const('MIXER_OBJECTF_WAVEIN',0x20000000)
		win_const_mgr.add_const('TF_LBI_CUSTOMUI',0x00000020)
		win_const_mgr.add_const('CRYPT_EXPORTABLE',0x00000001)
		win_const_mgr.add_const('KSPROPERTY_TYPE_RELATIONS',0x00000400)
		win_const_mgr.add_const('AVIIF_COMPUSE',0x0FFF0000)
		win_const_mgr.add_const('CM_SHOW_HELP',0x00000002)
		win_const_mgr.add_const('AEC_MODE_FULL_DUPLEX',0x00000002)
		win_const_mgr.add_const('RENDBIND_AUTHENTICATE',0x00000001)
		win_const_mgr.add_const('ICM_OFF',0x00000001)
		win_const_mgr.add_const('DISPID_NAVIGATOR',0x00000001)
		win_const_mgr.add_const('WM_GETDLGCODE',0x00000087)
		win_const_mgr.add_const('DNS_ERROR_UNSECURE_PACKET',0x00002521)
		win_const_mgr.add_const('IME_CHOTKEY_SYMBOL_TOGGLE',0x00000012)
		win_const_mgr.add_const('DI_CLASSINSTALLPARAMS',0x00100000)
		win_const_mgr.add_const('MSGF_NEXTWINDOW',0x00000006)
		win_const_mgr.add_const('MFASYNC_CALLBACK_QUEUE_PRIVATE_MASK',0xFFFF0000)
		win_const_mgr.add_const('CERT_SIMPLE_NAME_STR',0x00000001)
		win_const_mgr.add_const('MFS_GRAYED',0x00000003)
		win_const_mgr.add_const('MCI_WAVE_SET_ANYOUTPUT',0x08000000)
		win_const_mgr.add_const('SECPKG_CRED_ATTR_NAMES',0x00000001)
		win_const_mgr.add_const('RRF_NOEXPAND',0x10000000)
		win_const_mgr.add_const('ASYNC_RECO_SETFACTOID_FAILED',0x00000080)
		win_const_mgr.add_const('ACTRL_ACCESS_SUPPORTS_OBJECT_ENTRIES',0x00000001)
		win_const_mgr.add_const('AEC_STATUS_FD_HISTORY_CONTINUOUSLY_CONVERGED',0x00000001)
		win_const_mgr.add_const('IN4ADDR_LINKLOCALPREFIX_LENGTH',0x00000010)
		win_const_mgr.add_const('OID_FDDI_FRAMES_LOST',0x03020105)
		win_const_mgr.add_const('LINEERR_INVALCALLHANDLE',0x80000018)
		win_const_mgr.add_const('WMS_CONTAINER_FILESIZE_HI',0x0000000C)
		win_const_mgr.add_const('SQL_FD_FETCH_LAST',0x00000004)
		win_const_mgr.add_const('FACILITY_NS_WIN32',0x00000007)
		win_const_mgr.add_const('ERRACT_USER',0x00000003)
		win_const_mgr.add_const('SCARD_PROVIDER_KSP',0x00000003)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_EXITWINDOWS',0x00000080)
		win_const_mgr.add_const('PDH_UNABLE_MAP_NAME_FILES',0x80000BD5)
		win_const_mgr.add_const('CACHEGROUP_TYPE_INVALID',0x00000001)
		win_const_mgr.add_const('METHOD_BGP4_NEXTHOP_ATTR',0x00000008)
		win_const_mgr.add_const('ACM_FILTERTAGDETAILSF_QUERYMASK',0x0000000F)
		win_const_mgr.add_const('WIA_INTENT_IMAGE_TYPE_TEXT',0x00000004)
		win_const_mgr.add_const('SUBLANG_SLOVAK_SLOVAKIA',0x00000001)
		win_const_mgr.add_const('GESTURE_BRACKET_OVER',0x00000000)
		win_const_mgr.add_const('NDIS_DEVICE_WAKE_UP_ENABLE',0x00000001)
		win_const_mgr.add_const('OFN_FORCESHOWHIDDEN',0x10000000)
		win_const_mgr.add_const('SECPKG_FLAG_CLIENT_ONLY',0x00000040)
		win_const_mgr.add_const('DMPAPER_PENV_5_ROTATED',0x00000071)
		win_const_mgr.add_const('CDIS_NEARHOT',0x00000400)
		win_const_mgr.add_const('CRYPT_SF',0x00000100)
		win_const_mgr.add_const('KSEVENT_TYPE_TOPOLOGY',0x10000000)
		win_const_mgr.add_const('DBPROP_CLIENT_CLSID',0x00000003)
		win_const_mgr.add_const('HCBT_ACTIVATE',0x00000005)
		win_const_mgr.add_const('SNMPAPI_TL_IN_USE',0x0000006B)
		win_const_mgr.add_const('_WIN32_IE_IE501',0x00000501)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_PROVIDER_TYPES',0x00000002)
		win_const_mgr.add_const('ERROR_SEVERITY_ERROR',0xC0000000)
		win_const_mgr.add_const('IMAGE_REL_IA64_DIR32',0x00000004)
		win_const_mgr.add_const('CM_SHOW_HELPICON',0x00000004)
		win_const_mgr.add_const('GLOBAL_WAN_ROUTE',0x00000001)
		win_const_mgr.add_const('LINETERMSHARING_SHAREDCONF',0x00000004)
		win_const_mgr.add_const('MCI_VCR_LIST_COUNT',0x00040000)
		win_const_mgr.add_const('CRYPT_KEK',0x00000400)
		win_const_mgr.add_const('SECURITY_SERVICE_ID_BASE_RID',0x00000050)
		win_const_mgr.add_const('XP1_GUARANTEED_DELIVERY',0x00000002)
		win_const_mgr.add_const('BIF_BROWSEFORCOMPUTER',0x00001000)
		win_const_mgr.add_const('MD_SERVER_STATE_STARTING',0x00000001)
		win_const_mgr.add_const('CMSG_ENCODED_MESSAGE',0x0000001D)
		win_const_mgr.add_const('OPTION_XWINDOW_DISPLAY_MANAGER',0x00000031)
		win_const_mgr.add_const('USE_NETERR',0x00000003)
		win_const_mgr.add_const('DIF_INSTALLCLASSDRIVERS',0x0000000A)
		win_const_mgr.add_const('MCI_OVLY_OPEN_PARENT',0x00020000)
		win_const_mgr.add_const('ERROR_TIME_SKEW',0x00000576)
		win_const_mgr.add_const('WAIT_FAILED',0xFFFFFFFF)
		win_const_mgr.add_const('DNF_UNUSED_30',0x40000000)
		win_const_mgr.add_const('DNF_UNUSED_31',0x80000000)
		win_const_mgr.add_const('SQL_QUERY_TIMEOUT_DEFAULT',0x00000000)
		win_const_mgr.add_const('CDRF_DOERASE',0x00000008)
		win_const_mgr.add_const('LANG_ORIYA',0x00000048)
		win_const_mgr.add_const('SSF_NOCONFIRMRECYCLE',0x00008000)
		win_const_mgr.add_const('CBS_DROPDOWN',0x00000002)
		win_const_mgr.add_const('LANG_YI',0x00000078)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_LOOPEDDATA',0x80000000)
		win_const_mgr.add_const('MIM_MENUDATA',0x00000008)
		win_const_mgr.add_const('MM_MIM_DATA',0x000003C3)
		win_const_mgr.add_const('WSA_QOS_EFLOWSPEC',0x00002B09)
		win_const_mgr.add_const('PD_ENABLESETUPHOOK',0x00002000)
		win_const_mgr.add_const('LINEFORWARDMODE_BUSYSPECIFIC',0x00000080)
		win_const_mgr.add_const('DVD_STREAM_DATA_CURRENT',0x00000800)
		win_const_mgr.add_const('URLACTION_SHELL_EXECUTE_HIGHRISK',0x00001806)
		win_const_mgr.add_const('PAN_MIDLINE_HIGH_TRIMMED',0x00000005)
		win_const_mgr.add_const('ERROR_BADSTARTPOSITION',0x0000030A)
		win_const_mgr.add_const('CPL_DBLCLK',0x00000005)
		win_const_mgr.add_const('MM_TWIPS',0x00000006)
		win_const_mgr.add_const('VER_SUITE_SMALLBUSINESS_RESTRICTED',0x00000020)
		win_const_mgr.add_const('SQL_DCS_DROP_CHARACTER_SET',0x00000001)
		win_const_mgr.add_const('DEBUG_CURRENT_DISASM',0x00000002)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_OID_REQUEST',0x00000096)
		win_const_mgr.add_const('CERT_COMPARE_SHIFT',0x00000010)
		win_const_mgr.add_const('CBEIF_TEXT',0x00000001)
		win_const_mgr.add_const('VNSPROTO_SPP',0x00000003)
		win_const_mgr.add_const('NIM_MODIFY',0x00000001)
		win_const_mgr.add_const('CSCONFIGFLAG_BITS',0x00000007)
		win_const_mgr.add_const('DUPLICATE_CLOSE_SOURCE',0x00000001)
		win_const_mgr.add_const('PROV_RSA_AES',0x00000018)
		win_const_mgr.add_const('SQL_TL_OFF',0x00000000)
		win_const_mgr.add_const('CM_SETUP_DEVNODE_READY',0x00000000)
		win_const_mgr.add_const('WH_HARDWARE',0x00000008)
		win_const_mgr.add_const('SUBLANG_TAMIL_INDIA',0x00000001)
		win_const_mgr.add_const('PP_KEYSTORAGE',0x00000011)
		win_const_mgr.add_const('URLACTION_JAVA_MIN',0x00001C00)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_UNKNOWN_DOI',0x00003626)
		win_const_mgr.add_const('SBS_BOTTOMALIGN',0x00000004)
		win_const_mgr.add_const('ARCONTENT_AUTORUNINF',0x00000002)
		win_const_mgr.add_const('SPARSE_CACHE_ENTRY',0x00010000)
		win_const_mgr.add_const('MFE_NO_SPACE',0x0000000D)
		win_const_mgr.add_const('_SIZE_T_MAX',0x00000000)
		win_const_mgr.add_const('OID_GEN_BYTES_RCV',0x00020219)
		win_const_mgr.add_const('DI_FLAGSEX_NO_CLASSLIST_NODE_MERGE',0x08000000)
		win_const_mgr.add_const('ERROR_SXS_UNKNOWN_ENCODING_GROUP',0x000036BC)
		win_const_mgr.add_const('EXECUTE_FLAG_IGNORE_CURRENT_INTERCEPTOR',0x00000002)
		win_const_mgr.add_const('IASSEMBLYCACHEITEM_COMMIT_DISPOSITION_REFRESHED',0x00000002)
		win_const_mgr.add_const('ERR_DISK_READ_ERROR',0xE0000004)
		win_const_mgr.add_const('SV_ANNOUNCE_PARMNUM',0x00000011)
		win_const_mgr.add_const('ERROR_INVALID_WINDOW_STYLE',0x000007D2)
		win_const_mgr.add_const('INF_STYLE_NONE',0x00000000)
		win_const_mgr.add_const('TLS1_ALERT_NO_RENEGOTIATION',0x00000064)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGKCBCREATE',0x00000016)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_ACTION_PERMIT',0x00000001)
		win_const_mgr.add_const('SSF_SOUNDSENTRYON',0x00000001)
		win_const_mgr.add_const('TF_SFT_MINIMIZED',0x00000004)
		win_const_mgr.add_const('IF_TYPE_PRIMARY_ISDN',0x00000015)
		win_const_mgr.add_const('PST_RS449',0x00000005)
		win_const_mgr.add_const('LINEERR_BILLINGREJECTED',0x80000054)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_DIALED',0x00000020)
		win_const_mgr.add_const('DNF_OLD_INET_DRIVER',0x00000400)
		win_const_mgr.add_const('SV_CONNECTIONNOSESSIONSTIMEOUT_PARMNUM',0x00000254)
		win_const_mgr.add_const('CACHE_HEADER_DATA_ROOT_LEAK_OFFSET',0x00000016)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY10',0x00000400)
		win_const_mgr.add_const('IP_ROUTER_MANAGER_VERSION',0x00000001)
		win_const_mgr.add_const('IMEVER_0400',0x00040000)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY13',0x00002000)
		win_const_mgr.add_const('INPLACE_E_FIRST',0x800401A0)
		win_const_mgr.add_const('ERROR_DBG_PRINTEXCEPTION_C',0x000002B6)
		win_const_mgr.add_const('NRC_TOOMANY',0x00000022)
		win_const_mgr.add_const('CTRY_DOMINICAN_REPUBLIC',0x00000001)
		win_const_mgr.add_const('DI_FLAGSEX_IN_SYSTEM_SETUP',0x00010000)
		win_const_mgr.add_const('SE_ERR_DLLNOTFOUND',0x00000020)
		win_const_mgr.add_const('IMAGE_REL_AMD64_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_USER_PEAK_RATE',0x0000001F)
		win_const_mgr.add_const('VFT2_DRV_KEYBOARD',0x00000002)
		win_const_mgr.add_const('PAN_BENT_ARMS_VERT',0x00000009)
		win_const_mgr.add_const('GCP_CLASSIN',0x00080000)
		win_const_mgr.add_const('DS_INET_ADDRESS',0x00000001)
		win_const_mgr.add_const('VK_CAPITAL',0x00000014)
		win_const_mgr.add_const('SECTION_EXTEND_SIZE',0x00000010)
		win_const_mgr.add_const('ERROR_REDIR_PAUSED',0x00000048)
		win_const_mgr.add_const('RPC_C_MQ_JOURNAL_ALWAYS',0x00000002)
		win_const_mgr.add_const('ACTION_ADMINUNLOCK',0x00000001)
		win_const_mgr.add_const('IME_HOTKEY_DSWITCH_FIRST',0x00000100)
		win_const_mgr.add_const('IDTR_KEY',0x00000008)
		win_const_mgr.add_const('DRM_ACTIVATE_MACHINE',0x00000001)
		win_const_mgr.add_const('INFO_BASE',0x00000000)
		win_const_mgr.add_const('ERROR_CTX_NO_FORCE_LOGOFF',0x00001B97)
		win_const_mgr.add_const('D3DLOCK_DISCARD',0x00002000)
		win_const_mgr.add_const('SET_SERVICE_PARTIAL_SUCCESS',0x00000001)
		win_const_mgr.add_const('PRODUCT_HOME_PREMIUM',0x00000003)
		win_const_mgr.add_const('CERT_STORE_ADD_USE_EXISTING',0x00000002)
		win_const_mgr.add_const('LINE_DEVSPECIFIC',0x00000004)
		win_const_mgr.add_const('IOC_UNIX',0x00000000)
		win_const_mgr.add_const('CERT_PROT_ROOT_INHIBIT_PURGE_LM_FLAG',0x00000004)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW3_SCREENLEFT',0x00000492)
		win_const_mgr.add_const('CM_DRP_REMOVAL_POLICY_OVERRIDE',0x00000022)
		win_const_mgr.add_const('SHFMT_ERROR',0xFFFFFFFF)
		win_const_mgr.add_const('SB_BOTH',0x00000003)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_COMMIT_REQUEST',0x04000000)
		win_const_mgr.add_const('DFM_WM_INITMENUPOPUP',0x00000008)
		win_const_mgr.add_const('VPDF_DISABLERINGRESUME',0x00000010)
		win_const_mgr.add_const('VPF_DISABLERELATIVE',0x00000002)
		win_const_mgr.add_const('SO_RCVTIMEO',0x00001006)
		win_const_mgr.add_const('LOCALE_SDAYNAME2',0x0000002B)
		win_const_mgr.add_const('SPMODE_BROWSER',0x00000008)
		win_const_mgr.add_const('EVENT_SYSTEM_CONTEXTHELPEND',0x0000000D)
		win_const_mgr.add_const('SECURITY_THIS_ORGANIZATION_RID',0x0000000F)
		win_const_mgr.add_const('URL_UNESCAPE',0x10000000)
		win_const_mgr.add_const('INVALID_TIME',0x00000000)
		win_const_mgr.add_const('DESKTOP_JOURNALPLAYBACK',0x00000020)
		win_const_mgr.add_const('ERROR_LOG_RESTART_INVALID',0x000019CF)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETAGENTINFO',0x0000000B)
		win_const_mgr.add_const('PORT_CYCLESERV',0x000002FB)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_HASH',0x0000362E)
		win_const_mgr.add_const('DISPID_WMPCORE_BASE',0x00000000)
		win_const_mgr.add_const('PIR_OPTION_REGISTRY',0x00000002)
		win_const_mgr.add_const('FILE_DEVICE_VIRTUAL_DISK',0x00000024)
		win_const_mgr.add_const('SUBLANG_MOHAWK_MOHAWK',0x00000001)
		win_const_mgr.add_const('SNMP_TRAP_AUTHFAIL',0x00000004)
		win_const_mgr.add_const('PSD_DISABLEPRINTER',0x00000020)
		win_const_mgr.add_const('MFCOMMENT',0x0000000F)
		win_const_mgr.add_const('SQL_API_SQLNUMRESULTCOLS',0x00000012)
		win_const_mgr.add_const('ERROR_DS_NO_CROSSREF_FOR_NC',0x000020AB)
		win_const_mgr.add_const('MXDCOP_SET_S0PAGE_RESOURCE',0x0000001E)
		win_const_mgr.add_const('DNSSEC_PROTOCOL_IPSEC',0x00000004)
		win_const_mgr.add_const('IP_DROP_SOURCE_MEMBERSHIP',0x00000010)
		win_const_mgr.add_const('IF_TYPE_POS',0x000000AB)
		win_const_mgr.add_const('ERROR_CORRUPT_SYSTEM_FILE',0x0000027A)
		win_const_mgr.add_const('CM_PROB_CANT_SHARE_IRQ',0x0000001E)
		win_const_mgr.add_const('STI_GENCAP_GENERATE_ARRIVALEVENT',0x00000004)
		win_const_mgr.add_const('DDCOLOR_SHARPNESS',0x00000010)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NO_CERT',0x000035EE)
		win_const_mgr.add_const('SQL_AA_FALSE',0x00000000)
		win_const_mgr.add_const('ERROR_GUID_SUBSTITUTION_MADE',0x000002A8)
		win_const_mgr.add_const('WSA_QOS_EPSFLOWSPEC',0x00002B13)
		win_const_mgr.add_const('VK_PRIOR',0x00000021)
		win_const_mgr.add_const('MCGIF_RECT',0x00000002)
		win_const_mgr.add_const('WIA_PAGE_AUTO',0x00000064)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_30',0x0000001E)
		win_const_mgr.add_const('LINETERMMODE_HOOKSWITCH',0x00000010)
		win_const_mgr.add_const('DXVA_EXECUTE_RETURN_OTHER_ERROR_SEVERE',0x00000004)
		win_const_mgr.add_const('CC_ELLIPSES',0x00000008)
		win_const_mgr.add_const('PRINTER_CHANGE_PORT',0x00700000)
		win_const_mgr.add_const('CACHE_FIND_CONTAINER_RETURN_NOCHANGE',0x00000001)
		win_const_mgr.add_const('DLG_ACMFILTERCHOOSE_ID',0x00000047)
		win_const_mgr.add_const('REG_FULL_RESOURCE_DESCRIPTOR',0x00000009)
		win_const_mgr.add_const('SQL_API_SQLALLOCCONNECT',0x00000001)
		win_const_mgr.add_const('DEBUG_VSEARCH_WRITABLE_ONLY',0x00000001)
		win_const_mgr.add_const('FWP_FILTER_ENUM_FLAG_INCLUDE_DISABLED',0x00000010)
		win_const_mgr.add_const('DBPROPVAL_TI_SERIALIZABLE',0x00100000)
		win_const_mgr.add_const('PHONESTATE_DISCONNECTED',0x00000004)
		win_const_mgr.add_const('LINEFORWARDMODE_BUSYEXTERNAL',0x00000040)
		win_const_mgr.add_const('LDAP_BIND_CMD',0x00000060)
		win_const_mgr.add_const('SQL_CA2_SENSITIVITY_DELETIONS',0x00000020)
		win_const_mgr.add_const('APPCOMMAND_VOLUME_MUTE',0x00000008)
		win_const_mgr.add_const('PORT_PPTP',0x0000162E)
		win_const_mgr.add_const('SHGFI_SHELLICONSIZE',0x00000004)
		win_const_mgr.add_const('MDM_AUTO_ML_2',0x00000002)
		win_const_mgr.add_const('ERROR_INVALID_LEVEL',0x0000007C)
		win_const_mgr.add_const('PSWIZB_BACK',0x00000001)
		win_const_mgr.add_const('STI_EVENTHANDLING_PENDING',0x00000004)
		win_const_mgr.add_const('MAPI_E_ACCESS_DENIED',0x00000006)
		win_const_mgr.add_const('DVD_AUDIO_CAPS_SDDS',0x00000010)
		win_const_mgr.add_const('_WIN32_WINNT_NT4',0x00000400)
		win_const_mgr.add_const('IP_FRAGOFF_MASK',0x00001FFF)
		win_const_mgr.add_const('VK_RETURN',0x0000000D)
		win_const_mgr.add_const('DFS_VOLUME_STATE_ONLINE',0x00000004)
		win_const_mgr.add_const('D3D10_SHADER_IEEE_STRICTNESS',0x00000001)
		win_const_mgr.add_const('ALG_SID_ECMQV',0x00000001)
		win_const_mgr.add_const('ERROR_DS_CONFIG_PARAM_MISSING',0x000020EB)
		win_const_mgr.add_const('WSAENOTEMPTY',0x00002752)
		win_const_mgr.add_const('ERROR_EVT_CONFIGURATION_ERROR',0x00003AA2)
		win_const_mgr.add_const('PAN_CULTURE_LATIN',0x00000000)
		win_const_mgr.add_const('TCS_FOCUSONBUTTONDOWN',0x00001000)
		win_const_mgr.add_const('CRYPT_VERIFYCONTEXT',0xF0000000)
		win_const_mgr.add_const('IF_TYPE_TERMPAD',0x0000005B)
		win_const_mgr.add_const('NLS_CP_WCTOMB',0x80000000)
		win_const_mgr.add_const('RIS_INTERFACE_DISABLED',0x00000002)
		win_const_mgr.add_const('SHIL_JUMBO',0x00000004)
		win_const_mgr.add_const('CM_REENUMERATE_NORMAL',0x00000000)
		win_const_mgr.add_const('DBG_MODLOAD',0x00000003)
		win_const_mgr.add_const('OID_GEN_ADMIN_STATUS',0x00010288)
		win_const_mgr.add_const('MCI_DGV_STATUS_WINDOW_VISIBLE',0x00004021)
		win_const_mgr.add_const('ERROR_DOMAIN_EXISTS',0x0000054C)
		win_const_mgr.add_const('DDSCAPS_OVERLAY',0x00000080)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_256BYTES',0x00900000)
		win_const_mgr.add_const('SCH_CRED_USE_DEFAULT_CREDS',0x00000040)
		win_const_mgr.add_const('KERB_REFRESH_SCCRED_RELEASE',0x00000000)
		win_const_mgr.add_const('CHANNEL_RC_UNKNOWN_CHANNEL_NAME',0x0000000D)
		win_const_mgr.add_const('SYSRGN',0x00000004)
		win_const_mgr.add_const('SCH_CRED_X509_CERTCHAIN',0x00000001)
		win_const_mgr.add_const('SS_USERITEM',0x0000000A)
		win_const_mgr.add_const('POWER_USER_NOTIFY_BUTTON',0x00000008)
		win_const_mgr.add_const('LINEADDRESSSTATE_NUMCALLS',0x00000020)
		win_const_mgr.add_const('PRODUCT_STARTER',0x0000000B)
		win_const_mgr.add_const('OFFLOAD_INBOUND_SA',0x00000001)
		win_const_mgr.add_const('MNC_CLOSE',0x00000001)
		win_const_mgr.add_const('IDC_CI_ICONDISPLAY',0x00000083)
		win_const_mgr.add_const('KERB_ETYPE_RSA_PRIV',0x00000009)
		win_const_mgr.add_const('IME_CONFIG_GENERAL',0x00000001)
		win_const_mgr.add_const('CSIDL_COMMON_ADMINTOOLS',0x00000002)
		win_const_mgr.add_const('WMDM_STATUS_STORAGECONTROL_APPENDING',0x00008000)
		win_const_mgr.add_const('R2_NOTMERGEPEN',0x00000002)
		win_const_mgr.add_const('SSF_SHOWEXTENSIONS',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_DUPLICATE_ASSEMBLY_NAME',0x000036CB)
		win_const_mgr.add_const('CERT_RDN_ENCODED_BLOB',0x00000001)
		win_const_mgr.add_const('IDM_SCROLL_PAGEUP',0x0000094F)
		win_const_mgr.add_const('DEBUG_GSEL_NO_SYMBOL_LOADS',0x00000001)
		win_const_mgr.add_const('IMAGE_WEAK_EXTERN_SEARCH_ALIAS',0x00000003)
		win_const_mgr.add_const('TMT_GLYPHTEXTCOLOR',0x00000EEB)
		win_const_mgr.add_const('MAX_DEVICE_IDENTIFIER_STRING',0x00000200)
		win_const_mgr.add_const('WT_EXECUTEDELETEWAIT',0x00000008)
		win_const_mgr.add_const('INTERNET_OPTION_RECEIVE_TIMEOUT',0x00000006)
		win_const_mgr.add_const('NRC_LOCKFAIL',0x0000003C)
		win_const_mgr.add_const('PRINTACTION_SERVERPROPERTIES',0x00000007)
		win_const_mgr.add_const('JL_SENDER_ONLY',0x00000001)
		win_const_mgr.add_const('CERT_UNICODE_ATTR_ERR_INDEX_MASK',0x0000003F)
		win_const_mgr.add_const('LOGON_PROFILE_PATH_RETURNED',0x00000400)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_SECREL',0x0000000F)
		win_const_mgr.add_const('SM_CXFRAME',0x00000020)
		win_const_mgr.add_const('WIA_MAJOR_EVENT_DEVICE_DISCONNECT',0x00000002)
		win_const_mgr.add_const('USER_MARSHAL_FC_FLOAT',0x0000000A)
		win_const_mgr.add_const('DISPID_NAVIGATECOMPLETE2',0x000000FC)
		win_const_mgr.add_const('SET_REPAIR_WARN_ABOUT_DATA_LOSS',0x00000008)
		win_const_mgr.add_const('SCS_CAP_COMPSTR',0x00000001)
		win_const_mgr.add_const('WVR_HREDRAW',0x00000100)
		win_const_mgr.add_const('VS_ALLOW_LATIN',0x00000001)
		win_const_mgr.add_const('SAVE_FORMAT_TEXT',0x00000001)
		win_const_mgr.add_const('IMAGE_DLLCHARACTERISTICS_NO_SEH',0x00000400)
		win_const_mgr.add_const('RQ_CUSTOM_NOTIFICATION',0x10000000)
		win_const_mgr.add_const('LINEGROUPSTATUS_NEWGROUP',0x00000001)
		win_const_mgr.add_const('D3DPRASTERCAPS_FOGVERTEX',0x00000080)
		win_const_mgr.add_const('CSIDL_DRIVES',0x00000011)
		win_const_mgr.add_const('IDD_VIEWPROPS',0x0000044D)
		win_const_mgr.add_const('DMDO_270',0x00000003)
		win_const_mgr.add_const('TMT_ACCENTCOLORHINT',0x00000EEF)
		win_const_mgr.add_const('COD_AUDIO_MINOR_LOUDSPEAKER',0x00000005)
		win_const_mgr.add_const('ENABLE_DISABLE_AUTO_OFFLINE',0x000000DB)
		win_const_mgr.add_const('EMARCH_ENC_I17_SIGN_INST_WORD_POS_X',0x0000001B)
		win_const_mgr.add_const('CERT_STORE_ADD_REPLACE_EXISTING',0x00000003)
		win_const_mgr.add_const('CRED_PERSIST_NONE',0x00000000)
		win_const_mgr.add_const('TC_OP_STROKE',0x00000002)
		win_const_mgr.add_const('FIND_NEXT',0x00000001)
		win_const_mgr.add_const('SQL_MAX_STATEMENT_LEN',0x00000069)
		win_const_mgr.add_const('KS_NABTS_GROUPID_PRODUCTION_COMPANY_ADVERTISER_BASE',0x00000830)
		win_const_mgr.add_const('DISPID_IWBSCRIPTCONTROL_SELECTABLECONTENT',0x00000004)
		win_const_mgr.add_const('TMT_WINDOW',0x00000646)
		win_const_mgr.add_const('ERROR_DIRECT_ACCESS_HANDLE',0x00000082)
		win_const_mgr.add_const('OID_FDDI_SMT_CONFIG_CAPABILITIES',0x0303020C)
		win_const_mgr.add_const('CAUSE_LOC_PUBLIC_LOCAL',0x00000002)
		win_const_mgr.add_const('ERROR_CANT_ACCESS_FILE',0x00000780)
		win_const_mgr.add_const('DXGI_PRESENT_RESTART',0x00000004)
		win_const_mgr.add_const('ASC_REQ_CONFIDENTIALITY',0x00000010)
		win_const_mgr.add_const('TAPE_DRIVE_COMPRESSION',0x00020000)
		win_const_mgr.add_const('TVGN_CHILD',0x00000004)
		win_const_mgr.add_const('MIXED_NODETYPE',0x00000004)
		win_const_mgr.add_const('DIF_SELECTCLASSDRIVERS',0x00000008)
		win_const_mgr.add_const('INT_PTR_MAX',0x7FFFFFFF)
		win_const_mgr.add_const('SE_PRIVILEGE_REMOVED',0x00000000)
		win_const_mgr.add_const('TF_RP_LOCALTHREAD',0x00000008)
		win_const_mgr.add_const('TBNF_DI_SETITEM',0x10000000)
		win_const_mgr.add_const('AUTH_REQ_ALLOW_PROXIABLE',0x00000002)
		win_const_mgr.add_const('D3D_MAX_SIMULTANEOUS_RENDERTARGETS',0x00000004)
		win_const_mgr.add_const('SERIAL_IOC_MCR_RTS',0x00000002)
		win_const_mgr.add_const('TMT_SMCAPTIONBARHEIGHT',0x000004B7)
		win_const_mgr.add_const('R2_BLACK',0x00000001)
		win_const_mgr.add_const('SQL_MAX_SCHEMA_NAME_LEN',0x00000020)
		win_const_mgr.add_const('CERT_RDN_GENERAL_STRING',0x0000000A)
		win_const_mgr.add_const('MDM_PROTOCOLID_DEFAULT',0x00000000)
		win_const_mgr.add_const('ERROR_STREAM_MINIVERSION_NOT_VALID',0x00001A99)
		win_const_mgr.add_const('DNS_MAX_TEXT_STRING_LENGTH',0x000000FF)
		win_const_mgr.add_const('SRRF_RT_REG_EXPAND_SZ',0x00000004)
		win_const_mgr.add_const('WS_MINIMIZE',0x20000000)
		win_const_mgr.add_const('SND_SYSTEM',0x00200000)
		win_const_mgr.add_const('OID_GEN_MEDIA_SENSE_COUNTS',0x00020215)
		win_const_mgr.add_const('IC_E_INTERNAL_ERROR',0x83010006)
		win_const_mgr.add_const('SFGAO_HASSUBFOLDER',0x80000000)
		win_const_mgr.add_const('SSPROP_STREAM_BASEPATH',0x00000011)
		win_const_mgr.add_const('SV_RAWWORKITEMS_PARMNUM',0x000001FB)
		win_const_mgr.add_const('WLAN_CONNECTION_IGNORE_PRIVACY_BIT',0x00000004)
		win_const_mgr.add_const('SVSI_DESELECT',0x00000000)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_MAX',0x00070000)
		win_const_mgr.add_const('HEAP_CREATE_ALIGN_16',0x00010000)
		win_const_mgr.add_const('SQL_IS_INSERT_LITERALS',0x00000001)
		win_const_mgr.add_const('VK_NUMPAD3',0x00000063)
		win_const_mgr.add_const('PHONEERR_INVALPOINTER',0x90000015)
		win_const_mgr.add_const('DS_REPMOD_WRITEABLE',0x00000002)
		win_const_mgr.add_const('PAN_SERIF_OBTUSE_SANS',0x0000000C)
		win_const_mgr.add_const('VK_NUMPAD7',0x00000067)
		win_const_mgr.add_const('VK_NUMPAD6',0x00000066)
		win_const_mgr.add_const('VK_NUMPAD5',0x00000065)
		win_const_mgr.add_const('VK_NUMPAD4',0x00000064)
		win_const_mgr.add_const('NDIS_PORT_CHARACTERISTICS_REVISION_1',0x00000001)
		win_const_mgr.add_const('LVS_EX_COLUMNSNAPPOINTS',0x40000000)
		win_const_mgr.add_const('DMPAPER_P32KBIG_ROTATED',0x0000006C)
		win_const_mgr.add_const('AM_VIDEO_FLAG_REPEAT_FIELD',0x00000040)
		win_const_mgr.add_const('DBPROP_MSREMOTE_INTERNET_TIMEOUT',0x00000006)
		win_const_mgr.add_const('SHDID_COMPUTER_OTHER',0x0000000C)
		win_const_mgr.add_const('META_SCALEVIEWPORTEXT',0x00000412)
		win_const_mgr.add_const('PRINTER_ERROR_SEVERE',0x20000000)
		win_const_mgr.add_const('EXCEPTION_WRITE_FAULT',0x00000001)
		win_const_mgr.add_const('AVIFILEINFO_MUSTUSEINDEX',0x00000020)
		win_const_mgr.add_const('LP_DEFAULT',0x00000000)
		win_const_mgr.add_const('MCI_DGV_RESERVE_SIZE',0x00020000)
		win_const_mgr.add_const('MD_WARNING_PATH_NOT_FOUND',0x000CC803)
		win_const_mgr.add_const('SECTION_QUERY',0x00000001)
		win_const_mgr.add_const('TCS_MULTISELECT',0x00000004)
		win_const_mgr.add_const('BACKUP_DISABLE_INCREMENTAL',0x00000000)
		win_const_mgr.add_const('DXVA_PICTURE_STRUCTURE_TOP_FIELD',0x00000001)
		win_const_mgr.add_const('IPV6_RTHDR',0x00000020)
		win_const_mgr.add_const('PROV_SPYRUS_LYNKS',0x00000014)
		win_const_mgr.add_const('SPDRP_SERVICE',0x00000004)
		win_const_mgr.add_const('LINECALLFEATURE_SWAPHOLD',0x04000000)
		win_const_mgr.add_const('ALT4KB_END',0x6FC00800000)
		win_const_mgr.add_const('SPI_GETACTIVEWINDOWTRACKING',0x00001000)
		win_const_mgr.add_const('ERROR_CANT_CROSS_RM_BOUNDARY',0x00001AA9)
		win_const_mgr.add_const('SQL_GETDATA_EXTENSIONS',0x00000051)
		win_const_mgr.add_const('ERROR_REPARSE_TAG_MISMATCH',0x0000112A)
		win_const_mgr.add_const('NDIS_MEDIA_CAP_RECEIVE',0x00000002)
		win_const_mgr.add_const('INSTALLFLAG_NONINTERACTIVE',0x00000004)
		win_const_mgr.add_const('VALIDATEUNC_VALID',0x00000007)
		win_const_mgr.add_const('DFS_SITE_PRIMARY',0x00000001)
		win_const_mgr.add_const('WIA_IPS_FILM_SCAN_MODE',0x00000C20)
		win_const_mgr.add_const('ERROR_CONTROLLING_IEPORT',0x000010E9)
		win_const_mgr.add_const('SQL_CV_CASCADED',0x00000004)
		win_const_mgr.add_const('E_SURFACE_NODC',0x8000C004)
		win_const_mgr.add_const('SHCNF_NOTIFYRECURSIVE',0x00010000)
		win_const_mgr.add_const('IMC_GETCOMPOSITIONWINDOW',0x0000000B)
		win_const_mgr.add_const('DBPROPVAL_IC_MIXED',0x00000008)
		win_const_mgr.add_const('MCI_VCR_STATUS_NUMBER_OF_AUDIO_TRACKS',0x00004020)
		win_const_mgr.add_const('MQMSG_ACKNOWLEDGMENT_POS_RECEIVE',0x00000002)
		win_const_mgr.add_const('HDS_HIDDEN',0x00000008)
		win_const_mgr.add_const('EVENT_TRACE_USE_NOCPUTIME',0x00000002)
		win_const_mgr.add_const('LINEERR_INVALBEARERMODE',0x80000016)
		win_const_mgr.add_const('MDPROPVAL_AU_UNCHANGED',0x00000001)
		win_const_mgr.add_const('TMT_GRADIENTCOLOR2',0x00000EE3)
		win_const_mgr.add_const('ERROR_DS_GC_NOT_AVAILABLE',0x00002019)
		win_const_mgr.add_const('ERROR_DS_INVALID_SCRIPT',0x00002198)
		win_const_mgr.add_const('RPC_X_NO_MORE_ENTRIES',0x000006EC)
		win_const_mgr.add_const('APPCOMMAND_BROWSER_BACKWARD',0x00000001)
		win_const_mgr.add_const('RF_USER_ACTION',0x10000000)
		win_const_mgr.add_const('PRIVATE_NAMESPACE_FLAG_DESTROY',0x00000001)
		win_const_mgr.add_const('FS_CHINESETRAD',0x00100000)
		win_const_mgr.add_const('MCI_VCR_ESCAPE_STRING',0x00000100)
		win_const_mgr.add_const('DS_CONTROL',0x00000400)
		win_const_mgr.add_const('TRACE_LEVEL_CRITICAL',0x00000001)
		win_const_mgr.add_const('INTERNET_DEFAULT_FTP_PORT',0x00000015)
		win_const_mgr.add_const('NDIS_PORT_STATE_REVISION_1',0x00000001)
		win_const_mgr.add_const('DEX_IDS_DISK_WRITE_ERROR',0x0000058B)
		win_const_mgr.add_const('DDCKEYCAPS_NOCOSTOVERLAY',0x00040000)
		win_const_mgr.add_const('HTTP_LOGGING_FLAG_USE_UTF8_CONVERSION',0x00000002)
		win_const_mgr.add_const('PFN_LCLETTER',0x00000003)
		win_const_mgr.add_const('SHGDFIL_DESCRIPTIONID',0x00000003)
		win_const_mgr.add_const('SPFILENOTIFY_STARTRENAME',0x00000008)
		win_const_mgr.add_const('ERROR_INVALID_GW_COMMAND',0x000005A3)
		win_const_mgr.add_const('VR_PENDING',0x00000000)
		win_const_mgr.add_const('ERROR_BAD_SERVICE_ENTRYPOINT',0x00000262)
		win_const_mgr.add_const('PORT_TYPE_NET_ATTACHED',0x00000008)
		win_const_mgr.add_const('DAO_NOINDICATOR',0x00000000)
		win_const_mgr.add_const('SNMP_ERROR_TOOBIG',0x00000001)
		win_const_mgr.add_const('CERT_PROT_ROOT_DISABLE_PEER_TRUST',0x00010000)
		win_const_mgr.add_const('CERT_COMPARE_SUBJECT_INFO_ACCESS',0x00000013)
		win_const_mgr.add_const('DNS_TYPE_ALL',0x00000000)
		win_const_mgr.add_const('SQL_OPT_TRACEFILE',0x00000069)
		win_const_mgr.add_const('LVHT_ABOVE',0x00000008)
		win_const_mgr.add_const('NIIF_NDIS_WDM_INTERFACE',0x00000020)
		win_const_mgr.add_const('KSWAVE_BUFFER_ATTRIBUTEF_LOOPING',0x00000001)
		win_const_mgr.add_const('BG_E_INVALID_PROXY_INFO',0x8020003F)
		win_const_mgr.add_const('STI_ONLINESTATE_PAUSED',0x00000008)
		win_const_mgr.add_const('MCI_DGV_CUT_AT',0x00010000)
		win_const_mgr.add_const('BST_INDETERMINATE',0x00000002)
		win_const_mgr.add_const('FILE_ACTION_MODIFIED',0x00000003)
		win_const_mgr.add_const('MDM_ERROR_CONTROL',0x00000002)
		win_const_mgr.add_const('ERROR_DS_EXISTS_IN_RDNATTID',0x00002196)
		win_const_mgr.add_const('DBT_CONFIGCHANGECANCELED',0x00000019)
		win_const_mgr.add_const('X3_D_WH_INST_WORD_POS_X',0x00000018)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_PROVIDER_CHIMNEY_OFFLOAD_CHARACTERISTICS',0x00000094)
		win_const_mgr.add_const('SB_THUMBTRACK',0x00000005)
		win_const_mgr.add_const('DIF_VALIDATECLASSDRIVERS',0x00000009)
		win_const_mgr.add_const('KSMPEGVIDMODE_PANSCAN',0x00000001)
		win_const_mgr.add_const('NDIS_PROTOCOL_ID_NBF',0x00000007)
		win_const_mgr.add_const('VIEW_PRIORITY_NONE',0x00000000)
		win_const_mgr.add_const('TMT_ICONTITLEFONT',0x00000326)
		win_const_mgr.add_const('REO_GETOBJ_POLESITE',0x00000004)
		win_const_mgr.add_const('EC_TIMECODE_AVAILABLE',0x00000030)
		win_const_mgr.add_const('RTCEF_SESSION_OPERATION_COMPLETE',0x00000008)
		win_const_mgr.add_const('MSV1_0_USE_CLIENT_CHALLENGE',0x00000080)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_ON_SRCNODE',0x00000002)
		win_const_mgr.add_const('PRINTER_STATUS_SERVER_OFFLINE',0x02000000)
		win_const_mgr.add_const('DDOVER_KEYSRCOVERRIDE',0x00002000)
		win_const_mgr.add_const('PRINTER_CONTROL_RESUME',0x00000002)
		win_const_mgr.add_const('TAPIMAXAPPNAMESIZE',0x00000028)
		win_const_mgr.add_const('DBPROPVAL_SQ_COMPARISON',0x00000002)
		win_const_mgr.add_const('PID_THUMBNAIL',0x00000011)
		win_const_mgr.add_const('SFGAO_CANMONIKER',0x00400000)
		win_const_mgr.add_const('SQL_TRANSLATE_OPTION',0x0000006B)
		win_const_mgr.add_const('CAUSE_LOC_BEYOND_INTERWORKING',0x0000000A)
		win_const_mgr.add_const('LDAP_OPT_ENCRYPT',0x00000096)
		win_const_mgr.add_const('D3DPTEXTURECAPS_NOPROJECTEDBUMPENV',0x00200000)
		win_const_mgr.add_const('POLICY_QOS_SCHANNEL_REQUIRED',0x00000001)
		win_const_mgr.add_const('OPATH_TOK_CLOSE_PAREN',0x0000006B)
		win_const_mgr.add_const('SQL_AF_SUM',0x00000010)
		win_const_mgr.add_const('LR_LOADMAP3DCOLORS',0x00001000)
		win_const_mgr.add_const('OID_ATM_MAX_AAL1_PACKET_SIZE',0x08010109)
		win_const_mgr.add_const('IDM_JUSTIFYNONE',0x0000005E)
		win_const_mgr.add_const('SV_NAME_PARMNUM',0x00000066)
		win_const_mgr.add_const('DNS_TYPE_ZERO',0x00000000)
		win_const_mgr.add_const('STAT_NOISE_WORDS',0x00000010)
		win_const_mgr.add_const('MD_AUTH_PASSPORT',0x00000040)
		win_const_mgr.add_const('CF_APPLY',0x00000200)
		win_const_mgr.add_const('NDIS_WMI_EVENT_HEADER_REVISION_1',0x00000001)
		win_const_mgr.add_const('PERM_FILE_WRITE',0x00000002)
		win_const_mgr.add_const('ERROR_NO_INHERITANCE',0x0000056F)
		win_const_mgr.add_const('IF_TYPE_ISO88026_MAN',0x0000000A)
		win_const_mgr.add_const('RTCRF_REGISTER_NOTIFY',0x00000008)
		win_const_mgr.add_const('FRS_ERR_INVALID_SERVICE_PARAMETER',0x00001F51)
		win_const_mgr.add_const('DMO_E_TYPE_NOT_ACCEPTED',0x80040205)
		win_const_mgr.add_const('SYSTEM_AUDIT_ACE_TYPE',0x00000002)
		win_const_mgr.add_const('DB_MODE_SHARE_EXCLUSIVE',0x00000000)
		win_const_mgr.add_const('PDERR_GETDEVMODEFAIL',0x00001005)
		win_const_mgr.add_const('SIOM_ICONINDEX',0x00000002)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYSHRINKYN',0x00400000)
		win_const_mgr.add_const('IDM_GETUSERACTIONTIME',0x0000097F)
		win_const_mgr.add_const('RTCEF_SESSION_REFERRED',0x00200000)
		win_const_mgr.add_const('ADS_JOB_PRINTING',0x00000010)
		win_const_mgr.add_const('SVAUD_LOGONLIM',0x00010000)
		win_const_mgr.add_const('UNDNAME_NO_MS_THISTYPE',0x00000020)
		win_const_mgr.add_const('FILE_VOLUME_QUOTAS',0x00000020)
		win_const_mgr.add_const('WMSZ_BOTTOMLEFT',0x00000007)
		win_const_mgr.add_const('LINEERR_USERUSERINFOTOOBIG',0x80000051)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_COMPLETIONID',0x00000800)
		win_const_mgr.add_const('BIF_RETURNONLYFSDIRS',0x00000001)
		win_const_mgr.add_const('TPM_BOTTOMALIGN',0x00000020)
		win_const_mgr.add_const('DBPROPVAL_ORS_INTEGRATEDINDEX',0x00000002)
		win_const_mgr.add_const('ISC_RET_CONFIDENTIALITY',0x00000010)
		win_const_mgr.add_const('IDM_UNGROUP',0x0000002D)
		win_const_mgr.add_const('TBS_NOTHUMB',0x00000080)
		win_const_mgr.add_const('MCI_VCR_UNFREEZE_OUTPUT',0x00020000)
		win_const_mgr.add_const('RBBS_NOVERT',0x00000010)
		win_const_mgr.add_const('DS_DOMAIN_PRIMARY',0x00000008)
		win_const_mgr.add_const('FWPM_FILTER_FLAG_NONE',0x00000000)
		win_const_mgr.add_const('NDIS_LINK_PARAMETERS_REVISION_1',0x00000001)
		win_const_mgr.add_const('FAX_ERR_NOT_SUPPORTED_ON_THIS_SKU',0x00001B63)
		win_const_mgr.add_const('ERROR_CLUSTER_NETWORK_EXISTS',0x000013B4)
		win_const_mgr.add_const('ICDRAW_BUFFER',0x00000100)
		win_const_mgr.add_const('DISPID_VIEWUPDATE',0x00000119)
		win_const_mgr.add_const('WINHTTP_QUERY_AUTHORIZATION',0x0000001C)
		win_const_mgr.add_const('ENABLE_PROCESSED_OUTPUT',0x00000001)
		win_const_mgr.add_const('TIMEMEDIAELEMENT_OFFSET',0x00000400)
		win_const_mgr.add_const('DEBUG_PROCESS_ONLY_THIS_PROCESS',0x00000002)
		win_const_mgr.add_const('TF_IPPMF_FORPROCESS',0x10000000)
		win_const_mgr.add_const('WEBPOST_ERROR_AUTOBIND_FAILED',0xC0042112)
		win_const_mgr.add_const('FR_PROP_BODYPARTSTRING',0x00000003)
		win_const_mgr.add_const('VARIABLE_PITCH',0x00000002)
		win_const_mgr.add_const('REG_NOTIFY_CHANGE_ATTRIBUTES',0x00000002)
		win_const_mgr.add_const('ACMDRIVERDETAILS_SUPPORTF_LOCAL',0x40000000)
		win_const_mgr.add_const('DEV_PORT_ARTI',0x00000007)
		win_const_mgr.add_const('LANG_JAPANESE',0x00000011)
		win_const_mgr.add_const('AUDIO_MIN_FRAMERATE',0x0000000A)
		win_const_mgr.add_const('NRB_FUNCTION_NVCACHE_POWER_MODE_RETURN',0x00000001)
		win_const_mgr.add_const('INTERNET_IDENTITY_FLAG_SHARED_CACHE',0x00000002)
		win_const_mgr.add_const('LCS_GM_GRAPHICS',0x00000002)
		win_const_mgr.add_const('LINECALLINFOSTATE_CALLID',0x00000040)
		win_const_mgr.add_const('ERROR_IP_ADDRESS_CONFLICT2',0x00000264)
		win_const_mgr.add_const('ERROR_DS_SRC_NAME_MISMATCH',0x00002124)
		win_const_mgr.add_const('ERROR_IP_ADDRESS_CONFLICT1',0x00000263)
		win_const_mgr.add_const('SHDID_COMPUTER_SHAREDDOCS',0x00000014)
		win_const_mgr.add_const('TKF_TOGGLEKEYSON',0x00000001)
		win_const_mgr.add_const('TBS_COMMAND_LOCALITY_FOUR',0x00000004)
		win_const_mgr.add_const('ISC_RET_INTEGRITY',0x00010000)
		win_const_mgr.add_const('PSM_UDI_C_PLANE',0x0000001D)
		win_const_mgr.add_const('PID_LINK_TARGET',0x00000002)
		win_const_mgr.add_const('MUI_QUERY_TYPE',0x00000001)
		win_const_mgr.add_const('MDM_V110_SPEED_14DOT4K',0x00000006)
		win_const_mgr.add_const('CMSG_DATA',0x00000001)
		win_const_mgr.add_const('SQL_QU_TABLE_DEFINITION',0x00000004)
		win_const_mgr.add_const('WIA_DPS_SHEET_FEEDER_REGISTRATION',0x00000C06)
		win_const_mgr.add_const('PROTO_IP_NAT',0x00002715)
		win_const_mgr.add_const('ERROR_CAN_NOT_DEL_LOCAL_WINS',0x00000FA1)
		win_const_mgr.add_const('ERROR_DS_SENSITIVE_GROUP_VIOLATION',0x00002139)
		win_const_mgr.add_const('LINEERR_NOMEM',0x80000044)
		win_const_mgr.add_const('CREATE_BREAKAWAY_FROM_JOB',0x01000000)
		win_const_mgr.add_const('NTMS_OMID_TYPE_FILESYSTEM_INFO',0x00000002)
		win_const_mgr.add_const('FD_GROUP_QOS',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_EXTENDED_ERROR',0x00000018)
		win_const_mgr.add_const('CF_NOSCRIPTSEL',0x00800000)
		win_const_mgr.add_const('IMAGE_NT_OPTIONAL_HDR32_MAGIC',0x00000010)
		win_const_mgr.add_const('LINEERR_INVALTIMEOUT',0x8000003B)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_ID',0x00000003)
		win_const_mgr.add_const('LCMAP_UPPERCASE',0x00000200)
		win_const_mgr.add_const('PDH_LOG_TYPE_TRACE_GENERIC',0x00000005)
		win_const_mgr.add_const('NS_X500',0x00000028)
		win_const_mgr.add_const('DATA_SOURCE_WBEM',0x00000004)
		win_const_mgr.add_const('META_MOVETO',0x00000214)
		win_const_mgr.add_const('DXVA_CONFIG_BLEND_TYPE_FRONT_BUFFER',0x00000000)
		win_const_mgr.add_const('SHCNEE_ORDERCHANGED',0x00000002)
		win_const_mgr.add_const('ERROR_POPUP_ALREADY_ACTIVE',0x000005A6)
		win_const_mgr.add_const('TMT_VALIGN',0x00000FA7)
		win_const_mgr.add_const('DVB_TDT_TID',0x00000070)
		win_const_mgr.add_const('USER_COUNTRY_CODE_PARMNUM',0x00000018)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_QUALITY',0x00080000)
		win_const_mgr.add_const('MNC_EXECUTE',0x00000002)
		win_const_mgr.add_const('ERROR_PROTECTION_VIOLATION',0x00000073)
		win_const_mgr.add_const('MEDIA_ERASEABLE',0x00000001)
		win_const_mgr.add_const('DEFAULT_PITCH',0x00000000)
		win_const_mgr.add_const('DEBUG_PHYSICAL_DEFAULT',0x00000000)
		win_const_mgr.add_const('SQL_PAS_NO_BATCH',0x00000002)
		win_const_mgr.add_const('CC_FULLOPEN',0x00000002)
		win_const_mgr.add_const('BLUETOOTH_MAX_SERVICE_NAME_SIZE',0x00000100)
		win_const_mgr.add_const('DBTF_XPORT',0x00000002)
		win_const_mgr.add_const('ERROR_CANT_OPEN_ANONYMOUS',0x00000543)
		win_const_mgr.add_const('IME_SETCONVERSIONMODE',0x00000010)
		win_const_mgr.add_const('RPC_S_FP_UNDERFLOW',0x000006EA)
		win_const_mgr.add_const('IF_TYPE_VOICEOVERATM',0x00000098)
		win_const_mgr.add_const('JT_FAIL_RECEIVE',0x00000004)
		win_const_mgr.add_const('IDM_MULTILEVELREDO',0x0000001E)
		win_const_mgr.add_const('KSDSOUND_BUFFER_CTRL_HRTF_3D',0x40000000)
		win_const_mgr.add_const('GETSCALINGFACTOR',0x0000000E)
		win_const_mgr.add_const('ISC_SHOWUIALLCANDIDATEWINDOW',0x0000000F)
		win_const_mgr.add_const('PAN_SERIF_OBTUSE_COVE',0x00000003)
		win_const_mgr.add_const('DHCP_ENDPOINT_FLAG_CANT_MODIFY',0x00000001)
		win_const_mgr.add_const('CM_PROB_REGISTRY_TOO_LARGE',0x00000031)
		win_const_mgr.add_const('D3DTSS_TCI_SPHEREMAP',0x00040000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_SUPPORTEDDATASECTORTYPES',0x00000108)
		win_const_mgr.add_const('CPLPAGE_KEYBOARD_SPEED',0x00000001)
		win_const_mgr.add_const('FOF_SIMPLEPROGRESS',0x00000100)
		win_const_mgr.add_const('KSPROBE_ALLOCATEMDL',0x00000010)
		win_const_mgr.add_const('GESTURE_OPENUP',0x00000000)
		win_const_mgr.add_const('CAL_SCALNAME',0x00000002)
		win_const_mgr.add_const('MMIOM_RENAME',0x00000006)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_RIGHT',0x00400000)
		win_const_mgr.add_const('EAP_E_SERVER_ROOT_CERT_LAST',0x804204FF)
		win_const_mgr.add_const('ERROR_EA_TABLE_FULL',0x00000115)
		win_const_mgr.add_const('OID_LTALK_IN_LENGTH_ERRORS',0x05020102)
		win_const_mgr.add_const('MAX_UCSCHAR',0x0010FFFF)
		win_const_mgr.add_const('CERT_TRUST_PUB_ALLOW_TRUST_MASK',0x00000003)
		win_const_mgr.add_const('BLUETOOTH_SERVICE_DISABLE',0x00000000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_REQUESTEDWRITESPEED',0x0000010B)
		win_const_mgr.add_const('DTPB_USEERASEBKGND',0x00000004)
		win_const_mgr.add_const('DNS_TYPE_TEXT',0x00000010)
		win_const_mgr.add_const('OIC_QUES',0x00007F02)
		win_const_mgr.add_const('LDAP_SERVER_COPY_CONTROL_DONT_USE_COPY',0x00000001)
		win_const_mgr.add_const('WM_COPYDATA',0x0000004A)
		win_const_mgr.add_const('SQL_ODBC_SQL_OPT_IEF',0x00000049)
		win_const_mgr.add_const('SS_ETCHEDVERT',0x00000011)
		win_const_mgr.add_const('ERROR_SEGMENT_NOTIFICATION',0x000002BE)
		win_const_mgr.add_const('WB_MOVEWORDLEFT',0x00000004)
		win_const_mgr.add_const('IO_REPARSE_TAG_SYMLINK',0xA000000C)
		win_const_mgr.add_const('MDPROPVAL_MSF_DRILLDOWNLEVELTOP',0x00004000)
		win_const_mgr.add_const('BG_COPY_FILE_ALL',0x0000000F)
		win_const_mgr.add_const('ISC_REQ_STREAM',0x00008000)
		win_const_mgr.add_const('BG_E_ERROR_CONTEXT_GENERAL_TRANSPORT',0x8020000B)
		win_const_mgr.add_const('PHOTO_EXPOSUREPROGRAM_LANDSCAPE',0x00000008)
		win_const_mgr.add_const('EMR_SELECTCLIPPATH',0x00000043)
		win_const_mgr.add_const('SI_RESET_SACL_TREE',0x00008000)
		win_const_mgr.add_const('SP_HANDSHAKING',0x00000010)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_REMOTE_LOGON',0x80100000)
		win_const_mgr.add_const('COD_IMAGING_MINOR_PRINTER_MASK',0x00000020)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_CAN_PREVIEW',0x00004008)
		win_const_mgr.add_const('NETSH_MAX_CMD_TOKEN_LENGTH',0x00000080)
		win_const_mgr.add_const('ADS_PRINTER_PAPER_PROBLEM',0x00000007)
		win_const_mgr.add_const('SPI_GETPOWEROFFACTIVE',0x00000054)
		win_const_mgr.add_const('DPNHINITIALIZE_DISABLELOCALFIREWALLSUPPORT',0x00000002)
		win_const_mgr.add_const('MCI_VCR_MARK_ERASE',0x00020000)
		win_const_mgr.add_const('AA_F_CREATE',0x00000200)
		win_const_mgr.add_const('AUTO_DETECT_PACKET_TYPE',0xFFFFFFFF)
		win_const_mgr.add_const('HIST_VIEWTREE',0x00000004)
		win_const_mgr.add_const('CF_UNICODETEXT',0x0000000D)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_SPEAKEROFF',0x00000016)
		win_const_mgr.add_const('MCI_DGV_FILE_MODE_IDLE_S',0x00008007)
		win_const_mgr.add_const('DRV_LOAD',0x00000001)
		win_const_mgr.add_const('OID_CO_DELETE_ADDRESS',0xFE000005)
		win_const_mgr.add_const('SQL_TXN_REPEATABLE_READ',0x00000004)
		win_const_mgr.add_const('D3DFVFCAPS_DONOTSTRIPELEMENTS',0x00080000)
		win_const_mgr.add_const('ERROR_DS_OBJECT_CLASS_REQUIRED',0x0000207B)
		win_const_mgr.add_const('PBT_APMRESUMESUSPEND',0x00000007)
		win_const_mgr.add_const('UAS_ROLE_PRIMARY',0x00000003)
		win_const_mgr.add_const('MCI_DGV_FILE_S',0x00008002)
		win_const_mgr.add_const('PAN_LETT_OBLIQUE_OFF_CENTER',0x0000000E)
		win_const_mgr.add_const('PSH_USEHICON',0x00000002)
		win_const_mgr.add_const('ERROR_PROFILING_NOT_STOPPED',0x00000227)
		win_const_mgr.add_const('LINECALLFEATURE_SETUPCONF',0x01000000)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_UNKNOWN',0x0000FFFF)
		win_const_mgr.add_const('HTTP_REQUEST_AUTH_FLAG_TOKEN_FOR_CACHED_CRED',0x00000001)
		win_const_mgr.add_const('SDP_ATTRIB_RECORD_STATE',0x00000002)
		win_const_mgr.add_const('CMM_LOGOICON',0x00000006)
		win_const_mgr.add_const('NT351_INTERFACE_SIZE',0x00000040)
		win_const_mgr.add_const('DISPID_COLLECTION_MIN',0x000F4240)
		win_const_mgr.add_const('ICINSTALL_UNICODE',0x00008000)
		win_const_mgr.add_const('SI_USER_FAILED',0x00000002)
		win_const_mgr.add_const('ERROR_NOLOGON_SERVER_TRUST_ACCOUNT',0x00000711)
		win_const_mgr.add_const('IF_MAX_PHYS_ADDRESS_LENGTH',0x00000020)
		win_const_mgr.add_const('DDFXCAPS_BLTMIRRORUPDOWN',0x00000080)
		win_const_mgr.add_const('IRTIR_TASK_FINISHED',0x00000004)
		win_const_mgr.add_const('STATE_SYSTEM_SELECTED',0x00000002)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_DEF_FLOW_COUNT',0x00000005)
		win_const_mgr.add_const('IMGLOAD_MASK',0x01F00000)
		win_const_mgr.add_const('COLOR_CAPTIONTEXT',0x00000009)
		win_const_mgr.add_const('ERROR_SEM_TIMEOUT',0x00000079)
		win_const_mgr.add_const('SCSI_IOCTL_DATA_UNSPECIFIED',0x00000002)
		win_const_mgr.add_const('FILEOP_DOIT',0x00000001)
		win_const_mgr.add_const('FILE_SUPPORTS_OBJECT_IDS',0x00010000)
		win_const_mgr.add_const('LINEADDRFEATURE_PICKUPGROUP',0x00000200)
		win_const_mgr.add_const('SYNC_HANDLERTYPE_COMPUTERS',0x00000005)
		win_const_mgr.add_const('PORT_XYPLEXMUX',0x000000AD)
		win_const_mgr.add_const('TIMETRANSITIONELEMENT_OFFSET',0x00001500)
		win_const_mgr.add_const('SIOM_RESERVED_SHARED',0x00000000)
		win_const_mgr.add_const('FWPM_CALLOUT_FLAG_USES_PROVIDER_CONTEXT',0x00020000)
		win_const_mgr.add_const('F_END',0x00000006)
		win_const_mgr.add_const('CERT_NAME_DISABLE_IE4_UTF8_FLAG',0x00010000)
		win_const_mgr.add_const('SV_TYPE_DOMAIN_ENUM',0x80000000)
		win_const_mgr.add_const('DEBUG_REQUEST_SET_ADDITIONAL_CREATE_OPTIONS',0x00000005)
		win_const_mgr.add_const('DISPID_SAVEDOCUMENT',0x00000004)
		win_const_mgr.add_const('MSIM_DISPID_ON_NM_CANCELLED',0x00000E15)
		win_const_mgr.add_const('SQL_EN_ON',0x00000001)
		win_const_mgr.add_const('DISPID_ADDSEARCHPROVIDER',0x0000000E)
		win_const_mgr.add_const('CTRY_RUSSIA',0x00000007)
		win_const_mgr.add_const('COD_LAN_ACCESS_BIT_OFFSET',0x00000005)
		win_const_mgr.add_const('DDPF_ALPHAPIXELS',0x00000001)
		win_const_mgr.add_const('D3DCS_BACK',0x00000020)
		win_const_mgr.add_const('ERROR_DS_NO_RIDS_ALLOCATED',0x00002010)
		win_const_mgr.add_const('RPC_C_AUTHZ_DCE',0x00000002)
		win_const_mgr.add_const('URLACTION_ACTIVEX_OVERRIDE_OBJECT_SAFETY',0x00001201)
		win_const_mgr.add_const('BAUD_9600',0x00000800)
		win_const_mgr.add_const('MCI_VCR_FREEZE_FIELD',0x00040000)
		win_const_mgr.add_const('SQL_BP_DELETE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_RANGE_CONSTRAINT',0x00002082)
		win_const_mgr.add_const('PID_SECURITY',0x00000013)
		win_const_mgr.add_const('ERROR_ABIOS_ERROR',0x0000021A)
		win_const_mgr.add_const('DN_NEED_RESTART',0x00000100)
		win_const_mgr.add_const('MIXERLINE_TARGETTYPE_UNDEFINED',0x00000000)
		win_const_mgr.add_const('PERCEIVEDFLAG_WMSDK',0x00000020)
		win_const_mgr.add_const('URLMON_OPTION_URL_ENCODING',0x10000004)
		win_const_mgr.add_const('DBCOMPUTEMODE_NOTCOMPUTED',0x00000003)
		win_const_mgr.add_const('CF_ENABLEHOOK',0x00000008)
		win_const_mgr.add_const('FILE_ATTRIBUTE_SYSTEM',0x00000004)
		win_const_mgr.add_const('MCI_DGV_MONITOR_SOURCE',0x00020000)
		win_const_mgr.add_const('PE_ATTRIB_TYPE_POLICY_LOCATOR',0x00000001)
		win_const_mgr.add_const('DI_FLAGSEX_EXCLUDE_OLD_INET_DRIVERS',0x00800000)
		win_const_mgr.add_const('RPC_S_NO_CONTEXT_AVAILABLE',0x000006E5)
		win_const_mgr.add_const('PROTO_TYPE_MS1',0x00000003)
		win_const_mgr.add_const('DI_NOSELECTICONS',0x40000000)
		win_const_mgr.add_const('ASP_MD_UT_APP',0x00000065)
		win_const_mgr.add_const('SUBLANG_SAMI_LULE_NORWAY',0x00000004)
		win_const_mgr.add_const('CREDUIWIN_CHECKBOX',0x00000002)
		win_const_mgr.add_const('CERT_DISPWELL_TRUST_ADD_LEAF_CERT',0x00000005)
		win_const_mgr.add_const('ERROR_SXS_XML_E_BADCHARINSTRING',0x000036D2)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_ONES_NETBC',0x00004000)
		win_const_mgr.add_const('IDB_VIEW_LARGE_COLOR',0x00000005)
		win_const_mgr.add_const('WM_PRINTCLIENT',0x00000318)
		win_const_mgr.add_const('FACILITY_STATE_MANAGEMENT',0x00000022)
		win_const_mgr.add_const('TMT_PROGRESSCHUNKSIZE',0x0000096B)
		win_const_mgr.add_const('MAPI_E_LOGON_FAILURE',0x00000003)
		win_const_mgr.add_const('CBM_FIRST',0x00001700)
		win_const_mgr.add_const('PARMNUM_BASE_INFOLEVEL',0x000003E8)
		win_const_mgr.add_const('SQL_FN_TSI_HOUR',0x00000008)
		win_const_mgr.add_const('IDC_CV_ICONDISPLAY',0x000000A5)
		win_const_mgr.add_const('SQLAOPVARP',0x00000033)
		win_const_mgr.add_const('STATE_SYSTEM_SELECTABLE',0x00200000)
		win_const_mgr.add_const('LDAP_FILTER_OR',0x00000000)
		win_const_mgr.add_const('SQL_CONVERT_VARBINARY',0x00000045)
		win_const_mgr.add_const('IMAGE_ICON',0x00000001)
		win_const_mgr.add_const('LBS_NOTIFY',0x00000001)
		win_const_mgr.add_const('DEBUG_PROCESS',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_ACCEPT_ENCODING',0x0000001A)
		win_const_mgr.add_const('FILE_NOTIFY_CHANGE_LAST_WRITE',0x00000010)
		win_const_mgr.add_const('SQL_MAX_ROW_SIZE',0x00000068)
		win_const_mgr.add_const('D3D10_SHADER_SKIP_VALIDATION',0x00000001)
		win_const_mgr.add_const('ICC_INTERNET_CLASSES',0x00000800)
		win_const_mgr.add_const('SUBLANG_MALAYALAM_INDIA',0x00000001)
		win_const_mgr.add_const('ODBC_ERROR_GENERAL_ERR',0x00000001)
		win_const_mgr.add_const('REO_READWRITEMASK',0x0000003F)
		win_const_mgr.add_const('ERROR_NTLM_BLOCKED',0x00000791)
		win_const_mgr.add_const('SQL_CONCUR_ROWVER',0x00000003)
		win_const_mgr.add_const('SQL_CVT_BIT',0x00001000)
		win_const_mgr.add_const('IF_TYPE_RADSL',0x0000005F)
		win_const_mgr.add_const('ERROR_NO_SUCH_ALIAS',0x00000560)
		win_const_mgr.add_const('NETE_NETNOTSTARTED',0x00000007)
		win_const_mgr.add_const('IMPORTANCE_NORMAL_SET',0x00000003)
		win_const_mgr.add_const('APPCOMMAND_BROWSER_HOME',0x00000007)
		win_const_mgr.add_const('D3D10_DEFAULT_MIP_LOD_BIAS',0x00000000)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_DIRECTED_BYTES_XMIT',0x00080000)
		win_const_mgr.add_const('AA_F_DELETE',0x00000400)
		win_const_mgr.add_const('FILE_COMPRESSION_NONE',0x00000000)
		win_const_mgr.add_const('DRM_DEVICE_REGISTER_TYPE_STORAGE',0x00000002)
		win_const_mgr.add_const('SUBLANG_THAI_THAILAND',0x00000001)
		win_const_mgr.add_const('FWPM_CONTEXT_ALE_SET_CONNECTION_REQUIRE_IPSEC_SECURITY',0x00000002)
		win_const_mgr.add_const('IDM_TRIED_DOVERB',0x0000003D)
		win_const_mgr.add_const('LSA_TLN_DISABLED_CONFLICT',0x00000004)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_ALPHA',0x00000002)
		win_const_mgr.add_const('HH_SYNC',0x00000009)
		win_const_mgr.add_const('CALG_OID_INFO_PARAMETERS',0xFFFFFFFE)
		win_const_mgr.add_const('SECPKG_ATTR_USER_FLAGS',0x0000000B)
		win_const_mgr.add_const('MDM_PROTOCOLID_PIAFS',0x00000009)
		win_const_mgr.add_const('STI_ONLINESTATE_OPERATIONAL',0x00000001)
		win_const_mgr.add_const('SI_EDIT_PROPERTIES',0x00000080)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_SOFTWARE',0x00040000)
		win_const_mgr.add_const('SYSPAL_NOSTATIC256',0x00000003)
		win_const_mgr.add_const('FLAG_NO_COMPUTER',0x00000002)
		win_const_mgr.add_const('STRETCHBLT',0x00000800)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_PRIORITY',0x0000000E)
		win_const_mgr.add_const('IDD_PASTESPECIAL4',0x00000454)
		win_const_mgr.add_const('SQL_ODBC_API_CONFORMANCE',0x00000009)
		win_const_mgr.add_const('UF_TEMP_DUPLICATE_ACCOUNT',0x00000100)
		win_const_mgr.add_const('DS_UNKNOWN_ADDRESS_TYPE',0x00000000)
		win_const_mgr.add_const('HTTP_SEND_RESPONSE_FLAG_BUFFER_DATA',0x00000004)
		win_const_mgr.add_const('D3DTA_TFACTOR',0x00000003)
		win_const_mgr.add_const('SQL_INTERVAL',0x0000000A)
		win_const_mgr.add_const('META_SETDIBTODEV',0x00000000)
		win_const_mgr.add_const('WIA_PAGE_JIS_4A',0x00000033)
		win_const_mgr.add_const('WINEFS_SETUSERKEY_SET_CAPABILITIES',0x00000001)
		win_const_mgr.add_const('MD_ERROR_SUB502_TIMEOUT',0x00000001)
		win_const_mgr.add_const('LVIS_STATEIMAGEMASK',0x0000F000)
		win_const_mgr.add_const('KP_CLIENT_RANDOM',0x00000015)
		win_const_mgr.add_const('TSF_NO_SECURITY',0x00000008)
		win_const_mgr.add_const('CFU_UNDERLINETHICKDOTTED',0x00000011)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_POLICY_ADMINS',0x00000208)
		win_const_mgr.add_const('SPFILENOTIFY_FILEOPDELAYED',0x00000014)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_MD5',0x00000034)
		win_const_mgr.add_const('ERROR_INVALID_IMPORT_OF_NON_DLL',0x000004FC)
		win_const_mgr.add_const('SRRF_NOEXPAND',0x10000000)
		win_const_mgr.add_const('RTL_CRITICAL_SECTION_DEBUG_FLAG_STATIC_INIT',0x00000001)
		win_const_mgr.add_const('MF_FLAGS_CREATE_BUT_NO_SHOW_DISABLED',0x00000008)
		win_const_mgr.add_const('OFFLINE_STATUS_REMOTE',0x00000002)
		win_const_mgr.add_const('IPPORT_FTP_DATA',0x00000014)
		win_const_mgr.add_const('CSIDL_FLAG_DONT_VERIFY',0x00004000)
		win_const_mgr.add_const('CI_STATE_LOW_DISK',0x00010000)
		win_const_mgr.add_const('SQL_FILE_QUALIFIER',0x00000002)
		win_const_mgr.add_const('CTRY_MONGOLIA',0x000003D0)
		win_const_mgr.add_const('LANG_ZULU',0x00000035)
		win_const_mgr.add_const('DBPROPVAL_ASYNCH_SEQUENTIALPOPULATION',0x00000002)
		win_const_mgr.add_const('ERROR_BAD_LENGTH',0x00000018)
		win_const_mgr.add_const('CR_PROP_CAXCHGCERTCRLCHAIN',0x00000021)
		win_const_mgr.add_const('STREAMBUFFER_EC_BASE',0x00000326)
		win_const_mgr.add_const('OLEMISC_SIMPLEFRAME',0x00010000)
		win_const_mgr.add_const('TAPE_DRIVE_ERASE_LONG',0x00000020)
		win_const_mgr.add_const('OBM_REDUCED',0x00007FEA)
		win_const_mgr.add_const('IDD_DYNAWIZ_SELECT_PREVPAGE',0x00002711)
		win_const_mgr.add_const('SPMODE_SHELL',0x00000001)
		win_const_mgr.add_const('NETINFO_DLL16',0x00000001)
		win_const_mgr.add_const('LONG_PTR_MAX',0x7FFFFFFF)
		win_const_mgr.add_const('PHONELAMPMODE_DUMMY',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_REQUESTEDROTATIONTYPEISPURECAV',0x00000112)
		win_const_mgr.add_const('OLEMISC_SETCLIENTSITEFIRST',0x00020000)
		win_const_mgr.add_const('OID_802_5_CURRENT_ADDRESS',0x02010102)
		win_const_mgr.add_const('SDP_ATTRIB_INFO_TIME_TO_LIVE',0x00000007)
		win_const_mgr.add_const('D3DPTEXTURECAPS_VOLUMEMAP',0x00002000)
		win_const_mgr.add_const('HSHELL_WINDOWREPLACED',0x0000000D)
		win_const_mgr.add_const('MFE_OLD_ROUTER',0x0000000B)
		win_const_mgr.add_const('ACCESS_ACCESS_LIST_PARMNUM',0x00000004)
		win_const_mgr.add_const('WS_EX_STATICEDGE',0x00020000)
		win_const_mgr.add_const('DMDUP_HORIZONTAL',0x00000003)
		win_const_mgr.add_const('ERROR_DATA_NOT_ACCEPTED',0x00000250)
		win_const_mgr.add_const('D3DDEVCAPS2_CAN_STRETCHRECT_FROM_TEXTURES',0x00000010)
		win_const_mgr.add_const('R2_MERGENOTPEN',0x0000000C)
		win_const_mgr.add_const('ERROR_CALLBACK_POP_STACK',0x00000300)
		win_const_mgr.add_const('SPI_GETAUDIODESCRIPTION',0x00000074)
		win_const_mgr.add_const('LANG_ROMANSH',0x00000017)
		win_const_mgr.add_const('HHWIN_PROP_CHANGE_TITLE',0x00000001)
		win_const_mgr.add_const('CRYPT_NEXT',0x00000002)
		win_const_mgr.add_const('DEBUG_DUMP_TRACE_LOG',0x00000404)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_ALLOW_NULL_TARGET_NAME_MATCH',0x00000200)
		win_const_mgr.add_const('WS_SYSMENU',0x00080000)
		win_const_mgr.add_const('STANDARD_RIGHTS_REQUIRED',0x000F0000)
		win_const_mgr.add_const('DRM_LICENSE_STATE_DATA_SAP_PRESENT',0x00000004)
		win_const_mgr.add_const('DS_REPSYNCALL_PUSH_CHANGES_OUTWARD',0x00000020)
		win_const_mgr.add_const('AE_NORMAL',0x00000000)
		win_const_mgr.add_const('EM_SETMODIFY',0x000000B9)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_QUEUE',0x01000000)
		win_const_mgr.add_const('PRINTER_ACCESS_ADMINISTER',0x00000004)
		win_const_mgr.add_const('SECPKG_CALL_THREAD_TERM',0x00000080)
		win_const_mgr.add_const('SERVICE_RECOGNIZER_DRIVER',0x00000008)
		win_const_mgr.add_const('MD_DIRBROW_SHOW_EXTENSION',0x00000010)
		win_const_mgr.add_const('HHWIN_BUTTON_BROWSE_BCK',0x00000001)
		win_const_mgr.add_const('COLOR_WINDOWFRAME',0x00000006)
		win_const_mgr.add_const('EN_LINK',0x00000070)
		win_const_mgr.add_const('ERROR_DS_NOT_SUPPORTED',0x00002040)
		win_const_mgr.add_const('PORT_KSHELL',0x00000220)
		win_const_mgr.add_const('SUBLANG_SPANISH_MEXICAN',0x00000002)
		win_const_mgr.add_const('SQL_API_SQLPROCEDURES',0x00000043)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESUME',0x00000007)
		win_const_mgr.add_const('CERT_AUTH_ROOT_AUTO_UPDATE_DISABLE_PARTIAL_CHAIN_LOGGING_FLAG',0x00000002)
		win_const_mgr.add_const('WLX_SAS_TYPE_SC_REMOVE',0x00000006)
		win_const_mgr.add_const('ILC_COLOR',0x00000000)
		win_const_mgr.add_const('ISR_RESVD_REG',0x00000003)
		win_const_mgr.add_const('PRINTACTION_NETINSTALLLINK',0x00000003)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_MOE',0x0000000B)
		win_const_mgr.add_const('OF_VERIFY',0x00000400)
		win_const_mgr.add_const('SPINST_LOGCONFIGS_ARE_OVERRIDES',0x00040000)
		win_const_mgr.add_const('SVSI_CHECK2',0x00000200)
		win_const_mgr.add_const('OPTION_TFTP_SERVER_NAME',0x00000042)
		win_const_mgr.add_const('JIFMK_COM',0x0000FFFE)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_SYSTEM_OPS',0x00000225)
		win_const_mgr.add_const('IDM_SENDBACKWARD',0x00000020)
		win_const_mgr.add_const('STGM_DIRECT_SWMR',0x00400000)
		win_const_mgr.add_const('SOL_SOCKET',0x00000000)
		win_const_mgr.add_const('WININETINFO_OPTION_LOCK_HANDLE',0x0000FFFE)
		win_const_mgr.add_const('SDP_ATTRIB_SYNCH_SUPPORTED_DATA_STORES_LIST',0x00000301)
		win_const_mgr.add_const('SQL_INTEGER',0x00000004)
		win_const_mgr.add_const('WINHTTP_AUTH_TARGET_SERVER',0x00000000)
		win_const_mgr.add_const('SM_CYCAPTION',0x00000004)
		win_const_mgr.add_const('DDOVER_REFRESHALL',0x00020000)
		win_const_mgr.add_const('NTDSSITECONN_OPT_DISABLE_COMPRESSION',0x00000001)
		win_const_mgr.add_const('ATTR_FIXEDCONVERTED',0x00000005)
		win_const_mgr.add_const('CERT_ALT_NAME_X400_ADDRESS',0x00000004)
		win_const_mgr.add_const('MSIM_DISPID_ONLOCALSTATECHANGERESULT',0x00000E08)
		win_const_mgr.add_const('ERROR_SERVICE_NOT_ACTIVE',0x00000426)
		win_const_mgr.add_const('TREE_SEC_INFO_SET',0x00000001)
		win_const_mgr.add_const('CRYPT_KEEP_TIME_VALID',0x00000080)
		win_const_mgr.add_const('TMT_SMALLCAPTIONFONT',0x00000322)
		win_const_mgr.add_const('TBCDRF_NOOFFSET',0x00040000)
		win_const_mgr.add_const('C1_PUNCT',0x00000010)
		win_const_mgr.add_const('PRINTER_CHANGE_DELETE_PORT',0x00400000)
		win_const_mgr.add_const('PXE_TRACE_WARNING',0x00040000)
		win_const_mgr.add_const('REPL_STATE_OK',0x00000000)
		win_const_mgr.add_const('SPI_SETCOMBOBOXANIMATION',0x00001005)
		win_const_mgr.add_const('SQL_CN_DIFFERENT',0x00000001)
		win_const_mgr.add_const('COR_NATIVE_LINK_CUSTOM_VALUE_CC',0x00000012)
		win_const_mgr.add_const('RBAB_ADDBAND',0x00000002)
		win_const_mgr.add_const('MIXERCONTROL_CT_CLASS_TIME',0x60000000)
		win_const_mgr.add_const('SETUP_FORCECRL_FLAG',0x00000100)
		win_const_mgr.add_const('NTDDI_WIN2KSP2',0x05000200)
		win_const_mgr.add_const('LINECALLCOMPLMODE_INTRUDE',0x00000004)
		win_const_mgr.add_const('ERROR_DS_BAD_RDN_ATT_ID_SYNTAX',0x000020C8)
		win_const_mgr.add_const('NTDSSETTINGS_DEFAULT_SERVER_REDUNDANCY',0x00000002)
		win_const_mgr.add_const('TF_TMAE_NOACTIVATEKEYBOARDLAYOUT',0x00000020)
		win_const_mgr.add_const('SELCERT_VALIDITY',0x00000068)
		win_const_mgr.add_const('TRACE_MESSAGE_FLAG_MASK',0x0000FFFF)
		win_const_mgr.add_const('X3_EMPTY_INST_WORD_POS_X',0x0000000E)
		win_const_mgr.add_const('DOT11_FLAGS_80211B_CHANNEL_AGILITY',0x00000004)
		win_const_mgr.add_const('D3DTEXOPCAPS_DISABLE',0x00000001)
		win_const_mgr.add_const('IMAGE_ARCHIVE_START_SIZE',0x00000008)
		win_const_mgr.add_const('WINEVENT_KEYWORD_EVENTLOG_CLASSIC',0x80000000000000)
		win_const_mgr.add_const('ERROR_INVALID_PASSWORDNAME',0x000004C0)
		win_const_mgr.add_const('SHGDFIL_NETRESOURCE',0x00000002)
		win_const_mgr.add_const('LDAP_AUTH_SIMPLE',0x00000080)
		win_const_mgr.add_const('MIXERCONTROL_CT_CLASS_SWITCH',0x20000000)
		win_const_mgr.add_const('EAP_E_SERVER_CERT_NOT_FOUND',0x80420200)
		win_const_mgr.add_const('IDC_EL_MANUAL',0x000000D4)
		win_const_mgr.add_const('PRIMARY_CACHE_SHARED',0x00000001)
		win_const_mgr.add_const('DLGC_STATIC',0x00000100)
		win_const_mgr.add_const('_WIN32_IE_IE30',0x00000300)
		win_const_mgr.add_const('ACM_METRIC_COUNT_HARDWARE',0x00000006)
		win_const_mgr.add_const('OID_FDDI_PORT_LER_ALARM',0x03030271)
		win_const_mgr.add_const('DISPID_IWBSCRIPTCONTROL_ONVISIBILITYCHANGE',0x0000000A)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_MUTE',0x00000012)
		win_const_mgr.add_const('DISPID_TABLEPARAMS_NUMCOLS',0x00000002)
		win_const_mgr.add_const('LVS_EX_GRIDLINES',0x00000001)
		win_const_mgr.add_const('GCS_DELTASTART',0x00000100)
		win_const_mgr.add_const('MM_STREAM_ERROR',0x000003D7)
		win_const_mgr.add_const('ERROR_RESOURCE_PROPERTIES_STORED',0x000013A0)
		win_const_mgr.add_const('DDFXCAPS_BLTARITHSTRETCHY',0x00000020)
		win_const_mgr.add_const('AMCONTROL_COLORINFO_PRESENT',0x00000080)
		win_const_mgr.add_const('ERROR_CLASS_HAS_WINDOWS',0x00000584)
		win_const_mgr.add_const('WPF_NO_RECURSIVE_POST',0x00000001)
		win_const_mgr.add_const('CAUSE_INCOMPATIBLE_DESTINATION',0x00000058)
		win_const_mgr.add_const('RPC_S_NOTHING_TO_EXPORT',0x000006DA)
		win_const_mgr.add_const('DDL_ARCHIVE',0x00000020)
		win_const_mgr.add_const('MMSYSERR_NOERROR',0x00000000)
		win_const_mgr.add_const('FPS_ABORTING',0x20200000)
		win_const_mgr.add_const('LDAP_ABANDON_CMD',0x00000050)
		win_const_mgr.add_const('LOCALE_IDIGITSUBSTITUTION',0x00001014)
		win_const_mgr.add_const('WINHTTP_QUERY_EXPECT',0x00000044)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_HANDLE_DATA',0x00000002)
		win_const_mgr.add_const('IF_TYPE_SDLC',0x00000011)
		win_const_mgr.add_const('NDIS_802_11_AUTH_REQUEST_PAIRWISE_ERROR',0x00000006)
		win_const_mgr.add_const('LANG_TURKISH',0x00000001)
		win_const_mgr.add_const('CRYPT_DECRYPT_RSA_NO_PADDING_CHECK',0x00000020)
		win_const_mgr.add_const('SQL_SRJO_FULL_OUTER_JOIN',0x00000008)
		win_const_mgr.add_const('BG_E_ERROR_INFORMATION_UNAVAILABLE',0x8020000F)
		win_const_mgr.add_const('IMAGE_REL_AMD64_ADDR32',0x00000002)
		win_const_mgr.add_const('BLLI_L2_X75',0x0000000D)
		win_const_mgr.add_const('ERROR_DS_DRA_OBJ_NC_MISMATCH',0x00002161)
		win_const_mgr.add_const('ERROR_INVALID_ADDRESS',0x000001E7)
		win_const_mgr.add_const('TIMEMEDIAPLAYERCONTROL_OFFSET',0x00001300)
		win_const_mgr.add_const('MFE_NOT_LAST_HOP',0x0000000A)
		win_const_mgr.add_const('PID_MISC_OWNER',0x00000004)
		win_const_mgr.add_const('SQL_DS_CASCADE',0x00000004)
		win_const_mgr.add_const('INTERNET_OPTION_COOKIES_3RD_PARTY',0x00000056)
		win_const_mgr.add_const('FWPM_CONTEXT_ALE_SET_CONNECTION_REQUIRE_IPSEC_ENCRYPTION',0x00000008)
		win_const_mgr.add_const('NI_OPENCANDIDATE',0x00000010)
		win_const_mgr.add_const('SQL_SPEC_MAJOR',0x00000003)
		win_const_mgr.add_const('UAS_ROLE_STANDALONE',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_PPC_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_IA64_SREL22',0x00000012)
		win_const_mgr.add_const('WM_PAINTCLIPBOARD',0x00000309)
		win_const_mgr.add_const('NS_NETBT',0x0000000D)
		win_const_mgr.add_const('IDC_EL_LINKSLISTBOX',0x000000CE)
		win_const_mgr.add_const('TXFS_RM_STATE_SHUTTING_DOWN',0x00000003)
		win_const_mgr.add_const('DRM_LOCKBOXTYPE_WHITEBOX',0x00000001)
		win_const_mgr.add_const('LINEERR_INVALTERMINALMODE',0x8000003A)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_EXPECTEDTABLEOFCONTENTS',0x0000010A)
		win_const_mgr.add_const('WMDM_FILE_ATTR_READONLY',0x01000000)
		win_const_mgr.add_const('QOS_NOT_SPECIFIED',0xFFFFFFFF)
		win_const_mgr.add_const('CREATE_PROCESS_DEBUG_EVENT',0x00000003)
		win_const_mgr.add_const('MAX_VENDORNAME',0x00000020)
		win_const_mgr.add_const('REPL_STATE_NEVER_REPLICATED',0x00000003)
		win_const_mgr.add_const('FACILITY_CMI',0x00000036)
		win_const_mgr.add_const('HOTKEYF_EXT',0x00000008)
		win_const_mgr.add_const('EDITF_ALLOWSIGNINGWITHOLDCAKEY',0x04000000)
		win_const_mgr.add_const('PID_PAGECOUNT',0x0000000E)
		win_const_mgr.add_const('DEBUG_DUMP_FILE_ORIGINAL_CAB_INDEX',0x00000000)
		win_const_mgr.add_const('BEST_COMPLETE',0x00000002)
		win_const_mgr.add_const('CM_DEVCAP_RAWDEVICEOK',0x00000040)
		win_const_mgr.add_const('EMR_CLOSEFIGURE',0x0000003D)
		win_const_mgr.add_const('SRRF_RM_ANY',0x00000000)
		win_const_mgr.add_const('ED_AUDIO_9',0x00000100)
		win_const_mgr.add_const('ED_AUDIO_8',0x00000080)
		win_const_mgr.add_const('COPY_FILE_COPY_SYMLINK',0x00000800)
		win_const_mgr.add_const('GCPCLASS_LATINNUMBER',0x00000005)
		win_const_mgr.add_const('TVS_EX_MULTISELECT',0x00000002)
		win_const_mgr.add_const('ED_AUDIO_2',0x00000002)
		win_const_mgr.add_const('IPX_PROTOCOL_LOCAL',0x00000001)
		win_const_mgr.add_const('ED_AUDIO_7',0x00000040)
		win_const_mgr.add_const('ED_AUDIO_6',0x00000020)
		win_const_mgr.add_const('ED_AUDIO_5',0x00000010)
		win_const_mgr.add_const('ED_AUDIO_4',0x00000008)
		win_const_mgr.add_const('SQL_PC_PSEUDO',0x00000002)
		win_const_mgr.add_const('ERROR_INSUFFICIENT_LOGON_INFO',0x00000260)
		win_const_mgr.add_const('SV_MINKEEPCOMPLSEARCH_PARMNUM',0x0000020C)
		win_const_mgr.add_const('WMS_CONTAINER_ALLOW_PLAYLIST_SKIP_FORWARD',0x00000100)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_TARGET_COMPUTER',0x00000001)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_NO_REMOVING_SUBSCRIPTIONS',0x00001D05)
		win_const_mgr.add_const('CREDUI_FLAGS_DO_NOT_PERSIST',0x00000002)
		win_const_mgr.add_const('LINEAGENTSTATEEX_NOTREADY',0x00000001)
		win_const_mgr.add_const('WS_OVERLAPPED',0x00000000)
		win_const_mgr.add_const('MOVEFILE_REPLACE_EXISTING',0x00000001)
		win_const_mgr.add_const('KSPROBE_ALLOWFORMATCHANGE',0x00000080)
		win_const_mgr.add_const('GQOS_ERRORVALUE_UNKNOWN',0xFFFFFFFF)
		win_const_mgr.add_const('DISABLE_BTB_FIX',0x00000001)
		win_const_mgr.add_const('FW_EXTRABOLD',0x00000320)
		win_const_mgr.add_const('NCRYPT_ALLOW_EXPORT_FLAG',0x00000001)
		win_const_mgr.add_const('IDS_CAP_FILE_WRITE_ERROR',0x000001AE)
		win_const_mgr.add_const('KERB_ETYPE_RSA_SHA1_CMS',0x0000000B)
		win_const_mgr.add_const('SQL_API_SQLBULKOPERATIONS',0x00000018)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW3_SETINTERVAL',0x0000048A)
		win_const_mgr.add_const('ACTION_REVOCATION_DEFAULT_ONLINE',0x00010000)
		win_const_mgr.add_const('DDCAPS_OVERLAYFOURCC',0x00002000)
		win_const_mgr.add_const('MD_EXTLOG_DATE',0x00000001)
		win_const_mgr.add_const('CTRY_KAZAKSTAN',0x00000007)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_ROLLBACK',0x00000008)
		win_const_mgr.add_const('SQL_QI_OFF',0x00000000)
		win_const_mgr.add_const('MD_NOTIFY_SECURE_PORT',0x00000001)
		win_const_mgr.add_const('ICDECOMPRESS_NOTKEYFRAME',0x08000000)
		win_const_mgr.add_const('WMDM_STORAGE_ATTR_CANEDITMETADATA',0x00000080)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_CTL_SIGNER_REV_UNKNOWN_FLAG',0x00000200)
		win_const_mgr.add_const('SM_CYMINIMIZED',0x0000003A)
		win_const_mgr.add_const('IDD_DYNAWIZ_INSTALLDETECTED_PREVPAGE',0x00002716)
		win_const_mgr.add_const('COMP_ELEM_FRIENDLYNAME',0x00000400)
		win_const_mgr.add_const('DB_MODE_SHARE_DENY_NONE',0x00000010)
		win_const_mgr.add_const('MCI_VCR_OFFSET',0x00000500)
		win_const_mgr.add_const('CF_RIFF',0x0000000B)
		win_const_mgr.add_const('INTERNET_STATUS_RESPONSE_RECEIVED',0x00000029)
		win_const_mgr.add_const('LCS_GM_ABS_COLORIMETRIC',0x00000008)
		win_const_mgr.add_const('D3DPRASTERCAPS_COLORPERSPECTIVE',0x00400000)
		win_const_mgr.add_const('ICM_CTF',0x00000005)
		win_const_mgr.add_const('MAX_DEINTERLACE_DEVICE_GUIDS',0x00000020)
		win_const_mgr.add_const('PERF_COUNTERSET_FLAG_INSTANCE',0x00000010)
		win_const_mgr.add_const('WMDM_MODE_TRANSFER_PROTECTED',0x00000080)
		win_const_mgr.add_const('BDR_RAISEDOUTER',0x00000001)
		win_const_mgr.add_const('PP_SYM_KEYSIZE',0x00000013)
		win_const_mgr.add_const('TRANSACTION_COMMIT',0x00000008)
		win_const_mgr.add_const('ULONG_ERROR',0x00000000)
		win_const_mgr.add_const('NULL_BRUSH',0x00000005)
		win_const_mgr.add_const('PRINTER_CHANGE_DELETE_FORM',0x00040000)
		win_const_mgr.add_const('LIF_STATE',0x00000002)
		win_const_mgr.add_const('WINEVENT_KEYWORD_RESERVED_61',0x2000000000000000)
		win_const_mgr.add_const('HTTP_1_1_CACHE_ENTRY',0x00000040)
		win_const_mgr.add_const('MCI_ANIM_PLAY_FAST',0x00040000)
		win_const_mgr.add_const('PROCESSOR_STRONGARM',0x00000A11)
		win_const_mgr.add_const('WKSTA_USEWRITERAWWITHDATA_PARMNUM',0x00000038)
		win_const_mgr.add_const('PHONEPRIVILEGE_OWNER',0x00000002)
		win_const_mgr.add_const('CERT_ALT_NAME_ENTRY_ERR_INDEX_SHIFT',0x00000010)
		win_const_mgr.add_const('RATING_ONE_STAR_SET',0x00000001)
		win_const_mgr.add_const('CERT_TRUST_HAS_EXCLUDED_NAME_CONSTRAINT',0x00008000)
		win_const_mgr.add_const('MULTICLASSINFO_GETTYPEINFO',0x00000001)
		win_const_mgr.add_const('FACILITY_ACS',0x00000014)
		win_const_mgr.add_const('DRM_SERVICE_TYPE_PUBLISHING',0x00000004)
		win_const_mgr.add_const('EC_LENGTH_CHANGED',0x0000001E)
		win_const_mgr.add_const('CRED_TI_WORKGROUP_MEMBER',0x00000020)
		win_const_mgr.add_const('WKSTA_LOCKMAXIMUM_PARMNUM',0x0000002B)
		win_const_mgr.add_const('WINHTTP_OPTION_PASSPORT_COBRANDING_URL',0x00000052)
		win_const_mgr.add_const('URL_ESCAPE_UNSAFE',0x20000000)
		win_const_mgr.add_const('MM_SNDBLST_WAVEIN',0x00000007)
		win_const_mgr.add_const('ERROR_DRIVE_MEDIA_MISMATCH',0x000010CF)
		win_const_mgr.add_const('CAC_RANDOM',0x00000002)
		win_const_mgr.add_const('DS_REPMOD_UPDATE_INSTANCE',0x00000002)
		win_const_mgr.add_const('KS_DVD_SECTOR_PROTECT_MASK',0x00000020)
		win_const_mgr.add_const('TF_LBI_STYLE_TEXTCOLORICON',0x00000020)
		win_const_mgr.add_const('DSF_WPD_DEVICES',0x00000001)
		win_const_mgr.add_const('ERROR_EVT_FILTER_TOO_COMPLEX',0x00003AB2)
		win_const_mgr.add_const('CSIDL_STARTUP',0x00000007)
		win_const_mgr.add_const('DDF_BACKGROUNDPAL',0x00000200)
		win_const_mgr.add_const('DBPROPVAL_OS_ENABLEALL',0x00000000)
		win_const_mgr.add_const('ATF_ONOFFFEEDBACK',0x00000002)
		win_const_mgr.add_const('WMDM_E_REVOKED',0x8004500E)
		win_const_mgr.add_const('OID_FDDI_LCONNECTION_STATE',0x03020109)
		win_const_mgr.add_const('COLOR_MENUBAR',0x0000001E)
		win_const_mgr.add_const('LVGS_COLLAPSED',0x00000001)
		win_const_mgr.add_const('META_SETTEXTCOLOR',0x00000209)
		win_const_mgr.add_const('TMT_MENUBARWIDTH',0x000004B8)
		win_const_mgr.add_const('BTH_MFG_INTEL',0x00000002)
		win_const_mgr.add_const('ETW_COUNTED_ANSISTRING_TYPE_VALUE',0x0000006D)
		win_const_mgr.add_const('FORMATDLGORD31',0x00000607)
		win_const_mgr.add_const('CHANGER_BAR_CODE_SCANNER_INSTALLED',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_ACQUIREEXCLUSIVEACCESS',0x00000102)
		win_const_mgr.add_const('SCRIPT_ENCODE_DEFAULT_LANGUAGE',0x00000001)
		win_const_mgr.add_const('ERROR_CANT_DISABLE_MANDATORY',0x0000051E)
		win_const_mgr.add_const('LOCALE_SNEGINFINITY',0x00000006)
		win_const_mgr.add_const('ERROR_BAD_ENVIRONMENT',0x0000000A)
		win_const_mgr.add_const('DDBLT_ZBUFFERSRCCONSTOVERRIDE',0x00400000)
		win_const_mgr.add_const('DEBUG_NOTIFY_SESSION_ACTIVE',0x00000000)
		win_const_mgr.add_const('EMR_RESIZEPALETTE',0x00000033)
		win_const_mgr.add_const('SQL_ISV_DOMAINS',0x00000400)
		win_const_mgr.add_const('LV_VIEW_TILE',0x00000004)
		win_const_mgr.add_const('BS_AUTOCHECKBOX',0x00000003)
		win_const_mgr.add_const('MIB_IF_TYPE_PPP',0x00000017)
		win_const_mgr.add_const('CAUSE_STATUS_ENQUIRY_RESPONSE',0x0000001E)
		win_const_mgr.add_const('PHONEERR_INVALAPPHANDLE',0x90000007)
		win_const_mgr.add_const('TC_RESERVED',0x00008000)
		win_const_mgr.add_const('DS_SCHEMA_GUID_ATTR',0x00000001)
		win_const_mgr.add_const('WINHTTP_OPTION_WRITE_BUFFER_SIZE',0x0000000D)
		win_const_mgr.add_const('RC_SCALING',0x00000004)
		win_const_mgr.add_const('PSR_SI',0x00000017)
		win_const_mgr.add_const('DRIVER_W9X_SUSPECT_COMPATID_RANK',0x0000FFFF)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_ACCOUNT_OPS',0x00000224)
		win_const_mgr.add_const('DDSD_MIPMAPCOUNT',0x00020000)
		win_const_mgr.add_const('JOY_BUTTON17',0x00010000)
		win_const_mgr.add_const('DI_FLAGSEX_RESERVED4',0x00004000)
		win_const_mgr.add_const('DI_FLAGSEX_RESERVED3',0x00000002)
		win_const_mgr.add_const('DI_FLAGSEX_RESERVED2',0x00000001)
		win_const_mgr.add_const('GIL_SIMULATEDOC',0x00000001)
		win_const_mgr.add_const('V86FLAGS_CARRY',0x00000001)
		win_const_mgr.add_const('COD_MAJOR_AUDIO',0x00000004)
		win_const_mgr.add_const('RPC_C_FULL_CERT_CHAIN',0x00000001)
		win_const_mgr.add_const('MD_CPU_TRACE',0x00000002)
		win_const_mgr.add_const('SERVICE_CONTROL_SESSIONCHANGE',0x0000000E)
		win_const_mgr.add_const('SI_SERVER_IS_DC',0x00001000)
		win_const_mgr.add_const('MPEGLAYER3_ID_CONSTANTFRAMESIZE',0x00000002)
		win_const_mgr.add_const('PSR_ED',0x0000002B)
		win_const_mgr.add_const('KERB_ETYPE_DES_CBC_MD5_NT',0x00000014)
		win_const_mgr.add_const('DEBUG_FILTER_REMOVE',0x00000004)
		win_const_mgr.add_const('LB_GETTEXTLEN',0x0000018A)
		win_const_mgr.add_const('PHONEINITIALIZEEXOPTION_USEHIDDENWINDOW',0x00000001)
		win_const_mgr.add_const('DS_REPSYNC_PERIODIC',0x00000004)
		win_const_mgr.add_const('LINECALLSTATE_OFFERING',0x00000002)
		win_const_mgr.add_const('OPERATION_ASYNC',0x00000010)
		win_const_mgr.add_const('PROCESSOR_INTEL_IA64',0x00000898)
		win_const_mgr.add_const('LANG_HEBREW',0x00000000)
		win_const_mgr.add_const('SORT_HUNGARIAN_DEFAULT',0x00000000)
		win_const_mgr.add_const('NETLOGON_CONTROL_FIND_USER',0x00000008)
		win_const_mgr.add_const('SF_NCRFORNONASCII',0x00000040)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_SUPPORTEDWRITESPEEDDESCRIPTORS',0x00000116)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_ENVIRONMENT',0x00000000)
		win_const_mgr.add_const('WINEVENT_LEVEL_INFO',0x00000004)
		win_const_mgr.add_const('WINHTTP_QUERY_PRAGMA',0x00000011)
		win_const_mgr.add_const('SQL_FB_OFF',0x00000000)
		win_const_mgr.add_const('ERROR_INVALID_DOMAIN_STATE',0x00000549)
		win_const_mgr.add_const('SSF_INDICATOR',0x00000004)
		win_const_mgr.add_const('CDDS_PREPAINT',0x00000001)
		win_const_mgr.add_const('SERVICE_CONTROL_PRESHUTDOWN',0x0000000F)
		win_const_mgr.add_const('IPPORT_HTTPS',0x000001BB)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NOTCBPRIV',0x0000361B)
		win_const_mgr.add_const('WMDRM_SECURITY_PERFORM_FORCE_INDIV',0x00000004)
		win_const_mgr.add_const('CRYPT_PSTORE',0x00000002)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_100',0x80190064)
		win_const_mgr.add_const('NDIS_ENCAPSULATION_IEEE_802_3',0x00000002)
		win_const_mgr.add_const('STDPROP_DISPLAYKEY',0x00000065)
		win_const_mgr.add_const('DWM_TNP_VISIBLE',0x00000008)
		win_const_mgr.add_const('NETE_NOMAP',0x00000000)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_SERVICE_T3',0x00000400)
		win_const_mgr.add_const('FACILITY_COMPLUS',0x00000011)
		win_const_mgr.add_const('SEARCH_PRIMARY',0x00000001)
		win_const_mgr.add_const('OBM_OLD_ZOOM',0x00007FF4)
		win_const_mgr.add_const('CRL_DIST_POINT_ERR_INDEX_SHIFT',0x00000018)
		win_const_mgr.add_const('IDC_PU_TEXT',0x00000385)
		win_const_mgr.add_const('IMAGE_REL_MIPS_LITERAL',0x00000007)
		win_const_mgr.add_const('IDD_ACMFILTERCHOOSE_BTN_HELP',0x00000009)
		win_const_mgr.add_const('CBR_14400',0x00003840)
		win_const_mgr.add_const('IN_CLASSA_MAX',0x00000080)
		win_const_mgr.add_const('WNPS_MULT',0x00000002)
		win_const_mgr.add_const('ENLISTMENT_RECOVER',0x00000004)
		win_const_mgr.add_const('DDFLIP_NOVSYNC',0x00000008)
		win_const_mgr.add_const('LOGON32_PROVIDER_DEFAULT',0x00000000)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_FILLED_V',0x00000011)
		win_const_mgr.add_const('BSF_FEEDNAVIGATION',0x00080000)
		win_const_mgr.add_const('CERT_ALT_NAME_ENTRY_ERR_INDEX_MASK',0x000000FF)
		win_const_mgr.add_const('LOGON32_LOGON_INTERACTIVE',0x00000002)
		win_const_mgr.add_const('CERT_VERIFY_REV_CHAIN_FLAG',0x00000001)
		win_const_mgr.add_const('DDFLIP_ODD',0x00000004)
		win_const_mgr.add_const('PARTITION_XENIX_2',0x00000003)
		win_const_mgr.add_const('VARIANT_NOUSEROVERRIDE',0x00000004)
		win_const_mgr.add_const('IPPORT_CMDSERVER',0x00000202)
		win_const_mgr.add_const('TMT_TEXTITALIC',0x000008AA)
		win_const_mgr.add_const('DV_SMCHN',0x00000000)
		win_const_mgr.add_const('INTERNET_COOKIE_EVALUATE_P3P',0x00000040)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_IPSECV1_AH_AND_ESP_ENABLED',0x00000004)
		win_const_mgr.add_const('IPX_PTYPE',0x00004000)
		win_const_mgr.add_const('PERF_TYPE_TEXT',0x00000800)
		win_const_mgr.add_const('MMIO_PARSE',0x00000100)
		win_const_mgr.add_const('ACCESS_WRITE',0x00000002)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_CORDUNPLUGGED',0x00000000)
		win_const_mgr.add_const('FILE_TYPE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('DISKQUOTA_USER_ACCOUNT_RESOLVED',0x00000000)
		win_const_mgr.add_const('SQL_TIMEDATE_DIFF_INTERVALS',0x0000006E)
		win_const_mgr.add_const('IPP_E_CLIENTMUSTEMULATE',0xC0048103)
		win_const_mgr.add_const('BG_E_PASSWORD_TOO_LARGE',0x80200026)
		win_const_mgr.add_const('KS_MAX_SIZE_MPEG1_SEQUENCE_INFO',0x0000008C)
		win_const_mgr.add_const('WCS_DEFAULT',0x00000000)
		win_const_mgr.add_const('V86FLAGS_SIGN',0x00000080)
		win_const_mgr.add_const('RECOFLAG_SINGLESEG',0x00000004)
		win_const_mgr.add_const('PSR_SS',0x00000028)
		win_const_mgr.add_const('GESTURE_UP_RIGHT',0x00000000)
		win_const_mgr.add_const('PCF_SPECIALCHARS',0x00000100)
		win_const_mgr.add_const('PORT_NAMP',0x000000A7)
		win_const_mgr.add_const('PC_RECTANGLE',0x00000002)
		win_const_mgr.add_const('WINHTTP_QUERY_VARY',0x00000041)
		win_const_mgr.add_const('LINEREQUESTMODE_MAKECALL',0x00000001)
		win_const_mgr.add_const('SNMPAPI_NOT_INITIALIZED',0x00000012)
		win_const_mgr.add_const('PORT_RPASSWD',0x00000306)
		win_const_mgr.add_const('PXE_ADDR_USE_DHCP_RULES',0x00000008)
		win_const_mgr.add_const('WM_MDINEXT',0x00000224)
		win_const_mgr.add_const('PDH_SQL_EXEC_DIRECT_FAILED',0xC0000BE2)
		win_const_mgr.add_const('LINEMEDIAMODE_TDD',0x00000040)
		win_const_mgr.add_const('LSA_TLN_DISABLED_ADMIN',0x00000002)
		win_const_mgr.add_const('PORT_RIP',0x00000208)
		win_const_mgr.add_const('PORT_RIS',0x000000B4)
		win_const_mgr.add_const('MCGIP_CALENDARCELL',0x00000008)
		win_const_mgr.add_const('CTRY_LEBANON',0x000003C1)
		win_const_mgr.add_const('TA_RIGHT',0x00000002)
		win_const_mgr.add_const('BUTTON_IMAGELIST_ALIGN_LEFT',0x00000000)
		win_const_mgr.add_const('SCESTATUS_PREFIX_OVERFLOW',0x0000000B)
		win_const_mgr.add_const('WM_RENDERFORMAT',0x00000305)
		win_const_mgr.add_const('PROV_STT_ACQ',0x00000008)
		win_const_mgr.add_const('GMEM_NOTIFY',0x00004000)
		win_const_mgr.add_const('WIA_DIP_WIA_VERSION',0x0000000E)
		win_const_mgr.add_const('GCS_RESULTSTR',0x00000800)
		win_const_mgr.add_const('PSP_DEFAULT',0x00000000)
		win_const_mgr.add_const('LINECALLINFOSTATE_BEARERMODE',0x00000004)
		win_const_mgr.add_const('SCRIPTTYPELIB_ISCONTROL',0x00000010)
		win_const_mgr.add_const('SUBLANG_SLOVENIAN_SLOVENIA',0x00000001)
		win_const_mgr.add_const('TF_DISABLE_BALLOON',0x00000002)
		win_const_mgr.add_const('TTFCFP_APPLE_PLATFORMID',0x00000001)
		win_const_mgr.add_const('VOS__WINDOWS16',0x00000001)
		win_const_mgr.add_const('FD_CLOSE_BIT',0x00000005)
		win_const_mgr.add_const('WAVE_FORMAT_2M08',0x00000010)
		win_const_mgr.add_const('EAP_E_SERVER_ROOT_CERT_NOT_FOUND',0x80420400)
		win_const_mgr.add_const('DISPID_WINDOWSETTOP',0x00000109)
		win_const_mgr.add_const('SPC_INC_PE_RESOURCES_FLAG',0x00000080)
		win_const_mgr.add_const('EC_EOS_SOON',0x00000046)
		win_const_mgr.add_const('DS_KCC_FLAG_DAMPED',0x00000001)
		win_const_mgr.add_const('WS_EX_LAYERED',0x00080000)
		win_const_mgr.add_const('DDSCAPS2_DONOTPERSIST',0x00040000)
		win_const_mgr.add_const('DNS_OPCODE_UNKNOWN',0x00000003)
		win_const_mgr.add_const('WM_DESTROY',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_IA64_TOKEN',0x0000001B)
		win_const_mgr.add_const('DEBUG_OUTTYPE_BLOCK_RECURSE',0x00200000)
		win_const_mgr.add_const('DISPLAYDIB_NOTACTIVE',0x00000006)
		win_const_mgr.add_const('WB_RIGHT',0x00000001)
		win_const_mgr.add_const('DS_TIMESERV_FLAG',0x00000040)
		win_const_mgr.add_const('SBM_GETSCROLLBARINFO',0x000000EB)
		win_const_mgr.add_const('ERROR_FILE_IDENTITY_NOT_PERSISTENT',0x00001AA7)
		win_const_mgr.add_const('FACILITY_VIDEO',0x0000001B)
		win_const_mgr.add_const('PAN_PROP_CONDENSED',0x00000006)
		win_const_mgr.add_const('MIXER_OBJECTF_HANDLE',0x80000000)
		win_const_mgr.add_const('MOUSEEVENTF_XUP',0x00000100)
		win_const_mgr.add_const('DM_PAPERLENGTH',0x00000004)
		win_const_mgr.add_const('WT_TRANSFER_IMPERSONATION',0x00000100)
		win_const_mgr.add_const('URLACTION_FEATURE_FORCE_ADDR_AND_STATUS',0x00002104)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_SECONDS',0x00000804)
		win_const_mgr.add_const('INHERIT_ONLY_ACE',0x00000008)
		win_const_mgr.add_const('MPEG_PMT_TID',0x00000002)
		win_const_mgr.add_const('WLX_SAS_TYPE_SC_LAST_READER_REMOVED',0x00000009)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_DEFAULT_FILTER_COMPUTERS',0x00000100)
		win_const_mgr.add_const('INTERNET_OPEN_TYPE_PROXY',0x00000003)
		win_const_mgr.add_const('DBPROP_CI_PROVIDER',0x00000008)
		win_const_mgr.add_const('ERROR_UNKNOWN_PORT',0x00000704)
		win_const_mgr.add_const('INTERNET_DIALSTATE_DISCONNECTED',0x00000001)
		win_const_mgr.add_const('SF_NOTIFY_LOG',0x00000200)
		win_const_mgr.add_const('SHHLNF_WRITENOHISTORY',0x08000000)
		win_const_mgr.add_const('DVB_ST_TID',0x00000072)
		win_const_mgr.add_const('ERROR_INVALID_DRIVE_OBJECT',0x000010E1)
		win_const_mgr.add_const('CERT_HCRYPTPROV_OR_NCRYPT_KEY_HANDLE_PROP_ID',0x0000004F)
		win_const_mgr.add_const('ERROR_LOG_CLIENT_ALREADY_REGISTERED',0x000019EC)
		win_const_mgr.add_const('PROCESS_TERMINATE',0x00000001)
		win_const_mgr.add_const('CERT_STORE_CTRL_AUTO_RESYNC',0x00000004)
		win_const_mgr.add_const('WINHTTP_QUERY_REFRESH',0x0000002E)
		win_const_mgr.add_const('HTTP_QUERY_COST',0x0000000F)
		win_const_mgr.add_const('PXE_ADDR_USE_PORT',0x00000002)
		win_const_mgr.add_const('META_STRETCHDIB',0x00000000)
		win_const_mgr.add_const('VK_SNAPSHOT',0x0000002C)
		win_const_mgr.add_const('MAX_TITLE_LEN',0x0000003C)
		win_const_mgr.add_const('REFERENCE_BLACK_MIN',0x00000000)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_FLOW_HANDLE',0x00000002)
		win_const_mgr.add_const('PT_TEMPORARY',0x00000001)
		win_const_mgr.add_const('DISPLAYDIB_NOPALETTE',0x00000010)
		win_const_mgr.add_const('DCB_ENABLE',0x00000004)
		win_const_mgr.add_const('ERROR_DBG_EXCEPTION_NOT_HANDLED',0x000002B0)
		win_const_mgr.add_const('TXFS_RM_FLAG_RENAME_RM',0x00000002)
		win_const_mgr.add_const('IF_TYPE_GR303_IDT',0x000000B2)
		win_const_mgr.add_const('EMR_PAINTRGN',0x0000004A)
		win_const_mgr.add_const('FILE_DEVICE_PRINTER',0x00000018)
		win_const_mgr.add_const('ISC_RET_FRAGMENT_ONLY',0x00200000)
		win_const_mgr.add_const('PROP_DISPLAY_HINT',0x00000004)
		win_const_mgr.add_const('RASLCPAP_CHAP',0x0000C223)
		win_const_mgr.add_const('IDM_TRIED_UNDO',0x0000003A)
		win_const_mgr.add_const('METHOD_BGP4_PEER_ID',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_WRITE_BUFFER_SIZE',0x0000000D)
		win_const_mgr.add_const('CMSG_CONTENT_ENCRYPT_PAD_ENCODED_LEN_FLAG',0x00000001)
		win_const_mgr.add_const('LINEEQOSINFO_POLICYFAILURE',0x00000003)
		win_const_mgr.add_const('ERROR_LABEL_QUESTIONABLE',0x00000002)
		win_const_mgr.add_const('MDM_SHIFT_PROTOCOLID',0x00000010)
		win_const_mgr.add_const('WIA_PROP_CACHEABLE',0x00010000)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM7B_VAL_POS_X',0x00000000)
		win_const_mgr.add_const('SHARE_PATH_PARMNUM',0x00000008)
		win_const_mgr.add_const('MF_FLAGS_NO_CREATE_IF_NO_RESOURCE',0x00000002)
		win_const_mgr.add_const('PRIVACY_TEMPLATE_ADVANCED',0x00000065)
		win_const_mgr.add_const('TBCDRF_BLENDICON',0x00200000)
		win_const_mgr.add_const('WLX_SAS_ACTION_SHUTDOWN_POWER_OFF',0x0000000A)
		win_const_mgr.add_const('HTTP_MAX_SERVER_QUEUE_LENGTH',0x7FFFFFFF)
		win_const_mgr.add_const('PFM_NUMBERINGSTART',0x00008000)
		win_const_mgr.add_const('DISPID_PRINTTEMPLATETEARDOWN',0x000000E2)
		win_const_mgr.add_const('PROTO_IP_NT_STATIC_NON_DOD',0x00002717)
		win_const_mgr.add_const('MCI_ANIM_OPEN_NOSTATIC',0x00040000)
		win_const_mgr.add_const('DC_MINEXTENT',0x00000004)
		win_const_mgr.add_const('DEVPROP_TYPE_BOOLEAN',0x00000011)
		win_const_mgr.add_const('SYMSEARCH_RECURSE',0x00000000)
		win_const_mgr.add_const('WMDM_MODE_TRANSFER_UNPROTECTED',0x00000100)
		win_const_mgr.add_const('DLGC_UNDEFPUSHBUTTON',0x00000020)
		win_const_mgr.add_const('IPX_ROUTE_FILTER_PERMIT',0x00000001)
		win_const_mgr.add_const('CACHE_FULLY_ASSOCIATIVE',0x000000FF)
		win_const_mgr.add_const('MAPMIME_CLSID',0x00000001)
		win_const_mgr.add_const('MCI_VCR_STATUS_CLOCK_ID',0x00004021)
		win_const_mgr.add_const('OPTION_CLIENT_CLASS_INFO',0x0000003C)
		win_const_mgr.add_const('TAPE_DRIVE_SETMARKS',0x80100000)
		win_const_mgr.add_const('MD_NOTIFY_END_OF_NET_SESSION',0x00000100)
		win_const_mgr.add_const('DIRID_SPOOLDRIVERS',0x00000034)
		win_const_mgr.add_const('INDEX_GUID_PARAGRAPH',0x00000007)
		win_const_mgr.add_const('PROCESS_CREATE_THREAD',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_QM_POLICY_PENDING_DELETION',0x000032DF)
		win_const_mgr.add_const('ERROR_DS_CANT_FIND_EXPECTED_NC',0x000020E4)
		win_const_mgr.add_const('WAB_VCARD_FILE',0x00000000)
		win_const_mgr.add_const('RIDEV_APPKEYS',0x00000400)
		win_const_mgr.add_const('SHCNE_RENAMEITEM',0x00000001)
		win_const_mgr.add_const('SFGAO_VALIDATE',0x01000000)
		win_const_mgr.add_const('CB_GETITEMHEIGHT',0x00000154)
		win_const_mgr.add_const('WM_MOUSELAST',0x00000209)
		win_const_mgr.add_const('IF_TYPE_X213',0x0000005D)
		win_const_mgr.add_const('DDSETSURFACEDESC_RECREATEDC',0x00000000)
		win_const_mgr.add_const('MSIM_DISPID_ONFRIENDLYNAMECHANGERESULT',0x00000E04)
		win_const_mgr.add_const('VK_SHIFT',0x00000010)
		win_const_mgr.add_const('ERROR_BAD_FORMAT',0x0000000B)
		win_const_mgr.add_const('CMSG_MAIL_LIST_ENCRYPT_FREE_PARA_FLAG',0x00000001)
		win_const_mgr.add_const('PIDSI_TITLE',0x00000002)
		win_const_mgr.add_const('ERROR_NOT_REGISTRY_FILE',0x000003F9)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_NOCONF',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_SQ_IN',0x00000008)
		win_const_mgr.add_const('ALG_SID_SCHANNEL_MAC_KEY',0x00000003)
		win_const_mgr.add_const('D3DMAXUSERCLIPPLANES',0x00000020)
		win_const_mgr.add_const('PP_SESSION_KEYSIZE',0x00000014)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_245',0x00000000)
		win_const_mgr.add_const('LINECALLCOMPLMODE_CAMPON',0x00000001)
		win_const_mgr.add_const('SSPROP_INIT_WSID',0x0000000B)
		win_const_mgr.add_const('SNMP_OUTPUT_TO_DEBUGGER',0x00000008)
		win_const_mgr.add_const('ENM_LANGCHANGE',0x01000000)
		win_const_mgr.add_const('PSINJECT_ENDSETUP',0x00000011)
		win_const_mgr.add_const('WVR_ALIGNRIGHT',0x00000080)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_247',0x00000000)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_EXTERNAL_DOWNLEVEL_DOMAIN',0x00000040)
		win_const_mgr.add_const('BDR_RAISEDINNER',0x00000004)
		win_const_mgr.add_const('DEVICEPOWER_FILTER_HARDWARE',0x10000000)
		win_const_mgr.add_const('MCI_VCR_SET_TIME_MODE',0x00010000)
		win_const_mgr.add_const('TAPE_ABSOLUTE_POSITION',0x00000000)
		win_const_mgr.add_const('PORT_STATSRV',0x00000085)
		win_const_mgr.add_const('NUMMARKERS',0x00000014)
		win_const_mgr.add_const('DDPF_PALETTEINDEXED8',0x00000020)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_241',0x00000000)
		win_const_mgr.add_const('MCI_SEQ_SET_MASTER',0x00080000)
		win_const_mgr.add_const('MCI_WAVE_STATUS_AVGBYTESPERSEC',0x00004004)
		win_const_mgr.add_const('DDPF_PALETTEINDEXED2',0x00001000)
		win_const_mgr.add_const('GESTURE_DOUBLE_LEFT',0x00000000)
		win_const_mgr.add_const('FEI_INITIALIZING',0x00000018)
		win_const_mgr.add_const('CMSG_KEY_AGREE_ENCRYPT_FREE_PUBKEY_PARA_FLAG',0x00000008)
		win_const_mgr.add_const('PIDMSI_COPYRIGHT',0x0000000B)
		win_const_mgr.add_const('AF_ISO',0x00000007)
		win_const_mgr.add_const('SPREG_SUCCESS',0x00000000)
		win_const_mgr.add_const('MMIO_FINDLIST',0x00000040)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW4_FRAMEELEMENT',0x0000049D)
		win_const_mgr.add_const('_MULTIMON_USE_SECURE_CRT',0x00000000)
		win_const_mgr.add_const('CERT_RDN_VIDEOTEX_STRING',0x00000006)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_ACCEPT',0x0000000F)
		win_const_mgr.add_const('DNS_RCLASS_CSNET',0x00000200)
		win_const_mgr.add_const('STM_ONLY_THIS_NAME',0x00000008)
		win_const_mgr.add_const('ERROR_NO_NET_OR_BAD_PATH',0x000004B3)
		win_const_mgr.add_const('IMAGE_REL_MIPS_REFWORDNB',0x00000022)
		win_const_mgr.add_const('SQL_DP_OFF',0x00000000)
		win_const_mgr.add_const('SECURITY_FLAG_FORTEZZA',0x08000000)
		win_const_mgr.add_const('ERROR_PRODUCT_VERSION',0x00000666)
		win_const_mgr.add_const('SFVM_BACKGROUNDENUM',0x00000020)
		win_const_mgr.add_const('CERT_PROT_ROOT_ONLY_LM_GPT_FLAG',0x00000008)
		win_const_mgr.add_const('OPEN_EXISTING',0x00000003)
		win_const_mgr.add_const('MDPROPVAL_MSF_DRILLDOWNLEVEL',0x00000800)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_RESPONSE_VALIDATED',0x00008000)
		win_const_mgr.add_const('EMR_CHORD',0x0000002E)
		win_const_mgr.add_const('EVENT_TRACE_USE_GLOBAL_SEQUENCE',0x00004000)
		win_const_mgr.add_const('ERROR_CTX_LICENSE_NOT_AVAILABLE',0x00001B8E)
		win_const_mgr.add_const('OID_TAPI_DIAL',0x07030108)
		win_const_mgr.add_const('DBPROPVAL_IN_IGNORENULL',0x00000002)
		win_const_mgr.add_const('CRYPT_UI_PROMPT',0x00000004)
		win_const_mgr.add_const('WSB_PROP_CXHTHUMB',0x00000010)
		win_const_mgr.add_const('FILEOP_SKIP',0x00000002)
		win_const_mgr.add_const('KP_PRECOMP_MD5',0x00000018)
		win_const_mgr.add_const('ERROR_DESTINATION_ELEMENT_FULL',0x00000489)
		win_const_mgr.add_const('ERROR_INSTALL_ALREADY_RUNNING',0x00000652)
		win_const_mgr.add_const('PS_256M',0x00000001)
		win_const_mgr.add_const('WMPGC_FLAGS_ALLOW_PREROLL',0x00000001)
		win_const_mgr.add_const('CERT_VERIFY_NO_TIME_CHECK_FLAG',0x00000004)
		win_const_mgr.add_const('RECOFLAG_AUTOSPACE',0x00000040)
		win_const_mgr.add_const('HDS_FULLDRAG',0x00000080)
		win_const_mgr.add_const('DFCS_SCROLLDOWN',0x00000001)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_MIN_CUSTOM',0x00400000)
		win_const_mgr.add_const('TRACE_HEADER_FLAG_LOG_WNODE',0x00040000)
		win_const_mgr.add_const('RPC_C_DONT_FAIL',0x00000004)
		win_const_mgr.add_const('HLNF_TRUSTEDFORACTIVEX',0x00400000)
		win_const_mgr.add_const('IMAGE_REL_IA64_SECREL22',0x0000000C)
		win_const_mgr.add_const('WSAEPROVIDERFAILEDINIT',0x0000277A)
		win_const_mgr.add_const('OCSP_BASIC_REVOKED_CERT_STATUS',0x00000001)
		win_const_mgr.add_const('RIGHT_CTRL_PRESSED',0x00000004)
		win_const_mgr.add_const('DNOBJECT_MIRROR',0x00000019)
		win_const_mgr.add_const('IDM_TEMPLATE_PAGESETUP',0x000008FA)
		win_const_mgr.add_const('DEBUG_SYMTYPE_DIA',0x00000007)
		win_const_mgr.add_const('IPX_INTERFACE_INFO_TYPE',0x00000001)
		win_const_mgr.add_const('POLICY_AUDIT_SUBCATEGORY_COUNT',0x00000032)
		win_const_mgr.add_const('DOF_SHELLDATA',0x00000002)
		win_const_mgr.add_const('MAX_SYM_NAME',0x000007D0)
		win_const_mgr.add_const('D3DSI_OPCODE_MASK',0x0000FFFF)
		win_const_mgr.add_const('CM_SET_HW_PROF_FLAGS_BITS',0x00000001)
		win_const_mgr.add_const('INTERNET_CACHE_GROUP_REMOVE',0x00000001)
		win_const_mgr.add_const('HTTP_QUERY_EXPECT',0x00000044)
		win_const_mgr.add_const('NUMBRUSHES',0x00000010)
		win_const_mgr.add_const('D3DCURSORCAPS_LOWRES',0x00000002)
		win_const_mgr.add_const('RAS_FLAGS_QUARANTINE_PRESENT',0x00000008)
		win_const_mgr.add_const('BCP_FMT_SERVER_COL',0x00000005)
		win_const_mgr.add_const('WIA_PAGE_ISO_B10',0x0000001B)
		win_const_mgr.add_const('DISPID_FONT_NAME',0x00000000)
		win_const_mgr.add_const('SOCKET_SETTINGS_ALLOW_INSECURE',0x00000002)
		win_const_mgr.add_const('TLS1_ALERT_RECORD_OVERFLOW',0x00000016)
		win_const_mgr.add_const('SQL_FD_FETCH_PRIOR',0x00000008)
		win_const_mgr.add_const('URLACTION_WINDOWS_BROWSER_APPLICATIONS',0x00002400)
		win_const_mgr.add_const('HTTP_QUERY_DERIVED_FROM',0x0000000E)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_NO_REMOVING_CHANNELS',0x00001D02)
		win_const_mgr.add_const('GGL_INDEX',0x00000002)
		win_const_mgr.add_const('UF_TRUSTED_TO_AUTHENTICATE_FOR_DELEGATION',0x01000000)
		win_const_mgr.add_const('TXFS_RM_FLAG_LOG_CONTAINER_COUNT_MAX',0x00000004)
		win_const_mgr.add_const('PL_USER',0x00000003)
		win_const_mgr.add_const('SQL_CONVERT_TIME',0x00000042)
		win_const_mgr.add_const('ISC_RET_INTERMEDIATE_RETURN',0x00001000)
		win_const_mgr.add_const('CM_GLOBAL_STATE_CAN_DO_UI',0x00000001)
		win_const_mgr.add_const('PERF_COUNTER_FRACTION',0x00020000)
		win_const_mgr.add_const('MF_CHECKED',0x00000008)
		win_const_mgr.add_const('SQL_NNC_NON_NULL',0x00000001)
		win_const_mgr.add_const('NUMPRS_TRAILING_PLUS',0x00000008)
		win_const_mgr.add_const('ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME',0x0000170C)
		win_const_mgr.add_const('NIF_ICON',0x00000002)
		win_const_mgr.add_const('SHPWHF_VALIDATEVIAWEBFOLDERS',0x00010000)
		win_const_mgr.add_const('SUBLANG_ITALIAN',0x00000001)
		win_const_mgr.add_const('SDP_ATTRIB_HID_SDP_DISABLE',0x00000208)
		win_const_mgr.add_const('LOWER_GET_HINT_MASK',0x0000FF00)
		win_const_mgr.add_const('DDSCAPS_PRIMARYSURFACELEFT',0x00000000)
		win_const_mgr.add_const('KSDSOUND_BUFFER_CTRL_POSITIONNOTIFY',0x00000010)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYSTRETCHYN',0x04000000)
		win_const_mgr.add_const('LCMAP_LOWERCASE',0x00000100)
		win_const_mgr.add_const('PHOTOACQ_DISABLE_DB_INTEGRATION',0x00000010)
		win_const_mgr.add_const('CERT_SMART_CARD_DATA_PROP_ID',0x00000010)
		win_const_mgr.add_const('SHPWHF_NOFILESELECTOR',0x00000004)
		win_const_mgr.add_const('MAX_THEMECOLOR',0x00000040)
		win_const_mgr.add_const('USER_TRUSTED_FOR_DELEGATION',0x00002000)
		win_const_mgr.add_const('IME_ITHOTKEY_RESEND_RESULTSTR',0x00000200)
		win_const_mgr.add_const('WM_CLEAR',0x00000303)
		win_const_mgr.add_const('IDM_OVERRIDE_CURSOR',0x00000974)
		win_const_mgr.add_const('NNTP_MD_ID_BEGIN_RESERVED',0x00000000)
		win_const_mgr.add_const('SYMFLAG_RESET',0x80000000)
		win_const_mgr.add_const('ERROR_DS_REPL_LIFETIME_EXCEEDED',0x000021A6)
		win_const_mgr.add_const('PST_NETWORK_BRIDGE',0x00000100)
		win_const_mgr.add_const('FWPM_CONTEXT_IPSEC_INBOUND_PERSIST_CONNECTION_SECURITY',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_DATA_SEND_TIMEOUT',0x00000007)
		win_const_mgr.add_const('CTF_PROCESS_REF',0x00000004)
		win_const_mgr.add_const('ERROR_NO_PROC_SLOTS',0x00000059)
		win_const_mgr.add_const('DEBUG_SESSION_END_SESSION_PASSIVE',0x00000003)
		win_const_mgr.add_const('JOB_CONTROL_PAUSE',0x00000001)
		win_const_mgr.add_const('CERT_BIOMETRIC_OID_DATA_CHOICE',0x00000002)
		win_const_mgr.add_const('NTDDI_WIN2KSP1',0x05000100)
		win_const_mgr.add_const('DDOVER_ALPHADESTNEG',0x00000004)
		win_const_mgr.add_const('DNS_REGISTER',0x00000001)
		win_const_mgr.add_const('ISO_NON_HIERARCHICAL',0x00000001)
		win_const_mgr.add_const('CRL_FIND_EXISTING',0x00000002)
		win_const_mgr.add_const('SPREG_TIMEOUT',0x00000005)
		win_const_mgr.add_const('ACM_STREAMCONVERTF_END',0x00000020)
		win_const_mgr.add_const('DISPLAY_DEVICE_REMOVABLE',0x00000020)
		win_const_mgr.add_const('PIR_STATUS_MINIPORT_INVALID',0x00000007)
		win_const_mgr.add_const('TVIS_EXPANDED',0x00000020)
		win_const_mgr.add_const('IPV6_MULTICAST_HOPS',0x0000000A)
		win_const_mgr.add_const('SQL_LOCK_UNLOCK',0x00000002)
		win_const_mgr.add_const('NRB_FUNCTION_QUERY_CACHE_MISS',0x00000013)
		win_const_mgr.add_const('PROPTYPE_LONG',0x00000001)
		win_const_mgr.add_const('COMMON_LVB_UNDERSCORE',0x00008000)
		win_const_mgr.add_const('PROPID_MGMT_MSMQ_BASE',0x00000000)
		win_const_mgr.add_const('HTTP_QUERY_FROM',0x0000001F)
		win_const_mgr.add_const('FS_BALTIC',0x00000080)
		win_const_mgr.add_const('CERT_TRUST_IS_SELF_SIGNED',0x00000008)
		win_const_mgr.add_const('MCI_DGV_WHERE_FRAME',0x00080000)
		win_const_mgr.add_const('HCF_HOTKEYAVAILABLE',0x00000040)
		win_const_mgr.add_const('CRR_CALL_LIMIT',0xFFFFFFFD)
		win_const_mgr.add_const('DISPID_WINDOWMOVE',0x0000006D)
		win_const_mgr.add_const('ISDB_SDTT_PID',0x00000023)
		win_const_mgr.add_const('CTRY_EGYPT',0x00000014)
		win_const_mgr.add_const('ERROR_DS_FOREST_VERSION_TOO_HIGH',0x00002173)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_WINEVT_RECEIVE',0x00000000)
		win_const_mgr.add_const('DEBUG_DUMP_IMAGE_FILE',0x00000403)
		win_const_mgr.add_const('CERT_STORE_OPEN_EXISTING_FLAG',0x00004000)
		win_const_mgr.add_const('PD_ENABLEPRINTHOOK',0x00001000)
		win_const_mgr.add_const('OID_IRDA_SUPPORTED_SPEEDS',0x0A010102)
		win_const_mgr.add_const('AA_S_WRITE',0x00000020)
		win_const_mgr.add_const('PHRASE_FEEDBACK',0x00000004)
		win_const_mgr.add_const('WIA_INTENT_NONE',0x00000000)
		win_const_mgr.add_const('STAT_REFRESH',0x00000003)
		win_const_mgr.add_const('SPI_SETANIMATION',0x00000049)
		win_const_mgr.add_const('IME_CAND_MEANING',0x00000003)
		win_const_mgr.add_const('DRM_EL_GROUPIDENTITY_NAME',0x00000004)
		win_const_mgr.add_const('TIME_NOTIMEMARKER',0x00000004)
		win_const_mgr.add_const('SHUTDOWN_INSTALL_UPDATES',0x00000040)
		win_const_mgr.add_const('DEVPROP_TYPE_INT64',0x00000008)
		win_const_mgr.add_const('ERROR_EVT_FILTER_INVARG',0x00003AA8)
		win_const_mgr.add_const('TBS_NOTIFYBEFOREMOVE',0x00000800)
		win_const_mgr.add_const('ERROR_LABEL_TOO_LONG',0x0000009A)
		win_const_mgr.add_const('WIA_SHOW_PREVIEW_CONTROL',0x00000000)
		win_const_mgr.add_const('ENABLE_WRAP_AT_EOL_OUTPUT',0x00000002)
		win_const_mgr.add_const('FLAGSTATUS_COMPLETED',0x00000001)
		win_const_mgr.add_const('PID_FINDDATA',0x00000000)
		win_const_mgr.add_const('WMDM_E_MOREDATA',0x80045009)
		win_const_mgr.add_const('PROTO_IP_DHCP_ALLOCATOR',0x00002714)
		win_const_mgr.add_const('KLF_ACTIVATE',0x00000001)
		win_const_mgr.add_const('IDM_SHOWPRINT',0x000007DA)
		win_const_mgr.add_const('HLNF_UNTRUSTEDFORDOWNLOAD',0x02000000)
		win_const_mgr.add_const('MOUSEEVENTF_VIRTUALDESK',0x00004000)
		win_const_mgr.add_const('ISSH_BREAK_BIT',0x00000080)
		win_const_mgr.add_const('WSAEINVALIDPROCTABLE',0x00002778)
		win_const_mgr.add_const('DEFAULT_SNMPTRAP_PORT_IPX',0x00009010)
		win_const_mgr.add_const('DEBUG_REQUEST_TARGET_EXCEPTION_THREAD',0x00000002)
		win_const_mgr.add_const('CAUSE_BEARER_CAPABILITY_UNAVAILABLE',0x0000003A)
		win_const_mgr.add_const('IPX_NO_UPDATE',0x00000002)
		win_const_mgr.add_const('RF_POWER',0x00000040)
		win_const_mgr.add_const('BOM_DEFPARADIR',0x00000001)
		win_const_mgr.add_const('MAX_LCPRI',0x0000FFFF)
		win_const_mgr.add_const('SHCNE_DELETE',0x00000004)
		win_const_mgr.add_const('HEAP_GENERATE_EXCEPTIONS',0x00000004)
		win_const_mgr.add_const('SI_EDIT_PERMS',0x00000000)
		win_const_mgr.add_const('SQL_FETCH_FIRST_USER',0x0000001F)
		win_const_mgr.add_const('DMDFO_CENTER',0x00000002)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_DEVICE_OBJECT_ATTRIBUTES',0x00000085)
		win_const_mgr.add_const('DBTF_SLOWNET',0x00000004)
		win_const_mgr.add_const('GAA_FLAG_INCLUDE_GATEWAYS',0x00000080)
		win_const_mgr.add_const('HSHELL_HIGHBIT',0x00008000)
		win_const_mgr.add_const('ACM_DRIVERADDF_FUNCTION',0x00000003)
		win_const_mgr.add_const('ERROR_SXS_XML_E_BADXMLCASE',0x000036F5)
		win_const_mgr.add_const('DBPROPVAL_CO_STRING',0x00000002)
		win_const_mgr.add_const('FDTF_NOAUTOREADINGORDER',0x00000400)
		win_const_mgr.add_const('IMAGE_REL_EBC_REL32',0x00000002)
		win_const_mgr.add_const('DFCS_CAPTIONHELP',0x00000004)
		win_const_mgr.add_const('COLOR_GRADIENTINACTIVECAPTION',0x0000001C)
		win_const_mgr.add_const('DI_FLAGSEX_CI_FAILED',0x00000004)
		win_const_mgr.add_const('LINEFORWARDMODE_NOANSWEXTERNAL',0x00000400)
		win_const_mgr.add_const('IF_TYPE_DVBRCC_DOWNSTREAM',0x00000093)
		win_const_mgr.add_const('RES_CURSOR',0x00000002)
		win_const_mgr.add_const('PP_UNIQUE_CONTAINER',0x00000024)
		win_const_mgr.add_const('RQ_END_REQUEST',0x00000800)
		win_const_mgr.add_const('IPPORT_TCPMUX',0x00000001)
		win_const_mgr.add_const('DS_REPSYNC_TWO_WAY',0x00000800)
		win_const_mgr.add_const('CERT_EXCLUDED_SUBTREE_BIT',0x80000000)
		win_const_mgr.add_const('WMDM_STORAGECONTROL_INSERTBEFORE',0x00000200)
		win_const_mgr.add_const('SCARD_POWER_DOWN',0x00000000)
		win_const_mgr.add_const('OID_WAN_CO_GET_INFO',0x04010180)
		win_const_mgr.add_const('GESTURE_DOUBLE_ARROW_RIGHT',0x00000000)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_PCI_DEVICE_CUSTOM_PROPERTIES_REVISION_1',0x00000001)
		win_const_mgr.add_const('PROPID_QUERY_ALL',0x00000006)
		win_const_mgr.add_const('CDRF_SKIPDEFAULT',0x00000004)
		win_const_mgr.add_const('RPC_S_NO_PRINC_NAME',0x0000071E)
		win_const_mgr.add_const('MH_CREATE',0x00000001)
		win_const_mgr.add_const('FWPM_NET_EVENT_FLAG_IP_VERSION_SET',0x00000100)
		win_const_mgr.add_const('SQL_ATTR_PARAM_BIND_TYPE',0x00000012)
		win_const_mgr.add_const('DMPAPER_ENV_C5',0x0000001C)
		win_const_mgr.add_const('ERROR_IPSEC_TRANSPORT_FILTER_EXISTS',0x000032D0)
		win_const_mgr.add_const('NUM_LOG_CONF',0x00000006)
		win_const_mgr.add_const('WN_PRIMARY_AUTHENT_CLASS',0x00000004)
		win_const_mgr.add_const('MCI_DGV_WINDOW_DEFAULT',0x00000000)
		win_const_mgr.add_const('SQL_CVT_VARBINARY',0x00000800)
		win_const_mgr.add_const('SQL_ATTR_ODBC_VERSION',0x000000C8)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_MIN_CUSTOM',0x00000100)
		win_const_mgr.add_const('SQL_CURSOR_TYPE',0x00000006)
		win_const_mgr.add_const('PDH_FLAGS_CLOSE_QUERY',0x00000001)
		win_const_mgr.add_const('BCRYPT_RNG_OPERATION',0x00000020)
		win_const_mgr.add_const('MCI_UNFREEZE',0x00000845)
		win_const_mgr.add_const('DMDFO_DEFAULT',0x00000000)
		win_const_mgr.add_const('PRINTDLGEXORD',0x0000060D)
		win_const_mgr.add_const('CERT_FILE_STORE_COMMIT_ENABLE_FLAG',0x00010000)
		win_const_mgr.add_const('SAM_DAYS_PER_WEEK',0x00000007)
		win_const_mgr.add_const('DISPID_IMULTISESSION_INUSE',0x00000101)
		win_const_mgr.add_const('PSINJECT_PLATECOLOR',0x00000068)
		win_const_mgr.add_const('EPT_S_CANT_CREATE',0x0000076B)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_DISCONNECT',0x00000006)
		win_const_mgr.add_const('QS_KEY',0x00000001)
		win_const_mgr.add_const('CM_PROB_DUPLICATE_DEVICE',0x0000002A)
		win_const_mgr.add_const('SUBLANG_JAPANESE_JAPAN',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_QM_ACQUIRE_DROP',0x000035F2)
		win_const_mgr.add_const('NS_PNRPNAME',0x00000026)
		win_const_mgr.add_const('PSH_WIZARD_LITE',0x00400000)
		win_const_mgr.add_const('IF_TYPE_MPC',0x00000071)
		win_const_mgr.add_const('TRACE_HEADER_FLAG_USE_MOF_PTR',0x00100000)
		win_const_mgr.add_const('DDE_FREQUESTED',0x00001000)
		win_const_mgr.add_const('CRYPT_ACQUIRE_USE_PROV_INFO_FLAG',0x00000002)
		win_const_mgr.add_const('EAP_E_EAPHOST_METHOD_OPERATION_NOT_SUPPORTED',0x80420020)
		win_const_mgr.add_const('MM_STREAM_CLOSE',0x000003D5)
		win_const_mgr.add_const('D3DPSHADECAPS_COLORGOURAUDRGB',0x00000008)
		win_const_mgr.add_const('MAC_BINARY',0x00000001)
		win_const_mgr.add_const('SFVM_DEFVIEWMODE',0x0000001B)
		win_const_mgr.add_const('LANG_HINDI',0x00000039)
		win_const_mgr.add_const('DAO_NULL',0x00000000)
		win_const_mgr.add_const('DDCAPS_COLORKEYHWASSIST',0x01000000)
		win_const_mgr.add_const('MDITILE_VERTICAL',0x00000000)
		win_const_mgr.add_const('LDAP_MOD_BVALUES',0x00000080)
		win_const_mgr.add_const('CDO_E_PROP_UNSUPPORTED',0x80040205)
		win_const_mgr.add_const('RPC_PROTSEQ_TCP',0x00000001)
		win_const_mgr.add_const('SQLUNIQUEID',0x00000024)
		win_const_mgr.add_const('CTRY_ESTONIA',0x00000174)
		win_const_mgr.add_const('EAP_E_USER_ROOT_CERT_LAST',0x804203FF)
		win_const_mgr.add_const('LANG_DEFAULT_ID',0x00000100)
		win_const_mgr.add_const('ERROR_DS_DRA_NO_REPLICA',0x00002104)
		win_const_mgr.add_const('PARTITION_PREP',0x00000041)
		win_const_mgr.add_const('SV_MAXGLOBALOPENSEARCH_PARMNUM',0x00000235)
		win_const_mgr.add_const('PORT_LPD730',0x000002DA)
		win_const_mgr.add_const('TF_LBI_STYLE_HIDEONNOOTHERITEMS',0x00000004)
		win_const_mgr.add_const('TBSTYLE_DROPDOWN',0x00000008)
		win_const_mgr.add_const('MN_GETHMENU',0x000001E1)
		win_const_mgr.add_const('DDL_DIRECTORY',0x00000010)
		win_const_mgr.add_const('SV_TYPE_ALTERNATE_XPORT',0x20000000)
		win_const_mgr.add_const('DNS_CLASS_ALL',0x00000000)
		win_const_mgr.add_const('CERT_STORE_PROV_READ_CRL_FUNC',0x00000005)
		win_const_mgr.add_const('ERROR_DS_DRA_CONNECTION_FAILED',0x000020FC)
		win_const_mgr.add_const('DLLVER_PLATFORM_WINDOWS',0x00000001)
		win_const_mgr.add_const('EMR_RECTANGLE',0x0000002B)
		win_const_mgr.add_const('WINHTTP_AUTOPROXY_RUN_INPROCESS',0x00010000)
		win_const_mgr.add_const('ACCESS_ATTR_PARMNUM',0x00000002)
		win_const_mgr.add_const('NRB_OUTPUT_DATA_UNDERRUN',0x00000006)
		win_const_mgr.add_const('SPFILENOTIFY_ENDRENAME',0x00000009)
		win_const_mgr.add_const('KP_INFO',0x00000012)
		win_const_mgr.add_const('CM_LOCATE_DEVNODE_NORMAL',0x00000000)
		win_const_mgr.add_const('MDPROPVAL_MMF_OPENINGPERIOD',0x00000004)
		win_const_mgr.add_const('D3D10_MIN_BORDER_COLOR_COMPONENT',0x00000000)
		win_const_mgr.add_const('PTE_PS',0x00000037)
		win_const_mgr.add_const('ERROR_MUTUAL_AUTH_FAILED',0x00000575)
		win_const_mgr.add_const('LOCALE_STIME',0x0000001E)
		win_const_mgr.add_const('DEBUG_SOURCE_IS_STATEMENT',0x00000001)
		win_const_mgr.add_const('PID_DISPLACED_FROM',0x00000002)
		win_const_mgr.add_const('MCI_VCR_STATUS_CLOCK',0x0000401C)
		win_const_mgr.add_const('MAPIFORM_SELECT_FOLDER_REGISTRY_ONLY',0x00000001)
		win_const_mgr.add_const('WM_PALETTECHANGED',0x00000311)
		win_const_mgr.add_const('MV_INSTANCE',0x00002000)
		win_const_mgr.add_const('CRR_RECYCLED_FROM_UI',0xFFFFFFFB)
		win_const_mgr.add_const('DFS_VOLUME_STATE_RESYNCHRONIZE',0x00000010)
		win_const_mgr.add_const('IIS_MD_APP_BASE',0x0000238C)
		win_const_mgr.add_const('PSR_CPL_LEN',0x00000002)
		win_const_mgr.add_const('MCIWNDF_NOTIFYMEDIAW',0x00000800)
		win_const_mgr.add_const('CRYPT_DECODE_TO_BE_SIGNED_FLAG',0x00000002)
		win_const_mgr.add_const('CMSG_TRUSTED_SIGNER_FLAG',0x00000001)
		win_const_mgr.add_const('XP_ENCRYPTS',0x00002000)
		win_const_mgr.add_const('GC_WCH_ALL',0x00000004)
		win_const_mgr.add_const('WM_PRINT',0x00000317)
		win_const_mgr.add_const('RPC_FLAGS_VALID_BIT',0x00008000)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_LOCATION_SHIFT',0x00000010)
		win_const_mgr.add_const('ERROR_TRANSACTION_NOT_FOUND',0x00001A3B)
		win_const_mgr.add_const('ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE',0x00001783)
		win_const_mgr.add_const('D3DPMISCCAPS_INDEPENDENTWRITEMASKS',0x00004000)
		win_const_mgr.add_const('DISPID_FONT_ITALIC',0x00000004)
		win_const_mgr.add_const('ERROR_CTX_CONSOLE_DISCONNECT',0x00001B81)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_DH_FAIL',0x000035FE)
		win_const_mgr.add_const('STGM_READ',0x00000000)
		win_const_mgr.add_const('POLICY_AUDIT_EVENT_NONE',0x00000004)
		win_const_mgr.add_const('ERROR_KEY_DELETED',0x000003FA)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_ALL_LOCAL',0x00000080)
		win_const_mgr.add_const('D3DPMISCCAPS_CULLCCW',0x00000040)
		win_const_mgr.add_const('PHONEERR_RESOURCEUNAVAIL',0x9000001F)
		win_const_mgr.add_const('HH_ENUM_CATEGORY',0x00000015)
		win_const_mgr.add_const('SORT_CHINESE_BOPOMOFO',0x00000003)
		win_const_mgr.add_const('WNODE_FLAG_ANSI_INSTANCENAMES',0x00004000)
		win_const_mgr.add_const('SQL_COLUMN_UNSIGNED',0x00000008)
		win_const_mgr.add_const('LGRPID_ARMENIAN',0x00000011)
		win_const_mgr.add_const('DIGCF_DEVICEINTERFACE',0x00000010)
		win_const_mgr.add_const('ERROR_FAIL_NOACTION_REBOOT',0x0000015E)
		win_const_mgr.add_const('SEL_MULTIOBJECT',0x00000008)
		win_const_mgr.add_const('SHDID_MOBILE_DEVICE',0x00000015)
		win_const_mgr.add_const('ILS_GLOW',0x00000001)
		win_const_mgr.add_const('IF_NORPCICERTREQUEST',0x00000008)
		win_const_mgr.add_const('ACCESS_MAX_MS_V5_ACE_TYPE',0x00000011)
		win_const_mgr.add_const('KS_VIDEO_ALLOC_VPE_AGP',0x00000004)
		win_const_mgr.add_const('TAPE_DRIVE_WRITE_SHORT_FMKS',0x84000000)
		win_const_mgr.add_const('ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE',0x00000511)
		win_const_mgr.add_const('TF_RP_SUBITEMINSETTINGUI',0x00000010)
		win_const_mgr.add_const('LVCF_FMT',0x00000001)
		win_const_mgr.add_const('PDCAP_D2_SUPPORTED',0x00000004)
		win_const_mgr.add_const('SO_LINGER',0x00000080)
		win_const_mgr.add_const('SQL_CREATE_TABLE',0x00000084)
		win_const_mgr.add_const('SV_MAXAUDITSZ_PARMNUM',0x0000002B)
		win_const_mgr.add_const('NET_STRING_NAMED_SERVICE',0x00000200)
		win_const_mgr.add_const('SV_TYPE_SERVER',0x00000002)
		win_const_mgr.add_const('ERROR_SERVICE_NOT_IN_EXE',0x0000043B)
		win_const_mgr.add_const('TVS_DISABLEDRAGDROP',0x00000010)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_LOOPBACK',0x00000080)
		win_const_mgr.add_const('MCI_DEVTYPE_DAT',0x00000205)
		win_const_mgr.add_const('GOPHER_TYPE_IMAGE',0x00002000)
		win_const_mgr.add_const('TIMECODE_SMPTE_BINARY_GROUP',0x00000007)
		win_const_mgr.add_const('DSPRINT_REPUBLISH',0x00000008)
		win_const_mgr.add_const('CREDENTIAL_SUB_TYPE_KERBEROS_TKT',0x00000003)
		win_const_mgr.add_const('WM_MBUTTONDBLCLK',0x00000209)
		win_const_mgr.add_const('ERROR_END_OF_MEDIA',0x0000044C)
		win_const_mgr.add_const('PORT_UAAC',0x00000091)
		win_const_mgr.add_const('D3DPBLENDCAPS_SRCALPHA',0x00000010)
		win_const_mgr.add_const('CALLBACK_STREAM_SWITCH',0x00000001)
		win_const_mgr.add_const('GENERIC_EXECUTE',0x20000000)
		win_const_mgr.add_const('NUMPRS_PARENS',0x00000080)
		win_const_mgr.add_const('SHI1005_FLAGS_FORCE_SHARED_DELETE',0x00000200)
		win_const_mgr.add_const('SQL_HC_OFF',0x00000000)
		win_const_mgr.add_const('WIA_DONT_SHOW_PREVIEW_CONTROL',0x00000001)
		win_const_mgr.add_const('DRVCNF_OK',0x00000001)
		win_const_mgr.add_const('WINWATCHNOTIFY_CHANGED',0x00000004)
		win_const_mgr.add_const('ERROR_IS_SUBST_PATH',0x00000092)
		win_const_mgr.add_const('APPLICATION_INSTALL',0x00000000)
		win_const_mgr.add_const('MIN_EVENT',0x00000064)
		win_const_mgr.add_const('HICF_OTHER',0x00000000)
		win_const_mgr.add_const('WMS_CONTAINER_FLAGS',0x00000003)
		win_const_mgr.add_const('PUBLICKEYBLOBEX',0x0000000A)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_KILL_ON_JOB_CLOSE',0x00002000)
		win_const_mgr.add_const('DTT_GLOWSIZE',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_ORIG_URI',0x00000022)
		win_const_mgr.add_const('DS_NDNC_FLAG',0x00000400)
		win_const_mgr.add_const('BCSS_NOSPLIT',0x00000001)
		win_const_mgr.add_const('LDAP_OPT_THREAD_FN_PTRS',0x00000005)
		win_const_mgr.add_const('RPC_C_AUTHN_DCE_PUBLIC',0x00000002)
		win_const_mgr.add_const('SQL_MAX_DSN_LENGTH',0x00000020)
		win_const_mgr.add_const('R2_NOP',0x0000000B)
		win_const_mgr.add_const('HHWIN_PROP_TAB_SEARCH',0x00000001)
		win_const_mgr.add_const('WINHTTP_OPTION_EXTENDED_ERROR',0x00000018)
		win_const_mgr.add_const('TTF_DI_SETITEM',0x00008000)
		win_const_mgr.add_const('BG_E_NEW_OWNER_NO_FILE_ACCESS',0x80200016)
		win_const_mgr.add_const('SQL_CODE_MINUTE',0x00000005)
		win_const_mgr.add_const('DBPROPVAL_STGM_CONVERT',0x00040000)
		win_const_mgr.add_const('WINHTTP_QUERY_MAX_FORWARDS',0x0000003C)
		win_const_mgr.add_const('OID_GEN_DIRECTED_BYTES_XMIT',0x00020201)
		win_const_mgr.add_const('SMART_ABORT_OFFLINE_SELFTEST',0x0000007F)
		win_const_mgr.add_const('EVENT_TRACE_CONTROL_UPDATE',0x00000002)
		win_const_mgr.add_const('MAXIMUM_ATTR_STRING_LENGTH',0x00000020)
		win_const_mgr.add_const('MAX_CRED_SIZE',0x00000400)
		win_const_mgr.add_const('IP_DEFAULT_MULTICAST_TTL',0x00000001)
		win_const_mgr.add_const('RUNCMDS_QUIET',0x00000001)
		win_const_mgr.add_const('TMT_MENUBAR',0x0000065F)
		win_const_mgr.add_const('ATAPI_ID_CMD',0x000000A1)
		win_const_mgr.add_const('NDIS_ENCAPSULATION_NOT_SUPPORTED',0x00000000)
		win_const_mgr.add_const('MD_DIMTYPE_TIME',0x00000001)
		win_const_mgr.add_const('IDSI_FLAG_PROXY',0x00000004)
		win_const_mgr.add_const('BSF_ALLOWSFW',0x00000080)
		win_const_mgr.add_const('ERROR_DS_NAME_TOO_MANY_PARTS',0x0000209B)
		win_const_mgr.add_const('BDIF_NAME',0x00000004)
		win_const_mgr.add_const('NRB_FUNCTION_QUERY_ASCENDER_STATUS',0x000000D0)
		win_const_mgr.add_const('COM_RIGHTS_EXECUTE',0x00000001)
		win_const_mgr.add_const('SPI_GETKEYBOARDSPEED',0x0000000A)
		win_const_mgr.add_const('IF_TYPE_HDLC',0x00000076)
		win_const_mgr.add_const('KP_PREHASH',0x00000022)
		win_const_mgr.add_const('XINPUT_GAMEPAD_LEFT_THUMB_DEADZONE',0x00001EA9)
		win_const_mgr.add_const('AVI_HEADERSIZE',0x00000800)
		win_const_mgr.add_const('OPTION_MESSAGE',0x00000038)
		win_const_mgr.add_const('LVGF_NONE',0x00000000)
		win_const_mgr.add_const('ERROR_SHUTDOWN_IN_PROGRESS',0x0000045B)
		win_const_mgr.add_const('SBSP_DEFMODE',0x00000000)
		win_const_mgr.add_const('ERROR_TS_INCOMPATIBLE_SESSIONS',0x00001B9D)
		win_const_mgr.add_const('MUI_USE_SEARCH_ALL_LANGUAGES',0x00000040)
		win_const_mgr.add_const('CRYPTPROTECTMEMORY_CROSS_PROCESS',0x00000001)
		win_const_mgr.add_const('IPSEC_CIPHER_CONFIG_CBC_DES',0x00000001)
		win_const_mgr.add_const('LINEDEVSTATUSFLAGS_MSGWAIT',0x00000002)
		win_const_mgr.add_const('STATIC_CACHE_ENTRY',0x00000080)
		win_const_mgr.add_const('DISPID_WINDOW',0x00000001)
		win_const_mgr.add_const('IP_OPT_TS',0x00000044)
		win_const_mgr.add_const('USE_ASGTYPE_PARMNUM',0x00000004)
		win_const_mgr.add_const('CRL_REASON_SUPERSEDED',0x00000004)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_SAMPLE_USES_CURRENT_INPUT_FRAME',0x00000004)
		win_const_mgr.add_const('TASK_TRIGGER_FLAG_DISABLED',0x00000004)
		win_const_mgr.add_const('MAX_INSTALLWIZARD_DYNAPAGES',0x00000014)
		win_const_mgr.add_const('D3DFVFCAPS_PSIZE',0x00100000)
		win_const_mgr.add_const('SCARD_E_PCI_TOO_SMALL',0x80100019)
		win_const_mgr.add_const('RSC_FLAG_UPDHLPDLLS',0x00000010)
		win_const_mgr.add_const('CHANGER_PREDISMOUNT_ALIGN_TO_DRIVE',0x80000002)
		win_const_mgr.add_const('WAVE_FORMAT_48M08',0x00001000)
		win_const_mgr.add_const('APMTIMEOUT_DISABLED',0x00000000)
		win_const_mgr.add_const('ACMFORMATCHOOSE_STYLEF_ENABLEHOOK',0x00000008)
		win_const_mgr.add_const('WLX_OPTION_USE_CTRL_ALT_DEL',0x00000001)
		win_const_mgr.add_const('BSF_NOTIMEOUTIFNOTHUNG',0x00000040)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_449',0x801901C1)
		win_const_mgr.add_const('MCI_ANIM_GETDEVCAPS_NORMAL_RATE',0x00004004)
		win_const_mgr.add_const('CRYPT_VOLATILE',0x00001000)
		win_const_mgr.add_const('SCRIPTITEM_GLOBALMEMBERS',0x00000008)
		win_const_mgr.add_const('SNMPAPI_SIZE_INVALID',0x00000011)
		win_const_mgr.add_const('PROV_EC_ECDSA_FULL',0x00000010)
		win_const_mgr.add_const('CERT_VERIFY_REV_SERVER_OCSP_FLAG',0x00000008)
		win_const_mgr.add_const('MAXIMUM_PROCESSORS',0x00000020)
		win_const_mgr.add_const('TTF_TRANSPARENT',0x00000100)
		win_const_mgr.add_const('D3DPRASTERCAPS_FOGRANGE',0x00010000)
		win_const_mgr.add_const('DTR_KERNEL_INDEX',0x00000001)
		win_const_mgr.add_const('GLOBAL_FREE',0x00000002)
		win_const_mgr.add_const('MDM_V110_SPEED_57DOT6K',0x0000000A)
		win_const_mgr.add_const('PRIVACY_IMPACTED_CACHE_ENTRY',0x02000000)
		win_const_mgr.add_const('SV_SENDSFROMPREFERREDPROCESSOR_PARMNUM',0x00000249)
		win_const_mgr.add_const('ERROR_INVALID_WINDOW_HANDLE',0x00000578)
		win_const_mgr.add_const('PARTITION_XINT13',0x0000000E)
		win_const_mgr.add_const('SHDID_NET_DOMAIN',0x0000000D)
		win_const_mgr.add_const('CONNDLG_USE_MRU',0x00000004)
		win_const_mgr.add_const('ERROR_BADDB',0x000003F1)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_SUSPEND',0x00000008)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_INTERRUPT',0x00000040)
		win_const_mgr.add_const('LINECALLINFOSTATE_CALLEDID',0x00010000)
		win_const_mgr.add_const('CM_GETIDLIST_FILTER_BUSRELATIONS',0x00000020)
		win_const_mgr.add_const('PI_NUMBER_NOT_AVAILABLE',0x00000080)
		win_const_mgr.add_const('MDM_SHIFT_PROTOCOLDATA',0x00000014)
		win_const_mgr.add_const('LOCALE_SISO639LANGNAME2',0x00000067)
		win_const_mgr.add_const('PIDMSI_STATUS',0x00000007)
		win_const_mgr.add_const('SYNC_HANDLERTYPE_PROGRAMS',0x00000001)
		win_const_mgr.add_const('ILFIP_FROMSTANDBY',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_UINT',0x0000000E)
		win_const_mgr.add_const('IDM_GETZOOMNUMERATOR',0x00000929)
		win_const_mgr.add_const('LVCF_IMAGE',0x00000010)
		win_const_mgr.add_const('DEBUG_MANAGED_DLL_LOADED',0x00000002)
		win_const_mgr.add_const('AE_GUEST',0x00000000)
		win_const_mgr.add_const('CERT_END_ENTITY_SUBJECT_FLAG',0x00000040)
		win_const_mgr.add_const('RETURN_SMART_STATUS',0x000000DA)
		win_const_mgr.add_const('RBBIM_IMAGE',0x00000008)
		win_const_mgr.add_const('SVTI2_REMAP_PIPE_NAMES',0x00000002)
		win_const_mgr.add_const('URLPOLICY_BEHAVIOR_CHECK_LIST',0x00010000)
		win_const_mgr.add_const('FEATURESETTING_PRIVATE_END',0x00001FFF)
		win_const_mgr.add_const('SQL_LIKE_ESCAPE_CLAUSE',0x00000071)
		win_const_mgr.add_const('SECPKG_ATTR_SUPPORTED_ALGS',0x00000056)
		win_const_mgr.add_const('RIDI_DEVICEINFO',0x02000000)
		win_const_mgr.add_const('QS_TIMER',0x00000010)
		win_const_mgr.add_const('ERROR_DS_TIMELIMIT_EXCEEDED',0x00002022)
		win_const_mgr.add_const('KSNODEPIN_DEMUX_IN',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_REFQ3',0x00000013)
		win_const_mgr.add_const('USER_MARSHAL_POINTER',0x00000000)
		win_const_mgr.add_const('FLAG_EMBEDDEDPROFILE',0x00000001)
		win_const_mgr.add_const('DRV_INSTALL',0x00000009)
		win_const_mgr.add_const('DISPID_TABLEPARAMS_CELLATTRS',0x00000004)
		win_const_mgr.add_const('OID_TAPI_SET_MEDIA_MODE',0x07030121)
		win_const_mgr.add_const('ACTRL_ACCESS_ALLOWED',0x00000001)
		win_const_mgr.add_const('GTL_USECRLF',0x00000001)
		win_const_mgr.add_const('MKSYS_URLMONIKER',0x00000006)
		win_const_mgr.add_const('STI_DEVSTATUS_ONLINE_STATE',0x00000001)
		win_const_mgr.add_const('FD_QOS_BIT',0x00000006)
		win_const_mgr.add_const('COD_PHONE_MINOR_CORDLESS',0x00000002)
		win_const_mgr.add_const('LCID_ALTERNATE_SORTS',0x00000004)
		win_const_mgr.add_const('IF_TYPE_IF_GSN',0x00000091)
		win_const_mgr.add_const('SQL_CA2_READ_ONLY_CONCURRENCY',0x00000001)
		win_const_mgr.add_const('MQMSG_DELIVERY_RECOVERABLE',0x00000001)
		win_const_mgr.add_const('D3DPTEXTURECAPS_MIPMAP',0x00004000)
		win_const_mgr.add_const('REFERENCE_BLACK_MAX',0x00000FA0)
		win_const_mgr.add_const('MIXER_GETLINECONTROLSF_ONEBYID',0x00000001)
		win_const_mgr.add_const('MDITILE_SKIPDISABLED',0x00000002)
		win_const_mgr.add_const('TRANSACTIONMANAGER_QUERY_INFORMATION',0x00000001)
		win_const_mgr.add_const('INTERNET_DEFAULT_PORT',0x00000000)
		win_const_mgr.add_const('DNS_RTYPE_UINFO',0x00006400)
		win_const_mgr.add_const('NET_VALIDATE_PASSWORD_HISTORY_LENGTH',0x00000010)
		win_const_mgr.add_const('AE_USER',0x00000001)
		win_const_mgr.add_const('TVE_TOGGLE',0x00000003)
		win_const_mgr.add_const('VER_ERR_ARG_RET',0xFFFFFFFE)
		win_const_mgr.add_const('IKEEXT_CERT_AUTH_ENABLE_CRL_CHECK_STRONG',0x00000004)
		win_const_mgr.add_const('HICF_LMOUSE',0x00000080)
		win_const_mgr.add_const('S_THRESHOLD',0x00000001)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_HOTFIX_UNINSTALL',0x00000017)
		win_const_mgr.add_const('SSPROP_CHARACTERSET',0x00000005)
		win_const_mgr.add_const('ETO_IGNORELANGUAGE',0x00001000)
		win_const_mgr.add_const('ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC',0x00002184)
		win_const_mgr.add_const('IDC_LP_BREAKLINK',0x000003F0)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_REFQ1',0x00000015)
		win_const_mgr.add_const('DNF_ALWAYSEXCLUDEFROMLIST',0x00080000)
		win_const_mgr.add_const('ILCF_SWAP',0x00000001)
		win_const_mgr.add_const('WIA_IPA_REGION_TYPE',0x00001017)
		win_const_mgr.add_const('PSR_CPL',0x00000020)
		win_const_mgr.add_const('MQMSG_AUTH_LEVEL_MSMQ10',0x00000002)
		win_const_mgr.add_const('WMDM_SCP_REVOKED',0x00000008)
		win_const_mgr.add_const('LARGE_ENTRY',0x00000003)
		win_const_mgr.add_const('INFINFO_INF_PATH_LIST_SEARCH',0x00000005)
		win_const_mgr.add_const('SDP_ERROR_INVALID_CONTINUATION_STATE',0x00000005)
		win_const_mgr.add_const('NUM_FLICK_DIRECTIONS',0x00000008)
		win_const_mgr.add_const('WINHTTP_QUERY_RAW_HEADERS',0x00000015)
		win_const_mgr.add_const('CPF_FILE_ERROR',0x00000200)
		win_const_mgr.add_const('SBSP_SAMEBROWSER',0x00000001)
		win_const_mgr.add_const('WM_CONVERTRESULT',0x0000010B)
		win_const_mgr.add_const('VOS__BASE',0x00000000)
		win_const_mgr.add_const('WMDRM_CLEAN_LICENSE_STORE_SYNC',0x00000001)
		win_const_mgr.add_const('MOUSEEVENTF_RIGHTDOWN',0x00000008)
		win_const_mgr.add_const('RPC_NCA_FLAGS_BROADCAST',0x00000002)
		win_const_mgr.add_const('SSA_LINK',0x00001000)
		win_const_mgr.add_const('LINEFEATURE_DEVSPECIFICFEAT',0x00000002)
		win_const_mgr.add_const('DEVICEPOWER_FILTER_DEVICES_PRESENT',0x20000000)
		win_const_mgr.add_const('PSH_PROPSHEETPAGE',0x00000008)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_INTERNET_USER',0x80200000)
		win_const_mgr.add_const('WAVE_FORMAT_44M08',0x00000100)
		win_const_mgr.add_const('ERROR_CHILD_NOT_COMPLETE',0x00000081)
		win_const_mgr.add_const('NTDSDSA_OPT_DISABLE_OUTBOUND_SELECT_SECRET_NULL',0x00000001)
		win_const_mgr.add_const('GMDI_GOINTOPOPUPS',0x00000002)
		win_const_mgr.add_const('EMR_ROUNDRECT',0x0000002C)
		win_const_mgr.add_const('INTERNET_FLAG_IGNORE_CERT_DATE_INVALID',0x00002000)
		win_const_mgr.add_const('MCI_DGV_STATUS_FILEFORMAT',0x00004008)
		win_const_mgr.add_const('IF_TYPE_COMPOSITELINK',0x0000009B)
		win_const_mgr.add_const('RR_RID_LEN',0x00000018)
		win_const_mgr.add_const('DDBLTFX_NOTEARING',0x00000008)
		win_const_mgr.add_const('MCI_CLOSE',0x00000804)
		win_const_mgr.add_const('CHANGER_CLOSE_IEPORT',0x00000004)
		win_const_mgr.add_const('SQL_SR_USAGE_ON_CHARACTER_SET',0x00000002)
		win_const_mgr.add_const('WLAN_UI_API_INITIAL_VERSION',0x00000001)
		win_const_mgr.add_const('SECURITY_DIALUP_RID',0x00000001)
		win_const_mgr.add_const('RPC_X_WRONG_PIPE_VERSION',0x00000728)
		win_const_mgr.add_const('WIA_COMPRESSION_JPEG2K',0x00000007)
		win_const_mgr.add_const('TIMECODE_RATE_30DROP',0x00000000)
		win_const_mgr.add_const('SFGAO_FILESYSANCESTOR',0x10000000)
		win_const_mgr.add_const('WIA_IPS_PAGES',0x00000C18)
		win_const_mgr.add_const('DNS_QUERY_RESERVED',0x00000000)
		win_const_mgr.add_const('VFT2_DRV_SOUND',0x00000009)
		win_const_mgr.add_const('INVALID_TASK_ID',0x00000000)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_COMMANDS',0x00000005)
		win_const_mgr.add_const('CERT_DISPWELL_DISTRUST_ADD_CA_CERT',0x00000008)
		win_const_mgr.add_const('SM_CYVIRTUALSCREEN',0x0000004F)
		win_const_mgr.add_const('CFM_KERNING',0x00100000)
		win_const_mgr.add_const('ERROR_SETCOUNT_ON_BAD_LB',0x00000599)
		win_const_mgr.add_const('DXVA_FILM_GRAIN_BUFFER',0x00000011)
		win_const_mgr.add_const('CREDUI_FLAGS_ALWAYS_SHOW_UI',0x00000080)
		win_const_mgr.add_const('VER_SUITE_BLADE',0x00000400)
		win_const_mgr.add_const('USER_USE_AES_KEYS',0x00200000)
		win_const_mgr.add_const('FWP_ACTRL_MATCH_FILTER',0x00000001)
		win_const_mgr.add_const('SCOPE_TYPE_VPATH',0x00000200)
		win_const_mgr.add_const('TSF_FAIL_EXIST',0x00000000)
		win_const_mgr.add_const('NETBIOS_NAME_LEN',0x00000010)
		win_const_mgr.add_const('SND_FILENAME',0x00020000)
		win_const_mgr.add_const('LOCALE_IPOSSIGNPOSN',0x00000052)
		win_const_mgr.add_const('LVGS_NOHEADER',0x00000004)
		win_const_mgr.add_const('KAGPROP_MAXCOLUMNSINGROUPBY',0x0000000C)
		win_const_mgr.add_const('LVGF_GROUPID',0x00000010)
		win_const_mgr.add_const('FWP_OPTION_VALUE_DISABLE_LOOSE_SOURCE',0x00000000)
		win_const_mgr.add_const('DEFAULT_PALETTE',0x0000000F)
		win_const_mgr.add_const('TBSTYLE_AUTOSIZE',0x00000010)
		win_const_mgr.add_const('SM_CYMINTRACK',0x00000023)
		win_const_mgr.add_const('CLUSCTL_CONTROL_CODE_MASK',0x003FFFFF)
		win_const_mgr.add_const('CRED_MAX_ATTRIBUTES',0x00000040)
		win_const_mgr.add_const('DBPROPVAL_SQL_ANSI89_IEF',0x00000008)
		win_const_mgr.add_const('LB_DST_ADDR_USE_DSTADDR_FLAG',0x00000008)
		win_const_mgr.add_const('CM_PROB_LEGACY_SERVICE_NO_DEVICES',0x00000029)
		win_const_mgr.add_const('SM_IMMENABLED',0x00000052)
		win_const_mgr.add_const('IDD_DYNAWIZ_ANALYZE_NEXTPAGE',0x00002714)
		win_const_mgr.add_const('SNMP_MGMTAPI_TRAP_DUPINIT',0x0000002B)
		win_const_mgr.add_const('DS_NOFAILCREATE',0x00000010)
		win_const_mgr.add_const('KSNODEPIN_STANDARD_IN',0x00000001)
		win_const_mgr.add_const('WC_SEPCHARS',0x00000020)
		win_const_mgr.add_const('SP_COPY_NOSKIP',0x00000400)
		win_const_mgr.add_const('DI_SHOWOEM',0x00000001)
		win_const_mgr.add_const('DISPID_ACTIVEELMENTS_LENGTH',0x00000005)
		win_const_mgr.add_const('INTERNET_OPTION_REMOVE_IDENTITY',0x0000004F)
		win_const_mgr.add_const('PORT_DN6SMMRED',0x000000C4)
		win_const_mgr.add_const('SUBLANG_FRENCH_SWISS',0x00000004)
		win_const_mgr.add_const('DM_POSITION',0x00000020)
		win_const_mgr.add_const('WM_CLOSE',0x00000010)
		win_const_mgr.add_const('CTRY_PORTUGAL',0x0000015F)
		win_const_mgr.add_const('SQL_ISV_DOMAIN_CONSTRAINTS',0x00000200)
		win_const_mgr.add_const('CTRY_BELGIUM',0x00000020)
		win_const_mgr.add_const('MCI_DGV_INFO_STILL_QUALITY',0x00004002)
		win_const_mgr.add_const('COMPONENT_DEFAULT_TOP',0x0000FFFF)
		win_const_mgr.add_const('DNS_ERROR_MASK',0x00002328)
		win_const_mgr.add_const('CERT_CHAIN_REVOCATION_CHECK_CHAIN_EXCLUDE_ROOT',0x40000000)
		win_const_mgr.add_const('GPO_INFO_FLAG_FORCED_REFRESH',0x00000400)
		win_const_mgr.add_const('HDS_HOTTRACK',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_PPC_TOCREL16',0x00000008)
		win_const_mgr.add_const('LINECALLHUBTRACKING_NONE',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_PPC_TOCREL14',0x00000009)
		win_const_mgr.add_const('SERVICE_RESOURCE',0x00000001)
		win_const_mgr.add_const('ISCSI_LOGIN_FLAG_MULTIPATH_ENABLED',0x00000002)
		win_const_mgr.add_const('INTERNET_IDENTITY_FLAG_PRIVATE_CACHE',0x00000001)
		win_const_mgr.add_const('MCI_VD_OFFSET',0x00000400)
		win_const_mgr.add_const('SNMPAPI_MESSAGE_INVALID',0x00000013)
		win_const_mgr.add_const('DBDTF_RETURNFQDN',0x00000001)
		win_const_mgr.add_const('BATTERY_POWER_ON_LINE',0x00000001)
		win_const_mgr.add_const('AUTO_PROXY_FLAG_DETECTION_SUSPECT',0x00000040)
		win_const_mgr.add_const('BSF_SENDNOTIFYMESSAGE',0x00000100)
		win_const_mgr.add_const('TAPE_DRIVE_PADDING',0x00040000)
		win_const_mgr.add_const('URLACTION_HTML_INCLUDE_FILE_PATH',0x0000160A)
		win_const_mgr.add_const('PHONEINITIALIZEEXOPTION_USECOMPLETIONPORT',0x00000003)
		win_const_mgr.add_const('SQL_SRJO_EXCEPT_JOIN',0x00000004)
		win_const_mgr.add_const('CM_REENUMERATE_BITS',0x00000007)
		win_const_mgr.add_const('BSM_APPLICATIONS',0x00000008)
		win_const_mgr.add_const('SM_CXSCREEN',0x00000000)
		win_const_mgr.add_const('DEVICEPOWER_CLEAR_WAKEENABLED',0x00000002)
		win_const_mgr.add_const('CP_WINUNICODE',0x000004B0)
		win_const_mgr.add_const('DMMEDIA_STANDARD',0x00000001)
		win_const_mgr.add_const('PATCH_SYMBOL_UNDECORATED_TOO',0x00000004)
		win_const_mgr.add_const('OID_LTALK_FCS_ERRORS',0x05020206)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_SECRELLO',0x00000011)
		win_const_mgr.add_const('CDS_UPDATEREGISTRY',0x00000001)
		win_const_mgr.add_const('DI_PROPERTIES_CHANGE',0x00004000)
		win_const_mgr.add_const('ENABLE_LINE_INPUT',0x00000002)
		win_const_mgr.add_const('SUBLANG_GERMAN_SWISS',0x00000002)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_YEARS',0x00000014)
		win_const_mgr.add_const('VALIDATEUNC_PRINT',0x00000004)
		win_const_mgr.add_const('MCI_WAIT',0x00000002)
		win_const_mgr.add_const('SPI_SETDROPSHADOW',0x00001025)
		win_const_mgr.add_const('VK_OEM_PERIOD',0x000000BE)
		win_const_mgr.add_const('SERVICE_CHANGE_CONFIG',0x00000002)
		win_const_mgr.add_const('CERT_STORE_PROV_WRITE_CTL_FUNC',0x0000000A)
		win_const_mgr.add_const('SUBLANG_TAMAZIGHT_ALGERIA_LATIN',0x00000002)
		win_const_mgr.add_const('XECR_PKCS7',0x00000002)
		win_const_mgr.add_const('GL_ID_INPUTSYMBOL',0x00000027)
		win_const_mgr.add_const('TRACE_USE_MASK',0x00000002)
		win_const_mgr.add_const('IP_INTFC_INFO_ID',0x00000103)
		win_const_mgr.add_const('ERROR_ACCOUNT_LOCKED_OUT',0x00000775)
		win_const_mgr.add_const('ERROR_SXS_DUPLICATE_IID',0x000036C8)
		win_const_mgr.add_const('DMPAPER_LEGAL_EXTRA',0x00000033)
		win_const_mgr.add_const('SCH_CRED_REVOCATION_CHECK_CHAIN',0x00000200)
		win_const_mgr.add_const('ACMFILTERDETAILS_FILTER_CHARS',0x00000080)
		win_const_mgr.add_const('LOCALE_SABBREVDAYNAME7',0x00000037)
		win_const_mgr.add_const('MCI_DGV_LIST_COUNT',0x00020000)
		win_const_mgr.add_const('LOCALE_SABBREVDAYNAME5',0x00000035)
		win_const_mgr.add_const('SQL_CVT_DATE',0x00008000)
		win_const_mgr.add_const('MD_ACR_WRITE',0x00000002)
		win_const_mgr.add_const('LOCALE_SABBREVDAYNAME2',0x00000032)
		win_const_mgr.add_const('LOCALE_SABBREVDAYNAME1',0x00000031)
		win_const_mgr.add_const('D3DVS20CAPS_PREDICATION',0x00000001)
		win_const_mgr.add_const('MFE_IIF',0x00000008)
		win_const_mgr.add_const('ERROR_LOG_CONTAINER_READ_FAILED',0x000019EF)
		win_const_mgr.add_const('IPPROTO_RAW',0x000000FF)
		win_const_mgr.add_const('XA_NOMIGRATE',0x00000009)
		win_const_mgr.add_const('SUBLANG_WELSH_UNITED_KINGDOM',0x00000001)
		win_const_mgr.add_const('MDM_HDLCPPP_ML_DEFAULT',0x00000000)
		win_const_mgr.add_const('IME_CMODE_SYMBOL',0x00000400)
		win_const_mgr.add_const('META_OFFSETCLIPRGN',0x00000220)
		win_const_mgr.add_const('IF_TYPE_REACH_DSL',0x000000C0)
		win_const_mgr.add_const('KSAUDIO_QUALITY_ADVANCED',0x00000003)
		win_const_mgr.add_const('JOB_STATUS_PAPEROUT',0x00000040)
		win_const_mgr.add_const('EM_GETFIRSTVISIBLELINE',0x000000CE)
		win_const_mgr.add_const('OPTION_IMPRESS_SERVERS',0x0000000A)
		win_const_mgr.add_const('IMAGE_REL_SH3_DIRECT8',0x00000003)
		win_const_mgr.add_const('PAN_WEIGHT_BLACK',0x0000000A)
		win_const_mgr.add_const('CERT_TRUST_HAS_ISSUANCE_CHAIN_POLICY',0x00000200)
		win_const_mgr.add_const('EMR_EXTCREATEPEN',0x0000005F)
		win_const_mgr.add_const('DISPID_WMPCORE_MIN',0x00000001)
		win_const_mgr.add_const('DEBUG_CLASS_KERNEL',0x00000001)
		win_const_mgr.add_const('PIR_OPTION_DEFAULT',0x00000000)
		win_const_mgr.add_const('NOTIFIER_TYPE_INTERVAL',0x00000001)
		win_const_mgr.add_const('PIR_STATUS_MINIPORT_NONE',0x00000003)
		win_const_mgr.add_const('BS_CENTER',0x00000300)
		win_const_mgr.add_const('SAFER_POLICY_ONLY_AUDIT',0x00001000)
		win_const_mgr.add_const('DT_END_ELLIPSIS',0x00008000)
		win_const_mgr.add_const('RPC_S_INVALID_RPC_PROTSEQ',0x000006A8)
		win_const_mgr.add_const('PROPCALLER_POLICY',0x00000200)
		win_const_mgr.add_const('D3DFVF_TEXCOUNT_SHIFT',0x00000008)
		win_const_mgr.add_const('EC_VMR_SURFACE_FLIPPED',0x00000054)
		win_const_mgr.add_const('MCI_DGV_STATUS_PAUSE_MODE',0x00004026)
		win_const_mgr.add_const('NOTIFIER_TYPE_STATE_CHANGE',0x00000003)
		win_const_mgr.add_const('ERROR_TRUSTED_RELATIONSHIP_FAILURE',0x000006FD)
		win_const_mgr.add_const('CTRY_VIET_NAM',0x00000054)
		win_const_mgr.add_const('INHERIT_NO_PROPAGATE',0x00000004)
		win_const_mgr.add_const('SYMSEARCH_GLOBALSONLY',0x00000000)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_PARAMETERS',0x00000007)
		win_const_mgr.add_const('DISPID_XOBJ_MIN',0x00010000)
		win_const_mgr.add_const('USE_DISCONN',0x00000002)
		win_const_mgr.add_const('MARSHALINTERFACE_MIN',0x000001F4)
		win_const_mgr.add_const('STI_DEVICE_CREATE_STATUS',0x00000001)
		win_const_mgr.add_const('PLA_CAPABILITY_AUTOLOGGER',0x00000020)
		win_const_mgr.add_const('GDICOMMENT_IDENTIFIER',0x43494447)
		win_const_mgr.add_const('ATA_FLAGS_DATA_IN',0x00000001)
		win_const_mgr.add_const('CRYPT_DECODE_ALLOC_FLAG',0x00008000)
		win_const_mgr.add_const('CLIP_LH_ANGLES',0x00000001)
		win_const_mgr.add_const('LINEBUSYMODE_UNAVAIL',0x00000008)
		win_const_mgr.add_const('META_SETPIXEL',0x0000041F)
		win_const_mgr.add_const('LGRPID_TURKISH',0x00000006)
		win_const_mgr.add_const('WIA_RESERVED_FOR_NEW_PROPS',0x00000400)
		win_const_mgr.add_const('ERROR_THREAD_MODE_ALREADY_BACKGROUND',0x00000190)
		win_const_mgr.add_const('DEBUG_FILTER_CREATE_THREAD',0x00000000)
		win_const_mgr.add_const('REGDF_NOTVERIFIED',0x80000000)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_ON_PKTTYPE',0x00000100)
		win_const_mgr.add_const('LOCALE_IOPTIONALCALENDAR',0x0000100B)
		win_const_mgr.add_const('C3_HALFWIDTH',0x00000040)
		win_const_mgr.add_const('CRL_DIST_POINT_ERR_CRL_ISSUER_BIT',0x80000000)
		win_const_mgr.add_const('ACTRL_DS_READ_PROP',0x00000010)
		win_const_mgr.add_const('IDD_DYNAWIZ_FIRSTPAGE',0x00002710)
		win_const_mgr.add_const('PSINJECT_COMMENTS',0x0000000B)
		win_const_mgr.add_const('SN_TEST_SIGN',0x00000002)
		win_const_mgr.add_const('TCS_OWNERDRAWFIXED',0x00002000)
		win_const_mgr.add_const('SETUP_SERVER_UPGRADED_FLAG',0x00000400)
		win_const_mgr.add_const('SPINST_UNREGSVR',0x00000080)
		win_const_mgr.add_const('BG_E_NETWORK_DISCONNECTED',0x80200010)
		win_const_mgr.add_const('GETPENWIDTH',0x00000010)
		win_const_mgr.add_const('ERROR_SXS_XML_E_RESERVEDNAMESPACE',0x000036F2)
		win_const_mgr.add_const('IP4_ADDRESS_STRING_LENGTH',0x00000010)
		win_const_mgr.add_const('JOY_RETURNBUTTONS',0x00000080)
		win_const_mgr.add_const('JOY_CAL_READUONLY',0x04000000)
		win_const_mgr.add_const('JOB_OBJECT_SET_ATTRIBUTES',0x00000002)
		win_const_mgr.add_const('PSR_MBZ2_V',0x00000000)
		win_const_mgr.add_const('FROM_LEFT_2ND_BUTTON_PRESSED',0x00000004)
		win_const_mgr.add_const('MCI_ANIM_WHERE_DESTINATION',0x00040000)
		win_const_mgr.add_const('ERROR_SYMLINK_CLASS_DISABLED',0x000005B7)
		win_const_mgr.add_const('TMJOIN',0x00200000)
		win_const_mgr.add_const('WM_KEYDOWN',0x00000100)
		win_const_mgr.add_const('WINEVENT_KEYWORD_SQM',0x8000000000000)
		win_const_mgr.add_const('SYMFLAG_CONSTANT',0x00000100)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_253',0x00000000)
		win_const_mgr.add_const('STG_LAYOUT_INTERLEAVED',0x00000001)
		win_const_mgr.add_const('URLPOLICY_JAVA_HIGH',0x00010000)
		win_const_mgr.add_const('TXFS_RM_FLAG_LOG_NO_CONTAINER_COUNT_MAX',0x00000080)
		win_const_mgr.add_const('COPYFLG_IN_USE_TRY_RENAME',0x00004000)
		win_const_mgr.add_const('KSMETHOD_TYPE_SEND',0x00000001)
		win_const_mgr.add_const('OBJECT_INHERIT_ACE',0x00000001)
		win_const_mgr.add_const('SND_LOOP',0x00000008)
		win_const_mgr.add_const('WSANO_RECOVERY',0x00002AFB)
		win_const_mgr.add_const('SSF_FILTER',0x00010000)
		win_const_mgr.add_const('OPTION_NETBIOS_NODE_TYPE',0x0000002E)
		win_const_mgr.add_const('ERROR_DS_CANT_MOVE_APP_QUERY_GROUP',0x000021A1)
		win_const_mgr.add_const('SUBSCRIPTION_CAP_BACKGROUNDPROCESSING',0x00000008)
		win_const_mgr.add_const('DMCOLLATE_FALSE',0x00000000)
		win_const_mgr.add_const('LINETONEMODE_BEEP',0x00000008)
		win_const_mgr.add_const('DWL_DLGPROC',0x00000004)
		win_const_mgr.add_const('IDM_SHOWWBRTAGS',0x00000924)
		win_const_mgr.add_const('CERT_STORE_PROV_FIND_CTL_FUNC',0x00000014)
		win_const_mgr.add_const('MDPROPVAL_MSF_WTD',0x00000200)
		win_const_mgr.add_const('DEVPROP_TYPE_ERROR',0x00000017)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_ON_DSTNET',0x00000010)
		win_const_mgr.add_const('MM_ADDSEPARATOR',0x00000001)
		win_const_mgr.add_const('WMDM_STORAGE_ATTR_REMOVABLE',0x00000002)
		win_const_mgr.add_const('DTS_APPCANPARSE',0x00000010)
		win_const_mgr.add_const('CERT_RDN_OCTET_STRING',0x00000002)
		win_const_mgr.add_const('HHWIN_BUTTON_SEARCH',0x00000001)
		win_const_mgr.add_const('MAX_CLASSNAME_LENGTH',0x00000400)
		win_const_mgr.add_const('PPCF_NODIRECTORIES',0x00000010)
		win_const_mgr.add_const('SV_TYPE_WFW',0x00002000)
		win_const_mgr.add_const('BTH_ERROR_REMOTE_POWERING_OFF',0x00000015)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_KEY_INDEX',0x00000400)
		win_const_mgr.add_const('IDM_RCINSERT',0x00000899)
		win_const_mgr.add_const('DISPID_ONDBLCLICK',0x0000000B)
		win_const_mgr.add_const('NAME_FLAGS_MASK',0x00000087)
		win_const_mgr.add_const('ILD_IMAGE',0x00000020)
		win_const_mgr.add_const('EC_CLOCK_UNSET',0x00000051)
		win_const_mgr.add_const('WLX_SAS_ACTION_TASKLIST',0x00000007)
		win_const_mgr.add_const('WM_NCLBUTTONUP',0x000000A2)
		win_const_mgr.add_const('SLE_MINORERROR',0x00000002)
		win_const_mgr.add_const('ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT',0x00002160)
		win_const_mgr.add_const('OID_WAN_PROTOCOL_CAPS',0x0401010B)
		win_const_mgr.add_const('NTMS_SERIALNUMBER_LENGTH',0x00000020)
		win_const_mgr.add_const('SQL_AT_ADD_COLUMN_DEFAULT',0x00000040)
		win_const_mgr.add_const('SETALLJUSTVALUES',0x00000303)
		win_const_mgr.add_const('DS_REPL_NBR_FULL_REPLICA',0x00000400)
		win_const_mgr.add_const('PS_COMPONENT_SHAPER',0x00000004)
		win_const_mgr.add_const('ERROR_PATCH_RETAIN_RANGES_DIFFER',0xC00E3104)
		win_const_mgr.add_const('CERT_STORE_PROV_SET_CRL_PROPERTY_FUNC',0x00000008)
		win_const_mgr.add_const('MSG_MAXIOVLEN',0x00000010)
		win_const_mgr.add_const('WINWATCHNOTIFY_CHANGING',0x00000003)
		win_const_mgr.add_const('EN_MAXTEXT',0x00000501)
		win_const_mgr.add_const('ERROR_PIPE_NOT_CONNECTED',0x000000E9)
		win_const_mgr.add_const('D3D10_SRGB_TO_FLOAT_EXPONENT',0x00000002)
		win_const_mgr.add_const('SRCLIST_SUBDIRS',0x00000100)
		win_const_mgr.add_const('STATURLFLAG_ISTOPLEVEL',0x00000002)
		win_const_mgr.add_const('CACHEGROUP_ATTRIBUTE_STORAGE',0x00000020)
		win_const_mgr.add_const('OLEOBJ_E_LAST',0x8004018F)
		win_const_mgr.add_const('KSFILTER_FLAG_CRITICAL_PROCESSING',0x00000002)
		win_const_mgr.add_const('DEVPROPID_FIRST_USABLE',0x00000002)
		win_const_mgr.add_const('IDM_CHECKBOX',0x00000873)
		win_const_mgr.add_const('WINEVENT_CHANNEL_CLASSIC_TRACE',0x00000000)
		win_const_mgr.add_const('SHPWHF_ANYLOCATION',0x00000100)
		win_const_mgr.add_const('LC_WIDESTYLED',0x00000040)
		win_const_mgr.add_const('MK_RBUTTON',0x00000002)
		win_const_mgr.add_const('PD_PRINTSETUP',0x00000040)
		win_const_mgr.add_const('SECPKG_CALL_WOWCLIENT',0x00000040)
		win_const_mgr.add_const('MUI_PUBLIC_LANGUAGE_TYPE_FLAGS_MASK',0x00000067)
		win_const_mgr.add_const('PRODUCT_SMALLBUSINESS_SERVER',0x00000009)
		win_const_mgr.add_const('PATCH_TRANSFORM_PE_IRELOC_2',0x00000200)
		win_const_mgr.add_const('MTP_NEXTPHASE_READ_DATA',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_UNION_TAG',0x0000000C)
		win_const_mgr.add_const('ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE',0x00002183)
		win_const_mgr.add_const('MDPROPVAL_MSF_DRILLDOWNMEMBBER',0x00000400)
		win_const_mgr.add_const('WINEVENT_KEYWORD_WDI_DIAG',0x4000000000000)
		win_const_mgr.add_const('BUTTON_IMAGELIST_ALIGN_RIGHT',0x00000001)
		win_const_mgr.add_const('CF_DIBV5',0x00000011)
		win_const_mgr.add_const('MMIO_DENYREAD',0x00000030)
		win_const_mgr.add_const('LUP_ADDRCONFIG',0x00100000)
		win_const_mgr.add_const('DN_MAXADDL',0x00000014)
		win_const_mgr.add_const('DNS_ERROR_PACKET_FMT_BASE',0x0000251C)
		win_const_mgr.add_const('SF_NOTIFY_ORDER_LOW',0x00020000)
		win_const_mgr.add_const('OPER_STATE_DOWN',0x00000001)
		win_const_mgr.add_const('OID_GEN_LINK_SPEED_EX',0x0001028B)
		win_const_mgr.add_const('SORTED_CTL_EXT_COUNT_OFFSET',0x00000001)
		win_const_mgr.add_const('ERROR_DEVICE_DOOR_OPEN',0x0000048E)
		win_const_mgr.add_const('SFGAO_HASSTORAGE',0x00400000)
		win_const_mgr.add_const('SP_PROT_PCT1_CLIENT',0x00000002)
		win_const_mgr.add_const('DNS_QUERY_NO_LOCAL_NAME',0x00000020)
		win_const_mgr.add_const('OID_GEN_DEVICE_PROFILE',0x00020212)
		win_const_mgr.add_const('SCH_CRED_CACHE_ONLY_URL_RETRIEVAL',0x00008000)
		win_const_mgr.add_const('BG_E_LOCAL_FILE_CHANGED',0x8020001D)
		win_const_mgr.add_const('OID_GEN_MULTICAST_FRAMES_RCV',0x0002020A)
		win_const_mgr.add_const('BTH_ERROR_MAX_NUMBER_OF_CONNECTIONS',0x00000009)
		win_const_mgr.add_const('SECBUFFER_MECHLIST_SIGNATURE',0x0000000C)
		win_const_mgr.add_const('PROTECTED_SACL_SECURITY_INFORMATION',0x40000000)
		win_const_mgr.add_const('ERROR_INTERRUPT_STILL_CONNECTED',0x000002FC)
		win_const_mgr.add_const('MSAA_MENU_SIG',0xAA0DF00D)
		win_const_mgr.add_const('WS_DLGFRAME',0x00400000)
		win_const_mgr.add_const('ERROR_EVENTLOG_FILE_CORRUPT',0x000005DC)
		win_const_mgr.add_const('WM_TIMER',0x00000113)
		win_const_mgr.add_const('URLACTION_SCRIPT_PASTE',0x00001407)
		win_const_mgr.add_const('POLICY_CREATE_SECRET',0x00000020)
		win_const_mgr.add_const('IMEVER_0310',0x0003000A)
		win_const_mgr.add_const('RPC_C_AUTHN_INFO_TYPE_HTTP',0x00000001)
		win_const_mgr.add_const('AVISF_DISABLED',0x00000001)
		win_const_mgr.add_const('TMT_HOTTRACKING',0x0000065B)
		win_const_mgr.add_const('DDCAPS_OVERLAY',0x00000800)
		win_const_mgr.add_const('MCI_VCR_FREEZE_OUTPUT',0x00020000)
		win_const_mgr.add_const('DEX_IDS_NO_SOURCE_NAMES',0x0000057D)
		win_const_mgr.add_const('SQL_OUTER_JOINS',0x00000026)
		win_const_mgr.add_const('SERVICE_ENUMERATE_DEPENDENTS',0x00000008)
		win_const_mgr.add_const('CR_NO_SUCH_LOGICAL_DEV',0x00000014)
		win_const_mgr.add_const('IDC_PS_DISPLAYASICON',0x000001FA)
		win_const_mgr.add_const('GESTURE_UP_LEFT_LONG',0x00000000)
		win_const_mgr.add_const('FO_RENAME',0x00000004)
		win_const_mgr.add_const('WM_DROPFILES',0x00000233)
		win_const_mgr.add_const('ERROR_PNP_TRANSLATION_FAILED',0x000002A0)
		win_const_mgr.add_const('ICINSTALL_FUNCTION',0x00000001)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_CO_CALL_MANAGER_OPTIONAL_HANDLERS',0x000000A5)
		win_const_mgr.add_const('TAPE_CHECK_FOR_DRIVE_PROBLEM',0x00000002)
		win_const_mgr.add_const('POP3_MD_ID_END_RESERVED',0x00000000)
		win_const_mgr.add_const('IPPROTO_ND',0x0000004D)
		win_const_mgr.add_const('HTTP_QUERY_FLAG_COALESCE',0x10000000)
		win_const_mgr.add_const('AUTH_REQ_ALLOW_ENC_TKT_IN_SKEY',0x00000020)
		win_const_mgr.add_const('TXTLOG_RESERVED_FLAGS',0x0000FFF0)
		win_const_mgr.add_const('MQMSG_LAST_IN_XACT',0x00000001)
		win_const_mgr.add_const('SIGNERSCORE_INBOX',0x0D000003)
		win_const_mgr.add_const('SQL_DIAG_DROP_TABLE',0x00000020)
		win_const_mgr.add_const('USER_MARSHAL_FC_HYPER',0x0000000B)
		win_const_mgr.add_const('ERROR_NON_ACCOUNT_SID',0x000004E9)
		win_const_mgr.add_const('D3DPTADDRESSCAPS_MIRROR',0x00000002)
		win_const_mgr.add_const('DNS_MAX_LABEL_BUFFER_LENGTH',0x00000040)
		win_const_mgr.add_const('UM_SELTYPE_GLOBALGROUP',0x00000008)
		win_const_mgr.add_const('WM_PALETTEISCHANGING',0x00000310)
		win_const_mgr.add_const('EVENT_TRACE_USE_LOCAL_SEQUENCE',0x00008000)
		win_const_mgr.add_const('DLG_FLAGS_SEC_CERT_REV_FAILED',0x00800000)
		win_const_mgr.add_const('OID_802_11_TX_ANTENNA_SELECTED',0x0D01020D)
		win_const_mgr.add_const('MCI_FROM',0x00000004)
		win_const_mgr.add_const('DI_FLAGSEX_DIDINFOLIST',0x00000010)
		win_const_mgr.add_const('OID_IRDA_MAX_RECEIVE_WINDOW_SIZE',0x0A010204)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_UNKNOWN',0x00000000)
		win_const_mgr.add_const('META_EXTTEXTOUT',0x00000000)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_TABLE_PRIVILEGES',0x00000005)
		win_const_mgr.add_const('SPI_SETNONCLIENTMETRICS',0x0000002A)
		win_const_mgr.add_const('FILE_FLAG_OPEN_REPARSE_POINT',0x00200000)
		win_const_mgr.add_const('CRYPT_OID_INFO_CNG_SIGN_KEY',0x00000006)
		win_const_mgr.add_const('FRS_ERR_SYSVOL_IS_BUSY',0x00001F4F)
		win_const_mgr.add_const('WIA_DPC_FNUMBER',0x00000807)
		win_const_mgr.add_const('SDP_ATTRIB_HID_RECONNECT_INITIATE',0x00000205)
		win_const_mgr.add_const('AUTH_REQ_VALIDATE_CLIENT',0x00000080)
		win_const_mgr.add_const('PDERR_NODEVICES',0x00001007)
		win_const_mgr.add_const('ERROR_IO_INCOMPLETE',0x000003E4)
		win_const_mgr.add_const('LANG_ASSAMESE',0x00000004)
		win_const_mgr.add_const('CERT_CHAIN_MAX_AIA_URL_RETRIEVAL_CERT_COUNT_DEFAULT',0x0000000A)
		win_const_mgr.add_const('LINECALLORIGIN_CONFERENCE',0x00000040)
		win_const_mgr.add_const('_WIN32_IE_IE70',0x00000700)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_WRONGENCODING',0x00000009)
		win_const_mgr.add_const('WKSTA_USEENCRYPTION_PARMNUM',0x00000039)
		win_const_mgr.add_const('PSH_AEROWIZARD',0x00004000)
		win_const_mgr.add_const('RPC_C_AUTHN_LEVEL_PKT_INTEGRITY',0x00000005)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_ASSERTIONS',0x00000003)
		win_const_mgr.add_const('ERROR_BAD_DESCRIPTOR_FORMAT',0x00000551)
		win_const_mgr.add_const('PP_APPLI_CERT',0x00000012)
		win_const_mgr.add_const('QUERYFORM_CHANGESOPTFORMLIST',0x00000002)
		win_const_mgr.add_const('PCF_INTTIMEOUTS',0x00000080)
		win_const_mgr.add_const('WM_MAX_STREAMS',0x00000003)
		win_const_mgr.add_const('WM_NEXTMENU',0x00000213)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_CRL_FAILED',0x000035F9)
		win_const_mgr.add_const('ENM_MOUSEEVENTS',0x00020000)
		win_const_mgr.add_const('IMAGE_REL_IA64_IMM22',0x00000002)
		win_const_mgr.add_const('CHANGER_EXCHANGE_MEDIA',0x00000020)
		win_const_mgr.add_const('SQL_LCK_NO_CHANGE',0x00000001)
		win_const_mgr.add_const('STDPROP_UID',0x00000001)
		win_const_mgr.add_const('ERROR_DIRECTORY',0x0000010B)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_IA32_ON_WIN64',0x0000000A)
		win_const_mgr.add_const('SZ_ALG_MAX_SIZE',0x00000040)
		win_const_mgr.add_const('DOT11_FLAGS_80211B_SHORT_PREAMBLE',0x00000001)
		win_const_mgr.add_const('ERROR_VOLSNAP_PREPARE_HIBERNATE',0x0000028F)
		win_const_mgr.add_const('TMT_CAPTIONBARHEIGHT',0x000004B5)
		win_const_mgr.add_const('IDM_ENABLE_INTERACTION',0x000008FE)
		win_const_mgr.add_const('DELETE',0x00010000)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_PVK',0x00000003)
		win_const_mgr.add_const('ERROR_CTX_MODEM_RESPONSE_NO_CARRIER',0x00001B65)
		win_const_mgr.add_const('OE_SETTING',0x00000004)
		win_const_mgr.add_const('DDSCAPS2_CUBEMAP_POSITIVEX',0x00000400)
		win_const_mgr.add_const('DDSCAPS2_CUBEMAP_POSITIVEY',0x00001000)
		win_const_mgr.add_const('DDSCAPS2_CUBEMAP_POSITIVEZ',0x00004000)
		win_const_mgr.add_const('STYPE_DEVICE',0x00000002)
		win_const_mgr.add_const('SV_TYPE_NOVELL',0x00000080)
		win_const_mgr.add_const('SRCLIST_APPEND',0x00000200)
		win_const_mgr.add_const('SERKF_AVAILABLE',0x00000002)
		win_const_mgr.add_const('SCARD_CLASS_VENDOR_DEFINED',0x00000007)
		win_const_mgr.add_const('PHYSICALHEIGHT',0x0000006F)
		win_const_mgr.add_const('CM_HWPI_NOT_DOCKABLE',0x00000000)
		win_const_mgr.add_const('CM_PROB_FAILED_INSTALL',0x0000001C)
		win_const_mgr.add_const('CR_INVALID_RANGE_LIST',0x00000011)
		win_const_mgr.add_const('SYMSRV_VERSION',0x00000002)
		win_const_mgr.add_const('SM_CXVSCROLL',0x00000002)
		win_const_mgr.add_const('SE_SACL_AUTO_INHERIT_REQ',0x00000200)
		win_const_mgr.add_const('WIA_IPC_SEQUENCE',0x00001409)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_ENTERPRISE_DOMAIN',0x00000008)
		win_const_mgr.add_const('X3_P_SIGN_VAL_POS_X',0x00000000)
		win_const_mgr.add_const('HTVSCROLL',0x00000007)
		win_const_mgr.add_const('BLLI_L2_MODE_NORMAL',0x00000040)
		win_const_mgr.add_const('SCARD_E_CARD_UNSUPPORTED',0x8010001C)
		win_const_mgr.add_const('ERROR_DRIVERS_LEAKING_LOCKED_PAGES',0x000002D9)
		win_const_mgr.add_const('WINHTTP_QUERY_VIA',0x00000042)
		win_const_mgr.add_const('COOKIEACTION_LEASH',0x00000008)
		win_const_mgr.add_const('CR_NO_SUCH_VALUE',0x00000025)
		win_const_mgr.add_const('FWPM_NET_EVENT_IKEEXT_MM_FAILURE_FLAG_BENIGN',0x00000001)
		win_const_mgr.add_const('IF_LOCKICERTREQUEST',0x00000001)
		win_const_mgr.add_const('ERROR_MCA_OCCURED',0x0000028B)
		win_const_mgr.add_const('DNS_RCODE_NOERROR',0x00000000)
		win_const_mgr.add_const('SV_SESSOPENS_PARMNUM',0x000001F5)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_CJOBS',0x00000014)
		win_const_mgr.add_const('PID_LASTSAVE_DTM',0x0000000D)
		win_const_mgr.add_const('DEVICE_STATE_ACTIVE',0x00000001)
		win_const_mgr.add_const('DCR_MBZ1',0x00000002)
		win_const_mgr.add_const('STYPE_PRINTQ',0x00000001)
		win_const_mgr.add_const('MIB_IF_ADMIN_STATUS_UP',0x00000001)
		win_const_mgr.add_const('MM_MIDI_MAPPER',0x00000001)
		win_const_mgr.add_const('LOCALE_SYEARMONTH',0x00001006)
		win_const_mgr.add_const('SC_TASKLIST',0x0000F130)
		win_const_mgr.add_const('BIF_NOTRANSLATETARGETS',0x00000400)
		win_const_mgr.add_const('SQL_PARAM_IGNORE',0x00000001)
		win_const_mgr.add_const('RGB_GAMMA_MAX',0x0000FDE8)
		win_const_mgr.add_const('SCTE_EAS_TID',0x000000D8)
		win_const_mgr.add_const('SQL_DV_DROP_VIEW',0x00000001)
		win_const_mgr.add_const('ERROR_FILE_READ_ONLY',0x00001779)
		win_const_mgr.add_const('DEBUG_REQUEST_SOURCE_PATH_HAS_SOURCE_SERVER',0x00000000)
		win_const_mgr.add_const('WMS_EVENT_VERSION',0x00000001)
		win_const_mgr.add_const('AM_QUERY_DECODER_DVD_SUPPORT',0x00000003)
		win_const_mgr.add_const('SQL_CCOL_CREATE_COLLATION',0x00000001)
		win_const_mgr.add_const('SQL_AT_CONSTRAINT_DEFERRABLE',0x00040000)
		win_const_mgr.add_const('VOS_UNKNOWN',0x00000000)
		win_const_mgr.add_const('WIN_CERT_REVISION_2_0',0x00000200)
		win_const_mgr.add_const('D3DCOLORWRITEENABLE_ALPHA',0x00000001)
		win_const_mgr.add_const('ERROR_DATABASE_DOES_NOT_EXIST',0x00000429)
		win_const_mgr.add_const('MD_ERROR_SUB403_CERT_REQUIRED',0x00000007)
		win_const_mgr.add_const('SQL_CDO_CONSTRAINT_DEFERRABLE',0x00000080)
		win_const_mgr.add_const('TCSAT_PROTOCOL_UUID16',0x00000006)
		win_const_mgr.add_const('SSF_DOUBLECLICKINWEBVIEW',0x00000080)
		win_const_mgr.add_const('FILE_ATTRIBUTE_NOT_CONTENT_INDEXED',0x00002000)
		win_const_mgr.add_const('WIA_DPS_TRANSPARENCY_SELECT',0x00000C1E)
		win_const_mgr.add_const('SQLAOPAVG',0x00000004)
		win_const_mgr.add_const('DBIM_MINSIZE',0x00000001)
		win_const_mgr.add_const('WM_MOUSEHWHEEL',0x0000020E)
		win_const_mgr.add_const('ERROR_INVALID_SECURITY_DESCR',0x0000053A)
		win_const_mgr.add_const('NUM_DISCHARGE_POLICIES',0x00000004)
		win_const_mgr.add_const('DISPATCH_PROPERTYGET',0x00000002)
		win_const_mgr.add_const('PSH_RTLREADING',0x00000800)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_SERVICE_CC3',0x00000100)
		win_const_mgr.add_const('AE_LIM_LOGONHOURS',0x00000001)
		win_const_mgr.add_const('ERROR_JOIN_TO_SUBST',0x0000008C)
		win_const_mgr.add_const('SQL_API_ODBC3_ALL_FUNCTIONS_SIZE',0x000000FA)
		win_const_mgr.add_const('CERT_LOGOTYPE_INDIRECT_INFO_CHOICE',0x00000002)
		win_const_mgr.add_const('SV_OPLOCKBREAKWAIT_PARMNUM',0x00000216)
		win_const_mgr.add_const('IME_MODE_HIRAGANA',0x00000004)
		win_const_mgr.add_const('STDOLE2_MAJORVERNUM',0x00000002)
		win_const_mgr.add_const('FACILITY_NTSSPI',0x00000009)
		win_const_mgr.add_const('TAPE_LOAD',0x00000000)
		win_const_mgr.add_const('DS_REPSYNC_INITIAL_IN_PROGRESS',0x00010000)
		win_const_mgr.add_const('INTERNET_OPTION_REQUEST_PRIORITY',0x0000003A)
		win_const_mgr.add_const('DS_DOMAIN_DIRECT_INBOUND',0x00000020)
		win_const_mgr.add_const('MCI_STATUS_LENGTH',0x00000001)
		win_const_mgr.add_const('WMDM_FILE_ATTR_FOLDER',0x00000008)
		win_const_mgr.add_const('WSA_QOS_EFILTERSTYLE',0x00002B0B)
		win_const_mgr.add_const('TPM_LEFTBUTTON',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_I386_SEG12',0x00000009)
		win_const_mgr.add_const('CLCTL_USER_BASE',0x00000001)
		win_const_mgr.add_const('ERROR_CANNOT_IMPERSONATE',0x00000558)
		win_const_mgr.add_const('CONNDLG_NOT_PERSIST',0x00000020)
		win_const_mgr.add_const('SQL_TC_DML',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_PPC_ADDR32',0x00000002)
		win_const_mgr.add_const('ERROR_CLUSTER_INVALID_STRING_FORMAT',0x0000171D)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETAGENTSESSIONLIST',0x0000000D)
		win_const_mgr.add_const('MQMSG_AUTH_LEVEL_SIG10',0x00000002)
		win_const_mgr.add_const('GL_TRACE_EVENT',0x00002000)
		win_const_mgr.add_const('PORT_SRMP',0x000000C1)
		win_const_mgr.add_const('WIA_DPS_FILTER_SELECT',0x00000C0B)
		win_const_mgr.add_const('LINECALLINFOSTATE_CHARGINGINFO',0x01000000)
		win_const_mgr.add_const('ERROR_NOT_AUTHENTICATED',0x000004DC)
		win_const_mgr.add_const('DBPROP_MSDAORA8_DETERMINEKEYCOLUMNS',0x00000002)
		win_const_mgr.add_const('BS_MULTILINE',0x00002000)
		win_const_mgr.add_const('CAL_SABBREVDAYNAME7',0x00000014)
		win_const_mgr.add_const('SQL_CCS_CREATE_CHARACTER_SET',0x00000001)
		win_const_mgr.add_const('MKF_MOUSEKEYSON',0x00000001)
		win_const_mgr.add_const('FILE_SKIP_COMPLETION_PORT_ON_SUCCESS',0x00000001)
		win_const_mgr.add_const('DEBUG_CURRENT_DEFAULT',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_TI_CHAOS',0x00000010)
		win_const_mgr.add_const('DI_FLAGSEX_USECLASSFORCOMPAT',0x00002000)
		win_const_mgr.add_const('MCI_DGV_LIST_VIDEO_ALG',0x00004005)
		win_const_mgr.add_const('FPS_AVAILABLE',0x20100000)
		win_const_mgr.add_const('SECPKG_CALL_ASYNC_UPDATE',0x00001000)
		win_const_mgr.add_const('WSB_PROP_HBKGCOLOR',0x00000080)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_PAUSED',0x000013CE)
		win_const_mgr.add_const('RTM_MATCH_NEXTHOP',0x00000008)
		win_const_mgr.add_const('DIFFERENCE',0x0000000B)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGENUMERATEVALUEKEY',0x00000012)
		win_const_mgr.add_const('INPUT_MOUSE',0x00000000)
		win_const_mgr.add_const('SCARD_CLASS_COMMUNICATIONS',0x00000002)
		win_const_mgr.add_const('CERT_TRUST_IS_NOT_TIME_NESTED',0x00000002)
		win_const_mgr.add_const('DISC_UPDATE_PROFILE',0x00000001)
		win_const_mgr.add_const('LOW_SURROGATE_END',0x00000000)
		win_const_mgr.add_const('PORT_KIS',0x000000BA)
		win_const_mgr.add_const('CM_GETIDLIST_FILTER_SERVICE',0x00000002)
		win_const_mgr.add_const('SMINIT_AUTOTOOLTIP',0x00000200)
		win_const_mgr.add_const('OF_GET',0x00000002)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_GLOBAL_CATALOG',0x00000010)
		win_const_mgr.add_const('MAX_GOPHER_LOCATOR_LENGTH',0x00000001)
		win_const_mgr.add_const('KSMETHOD_TYPE_READ',0x00000001)
		win_const_mgr.add_const('MCGIP_FOOTER',0x00000003)
		win_const_mgr.add_const('IME_SMODE_AUTOMATIC',0x00000004)
		win_const_mgr.add_const('SET_TAPE_DRIVE_INFORMATION',0x00000001)
		win_const_mgr.add_const('ANSI_FIXED_FONT',0x0000000B)
		win_const_mgr.add_const('D3DTA_COMPLEMENT',0x00000010)
		win_const_mgr.add_const('HEAP_GROWABLE',0x00000002)
		win_const_mgr.add_const('TF_SFT_HIGHTRANSPARENCY',0x00000040)
		win_const_mgr.add_const('SQL_OSC_EXTENDED',0x00000002)
		win_const_mgr.add_const('ICC_DATE_CLASSES',0x00000100)
		win_const_mgr.add_const('CRED_PERSIST_SESSION',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_HASH',0x0000360D)
		win_const_mgr.add_const('WINHTTP_AUTO_DETECT_TYPE_DNS_A',0x00000002)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_COM_DESCRIPTOR',0x0000000E)
		win_const_mgr.add_const('IDS_CAP_AUDIO_DROP_COMPERROR',0x000001BA)
		win_const_mgr.add_const('DCM_FLAGS_LOCALTHREADTSF',0x00000004)
		win_const_mgr.add_const('SHTDN_REASON_FLAG_USER_DEFINED',0x40000000)
		win_const_mgr.add_const('RC_DEVBITS',0x00008000)
		win_const_mgr.add_const('CERT_VALIDITY_CERTIFICATE_REVOKED',0x00000008)
		win_const_mgr.add_const('CRYPT_GET_INSTALLED_OID_FUNC_FLAG',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_WINS_INIT_FAILED',0x0000258F)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_PRINTER_NAME',0x00000000)
		win_const_mgr.add_const('WIA_DIP_STI_GEN_CAPABILITIES',0x0000000D)
		win_const_mgr.add_const('LVS_EX_SNAPTOGRID',0x00080000)
		win_const_mgr.add_const('WMDM_STATUS_BUSY',0x00000002)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_PATH_TYPE_URL',0x00000003)
		win_const_mgr.add_const('IPX_STATIC_ROUTE_TABLE',0x00000003)
		win_const_mgr.add_const('OID_FDDI_SMT_CF_STATE',0x03030216)
		win_const_mgr.add_const('ETDT_DISABLE',0x00000001)
		win_const_mgr.add_const('IDC_EL_LINKSOURCE',0x000000D8)
		win_const_mgr.add_const('PAN_MIDLINE_LOW_POINTED',0x0000000C)
		win_const_mgr.add_const('OID_PNP_WAKE_UP_ERROR',0xFD020201)
		win_const_mgr.add_const('CMSG_SIGNER_CERT_INFO_PARAM',0x00000007)
		win_const_mgr.add_const('ADS_PRINTER_WARMING_UP',0x00010000)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_IS_IMPLICIT_BIND',0x00000200)
		win_const_mgr.add_const('SSA_RTL',0x00000100)
		win_const_mgr.add_const('SNMP_PDUAPI_UNRECOGNIZED_PDU',0x00000014)
		win_const_mgr.add_const('PW_CLIENTONLY',0x00000001)
		win_const_mgr.add_const('SM_REMOTECONTROL',0x00002001)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_KEY_COLOR',0x00000400)
		win_const_mgr.add_const('HSE_URL_FLAGS_DONT_CACHE',0x00000010)
		win_const_mgr.add_const('SERVICE_NOTIFY_RUNNING',0x00000008)
		win_const_mgr.add_const('VARCMP_LT',0x00000000)
		win_const_mgr.add_const('MAPI_THISSESSION',0x00000020)
		win_const_mgr.add_const('SSPROP_STREAM_COMMANDTYPE',0x00000012)
		win_const_mgr.add_const('MD_LOGFILE_PERIOD_DAILY',0x00000001)
		win_const_mgr.add_const('PHOTO_PROGRAMMODE_PORTRAIT',0x00000007)
		win_const_mgr.add_const('DEBUG_BREAK_EXECUTE',0x00000004)
		win_const_mgr.add_const('WINHTTP_OPTION_PROXY',0x00000026)
		win_const_mgr.add_const('IDB_HIST_HOT',0x0000000D)
		win_const_mgr.add_const('IF_TYPE_GIGABITETHERNET',0x00000075)
		win_const_mgr.add_const('OPTION_DEFAULT_TTL',0x00000017)
		win_const_mgr.add_const('EVENT_OBJECT_HIDE',0x00008003)
		win_const_mgr.add_const('RCRED_STATUS_NOCRED',0x00000000)
		win_const_mgr.add_const('HCF_DEFAULTDESKTOP',0x00000200)
		win_const_mgr.add_const('ET_DITHERMODE',0x00000004)
		win_const_mgr.add_const('AA_A_ACL',0x00008000)
		win_const_mgr.add_const('MCI_UPDATE',0x00000854)
		win_const_mgr.add_const('READ_CONTROL',0x00020000)
		win_const_mgr.add_const('ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST',0x00002157)
		win_const_mgr.add_const('IDM_IE50_PASTE',0x00000961)
		win_const_mgr.add_const('DB_NULL_HCHAPTER',0x00000000)
		win_const_mgr.add_const('DEBUG_SYMENT_IS_LOCAL',0x00000008)
		win_const_mgr.add_const('MDPROPVAL_MSF_QTD',0x00000080)
		win_const_mgr.add_const('TRACE_PROVIDER_FLAG_LEGACY',0x00000001)
		win_const_mgr.add_const('PHOTO_EXPOSUREPROGRAM_APERTURE',0x00000003)
		win_const_mgr.add_const('SQL_API_SQLCANCEL',0x00000005)
		win_const_mgr.add_const('PORT_RTIP',0x00000303)
		win_const_mgr.add_const('DISPID_FAVSELECTIONCHANGE',0x00000001)
		win_const_mgr.add_const('ASC_REQ_SEQUENCE_DETECT',0x00000008)
		win_const_mgr.add_const('NETERR_RING_STATUS_RECOVERY',0x00000040)
		win_const_mgr.add_const('VIF_MISMATCH',0x00000002)
		win_const_mgr.add_const('D3DSP_DCL_USAGEINDEX_SHIFT',0x00000010)
		win_const_mgr.add_const('EM_REPLACESEL',0x000000C2)
		win_const_mgr.add_const('NAT_BITS_PER_RNAT_REG',0x0000003F)
		win_const_mgr.add_const('SHDID_FS_OTHER',0x00000004)
		win_const_mgr.add_const('MD_NOTIFY_ORDER_MEDIUM',0x00040000)
		win_const_mgr.add_const('IMN_SETCANDIDATEPOS',0x00000009)
		win_const_mgr.add_const('PRJOB_DEVSTATUS',0x00000001)
		win_const_mgr.add_const('NDIS_ETH_TYPE_802_1Q',0x00008100)
		win_const_mgr.add_const('SPI_SETMOUSESPEED',0x00000071)
		win_const_mgr.add_const('OFFSET_VECTOR_EXT_INTERRUPT',0x00000002)
		win_const_mgr.add_const('MB_TYPEMASK',0x0000000F)
		win_const_mgr.add_const('NDIS_ETH_TYPE_802_1X',0x00000888)
		win_const_mgr.add_const('STGFMT_FILE',0x00000003)
		win_const_mgr.add_const('RAS_EAP_FLAG_MACHINE_AUTH',0x00000020)
		win_const_mgr.add_const('WIA_TRANSFER_CHILDREN_SINGLE_SCAN',0x00000001)
		win_const_mgr.add_const('POLICY_SERVER_ADMIN',0x00000400)
		win_const_mgr.add_const('D3DFVF_RESERVED0',0x00000001)
		win_const_mgr.add_const('ERROR_DS_NAME_ERROR_NOT_FOUND',0x00002116)
		win_const_mgr.add_const('D3DFVF_RESERVED2',0x00006000)
		win_const_mgr.add_const('WIA_IPA_ITEM_NAME',0x00001002)
		win_const_mgr.add_const('IF_NOLOCALICERTADMIN',0x00000020)
		win_const_mgr.add_const('DDCAPS2_NONLOCALVIDMEMCAPS',0x00000400)
		win_const_mgr.add_const('WMDM_FILE_ATTR_SYSTEM',0x00800000)
		win_const_mgr.add_const('DBPROPVAL_PT_PGUID_PROPID',0x00000040)
		win_const_mgr.add_const('QS_POSTMESSAGE',0x00000008)
		win_const_mgr.add_const('MB_SYSTEMMODAL',0x00001000)
		win_const_mgr.add_const('MM_MCISIGNAL',0x000003CB)
		win_const_mgr.add_const('WM_INITMENU',0x00000116)
		win_const_mgr.add_const('EDITF_DISABLEOLDOSCNUPN',0x00400000)
		win_const_mgr.add_const('OID_FDDI_MAC_TVX_VALUE',0x03030233)
		win_const_mgr.add_const('WINHTTP_QUERY_STATUS_CODE',0x00000013)
		win_const_mgr.add_const('DC_BUTTONS',0x00001000)
		win_const_mgr.add_const('SE_SACL_AUTO_INHERITED',0x00000800)
		win_const_mgr.add_const('SQL_SCCO_LOCK',0x00000002)
		win_const_mgr.add_const('SEE_MASK_NO_CONSOLE',0x00008000)
		win_const_mgr.add_const('SUBLANG_URDU_PAKISTAN',0x00000001)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_254',0x00000000)
		win_const_mgr.add_const('PERF_DISPLAY_NO_SUFFIX',0x00000000)
		win_const_mgr.add_const('WIA_IPC_AUDIO_DATA_FORMAT',0x00001406)
		win_const_mgr.add_const('TMT_TEXTBORDERCOLOR',0x00000EE9)
		win_const_mgr.add_const('LOCK_ELEMENT',0x00000000)
		win_const_mgr.add_const('DDSD_FVF',0x00200000)
		win_const_mgr.add_const('WM_GETTITLEBARINFOEX',0x0000033F)
		win_const_mgr.add_const('PDH_MAX_SCALE',0x00000007)
		win_const_mgr.add_const('IOF_SELECTCREATENEW',0x00000002)
		win_const_mgr.add_const('SHGFI_ICON',0x00000100)
		win_const_mgr.add_const('SKF_LSHIFTLOCKED',0x00010000)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_SENDCALLS',0x00000025)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_DIALQUIET',0x00000080)
		win_const_mgr.add_const('D3DFMT_A1_SURFACE_MAXHEIGHT',0x00000800)
		win_const_mgr.add_const('CRED_MAX_TARGETNAME_NAMESPACE_LENGTH',0x00000100)
		win_const_mgr.add_const('ERROR_NOT_SUPPORTED',0x00000032)
		win_const_mgr.add_const('MCI_SYSINFO_QUANTITY',0x00000100)
		win_const_mgr.add_const('IT_PORTABLE',0x00000002)
		win_const_mgr.add_const('ERROR_TOO_MANY_SEM_REQUESTS',0x00000067)
		win_const_mgr.add_const('BTH_ERROR_UNSUPPORTED_LMP_PARM_VALUE',0x00000020)
		win_const_mgr.add_const('CMS_USEAPPLYCALLBACK',0x00000100)
		win_const_mgr.add_const('ERROR_NO_EVENT_PAIR',0x00000244)
		win_const_mgr.add_const('ERROR_INVALID_SIGNAL_NUMBER',0x000000D1)
		win_const_mgr.add_const('ERROR_IPSEC_MM_FILTER_EXISTS',0x000032CE)
		win_const_mgr.add_const('STRING_PROVIDER_NAME_OFFSET',0x00000002)
		win_const_mgr.add_const('SQL_AA_TRUE',0x00000001)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_MSP',0x00000200)
		win_const_mgr.add_const('FAXDEVRECEIVE_SIZE',0x00001000)
		win_const_mgr.add_const('FKF_HOTKEYACTIVE',0x00000004)
		win_const_mgr.add_const('IIS_MD_FTP_BASE',0x00001388)
		win_const_mgr.add_const('CERT_RDN_PRINTABLE_STRING',0x00000004)
		win_const_mgr.add_const('STANDARD_RIGHTS_ALL',0x001F0000)
		win_const_mgr.add_const('SPDRP_EXCLUSIVE',0x0000001A)
		win_const_mgr.add_const('EC_GRAPH_CHANGED',0x00000050)
		win_const_mgr.add_const('ERROR_EXCL_SEM_ALREADY_OWNED',0x00000065)
		win_const_mgr.add_const('MXDCOP_GET_FILENAME',0x0000000E)
		win_const_mgr.add_const('PORT_CL1',0x000000AC)
		win_const_mgr.add_const('IMAGE_COLORSPACE_SRGB',0x00000001)
		win_const_mgr.add_const('PHONEBUTTONSTATE_UNKNOWN',0x00000004)
		win_const_mgr.add_const('AM_CONTENTPROPERTY_COPYRIGHT',0x00000004)
		win_const_mgr.add_const('SQL_IS_ON',0x00000001)
		win_const_mgr.add_const('SSPROP_COLUMNLEVELCOLLATION',0x00000004)
		win_const_mgr.add_const('CWP_ALL',0x00000000)
		win_const_mgr.add_const('MD_ACCESS_READ',0x00000001)
		win_const_mgr.add_const('PIR_STATUS_TABLE_ERROR',0x00000004)
		win_const_mgr.add_const('DISPID_AUTOSCAN',0x0000000B)
		win_const_mgr.add_const('IP_ADD_SOURCE_MEMBERSHIP',0x0000000F)
		win_const_mgr.add_const('FR_MATCHCASE',0x00000004)
		win_const_mgr.add_const('SSPROP_INIT_NETWORKADDRESS',0x00000005)
		win_const_mgr.add_const('MCI_WAVE_OFFSET',0x00000480)
		win_const_mgr.add_const('WIA_DPS_HORIZONTAL_SHEET_FEED_SIZE',0x00000C04)
		win_const_mgr.add_const('CRYPT_FLAG_TLS1',0x00000008)
		win_const_mgr.add_const('DMPAPER_LEDGER',0x00000004)
		win_const_mgr.add_const('D3DLINECAPS_BLEND',0x00000004)
		win_const_mgr.add_const('SQL_TXN_READ_UNCOMMITTED',0x00000001)
		win_const_mgr.add_const('IDS_CAP_VIDEO_ADD_ERROR',0x000001AB)
		win_const_mgr.add_const('AUTHZ_NO_SUCCESS_AUDIT',0x00000001)
		win_const_mgr.add_const('OID_WAN_QUALITY_OF_SERVICE',0x04010103)
		win_const_mgr.add_const('OID_GEN_BYTES_XMIT',0x0002021A)
		win_const_mgr.add_const('WIN_CERT_TYPE_PKCS_SIGNED_DATA',0x00000002)
		win_const_mgr.add_const('LB_GETTEXT',0x00000189)
		win_const_mgr.add_const('SCARD_LEAVE_CARD',0x00000000)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_DIRECTORY',0x00000009)
		win_const_mgr.add_const('SV_MAXPAGEDPOOLCHUNKSIZE_PARMNUM',0x00000248)
		win_const_mgr.add_const('SM_MIDEASTENABLED',0x0000004A)
		win_const_mgr.add_const('DOT11_MAX_NUM_OF_FRAGMENTS',0x00000010)
		win_const_mgr.add_const('SCF_USEUIRULES',0x00000008)
		win_const_mgr.add_const('CC_SOLIDCOLOR',0x00000080)
		win_const_mgr.add_const('CAL_GREGORIAN_US',0x00000002)
		win_const_mgr.add_const('VOS_DOS_WINDOWS32',0x00010004)
		win_const_mgr.add_const('SPI_SETACTIVEWNDTRKTIMEOUT',0x00002003)
		win_const_mgr.add_const('LUP_RETURN_PREFERRED_NAMES',0x00010000)
		win_const_mgr.add_const('COLOR_SCROLLBAR',0x00000000)
		win_const_mgr.add_const('INTERNET_FLAG_FWD_BACK',0x00000020)
		win_const_mgr.add_const('SQL_MAX_ROW_SIZE_INCLUDES_LONG',0x00000067)
		win_const_mgr.add_const('TF_CONVERSIONMODE_NATIVE',0x00000001)
		win_const_mgr.add_const('WKSTA_USECLOSEBEHIND_PARMNUM',0x00000032)
		win_const_mgr.add_const('TLS1_ALERT_HANDSHAKE_FAILURE',0x00000028)
		win_const_mgr.add_const('STATUS_SEVERITY_SUCCESS',0x00000000)
		win_const_mgr.add_const('ERROR_OBJECT_NO_LONGER_EXISTS',0x00001A97)
		win_const_mgr.add_const('GMDI_USEDISABLED',0x00000001)
		win_const_mgr.add_const('URLACTION_ACTIVEX_OVERRIDE_DATA_SAFETY',0x00001202)
		win_const_mgr.add_const('JOY_BUTTON4CHG',0x00000800)
		win_const_mgr.add_const('DB_NULL_HROW',0x00000000)
		win_const_mgr.add_const('TF_SFT_HIDDEN',0x00000008)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME4',0x00000047)
		win_const_mgr.add_const('ERROR_HOST_NODE_NOT_AVAILABLE',0x0000138D)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME6',0x00000049)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME1',0x00000044)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_BUFF_LEN',0x00000002)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME2',0x00000045)
		win_const_mgr.add_const('TASK_WEDNESDAY',0x00000008)
		win_const_mgr.add_const('DEBUG_OUTCTL_NOT_LOGGED',0x00000008)
		win_const_mgr.add_const('EVENT_MAX',0x7FFFFFFF)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME9',0x0000004C)
		win_const_mgr.add_const('ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY',0x00000312)
		win_const_mgr.add_const('MSIDBOPEN_PATCHFILE',0x00000020)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_VOLUMENAME',0x00000204)
		win_const_mgr.add_const('ARW_RIGHT',0x00000000)
		win_const_mgr.add_const('MUI_USE_INSTALLED_LANGUAGES',0x00000020)
		win_const_mgr.add_const('MCI_SEQ_SET_OFFSET',0x01000000)
		win_const_mgr.add_const('PSH_HEADER',0x00080000)
		win_const_mgr.add_const('IC_E_CAPS_INITIALIZATION_FAILURE',0x83010002)
		win_const_mgr.add_const('ISC_RET_FORWARD_CREDENTIALS',0x00400000)
		win_const_mgr.add_const('IP_RECVIF',0x00000018)
		win_const_mgr.add_const('LANG_TELUGU',0x00000004)
		win_const_mgr.add_const('DSSI_NO_ACCESS_CHECK',0x00000002)
		win_const_mgr.add_const('NETSETUP_MACHINE_PWD_PASSED',0x00000080)
		win_const_mgr.add_const('WM_XBUTTONDOWN',0x0000020B)
		win_const_mgr.add_const('CAL_GREGORIAN_XLIT_ENGLISH',0x0000000B)
		win_const_mgr.add_const('IDM_INSERTSPAN',0x00000935)
		win_const_mgr.add_const('KSAUDIO_QUALITY_WORST',0x00000000)
		win_const_mgr.add_const('MWT_LEFTMULTIPLY',0x00000002)
		win_const_mgr.add_const('MIDI_CACHE_ALL',0x00000001)
		win_const_mgr.add_const('CSC_CACHE_AUTO_REINT',0x00000010)
		win_const_mgr.add_const('ETW_OBJECT_TYPE_VALUE',0x00000001)
		win_const_mgr.add_const('DI_FLAGSEX_FILTERCLASSES',0x00000040)
		win_const_mgr.add_const('DDENUM_ATTACHEDSECONDARYDEVICES',0x00000001)
		win_const_mgr.add_const('ACM_FORMATENUMF_INPUT',0x00800000)
		win_const_mgr.add_const('MCI_FORMAT_FRAMES',0x00000003)
		win_const_mgr.add_const('SECURITY_PACKAGE_DIGEST_RID',0x00000015)
		win_const_mgr.add_const('WTS_EVENT_DELETE',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_DISABLE_AUTODIAL',0x00000046)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_DATADISCONTINUITY',0x00000004)
		win_const_mgr.add_const('LR_COPYFROMRESOURCE',0x00004000)
		win_const_mgr.add_const('SHORT_MAX',0x00007FFF)
		win_const_mgr.add_const('FILE_ANY_ACCESS',0x00000000)
		win_const_mgr.add_const('LANG_ARMENIAN',0x00000002)
		win_const_mgr.add_const('TLS1_ALERT_WARNING',0x00000001)
		win_const_mgr.add_const('DISPID_BLUR',0x00000006)
		win_const_mgr.add_const('CMM_IDENT',0x00000001)
		win_const_mgr.add_const('CDEF_DEVMON_CMGR_DEVICE',0x00000010)
		win_const_mgr.add_const('LOGTOKEN_TYPE_MASK',0x00000003)
		win_const_mgr.add_const('SQL_CV_CHECK_OPTION',0x00000002)
		win_const_mgr.add_const('SUBLANG_MACEDONIAN_MACEDONIA',0x00000001)
		win_const_mgr.add_const('HH_SET_QUERYSERVICE',0x0000001E)
		win_const_mgr.add_const('WM_DWMCOMPOSITIONCHANGED',0x0000031E)
		win_const_mgr.add_const('BN_SETFOCUS',0x00000006)
		win_const_mgr.add_const('TAPE_DRIVE_LOAD_UNLD_IMMED',0x80000020)
		win_const_mgr.add_const('CF_ANSIONLY',0x00000400)
		win_const_mgr.add_const('JOB_OBJECT_BASIC_LIMIT_VALID_FLAGS',0x00000000)
		win_const_mgr.add_const('MB_ICONASTERISK',0x00000040)
		win_const_mgr.add_const('PFNS_PLAIN',0x00000300)
		win_const_mgr.add_const('DDBLT_ALPHASRCSURFACEOVERRIDE',0x00000100)
		win_const_mgr.add_const('MAX_GOPHER_DISPLAY_TEXT',0x00000080)
		win_const_mgr.add_const('VIF_DIFFTYPE',0x00000020)
		win_const_mgr.add_const('BCM_FIRST',0x00001600)
		win_const_mgr.add_const('LCPRI_FORCECONFIG',0x00000000)
		win_const_mgr.add_const('PORT_SGMPTRAPS',0x000000A0)
		win_const_mgr.add_const('SV_ALERTSCHED_PARMNUM',0x00000025)
		win_const_mgr.add_const('EC_SKIP_FRAMES',0x00000025)
		win_const_mgr.add_const('STIF_DEFAULT',0x00000000)
		win_const_mgr.add_const('D3DFVF_TEX2',0x00000200)
		win_const_mgr.add_const('SSRVOPT_DWORD',0x00000002)
		win_const_mgr.add_const('D3DFVF_TEX0',0x00000000)
		win_const_mgr.add_const('SASL_OPTION_RECV_SIZE',0x00000002)
		win_const_mgr.add_const('D3DFVF_TEX6',0x00000600)
		win_const_mgr.add_const('D3DFVF_TEX7',0x00000700)
		win_const_mgr.add_const('D3DFVF_TEX4',0x00000400)
		win_const_mgr.add_const('CM_DETECT_RUN',0x80000000)
		win_const_mgr.add_const('VCSTATUS_NEW_MESSAGE',0x00400000)
		win_const_mgr.add_const('TMT_COMPANY',0x0000025B)
		win_const_mgr.add_const('D3DFVF_TEX8',0x00000800)
		win_const_mgr.add_const('ERROR_INVALID_IMAGE_HASH',0x00000241)
		win_const_mgr.add_const('DRM_DEVICE_REGISTER_TYPE_STREAMING',0x00000001)
		win_const_mgr.add_const('DS_REPADD_TWO_WAY',0x00000400)
		win_const_mgr.add_const('FSB_ENCARTA_MODE',0x00000001)
		win_const_mgr.add_const('DDCAPS2_CANCALIBRATEGAMMA',0x00100000)
		win_const_mgr.add_const('DISPID_DOM_COLLECTION_BASE',0x000F4240)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_CLEARTIMEOUT',0x00000450)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_GRP_SUM_FLOW_RATE',0x00000022)
		win_const_mgr.add_const('DCTT_DOWNLOAD_OUTLINE',0x00000008)
		win_const_mgr.add_const('MDM_MASK_AUTO_ML',0x00000003)
		win_const_mgr.add_const('SETXON',0x00000002)
		win_const_mgr.add_const('NTDSCONN_OPT_IS_GENERATED',0x00000001)
		win_const_mgr.add_const('D3DFVF_TEX5',0x00000500)
		win_const_mgr.add_const('IMAGE_REL_IA64_PCREL60F',0x00000017)
		win_const_mgr.add_const('DB_DISP_ERROR',0x0000001E)
		win_const_mgr.add_const('SQL_DESC_ROWS_PROCESSED_PTR',0x00000022)
		win_const_mgr.add_const('OPTION_HOST_NAME',0x0000000C)
		win_const_mgr.add_const('NRC_NAMERR',0x00000017)
		win_const_mgr.add_const('MDPROPVAL_RR_READONLY',0x00000002)
		win_const_mgr.add_const('PS_DASHDOT',0x00000003)
		win_const_mgr.add_const('LINEERR_INVALPRIVSELECT',0x80000036)
		win_const_mgr.add_const('IMAGE_REL_IA64_PCREL60I',0x00000018)
		win_const_mgr.add_const('DDBLTFX_MIRRORLEFTRIGHT',0x00000002)
		win_const_mgr.add_const('CSCONFIGFLAG_DISABLED',0x00000001)
		win_const_mgr.add_const('META_SETWINDOWORG',0x0000020B)
		win_const_mgr.add_const('SUBLANG_SPANISH_HONDURAS',0x00000012)
		win_const_mgr.add_const('D3DPS20CAPS_NODEPENDENTREADLIMIT',0x00000001)
		win_const_mgr.add_const('MCI_VD_GETDEVCAPS_FAST_RATE',0x00004003)
		win_const_mgr.add_const('SMART_NOT_SUPPORTED',0x00000009)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_ARM',0x00000001)
		win_const_mgr.add_const('HTTP_STATUS_REQUEST_TIMEOUT',0x00000198)
		win_const_mgr.add_const('UNISCRIBE_OPENTYPE',0x00000100)
		win_const_mgr.add_const('NTMSMLI_MAXTYPE',0x00000040)
		win_const_mgr.add_const('DEBUG_VSEARCH_DEFAULT',0x00000000)
		win_const_mgr.add_const('PDH_CSTATUS_VALID_DATA',0x00000000)
		win_const_mgr.add_const('DEVPROP_TYPE_SECURITY_DESCRIPTOR_STRING',0x00000014)
		win_const_mgr.add_const('CM_GLOBAL_STATE_ON_BIG_STACK',0x00000002)
		win_const_mgr.add_const('DDPF_ZBUFFER',0x00000400)
		win_const_mgr.add_const('ACM_DRIVERADDF_LOCAL',0x00000000)
		win_const_mgr.add_const('MAX_ISCSI_DISCOVERY_DOMAIN_LEN',0x00000100)
		win_const_mgr.add_const('ERROR_I24_NOT_READY',0x00000002)
		win_const_mgr.add_const('DEBUG_PROC_DESC_NO_SERVICES',0x00000002)
		win_const_mgr.add_const('ENABLE_ECHO_INPUT',0x00000004)
		win_const_mgr.add_const('MM_MCINOTIFY',0x000003B9)
		win_const_mgr.add_const('MFT_RADIOCHECK',0x00000200)
		win_const_mgr.add_const('MQMSG_FIRST_IN_XACT',0x00000001)
		win_const_mgr.add_const('GOPHER_TYPE_DIRECTORY',0x00000002)
		win_const_mgr.add_const('DISCHARGE_POLICY_LOW',0x00000001)
		win_const_mgr.add_const('OID_802_11_TEST',0x0D010120)
		win_const_mgr.add_const('LINECALLPARTYID_OUTOFAREA',0x00000002)
		win_const_mgr.add_const('LANG_DANISH',0x00000006)
		win_const_mgr.add_const('MQMSG_SENDERID_TYPE_NONE',0x00000000)
		win_const_mgr.add_const('MS_ROUTER_VERSION',0x00000500)
		win_const_mgr.add_const('ACN_STOP',0x00000002)
		win_const_mgr.add_const('DDCAPS2_RESERVED1',0x08000000)
		win_const_mgr.add_const('NDIS_DEVICE_TYPE_ENDPOINT',0x00000001)
		win_const_mgr.add_const('ERROR_NO_SYSTEM_RESOURCES',0x000005AA)
		win_const_mgr.add_const('PERF_TEXT_ASCII',0x00010000)
		win_const_mgr.add_const('DTT_GRAYED',0x00000001)
		win_const_mgr.add_const('SQL_RE_OFF',0x00000000)
		win_const_mgr.add_const('CM_GETIDLIST_DONOTGENERATE',0x10000040)
		win_const_mgr.add_const('SO_DISCDATALEN',0x00007006)
		win_const_mgr.add_const('DC_MEDIAREADY',0x0000001D)
		win_const_mgr.add_const('SPINST_ALL',0x00000001)
		win_const_mgr.add_const('MQ_MAX_Q_NAME_LEN',0x0000007C)
		win_const_mgr.add_const('TBSTYLE_EX_DRAWDDARROWS',0x00000001)
		win_const_mgr.add_const('LOCALE_IPOSSEPBYSPACE',0x00000055)
		win_const_mgr.add_const('SQL_NULL_HDBC',0x00000000)
		win_const_mgr.add_const('CM_CREATE_DEVNODE_BITS',0x0000000F)
		win_const_mgr.add_const('DIRID_APPS',0x00000018)
		win_const_mgr.add_const('SSRVOPT_DOWNSTREAM_STORE',0x00002000)
		win_const_mgr.add_const('DXVA_BITSTREAM_CONCEALMENT_METHOD_BACKWARD',0x00000003)
		win_const_mgr.add_const('PRODUCT_SMALLBUSINESS_SERVER_PREMIUM',0x00000019)
		win_const_mgr.add_const('VER_ERR_CALL_SIG',0x04000000)
		win_const_mgr.add_const('CMPT_PROTOCOL_UUID16',0x0000001B)
		win_const_mgr.add_const('CERT_RDN_TYPE_MASK',0x000000FF)
		win_const_mgr.add_const('LINESPECIALINFO_REORDER',0x00000004)
		win_const_mgr.add_const('INTERNET_SCHEME_HTTP',0x00000001)
		win_const_mgr.add_const('SDP_ATTRIB_IMAGING_SUPPORTED_FEATURES',0x00000311)
		win_const_mgr.add_const('FILE_SUPPORTS_TRANSACTIONS',0x00200000)
		win_const_mgr.add_const('ERROR_ILLEGAL_ELEMENT_ADDRESS',0x0000048A)
		win_const_mgr.add_const('PORT_NTP',0x0000007B)
		win_const_mgr.add_const('ERROR_BAD_MCFG_TABLE',0x00000317)
		win_const_mgr.add_const('HF32_SHARED',0x00000002)
		win_const_mgr.add_const('RPC_S_NO_CALL_ACTIVE',0x000006BD)
		win_const_mgr.add_const('DDCAPS_BLTSTRETCH',0x00000200)
		win_const_mgr.add_const('DS_REPADD_ASYNCHRONOUS_REPLICA',0x00000020)
		win_const_mgr.add_const('MAPI_LONG_MSGID',0x00004000)
		win_const_mgr.add_const('WM_IME_STARTCOMPOSITION',0x0000010D)
		win_const_mgr.add_const('SM_CYMIN',0x0000001D)
		win_const_mgr.add_const('BAUD_14400',0x00001000)
		win_const_mgr.add_const('MCI_DGV_STATUS_BITSPERSAMPLE',0x00000402)
		win_const_mgr.add_const('OPF_DISABLECONVERT',0x00000008)
		win_const_mgr.add_const('D3DPCMPCAPS_LESS',0x00000002)
		win_const_mgr.add_const('D3DPRESENT_INTERVAL_TWO',0x00000002)
		win_const_mgr.add_const('SERVICE_STOP',0x00000020)
		win_const_mgr.add_const('WLX_OPTION_SMART_CARD_INFO',0x00010002)
		win_const_mgr.add_const('MAX_LANA',0x000000FE)
		win_const_mgr.add_const('PLATFORM_ID_VMS',0x000002BC)
		win_const_mgr.add_const('OID_GEN_RECEIVE_BLOCK_SIZE',0x0001010B)
		win_const_mgr.add_const('TCS_TABS',0x00000000)
		win_const_mgr.add_const('VK_PRINT',0x0000002A)
		win_const_mgr.add_const('IP_EXPORT_INCLUDED',0x00000001)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_FILE',0x00000004)
		win_const_mgr.add_const('ASC_REQ_INTEGRITY',0x00020000)
		win_const_mgr.add_const('NFR_ANSI',0x00000001)
		win_const_mgr.add_const('NCRYPT_PERSIST_ONLY_FLAG',0x40000000)
		win_const_mgr.add_const('LB_SETITEMHEIGHT',0x000001A0)
		win_const_mgr.add_const('ERROR_SHUTDOWN_CLUSTER',0x00001390)
		win_const_mgr.add_const('IME_ESC_QUERY_SUPPORT',0x00000003)
		win_const_mgr.add_const('METHOD_IN_DIRECT',0x00000001)
		win_const_mgr.add_const('IDM_TRIED_ORDERLIST',0x0000002F)
		win_const_mgr.add_const('ES_PASSWORD',0x00000020)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NEGOTIATION_PENDING',0x000035EB)
		win_const_mgr.add_const('DI_DEFAULTSIZE',0x00000008)
		win_const_mgr.add_const('CGD_DEFAULT',0x00000000)
		win_const_mgr.add_const('TF_LBI_TEXT',0x00000002)
		win_const_mgr.add_const('MAX_SIZE_SECURITY_ID',0x00000200)
		win_const_mgr.add_const('TH_TAPI',0x00000002)
		win_const_mgr.add_const('WSA_WAIT_TIMEOUT',0x00000102)
		win_const_mgr.add_const('AC_SRC_OVER',0x00000000)
		win_const_mgr.add_const('CTRY_TRINIDAD_Y_TOBAGO',0x00000001)
		win_const_mgr.add_const('MMIO_INSTALLPROC',0x00010000)
		win_const_mgr.add_const('ERROR_DEPENDENCY_TREE_TOO_COMPLEX',0x00001729)
		win_const_mgr.add_const('RPC_C_HTTP_AUTHN_SCHEME_NTLM',0x00000002)
		win_const_mgr.add_const('IDC_EL_AUTOMATIC',0x000000CA)
		win_const_mgr.add_const('IDM_HTMLEDITMODE',0x0000090C)
		win_const_mgr.add_const('ERROR_PRINT_JOB_RESTART_REQUIRED',0x00000BCC)
		win_const_mgr.add_const('APPCOMMAND_CORRECTION_LIST',0x0000002D)
		win_const_mgr.add_const('IF_TYPE_IS088023_CSMACD',0x00000007)
		win_const_mgr.add_const('LVCFMT_COL_HAS_IMAGES',0x00008000)
		win_const_mgr.add_const('PHONEFEATURE_GENERICPHONE',0x10000000)
		win_const_mgr.add_const('CERT_NAME_STR_COMMA_FLAG',0x04000000)
		win_const_mgr.add_const('SEC_FILE',0x00800000)
		win_const_mgr.add_const('ALG_SID_AGREED_KEY_ANY',0x00000003)
		win_const_mgr.add_const('MDTREEOP_SELF',0x00000008)
		win_const_mgr.add_const('LINE_CALLINFO',0x00000001)
		win_const_mgr.add_const('SDP_ATTRIB_AVAILABILITY',0x00000008)
		win_const_mgr.add_const('SBSP_NOAUTOSELECT',0x04000000)
		win_const_mgr.add_const('CMC_STATUS_FAILED',0x00000002)
		win_const_mgr.add_const('CRL_V2',0x00000001)
		win_const_mgr.add_const('RATING_ONE_STAR_MIN',0x00000001)
		win_const_mgr.add_const('SEARCH_ALL',0x00000000)
		win_const_mgr.add_const('SQL_FD_FETCH_RESUME',0x00000040)
		win_const_mgr.add_const('IDSI_FLAG_SECURE',0x00000002)
		win_const_mgr.add_const('PIDASI_SAMPLE_SIZE',0x00000006)
		win_const_mgr.add_const('SQL_ACCESS_MODE',0x00000065)
		win_const_mgr.add_const('DEBUG_STATUS_REVERSE_GO',0x0000000B)
		win_const_mgr.add_const('OID_WAN_SET_BRIDGE_INFO',0x0401020B)
		win_const_mgr.add_const('PSPROTOCOL_ASCII',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_SQL_ODBC_MINIMUM',0x00000001)
		win_const_mgr.add_const('RPC_C_MQ_AUTHN_LEVEL_NONE',0x00000000)
		win_const_mgr.add_const('MDPROPVAL_MSF_DRILLDOWNMEMBERBOTTOM',0x00002000)
		win_const_mgr.add_const('OID_TAPI_SET_APP_SPECIFIC',0x0703011D)
		win_const_mgr.add_const('ERROR_RESOURCEMANAGER_NOT_FOUND',0x00001A3C)
		win_const_mgr.add_const('D3DSP_OPCODESPECIFICCONTROL_MASK',0x00000000)
		win_const_mgr.add_const('D3DFMT_A8R8G8B8',0x00000015)
		win_const_mgr.add_const('DSQPF_SHOWHIDDENOBJECTS',0x00000004)
		win_const_mgr.add_const('DMPAPER_B_PLUS',0x0000003A)
		win_const_mgr.add_const('SPEAKER_SIDE_LEFT',0x00000200)
		win_const_mgr.add_const('PIDISF_CACHEDSTICKY',0x00000002)
		win_const_mgr.add_const('STI_ONLINESTATE_BUSY',0x00000100)
		win_const_mgr.add_const('WMP_MDRT_FLAGS_UNREPORTED_DELETED_ITEMS',0x00000001)
		win_const_mgr.add_const('ED_VIDEO',0x02000000)
		win_const_mgr.add_const('ASC_RET_ALLOW_NON_USER_LOGONS',0x00200000)
		win_const_mgr.add_const('ERROR_IMPLEMENTATION_LIMIT',0x0000050C)
		win_const_mgr.add_const('ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET',0x00002110)
		win_const_mgr.add_const('CDIS_CHECKED',0x00000008)
		win_const_mgr.add_const('EMR_DELETECOLORSPACE',0x00000065)
		win_const_mgr.add_const('DCBA_FACEDOWNRIGHT',0x00000103)
		win_const_mgr.add_const('SV_TYPE_AFP',0x00000040)
		win_const_mgr.add_const('DDSCAPS2_HINTDYNAMIC',0x00000004)
		win_const_mgr.add_const('CTRY_CHILE',0x00000038)
		win_const_mgr.add_const('MF_HILITE',0x00000080)
		win_const_mgr.add_const('SSF_SHOWSYSFILES',0x00000020)
		win_const_mgr.add_const('WIA_PRIVATE_DEVPROP',0x00009802)
		win_const_mgr.add_const('DDBLT_KEYDESTOVERRIDE',0x00004000)
		win_const_mgr.add_const('ERROR_CLUSTER_INVALID_IPV6_NETWORK',0x00001726)
		win_const_mgr.add_const('ILLUMINANT_F2',0x00000008)
		win_const_mgr.add_const('SERVICE_CONFIG_FAILURE_ACTIONS_FLAG',0x00000004)
		win_const_mgr.add_const('SQL_DROP_SCHEMA',0x0000008C)
		win_const_mgr.add_const('FACILITY_DEBUGGER',0x00000001)
		win_const_mgr.add_const('CBA_DEBUG_INFO',0x10000000)
		win_const_mgr.add_const('INTERNET_STATUS_STATE_CHANGE',0x000000C8)
		win_const_mgr.add_const('IPPORT_IMAP',0x0000008F)
		win_const_mgr.add_const('SWP_NOMOVE',0x00000002)
		win_const_mgr.add_const('NTMSMLI_MAXAPPDESCR',0x00000100)
		win_const_mgr.add_const('ERROR_MUI_INVALID_FILE',0x00003AFD)
		win_const_mgr.add_const('JOYSTICKID1',0x00000000)
		win_const_mgr.add_const('JOYSTICKID2',0x00000001)
		win_const_mgr.add_const('HH_DISPLAY_SEARCH',0x00000003)
		win_const_mgr.add_const('ERROR_DS_IS_LEAF',0x00002033)
		win_const_mgr.add_const('FWPM_NET_EVENT_KEYWORD_INBOUND_MCAST',0x00000001)
		win_const_mgr.add_const('INTERNET_AUTOPROXY_INIT_ONLYQUERY',0x00000008)
		win_const_mgr.add_const('GUI_CARETBLINKING',0x00000001)
		win_const_mgr.add_const('RPC_IF_SEC_NO_CACHE',0x00000040)
		win_const_mgr.add_const('ETW_CHAR_TYPE_VALUE',0x0000000B)
		win_const_mgr.add_const('DISPID_DOM_COLLECTION_MAX',0x002DC6BF)
		win_const_mgr.add_const('TF_IPPMF_FORSYSTEMALL',0x40000000)
		win_const_mgr.add_const('WINHTTP_QUERY_COST',0x0000000F)
		win_const_mgr.add_const('CRYPT_MIN_DEPENDENCIES',0x00000001)
		win_const_mgr.add_const('BN_KILLFOCUS',0x00000007)
		win_const_mgr.add_const('TXTLOG_NEWDEV',0x01000000)
		win_const_mgr.add_const('MAXLONGLONG',0x00000007)
		win_const_mgr.add_const('NMP_PROCESS_MODERATOR',0x00000004)
		win_const_mgr.add_const('WS_CAPTION',0x00C00000)
		win_const_mgr.add_const('CM_PROB_DRIVER_SERVICE_KEY_INVALID',0x00000028)
		win_const_mgr.add_const('MDITILE_HORIZONTAL',0x00000001)
		win_const_mgr.add_const('PORT_NEWS',0x00000090)
		win_const_mgr.add_const('TRUST_AUTH_TYPE_NT4OWF',0x00000001)
		win_const_mgr.add_const('ACMDRIVERDETAILS_FEATURES_CHARS',0x00000200)
		win_const_mgr.add_const('ASPECT_FILTERING',0x00000001)
		win_const_mgr.add_const('SQL_QUOTED_IDENTIFIER_CASE',0x0000005D)
		win_const_mgr.add_const('INDEX_GUID_BASELINE',0x00000009)
		win_const_mgr.add_const('DNS_ERROR_DWORD_VALUE_TOO_LARGE',0x0000255F)
		win_const_mgr.add_const('ICC_USEREX_CLASSES',0x00000200)
		win_const_mgr.add_const('AF_FIREFOX',0x00000013)
		win_const_mgr.add_const('SQL_CVT_NUMERIC',0x00000002)
		win_const_mgr.add_const('VALID_LOGOFF',0x00000001)
		win_const_mgr.add_const('DICS_FLAG_CONFIGGENERAL',0x00000004)
		win_const_mgr.add_const('ERROR_INVALID_BLOCK',0x00000009)
		win_const_mgr.add_const('VK_ICO_HELP',0x000000E3)
		win_const_mgr.add_const('D3D10_FLOAT_TO_SRGB_SCALE_1',0x0000000C)
		win_const_mgr.add_const('FPS_DIALING',0x20000001)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_LOG_MATCHES',0x80000000)
		win_const_mgr.add_const('TMT_SCROLLBARHEIGHT',0x000004B3)
		win_const_mgr.add_const('SVAUD_GOODSESSLOGON',0x00000006)
		win_const_mgr.add_const('ERROR_PATCH_CORRUPT',0xC00E4102)
		win_const_mgr.add_const('VIEW_NEWFOLDER',0x0000000B)
		win_const_mgr.add_const('IPX_STATIC_NETBIOS_NAME_INFO_TYPE',0x0000000A)
		win_const_mgr.add_const('KERB_REQUEST_REMOVE_CREDENTIAL',0x00000004)
		win_const_mgr.add_const('LINE_LINEDEVSTATE',0x00000008)
		win_const_mgr.add_const('SECPKG_ATTR_THUNK_ALL',0x00010000)
		win_const_mgr.add_const('BTH_MFG_PHILIPS_SEMICONDUCTOR',0x00000025)
		win_const_mgr.add_const('SOUND_SYSTEM_FAULT',0x0000000D)
		win_const_mgr.add_const('VCSTATUS_DELETE_IS_MOVE',0x00100000)
		win_const_mgr.add_const('AF_INET',0x00000002)
		win_const_mgr.add_const('AA_F_OPEN',0x00000100)
		win_const_mgr.add_const('TBS_COMMAND_LOCALITY_TWO',0x00000002)
		win_const_mgr.add_const('KAGPROP_ACCESSIBLEPROCEDURES',0x00000002)
		win_const_mgr.add_const('PD_STRETCHDIB_1_1_OK',0x00000004)
		win_const_mgr.add_const('SPI_SETDRAGHEIGHT',0x0000004D)
		win_const_mgr.add_const('SCARD_SHARE_EXCLUSIVE',0x00000001)
		win_const_mgr.add_const('RSVP_PATH_TEAR',0x00000005)
		win_const_mgr.add_const('HHWIN_PARAM_HISTORY_COUNT',0x00000001)
		win_const_mgr.add_const('IME_MODE_KATAKANA',0x00000002)
		win_const_mgr.add_const('IMAGE_FILE_DLL',0x00002000)
		win_const_mgr.add_const('SF_MAX_PASSWORD',0x00000100)
		win_const_mgr.add_const('COPY_FILE_OPEN_SOURCE_FOR_WRITE',0x00000004)
		win_const_mgr.add_const('BF_DIAGONAL',0x00000010)
		win_const_mgr.add_const('WB_MOVEWORDRIGHT',0x00000005)
		win_const_mgr.add_const('CONTEXT_MENU_IMGDYNSRC',0x00000007)
		win_const_mgr.add_const('JT_ROUTING',0x00000003)
		win_const_mgr.add_const('MD_LOGCUSTOM_DATATYPE_ULONG',0x00000003)
		win_const_mgr.add_const('SBSP_PARENT',0x00002000)
		win_const_mgr.add_const('ERROR',0x00000000)
		win_const_mgr.add_const('CM_SETUP_DOWNLOAD',0x00000001)
		win_const_mgr.add_const('NETLOGON_HAS_TIMESERV',0x00000020)
		win_const_mgr.add_const('LSP_REDIRECTOR',0x00000002)
		win_const_mgr.add_const('MCI_DGV_STOP_HOLD',0x00010000)
		win_const_mgr.add_const('FILE_ATTRIBUTE_OFFLINE',0x00001000)
		win_const_mgr.add_const('CRYPT_ENCODE_NO_SIGNATURE_BYTE_REVERSAL_FLAG',0x00000008)
		win_const_mgr.add_const('NM_LAST',0x00000000)
		win_const_mgr.add_const('ACTRL_SYSTEM_ACCESS',0x04000000)
		win_const_mgr.add_const('PDH_LOG_TYPE_BINARY',0x00000003)
		win_const_mgr.add_const('AUTHZ_MIGRATED_LEGACY_PUBLISHER',0x00000002)
		win_const_mgr.add_const('SQL_INTERVAL_MINUTE',0x00000064)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_BLOCKIDOVERRIDE',0x00000010)
		win_const_mgr.add_const('CAL_ICALINTVALUE',0x00000001)
		win_const_mgr.add_const('MAX_COLUMNS',0x00000100)
		win_const_mgr.add_const('ERROR_PATH_NOT_FOUND',0x00000003)
		win_const_mgr.add_const('RPC_CONTEXT_HANDLE_FLAGS',0x30000000)
		win_const_mgr.add_const('SERVICE_GUARANTEED',0x80040000)
		win_const_mgr.add_const('ERROR_DS_CANT_REM_MISSING_ATT',0x00002084)
		win_const_mgr.add_const('PCMCIA_DEF_MEMBEGIN',0x000C0000)
		win_const_mgr.add_const('ERROR_NO_CALLBACK_ACTIVE',0x00000266)
		win_const_mgr.add_const('DXVA_MACROBLOCK_CONTROL_BUFFER',0x00000002)
		win_const_mgr.add_const('ID_BROWSE_CHANGEICON',0x00000001)
		win_const_mgr.add_const('ATA_FLAGS_DATA_OUT',0x00000001)
		win_const_mgr.add_const('WIA_SELECT_DEVICE_NODEFAULT',0x00000001)
		win_const_mgr.add_const('IF_TYPE_RFC1483',0x0000009F)
		win_const_mgr.add_const('CDS_RESET',0x40000000)
		win_const_mgr.add_const('FWP_FILTER_ENUM_FLAG_INCLUDE_BOOTTIME',0x00000008)
		win_const_mgr.add_const('SQL_MAX_INDEX_SIZE',0x00000066)
		win_const_mgr.add_const('ACM_DRIVERPRIORITYF_ABLEMASK',0x00000003)
		win_const_mgr.add_const('RC_PALETTE',0x00000100)
		win_const_mgr.add_const('CFU_UNDERLINE',0x00000001)
		win_const_mgr.add_const('MQMSG_AUTHENTICATION_NOT_REQUESTED',0x00000000)
		win_const_mgr.add_const('CM_QUERY_ARBITRATOR_BITS',0x00000001)
		win_const_mgr.add_const('NETSETUP_ACCT_CREATE',0x00000002)
		win_const_mgr.add_const('SECPKG_FLAG_ACCEPT_WIN32_NAME',0x00000200)
		win_const_mgr.add_const('ICEE_CREATE_MACHINE_AMD64',0x00000400)
		win_const_mgr.add_const('WMSZ_BOTTOMRIGHT',0x00000008)
		win_const_mgr.add_const('NET_DFS_SETDC_INITPKT',0x00000002)
		win_const_mgr.add_const('MQSEC_SET_QUEUE_PROPERTIES',0x00000010)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYSTRETCHY',0x02000000)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYSTRETCHX',0x00800000)
		win_const_mgr.add_const('UNRECOVERED_READS_VALID',0x00000008)
		win_const_mgr.add_const('SPWPT_SELECTDEVICE',0x00000001)
		win_const_mgr.add_const('HTTP_STATUS_PAYMENT_REQ',0x00000192)
		win_const_mgr.add_const('INTERNET_IDENTITY_FLAG_CLEAR_DATA',0x00000004)
		win_const_mgr.add_const('INTERNET_STATE_DISCONNECTED_BY_USER',0x00000010)
		win_const_mgr.add_const('HTTP_LOG_FIELD_CLIENT_PORT',0x00400000)
		win_const_mgr.add_const('AE_LIM_DISABLED',0x00000004)
		win_const_mgr.add_const('D3DPMISCCAPS_CULLCW',0x00000020)
		win_const_mgr.add_const('VK_OEM_102',0x000000E2)
		win_const_mgr.add_const('FAX_JOB_SUBMIT',0x00000001)
		win_const_mgr.add_const('WTS_EVENT_DISCONNECT',0x00000010)
		win_const_mgr.add_const('MCI_DEVTYPE_SCANNER',0x00000206)
		win_const_mgr.add_const('SUBLANG_KICHE_GUATEMALA',0x00000001)
		win_const_mgr.add_const('NCRYPTBUFFER_SSL_SERVER_RANDOM',0x00000015)
		win_const_mgr.add_const('PID_INTSITE_CONTENTCODE',0x0000000B)
		win_const_mgr.add_const('SM_CYFULLSCREEN',0x00000011)
		win_const_mgr.add_const('VK_DBE_HIRAGANA',0x00000000)
		win_const_mgr.add_const('WIA_DPS_MIN_VERTICAL_SHEET_FEED_SIZE',0x00000C21)
		win_const_mgr.add_const('ERROR_CLUSTER_DATABASE_SEQMISMATCH',0x000013DB)
		win_const_mgr.add_const('SNMPAPI_TL_UNDELIVERABLE',0x00000068)
		win_const_mgr.add_const('ASC_RET_REPLAY_DETECT',0x00000004)
		win_const_mgr.add_const('SQL_RESTRICT',0x00000001)
		win_const_mgr.add_const('PORT_DLSMON',0x000000C6)
		win_const_mgr.add_const('ERRACT_DLYRET',0x00000002)
		win_const_mgr.add_const('NMP_PROCESS_CONTROL',0x00000002)
		win_const_mgr.add_const('PHONELAMPMODE_BROKENFLUTTER',0x00000040)
		win_const_mgr.add_const('GLEX_ACCEPT',0x00000001)
		win_const_mgr.add_const('STI_GENCAP_AUTO_PORTSELECT',0x00000008)
		win_const_mgr.add_const('FWPM_FILTER_FLAG_CLEAR_ACTION_RIGHT',0x00000008)
		win_const_mgr.add_const('IP_MISS_STNS_SHIFT',0x00000004)
		win_const_mgr.add_const('TMT_TEXTSHADOWCOLOR',0x00000EEA)
		win_const_mgr.add_const('MFE_PROHIBITED',0x0000000C)
		win_const_mgr.add_const('DEBUG_GET_PROC_FULL_MATCH',0x00000001)
		win_const_mgr.add_const('SPI_GETDRAGFULLWINDOWS',0x00000026)
		win_const_mgr.add_const('SEF_SACL_AUTO_INHERIT',0x00000002)
		win_const_mgr.add_const('EVENT_SYSTEM_DRAGDROPSTART',0x0000000E)
		win_const_mgr.add_const('SQL_TIMEDATE_ADD_INTERVALS',0x0000006D)
		win_const_mgr.add_const('ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE',0x00001784)
		win_const_mgr.add_const('DDBLT_KEYSRCOVERRIDE',0x00010000)
		win_const_mgr.add_const('DPROMPT_BUFFERTOOSMALL',0x00000003)
		win_const_mgr.add_const('ALG_SID_SKIPJACK',0x0000000A)
		win_const_mgr.add_const('WINHELP_INDEX',0x00000010)
		win_const_mgr.add_const('GDICOMMENT_WINDOWS_METAFILE',0x80000001)
		win_const_mgr.add_const('EVLEN',0x00000010)
		win_const_mgr.add_const('DEBUG_GETMOD_NO_LOADED_MODULES',0x00000001)
		win_const_mgr.add_const('COOKIE_DONT_ALLOW_ALL',0x00000008)
		win_const_mgr.add_const('DRVCNF_CANCEL',0x00000000)
		win_const_mgr.add_const('MD_ERROR_SUB404_URL_SEQUENCE_DENIED',0x00000005)
		win_const_mgr.add_const('AUDCLNT_STREAMFLAGS_CROSSPROCESS',0x00010000)
		win_const_mgr.add_const('DBPROPVAL_ORS_STOREDPROC',0x00000004)
		win_const_mgr.add_const('NUMPRS_CURRENCY',0x00000400)
		win_const_mgr.add_const('IMAGE_SCN_CNT_UNINITIALIZED_DATA',0x00000080)
		win_const_mgr.add_const('ILC_MASK',0x00000001)
		win_const_mgr.add_const('IDTR_PPN',0x00000038)
		win_const_mgr.add_const('SQL_ISV_ASSERTIONS',0x00000001)
		win_const_mgr.add_const('DISPID_SEARCHCOMMAND_UPDATE',0x00000004)
		win_const_mgr.add_const('SORT_INVARIANT_MATH',0x00000001)
		win_const_mgr.add_const('PDH_RETRY',0x800007D4)
		win_const_mgr.add_const('DEBUG_GETFNENT_RAW_ENTRY_ONLY',0x00000001)
		win_const_mgr.add_const('ERROR_DBG_COMMAND_EXCEPTION',0x000002B9)
		win_const_mgr.add_const('DXGI_FORMAT_DEFINED',0x00000001)
		win_const_mgr.add_const('IDM_BORDERCOLOR',0x00000035)
		win_const_mgr.add_const('SWP_NOSIZE',0x00000001)
		win_const_mgr.add_const('LINEAGENTSTATUS_CAPSCHANGE',0x00000040)
		win_const_mgr.add_const('SNMP_OUTPUT_TO_EVENTLOG',0x00000004)
		win_const_mgr.add_const('TAPE_DRIVE_GET_LOGICAL_BLK',0x00200000)
		win_const_mgr.add_const('SNMPAPI_NO_SUPPORT',0x00000000)
		win_const_mgr.add_const('LINEMEDIAMODE_UNKNOWN',0x00000002)
		win_const_mgr.add_const('MCI_VD_FORMAT_TRACK',0x00004001)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_LOGGING_USERS',0x0000022F)
		win_const_mgr.add_const('PERF_DELTA_COUNTER',0x00400000)
		win_const_mgr.add_const('LOW_SURROGATE_START',0x00000000)
		win_const_mgr.add_const('OPTION_STATIC_ROUTES',0x00000021)
		win_const_mgr.add_const('OLECMDARGINDEX_SHOWPAGEACTIONMENU_HWND',0x00000000)
		win_const_mgr.add_const('EVENT_HEADER_FLAG_PRIVATE_SESSION',0x00000002)
		win_const_mgr.add_const('FLASHMODE_EXTERNALSYNC',0x00000006)
		win_const_mgr.add_const('DM_DUPLEX',0x00001000)
		win_const_mgr.add_const('WSAENOMORE',0x00002776)
		win_const_mgr.add_const('IMGLOAD_COMPLETE',0x01000000)
		win_const_mgr.add_const('PERF_SIZE_DWORD',0x00000000)
		win_const_mgr.add_const('MQSEC_DELETE_JOURNAL_MESSAGE',0x00000008)
		win_const_mgr.add_const('DOT11_STATUS_AUTH_VERIFIED',0x00010000)
		win_const_mgr.add_const('ASC_REQ_CALL_LEVEL',0x00001000)
		win_const_mgr.add_const('ERROR_PROFILING_NOT_STARTED',0x00000226)
		win_const_mgr.add_const('IPPORT_REGISTERED_MAX',0x00000000)
		win_const_mgr.add_const('SND_NOWAIT',0x00002000)
		win_const_mgr.add_const('IME_THOTKEY_SYMBOL_TOGGLE',0x00000072)
		win_const_mgr.add_const('IDM_CLEARAUTHENTICATIONCACHE',0x00003A9B)
		win_const_mgr.add_const('WIA_FILM_COLOR_SLIDE',0x00000000)
		win_const_mgr.add_const('ERROR_DS_DRA_SINK_DISABLED',0x00002109)
		win_const_mgr.add_const('TIME_ZONE_ID_DAYLIGHT',0x00000002)
		win_const_mgr.add_const('FILTER_WORKSTATION_TRUST_ACCOUNT',0x00000010)
		win_const_mgr.add_const('INTERNET_OPTION_ASYNC',0x0000001E)
		win_const_mgr.add_const('SUBLANG_SPANISH_URUGUAY',0x00000000)
		win_const_mgr.add_const('PAN_STROKE_RAPID_HORZ',0x00000007)
		win_const_mgr.add_const('CB_GETTOPINDEX',0x00000015)
		win_const_mgr.add_const('LINEPROXYREQUEST_SETQUEUEMEASUREMENTPERIOD',0x00000011)
		win_const_mgr.add_const('TMT_GRADIENTRATIO5',0x0000096A)
		win_const_mgr.add_const('DEBUG_SESSION_END',0x00000004)
		win_const_mgr.add_const('WSAECANCELLED',0x00002777)
		win_const_mgr.add_const('TASK_MAY',0x00000010)
		win_const_mgr.add_const('TMT_GRADIENTRATIO4',0x00000969)
		win_const_mgr.add_const('CE_MODE',0x00008000)
		win_const_mgr.add_const('ERROR_NONPAGED_SYSTEM_RESOURCES',0x000005AB)
		win_const_mgr.add_const('DRM_SERVICE_TYPE_CLIENTLICENSOR',0x00000008)
		win_const_mgr.add_const('KF_FLAG_DONT_UNEXPAND',0x00002000)
		win_const_mgr.add_const('IMAGE_REL_I386_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('SQL_DESC_ALLOC_TYPE',0x0000044B)
		win_const_mgr.add_const('COLOR_BLUE',0x000002C4)
		win_const_mgr.add_const('ERROR_EVT_FILTER_OUT_OF_RANGE',0x00003ABE)
		win_const_mgr.add_const('ERROR_SPECIAL_GROUP',0x0000055C)
		win_const_mgr.add_const('VALIDATEUNC_CONNECT',0x00000001)
		win_const_mgr.add_const('DEVICEPOWER_FILTER_WAKEENABLED',0x08000000)
		win_const_mgr.add_const('TIMECOLLECTION_OFFSET',0x00000600)
		win_const_mgr.add_const('LVS_EDITLABELS',0x00000200)
		win_const_mgr.add_const('ERROR_INVALID_PORT_ATTRIBUTES',0x00000221)
		win_const_mgr.add_const('ERROR_DS_INCOMPATIBLE_CONTROLS_USED',0x0000217E)
		win_const_mgr.add_const('CDRF_SKIPPOSTPAINT',0x00000100)
		win_const_mgr.add_const('EAP_I_EAPHOST_LAST',0x804200FF)
		win_const_mgr.add_const('SE_GROUP_USE_FOR_DENY_ONLY',0x00000010)
		win_const_mgr.add_const('CMSG_ATTR_CERT_COUNT_PARAM',0x0000001F)
		win_const_mgr.add_const('SE_GROUP_DEFAULTED',0x00000002)
		win_const_mgr.add_const('XP1_UNI_RECV',0x00010000)
		win_const_mgr.add_const('OBJ_METADC',0x00000004)
		win_const_mgr.add_const('RPC_C_IMP_LEVEL_IDENTIFY',0x00000002)
		win_const_mgr.add_const('IF_TYPE_HDH_1822',0x00000003)
		win_const_mgr.add_const('NRC_NAMTFUL',0x00000000)
		win_const_mgr.add_const('ICDECOMPRESS_HURRYUP',0x80000000)
		win_const_mgr.add_const('ST_NEWCHARS',0x00000004)
		win_const_mgr.add_const('MUTZ_DONT_UNESCAPE',0x00000800)
		win_const_mgr.add_const('VCSTATUS_MOVE',0x00040000)
		win_const_mgr.add_const('OID_GEN_VENDOR_DESCRIPTION',0x0001010D)
		win_const_mgr.add_const('WM_DEVMODECHANGE',0x0000001B)
		win_const_mgr.add_const('MAX_RECORDS_IN_FOREST_TRUST_INFO',0x00000FA0)
		win_const_mgr.add_const('SM_CXVIRTUALSCREEN',0x0000004E)
		win_const_mgr.add_const('CS_NOCLOSE',0x00000200)
		win_const_mgr.add_const('CF_PRIVATELAST',0x000002FF)
		win_const_mgr.add_const('CERT_COMPARE_ENHKEY_USAGE',0x0000000A)
		win_const_mgr.add_const('META_CREATEREGION',0x000006FF)
		win_const_mgr.add_const('CTLCOLOR_BTN',0x00000003)
		win_const_mgr.add_const('ACM_METRIC_COUNT_LOCAL_DRIVERS',0x00000014)
		win_const_mgr.add_const('DISPID_DOCUMENTCOMPLETE',0x00000103)
		win_const_mgr.add_const('IDM_ROWSELECT',0x0000089F)
		win_const_mgr.add_const('TTFCFP_LANG_KEEP_ALL',0x00000000)
		win_const_mgr.add_const('USE_SESSLOST',0x00000002)
		win_const_mgr.add_const('ILR_SCALE_CLIP',0x00000000)
		win_const_mgr.add_const('TASK_JANUARY',0x00000001)
		win_const_mgr.add_const('PDH_INVALID_ARGUMENT',0xC0000BBD)
		win_const_mgr.add_const('FCSM_LOGO',0x00000020)
		win_const_mgr.add_const('OID_CO_TAPI_LINE_CAPS',0xFE001002)
		win_const_mgr.add_const('CM_REENUMERATE_RETRY_INSTALLATION',0x00000002)
		win_const_mgr.add_const('DNS_STATUS_DOTTED_NAME',0x00002556)
		win_const_mgr.add_const('DEBUG_EXECUTE_NOT_LOGGED',0x00000002)
		win_const_mgr.add_const('ERROR_DS_CANT_RETRIEVE_CHILD',0x000020E6)
		win_const_mgr.add_const('DNS_TYPE_DNAME',0x00000027)
		win_const_mgr.add_const('RPC_S_INVALID_BOUND',0x000006C6)
		win_const_mgr.add_const('PORT_TACNEWS',0x00000062)
		win_const_mgr.add_const('ERROR_DS_OUT_OF_SCOPE',0x00002092)
		win_const_mgr.add_const('KSFILTER_FLAG_DISPATCH_LEVEL_PROCESSING',0x00000001)
		win_const_mgr.add_const('SV_TYPE_XENIX_SERVER',0x00000800)
		win_const_mgr.add_const('RRF_RT_REG_EXPAND_SZ',0x00000004)
		win_const_mgr.add_const('MAX_SEARCH_FORMAT_STRING',0x000000FF)
		win_const_mgr.add_const('CERT_DSS_S_LEN',0x00000014)
		win_const_mgr.add_const('HS_HORIZONTAL',0x00000000)
		win_const_mgr.add_const('OID_FDDI_IF_OUT_OCTETS',0x03030287)
		win_const_mgr.add_const('EAP_FLAG_LOGON',0x00000004)
		win_const_mgr.add_const('ODS_NOFOCUSRECT',0x00000200)
		win_const_mgr.add_const('ASYNC_RECO_SETGUIDE_FAILED',0x00000020)
		win_const_mgr.add_const('FIND_SIZE',0x00003000)
		win_const_mgr.add_const('SPI_GETICONMETRICS',0x0000002D)
		win_const_mgr.add_const('CERT_CHAIN_FIND_BY_ISSUER_COMPLEX_CHAIN_FLAG',0x00000002)
		win_const_mgr.add_const('CAL_HEBREW',0x00000008)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_SERVER',0x00000002)
		win_const_mgr.add_const('ERROR_CLASS_DOES_NOT_EXIST',0x00000583)
		win_const_mgr.add_const('ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT',0x0000219E)
		win_const_mgr.add_const('IF_TYPE_LOCALTALK',0x0000002A)
		win_const_mgr.add_const('OID_GEN_CO_MINIMUM_LINK_SPEED',0x00020120)
		win_const_mgr.add_const('DATABITS_5',0x00000001)
		win_const_mgr.add_const('FLG_ADDREG_32BITKEY',0x00004000)
		win_const_mgr.add_const('DDOVER_ALPHASRC',0x00000020)
		win_const_mgr.add_const('FPS_NOT_FAX_CALL',0x20001000)
		win_const_mgr.add_const('KP_PUB_EX_VAL',0x0000001D)
		win_const_mgr.add_const('MDPROPVAL_MSF_BOTTOMPERCENT',0x00000002)
		win_const_mgr.add_const('RUNTIME_FUNCTION_INDIRECT',0x00000001)
		win_const_mgr.add_const('TECHNOLOGY',0x00000002)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2ERASE_CLIENTNAME',0x00000103)
		win_const_mgr.add_const('NUMPRS_EXPONENT',0x00000800)
		win_const_mgr.add_const('HTTOP',0x0000000C)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_CAN_STRETCH',0x00004001)
		win_const_mgr.add_const('HH_SET_WIN_TYPE',0x00000004)
		win_const_mgr.add_const('IDM_LIVERESIZE',0x0000095E)
		win_const_mgr.add_const('DBPROPVAL_IT_CONTENT',0x00000003)
		win_const_mgr.add_const('SSRVOPT_CALLBACKW',0x00010000)
		win_const_mgr.add_const('CRYPTUI_ENABLE_ADDTOSTORE',0x00000020)
		win_const_mgr.add_const('PORT_LOCUSMAP',0x0000007D)
		win_const_mgr.add_const('CMS_USEDESCRIPTION',0x00000200)
		win_const_mgr.add_const('D3DSHADER_INSTRUCTION_PREDICATED',0x00000001)
		win_const_mgr.add_const('PORT_ANYFILESYS',0x0000003B)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_IRIS',0x00000014)
		win_const_mgr.add_const('DIRID_SHARED',0x00000019)
		win_const_mgr.add_const('SQL_API_SQLALLOCSTMT',0x00000003)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_CROSSADDRCONF',0x00000001)
		win_const_mgr.add_const('CAUSE_LOC_TRANSIT_NETWORK',0x00000003)
		win_const_mgr.add_const('SNMP_MGMTAPI_AGAIN',0x0000002D)
		win_const_mgr.add_const('PORT_X400SND',0x00000068)
		win_const_mgr.add_const('CAPTUREMODE_NORMAL',0x00000001)
		win_const_mgr.add_const('ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE',0x00003AE8)
		win_const_mgr.add_const('APPCOMMAND_BASS_UP',0x00000015)
		win_const_mgr.add_const('SHCNE_DRIVEADDGUI',0x00010000)
		win_const_mgr.add_const('PSWIZB_SHOW',0x00000000)
		win_const_mgr.add_const('MCI_SPIN',0x0000080C)
		win_const_mgr.add_const('DC_EMF_COMPLIANT',0x00000014)
		win_const_mgr.add_const('CT_CTYPE2',0x00000002)
		win_const_mgr.add_const('ERROR_BAD_INHERITANCE_ACL',0x0000053C)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_REPLICATOR',0x00000228)
		win_const_mgr.add_const('HHWIN_PARAM_SHOWSTATE',0x00000001)
		win_const_mgr.add_const('D3DDTCAPS_USHORT2N',0x00000010)
		win_const_mgr.add_const('IMAGE_FILE_NET_RUN_FROM_SWAP',0x00000800)
		win_const_mgr.add_const('CRYPT_MACHINE_KEYSET',0x00000020)
		win_const_mgr.add_const('D3DPBLENDCAPS_INVDESTALPHA',0x00000080)
		win_const_mgr.add_const('RASCS_DONE',0x00002000)
		win_const_mgr.add_const('IR_UNDETERMINE',0x00000170)
		win_const_mgr.add_const('JOB_OBJECT_MSG_EXIT_PROCESS',0x00000007)
		win_const_mgr.add_const('ERROR_NO_USER_SESSION_KEY',0x00000572)
		win_const_mgr.add_const('DDSCL_FPUSETUP',0x00000800)
		win_const_mgr.add_const('MODALS_LOCKOUT_OBSERVATION_WINDOW_PARMNUM',0x0000000B)
		win_const_mgr.add_const('DCX_INTERSECTUPDATE',0x00000200)
		win_const_mgr.add_const('URLACTION_FEATURE_MIN',0x00002100)
		win_const_mgr.add_const('BTNS_SHOWTEXT',0x00000040)
		win_const_mgr.add_const('ET_DEVICENAME',0x00000001)
		win_const_mgr.add_const('PI_RESTRICTED',0x00000040)
		win_const_mgr.add_const('HDI_WIDTH',0x00000001)
		win_const_mgr.add_const('SUBLANG_CHINESE_MACAU',0x00000005)
		win_const_mgr.add_const('MFBYTESTREAM_IS_READABLE',0x00000001)
		win_const_mgr.add_const('SV_MAXKEEPSEARCH_PARMNUM',0x0000020B)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_WHEEL',0x0000001F)
		win_const_mgr.add_const('WB_ISDELIMITER',0x00000002)
		win_const_mgr.add_const('PGS_AUTOSCROLL',0x00000002)
		win_const_mgr.add_const('INTERNET_STATUS_NAME_RESOLVED',0x0000000B)
		win_const_mgr.add_const('WIA_PAGE_DIN_2B',0x00000034)
		win_const_mgr.add_const('INTERNET_FLAG_IDN_PROXY',0x00000002)
		win_const_mgr.add_const('IEIFLAG_ASYNC',0x00000001)
		win_const_mgr.add_const('DEREGISTERED',0x00000005)
		win_const_mgr.add_const('ERROR_ILL_FORMED_PASSWORD',0x0000052C)
		win_const_mgr.add_const('CERT_AIA_URL_RETRIEVED_PROP_ID',0x00000043)
		win_const_mgr.add_const('WIA_DPC_THUMB_HEIGHT',0x00000813)
		win_const_mgr.add_const('URLACTION_SCRIPT_MIN',0x00001400)
		win_const_mgr.add_const('IMFT_SUBMENU',0x00000004)
		win_const_mgr.add_const('ERROR_RESOURCE_NOT_AVAILABLE',0x0000138E)
		win_const_mgr.add_const('DISPID_RESETSAFEMODE',0x00000002)
		win_const_mgr.add_const('WAVE_FORMAT_DEVELOPMENT',0x0000FFFF)
		win_const_mgr.add_const('SUBLANG_SAMI_LULE_SWEDEN',0x00000005)
		win_const_mgr.add_const('CM_DEVCAP_REMOVABLE',0x00000004)
		win_const_mgr.add_const('DMPAPER_A3_TRANSVERSE',0x00000043)
		win_const_mgr.add_const('DBPROPVAL_PERSIST_ADTG',0x00000000)
		win_const_mgr.add_const('MAPI_E_MESSAGE_IN_USE',0x00000016)
		win_const_mgr.add_const('TVS_FULLROWSELECT',0x00001000)
		win_const_mgr.add_const('IP_OPT_ROUTER_ALERT',0x00000094)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_SYSTEMRESTORE',0x00000001)
		win_const_mgr.add_const('IDTB_CONTRACT',0x000000C9)
		win_const_mgr.add_const('FWPM_CONTEXT_IPSEC_OUTBOUND_NEGOTIATE_DISCOVER',0x00000001)
		win_const_mgr.add_const('SQL_CA_CONSTRAINT_INITIALLY_DEFERRED',0x00000010)
		win_const_mgr.add_const('IMGDECODE_EVENT_BITSCOMPLETE',0x00000008)
		win_const_mgr.add_const('SQL_API_SQLFREECONNECT',0x0000000E)
		win_const_mgr.add_const('DRM_EL_REVOCATIONLIST_LID',0x00000800)
		win_const_mgr.add_const('LINEDEVSTATUSFLAGS_CONNECTED',0x00000001)
		win_const_mgr.add_const('OID_FDDI_MAC_COPIED_CT',0x0303023C)
		win_const_mgr.add_const('D3DDEVCAPS_TLVERTEXVIDEOMEMORY',0x00000080)
		win_const_mgr.add_const('WLX_SAS_ACTION_SHUTDOWN_SLEEP',0x0000000C)
		win_const_mgr.add_const('PORT_TFTP',0x00000045)
		win_const_mgr.add_const('ERROR_DESTROY_OBJECT_OF_OTHER_THREAD',0x0000059B)
		win_const_mgr.add_const('SQL_SEARCHABLE',0x00000003)
		win_const_mgr.add_const('MUTZ_ACCEPT_WILDCARD_SCHEME',0x00000080)
		win_const_mgr.add_const('CMSG_CMS_ENCAPSULATED_CTL_FLAG',0x00008000)
		win_const_mgr.add_const('OID_FDDI_PATH_SBA_AVAILABLE',0x03030258)
		win_const_mgr.add_const('NORMAL_CACHE_ENTRY',0x00000001)
		win_const_mgr.add_const('IDM_HWND',0x00000002)
		win_const_mgr.add_const('DUMP_DRIVER_NAME_LENGTH',0x0000000F)
		win_const_mgr.add_const('GAA_FLAG_INCLUDE_ALL_COMPARTMENTS',0x00000200)
		win_const_mgr.add_const('BG_E_INVALID_AUTH_TARGET',0x80200027)
		win_const_mgr.add_const('PERCEIVEDFLAG_HARDCODED',0x00000002)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME12',0x00000002)
		win_const_mgr.add_const('URLPOLICY_ACTIVEX_CHECK_LIST',0x00010000)
		win_const_mgr.add_const('SQL_CDO_CREATE_DOMAIN',0x00000001)
		win_const_mgr.add_const('SUBLANG_NEUTRAL',0x00000000)
		win_const_mgr.add_const('MEM_8K',0x00002000)
		win_const_mgr.add_const('COLOR_RED',0x000002C2)
		win_const_mgr.add_const('MCI_ANIM_STEP_FRAMES',0x00020000)
		win_const_mgr.add_const('SHIL_SMALL',0x00000001)
		win_const_mgr.add_const('ERROR_CTX_SECURITY_LAYER_ERROR',0x00001B9C)
		win_const_mgr.add_const('DMMEDIA_USER',0x00000100)
		win_const_mgr.add_const('CERT_RDN_TELETEX_STRING',0x00000005)
		win_const_mgr.add_const('FS_DISCONNECTED',0x20000400)
		win_const_mgr.add_const('OID_CO_ADD_PVC',0xFE000001)
		win_const_mgr.add_const('SPI_GETDEFAULTINPUTLANG',0x00000059)
		win_const_mgr.add_const('LINEDEVSTATE_CAPSCHANGE',0x00100000)
		win_const_mgr.add_const('TRANSPORT_TYPE_WMSG',0x00000008)
		win_const_mgr.add_const('PROTO_IP_BOOTP',0x0000270F)
		win_const_mgr.add_const('MSV1_0_OWF_PASSWORD_LENGTH',0x00000010)
		win_const_mgr.add_const('LOCALE_SPOSINFINITY',0x00000006)
		win_const_mgr.add_const('JIFMK_JPG',0x0000FFC8)
		win_const_mgr.add_const('DS_REPSYNCALL_ID_SERVERS_BY_DN',0x00000004)
		win_const_mgr.add_const('PIDSI_SUBJECT',0x00000003)
		win_const_mgr.add_const('CSF_EXPLORER',0x00000008)
		win_const_mgr.add_const('SQL_CHAR',0x00000001)
		win_const_mgr.add_const('SQL_MODE_READ_ONLY',0x00000001)
		win_const_mgr.add_const('WSA_QOS_ESDMODEOBJ',0x00002B15)
		win_const_mgr.add_const('F_NOPARENT',0x0000000A)
		win_const_mgr.add_const('IDM_COMMENT',0x0000087D)
		win_const_mgr.add_const('LINECALLPARTYID_ADDRESS',0x00000008)
		win_const_mgr.add_const('SECURITY_FLAG_IETFSSL4',0x00000020)
		win_const_mgr.add_const('CC_NONE',0x00000000)
		win_const_mgr.add_const('KTM_MARSHAL_BLOB_VERSION_MAJOR',0x00000001)
		win_const_mgr.add_const('PERF_NUMBER_HEX',0x00000000)
		win_const_mgr.add_const('TIMEDMPLAYEROBJECT_OFFSET',0x00001100)
		win_const_mgr.add_const('DM_ORIENTATION',0x00000001)
		win_const_mgr.add_const('DMDITHER_FINE',0x00000003)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_MM_COW',0x0000000C)
		win_const_mgr.add_const('ERROR_PAGEFILE_CREATE_FAILED',0x00000240)
		win_const_mgr.add_const('SIF_PAGE',0x00000002)
		win_const_mgr.add_const('SIZE_MAXIMIZED',0x00000002)
		win_const_mgr.add_const('CBN_SELCHANGE',0x00000001)
		win_const_mgr.add_const('AM_AC3_SERVICE_DIALOG_ONLY',0x00000004)
		win_const_mgr.add_const('MFCLOCK_JITTER_DPC',0x00000FA0)
		win_const_mgr.add_const('TXTLOG_SETUPAPI_BITS',0x00000003)
		win_const_mgr.add_const('DISPID_COLUMNSCHANGED',0x000000D4)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_REFQ2',0x00000014)
		win_const_mgr.add_const('CLASSFACTORY_E_LAST',0x8004011F)
		win_const_mgr.add_const('CERT_DISPWELL_TRUST_LEAF_CERT',0x00000003)
		win_const_mgr.add_const('DSBS_ROOT',0x00000004)
		win_const_mgr.add_const('SPI_SETSCREENSAVEACTIVE',0x00000011)
		win_const_mgr.add_const('DISPID_CLIENTTOHOSTWINDOW',0x0000010C)
		win_const_mgr.add_const('NLS_DBCSCHAR',0x00010000)
		win_const_mgr.add_const('MCI_VCR_STATUS_ASSEMBLE_RECORD',0x0000401D)
		win_const_mgr.add_const('ERROR_NO_RECOVERY_PROGRAM',0x0000043A)
		win_const_mgr.add_const('MIXER_GETLINEINFOF_SOURCE',0x00000001)
		win_const_mgr.add_const('ILDI_PURGE',0x00000001)
		win_const_mgr.add_const('WTS_WSD_POWEROFF',0x00000008)
		win_const_mgr.add_const('DISPID_TVFLAGS',0x00000014)
		win_const_mgr.add_const('MC_CAPS_RED_GREEN_BLUE_DRIVE',0x00000020)
		win_const_mgr.add_const('PFM_BORDER',0x00000800)
		win_const_mgr.add_const('IDC_VP_RESULTIMAGE',0x00000409)
		win_const_mgr.add_const('LDAP_VERSION_MIN',0x00000002)
		win_const_mgr.add_const('SQL_AD_ON',0x00000001)
		win_const_mgr.add_const('ERROR_DS_ADMIN_LIMIT_EXCEEDED',0x00002024)
		win_const_mgr.add_const('ERROR_FATAL_APP_EXIT',0x000002C9)
		win_const_mgr.add_const('ASYNC_RECO_ADDSTROKE_FAILED',0x00000004)
		win_const_mgr.add_const('DBIMF_DEBOSSED',0x00000020)
		win_const_mgr.add_const('SECURITY_MANDATORY_LOW_RID',0x00001000)
		win_const_mgr.add_const('LUP_RES_SERVICE',0x00008000)
		win_const_mgr.add_const('SSGF_DISPLAY',0x00000003)
		win_const_mgr.add_const('GD_CURSORCOMPONENT',0x00000001)
		win_const_mgr.add_const('MEM_WRITE_WATCH',0x00200000)
		win_const_mgr.add_const('VK_MBUTTON',0x00000004)
		win_const_mgr.add_const('BTH_ERROR_MEMORY_FULL',0x00000007)
		win_const_mgr.add_const('PROFILE_SERVER',0x40000000)
		win_const_mgr.add_const('ETW_NON_NULL_TERMINATED_STRING_TYPE_VALUE',0x00000070)
		win_const_mgr.add_const('RECOFLAG_DISABLEPERSONALIZATION',0x00000020)
		win_const_mgr.add_const('EV_TXEMPTY',0x00000004)
		win_const_mgr.add_const('CERT_INFO_ISSUER_FLAG',0x00000004)
		win_const_mgr.add_const('ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION',0x00001AAF)
		win_const_mgr.add_const('RPC_C_AUTHN_LEVEL_DEFAULT',0x00000000)
		win_const_mgr.add_const('UDS_SETBUDDYINT',0x00000002)
		win_const_mgr.add_const('LVS_EX_CHECKBOXES',0x00000004)
		win_const_mgr.add_const('WIA_DATA_THRESHOLD',0x00000000)
		win_const_mgr.add_const('IP_HOPLIMIT',0x00000015)
		win_const_mgr.add_const('PHOTO_ORIENTATION_ROTATE270',0x00000006)
		win_const_mgr.add_const('NETE_SSLSEC',0x00000012)
		win_const_mgr.add_const('IN6ADDR_LINKLOCALPREFIX_LENGTH',0x00000040)
		win_const_mgr.add_const('MCI_INFO_VERSION',0x00000400)
		win_const_mgr.add_const('MCI_DGV_SET_SPEED',0x00020000)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MINFPOINT',0x00000100)
		win_const_mgr.add_const('SUBLANG_AFRIKAANS_SOUTH_AFRICA',0x00000001)
		win_const_mgr.add_const('WIA_IPS_MIRROR',0x0000180E)
		win_const_mgr.add_const('FROM_LEFT_3RD_BUTTON_PRESSED',0x00000008)
		win_const_mgr.add_const('ETW_ASCIISTRING_TYPE_VALUE',0x00000067)
		win_const_mgr.add_const('SELCERT_FINEPRINT',0x00000065)
		win_const_mgr.add_const('SUBLANG_FILIPINO_PHILIPPINES',0x00000001)
		win_const_mgr.add_const('ERROR_SWAPERROR',0x000003E7)
		win_const_mgr.add_const('CF_DIB',0x00000008)
		win_const_mgr.add_const('SECPKG_ATTR_APP_DATA',0x00000005)
		win_const_mgr.add_const('RBNM_STYLE',0x00000002)
		win_const_mgr.add_const('WM_GETTEXT',0x0000000D)
		win_const_mgr.add_const('SQL_DROP_ASSERTION',0x00000088)
		win_const_mgr.add_const('DNS_ERROR_RECORD_ALREADY_EXISTS',0x000025EF)
		win_const_mgr.add_const('ERROR_DS_NAME_UNPARSEABLE',0x0000209E)
		win_const_mgr.add_const('TF_CONVERSIONMODE_NOCONVERSION',0x00000100)
		win_const_mgr.add_const('SO_DEREGISTER_NAME',0x0000A001)
		win_const_mgr.add_const('QOS_NON_ADAPTIVE_FLOW',0x00000002)
		win_const_mgr.add_const('TCS_BUTTONS',0x00000100)
		win_const_mgr.add_const('WMDM_E_BUSY',0x80045000)
		win_const_mgr.add_const('ACCESS_FAIL_OPEN',0x00000100)
		win_const_mgr.add_const('ENM_SELCHANGE',0x00080000)
		win_const_mgr.add_const('AE_UNSHARE',0x00000002)
		win_const_mgr.add_const('DDD_REMOVE_DEFINITION',0x00000002)
		win_const_mgr.add_const('UI_CAP_ROT90',0x00000002)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_DESKTOP',0x00000040)
		win_const_mgr.add_const('CAUSE_USER_REJECTS_CLIR',0x00000017)
		win_const_mgr.add_const('SM_CARETBLINKINGENABLED',0x00002002)
		win_const_mgr.add_const('SUBLANG_UZBEK_LATIN',0x00000001)
		win_const_mgr.add_const('BLLI_L3_IPI_SNAP',0x00000080)
		win_const_mgr.add_const('OFFLINESTATUS_OFFLINE_SUSPENDED',0x00000006)
		win_const_mgr.add_const('FS_JISJAPAN',0x00020000)
		win_const_mgr.add_const('CM_ADD_RANGE_DONOTADDIFCONFLICT',0x00000001)
		win_const_mgr.add_const('END_PATH',0x00001002)
		win_const_mgr.add_const('PRIVACY_TEMPLATE_NO_COOKIES',0x00000000)
		win_const_mgr.add_const('SCESTATUS_PROFILE_NOT_FOUND',0x00000006)
		win_const_mgr.add_const('SQL_MAX_COLUMNS_IN_GROUP_BY',0x00000061)
		win_const_mgr.add_const('DWN_RAWIMAGE',0x00000100)
		win_const_mgr.add_const('SM_SAMEDISPLAYFORMAT',0x00000051)
		win_const_mgr.add_const('ERROR_HOST_NODE_NOT_GROUP_OWNER',0x00001398)
		win_const_mgr.add_const('DEBUG_SESSION_HIBERNATE',0x00000006)
		win_const_mgr.add_const('MSGFLT_ADD',0x00000001)
		win_const_mgr.add_const('NIIF_HARDWARE_INTERFACE',0x00000001)
		win_const_mgr.add_const('VK_OEM_WSCTRL',0x000000EE)
		win_const_mgr.add_const('KRB_NT_X500_PRINCIPAL',0x00000006)
		win_const_mgr.add_const('ERROR_NODE_CANNOT_BE_CLUSTERED',0x0000170A)
		win_const_mgr.add_const('SPFILENOTIFY_COPYERROR',0x00000000)
		win_const_mgr.add_const('D3DPCMPCAPS_GREATEREQUAL',0x00000040)
		win_const_mgr.add_const('BS_DEFSPLITBUTTON',0x0000000D)
		win_const_mgr.add_const('D3DPBLENDCAPS_ONE',0x00000002)
		win_const_mgr.add_const('USER_FLAGS_PARMNUM',0x00000008)
		win_const_mgr.add_const('TCSBIN_PROTOCOL_UUID16',0x00000005)
		win_const_mgr.add_const('MCI_SEQ_STATUS_SLAVE',0x00004007)
		win_const_mgr.add_const('URLACTION_HTML_SUBMIT_FORMS',0x00001601)
		win_const_mgr.add_const('GDI_ERROR',0xFFFFFFFF)
		win_const_mgr.add_const('OLEUI_ERR_LOADTEMPLATEFAILURE',0x0000006F)
		win_const_mgr.add_const('PORT_REMOTEKIS',0x000000B9)
		win_const_mgr.add_const('PRIVACY_TEMPLATE_LOW',0x00000005)
		win_const_mgr.add_const('CERT_CHAIN_DISABLE_MY_PEER_TRUST',0x00000800)
		win_const_mgr.add_const('PDH_UNKNOWN_LOGSVC_COMMAND',0xC0000BD7)
		win_const_mgr.add_const('SDP_MAX_INQUIRY_SECONDS',0x0000003C)
		win_const_mgr.add_const('DISPID_SUBSCRIPTIONSENABLED',0x0000000A)
		win_const_mgr.add_const('LDAP_API_VERSION',0x000007D4)
		win_const_mgr.add_const('INTERNET_PRIORITY_FOREGROUND',0x000003E8)
		win_const_mgr.add_const('BLTALIGNMENT',0x00000077)
		win_const_mgr.add_const('LINEOPENOPTION_SINGLEADDRESS',0x80000000)
		win_const_mgr.add_const('DBPROP_INIT_IGNORECACHEDDATA',0x00000002)
		win_const_mgr.add_const('MAX_ISCSI_PORTAL_ALIAS_LEN',0x00000100)
		win_const_mgr.add_const('EN_SETFOCUS',0x00000100)
		win_const_mgr.add_const('OCSP_BASIC_GOOD_CERT_STATUS',0x00000000)
		win_const_mgr.add_const('CERT_ROOT_PROGRAM_NAME_CONSTRAINTS_PROP_ID',0x00000054)
		win_const_mgr.add_const('CD_LBSELCHANGE',0x00000000)
		win_const_mgr.add_const('PROCESS_VM_WRITE',0x00000020)
		win_const_mgr.add_const('OID_WAN_SET_COMP_INFO',0x0401020D)
		win_const_mgr.add_const('KERB_REQUEST_ADD_CREDENTIAL',0x00000001)
		win_const_mgr.add_const('DDCAPS2_COLORCONTROLPRIMARY',0x00000080)
		win_const_mgr.add_const('D3DFMT_A1_SURFACE_MAXWIDTH',0x00002000)
		win_const_mgr.add_const('SPINST_REGSVR',0x00000040)
		win_const_mgr.add_const('INT16_MAX',0x00007FFF)
		win_const_mgr.add_const('UNDNAME_NO_RETURN_UDT_MODEL',0x00000400)
		win_const_mgr.add_const('RTCEF_INFO',0x00001000)
		win_const_mgr.add_const('MM_DRVM_CLOSE',0x000003D1)
		win_const_mgr.add_const('PF_PAE_ENABLED',0x00000009)
		win_const_mgr.add_const('CR_PROP_CACERTVERSION',0x00000027)
		win_const_mgr.add_const('ERROR_DS_CANT_ON_RDN',0x00002016)
		win_const_mgr.add_const('ERRACT_IGNORE',0x00000006)
		win_const_mgr.add_const('D3DPRASTERCAPS_ANISOTROPY',0x00020000)
		win_const_mgr.add_const('SBSP_KEEPWORDWHEELTEXT',0x00040000)
		win_const_mgr.add_const('IDM_LINEBREAKLEFT',0x00000868)
		win_const_mgr.add_const('TB_PAGEUP',0x00000002)
		win_const_mgr.add_const('RES_SOFT_SEARCH',0x00000001)
		win_const_mgr.add_const('XP1_CONNECT_DATA',0x00000080)
		win_const_mgr.add_const('NCRYPT_IMPL_HARDWARE_FLAG',0x00000001)
		win_const_mgr.add_const('DISPID_FILEDOWNLOAD',0x0000010E)
		win_const_mgr.add_const('SPDRP_MAXIMUM_PROPERTY',0x00000024)
		win_const_mgr.add_const('GESTURE_UP_LEFT',0x00000000)
		win_const_mgr.add_const('L2_REASON_CODE_GROUP_SIZE',0x00010000)
		win_const_mgr.add_const('DLCTL_NO_BEHAVIORS',0x00008000)
		win_const_mgr.add_const('MFASYNC_CALLBACK_QUEUE_UNDEFINED',0x00000000)
		win_const_mgr.add_const('ALERT_SYSTEM_WARNING',0x00000002)
		win_const_mgr.add_const('SO_PROTOCOL_INFOA',0x00002004)
		win_const_mgr.add_const('ERROR_STACK_BUFFER_OVERRUN',0x00000502)
		win_const_mgr.add_const('DEBUG_CSS_PATHS',0x00000008)
		win_const_mgr.add_const('SECPKG_ATTR_REMOTE_CERTIFICATES',0x0000005F)
		win_const_mgr.add_const('IDM_SUNKEN',0x0000003E)
		win_const_mgr.add_const('DNS_RTYPE_PTR',0x00000000)
		win_const_mgr.add_const('NETE_NETBUSY',0x00000009)
		win_const_mgr.add_const('CAL_GREGORIAN_XLIT_FRENCH',0x0000000C)
		win_const_mgr.add_const('TAPE_LOCK',0x00000003)
		win_const_mgr.add_const('DBIMF_FIXED',0x00000001)
		win_const_mgr.add_const('DESKTOP_HOOKCONTROL',0x00000008)
		win_const_mgr.add_const('SPFEI_ALL_TTS_EVENTS',0x0000FFFE)
		win_const_mgr.add_const('MCW_SCREEN',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_MIPS_REFLO',0x00000005)
		win_const_mgr.add_const('SO_PROTOCOL_INFOW',0x00002005)
		win_const_mgr.add_const('IF_TYPE_IPSWITCH',0x0000004E)
		win_const_mgr.add_const('SQL_API_SQLALLOCHANDLESTD',0x00000049)
		win_const_mgr.add_const('WTS_EVENT_STATECHANGE',0x00000080)
		win_const_mgr.add_const('DE_E_OBJECT_NOT_FOUND',0x800C0006)
		win_const_mgr.add_const('NIF_SHOWTIP',0x00000080)
		win_const_mgr.add_const('IDM_HELP_README',0x000008AE)
		win_const_mgr.add_const('CERT_DESCRIPTION_PROP_ID',0x0000000D)
		win_const_mgr.add_const('SQL_DT_CASCADE',0x00000004)
		win_const_mgr.add_const('NS_PNRPCLOUD',0x00000027)
		win_const_mgr.add_const('MM_WOM_OPEN',0x000003BB)
		win_const_mgr.add_const('WPWIZ_ERROR_FILE_NOT_FOUND',0xC0042008)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_FILTER_PATHS',0x00000040)
		win_const_mgr.add_const('VP_COMMAND_GET',0x00000001)
		win_const_mgr.add_const('EMR_COLORCORRECTPALETTE',0x0000006F)
		win_const_mgr.add_const('IF_TYPE_CNR',0x00000055)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_SYSTEM',0x80004000)
		win_const_mgr.add_const('CERT_CREATE_SELFSIGN_NO_SIGN',0x00000001)
		win_const_mgr.add_const('OID_FDDI_PATH_T_R_MODE',0x03030257)
		win_const_mgr.add_const('AM_CONTENTPROPERTY_DESCRIPTION',0x00000008)
		win_const_mgr.add_const('TF_CONVERSIONMODE_KATAKANA',0x00000002)
		win_const_mgr.add_const('ES_CONTINUOUS',0x80000000)
		win_const_mgr.add_const('ES_EX_NOCALLOLEINIT',0x01000000)
		win_const_mgr.add_const('GTL_NUMBYTES',0x00000010)
		win_const_mgr.add_const('MCI_VD_STATUS_MEDIA_TYPE',0x00004004)
		win_const_mgr.add_const('HTTP_LOG_FIELD_REFERER',0x00040000)
		win_const_mgr.add_const('USER_PASSWORD_PARMNUM',0x00000003)
		win_const_mgr.add_const('CERT_CHAIN_FIND_BY_ISSUER_CACHE_ONLY_FLAG',0x00008000)
		win_const_mgr.add_const('IMGTRANS_OPAQUE',0x20000000)
		win_const_mgr.add_const('DDCKEYCAPS_SRCOVERLAYCLRSPACE',0x00004000)
		win_const_mgr.add_const('VOLUME_NAME_NONE',0x00000004)
		win_const_mgr.add_const('TXTBIT_MULTILINE',0x00000002)
		win_const_mgr.add_const('GPO_SECTION_MACHINE',0x00000002)
		win_const_mgr.add_const('ODT_TAB',0x00000065)
		win_const_mgr.add_const('IPPROTO_MAX',0x00000100)
		win_const_mgr.add_const('PSINJECT_PAGESATEND',0x00000003)
		win_const_mgr.add_const('ERROR_DS_AUTHORIZATION_FAILED',0x00002197)
		win_const_mgr.add_const('AM_GBF_NOWAIT',0x00000004)
		win_const_mgr.add_const('QUERYASMINFO_FLAG_VALIDATE',0x00000001)
		win_const_mgr.add_const('ERROR_DS_NCNAME_MUST_BE_NC',0x000020A5)
		win_const_mgr.add_const('SBS_LEFTALIGN',0x00000002)
		win_const_mgr.add_const('IOCTL_IP_INTERFACE_INFO',0x00000068)
		win_const_mgr.add_const('PCMCIA_OPT_NO_SOUND',0x00000008)
		win_const_mgr.add_const('BELOW_NORMAL_PRIORITY_CLASS',0x00004000)
		win_const_mgr.add_const('OS_SMALLBUSINESSSERVER',0x00000020)
		win_const_mgr.add_const('IMGCHG_MASK',0x0000000F)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_ALL_MULTICAST',0x00000004)
		win_const_mgr.add_const('IMAGE_WEAK_EXTERN_SEARCH_LIBRARY',0x00000002)
		win_const_mgr.add_const('CERT_FIND_EXT_ONLY_ENHKEY_USAGE_FLAG',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_SU_PRIVILEGE_DEFINITION',0x00000008)
		win_const_mgr.add_const('PKEY_PIDSTR_MAX',0x0000000A)
		win_const_mgr.add_const('MDMEMBER_TYPE_RESERVE4',0x00000008)
		win_const_mgr.add_const('DEBUG_STACK_NONVOLATILE_REGISTERS',0x00000020)
		win_const_mgr.add_const('MDMEMBER_TYPE_RESERVE1',0x00000005)
		win_const_mgr.add_const('DEBUG_ENGOPT_SYNCHRONIZE_BREAKPOINTS',0x00000800)
		win_const_mgr.add_const('MDMEMBER_TYPE_RESERVE3',0x00000007)
		win_const_mgr.add_const('MDMEMBER_TYPE_RESERVE2',0x00000006)
		win_const_mgr.add_const('MAX_TRANSPORT_NAME_LEN',0x00000028)
		win_const_mgr.add_const('PAN_MIDLINE_LOW_TRIMMED',0x0000000B)
		win_const_mgr.add_const('ECOOP_AND',0x00000003)
		win_const_mgr.add_const('NERR_BASE',0x00000834)
		win_const_mgr.add_const('LR_DEFAULTCOLOR',0x00000000)
		win_const_mgr.add_const('ASN_PRIVATE',0x000000C0)
		win_const_mgr.add_const('CAP_ATAPI_ID_CMD',0x00000002)
		win_const_mgr.add_const('FEI_RECEIVING',0x00000003)
		win_const_mgr.add_const('WIA_NUM_IPC',0x00000009)
		win_const_mgr.add_const('NTDSTRANSPORT_OPT_IGNORE_SCHEDULES',0x00000001)
		win_const_mgr.add_const('IMAGE_SCN_MEM_WRITE',0x80000000)
		win_const_mgr.add_const('DM_COLOR',0x00000800)
		win_const_mgr.add_const('FEI_NO_ANSWER',0x00000006)
		win_const_mgr.add_const('ACM_METRIC_MAX_SIZE_FORMAT',0x00000032)
		win_const_mgr.add_const('ADS_PRINTER_PENDING_DELETION',0x00000002)
		win_const_mgr.add_const('CERT_LOGOTYPE_NO_IMAGE_RESOLUTION_CHOICE',0x00000000)
		win_const_mgr.add_const('SCF_WORD',0x00000002)
		win_const_mgr.add_const('SV_DISKALERT_PARMNUM',0x00000029)
		win_const_mgr.add_const('IDM_TOOLBARS',0x00000852)
		win_const_mgr.add_const('SYSAUDIO_FLAGS_CLEAR_PREFERRED',0x00000002)
		win_const_mgr.add_const('RIDEV_EXINPUTSINK',0x00001000)
		win_const_mgr.add_const('CTRY_KENYA',0x000000FE)
		win_const_mgr.add_const('IDM_INSFIELDSET',0x00000847)
		win_const_mgr.add_const('DRM_SIGN_OFFLINE',0x00000002)
		win_const_mgr.add_const('SQL_TYPE_TIMESTAMP',0x0000005D)
		win_const_mgr.add_const('TIME_KILL_SYNCHRONOUS',0x00000100)
		win_const_mgr.add_const('CMSG_ENCRYPTED',0x00000006)
		win_const_mgr.add_const('CONTROLLED_LOAD_SERV',0x00000005)
		win_const_mgr.add_const('JOY_POVLEFT',0x00006978)
		win_const_mgr.add_const('LINEAGENTSESSIONSTATUS_NEWSESSION',0x00000001)
		win_const_mgr.add_const('ERROR_XML_PARSE_ERROR',0x000005B9)
		win_const_mgr.add_const('SPFILENOTIFY_ENDBACKUP',0x00000017)
		win_const_mgr.add_const('BF_BOTTOM',0x00000008)
		win_const_mgr.add_const('DISPID_DELTA',0x00000032)
		win_const_mgr.add_const('RPC_NCA_FLAGS_MAYBE',0x00000004)
		win_const_mgr.add_const('OID_CO_GET_ADDRESSES',0xFE000006)
		win_const_mgr.add_const('PFM_LINESPACING',0x00000100)
		win_const_mgr.add_const('NRC_LOCTFUL',0x00000011)
		win_const_mgr.add_const('DNS_ERROR_NEED_WINS_SERVERS',0x00002590)
		win_const_mgr.add_const('NRC_ENVNOTDEF',0x00000034)
		win_const_mgr.add_const('WKSTA_CHARCOUNT_PARMNUM',0x0000000C)
		win_const_mgr.add_const('DMDUP_SIMPLEX',0x00000001)
		win_const_mgr.add_const('DEBUG_BREAKPOINT_ENABLED',0x00000004)
		win_const_mgr.add_const('RPC_C_MQ_EXPRESS',0x00000000)
		win_const_mgr.add_const('R2_WHITE',0x00000010)
		win_const_mgr.add_const('ERROR_DDE_FAIL',0x00000484)
		win_const_mgr.add_const('DDD_LUID_BROADCAST_DRIVE',0x00000010)
		win_const_mgr.add_const('OVERRIDE_LOG_CONF',0x00000005)
		win_const_mgr.add_const('OID_FDDI_PORT_MAC_PLACEMENT',0x03030262)
		win_const_mgr.add_const('PIDMSI_EDITOR',0x00000002)
		win_const_mgr.add_const('SQL_DROP_COLLATION',0x0000008A)
		win_const_mgr.add_const('D3DSP_DSTSHIFT_MASK',0x0F000000)
		win_const_mgr.add_const('DMDITHER_RESERVED7',0x00000007)
		win_const_mgr.add_const('DEX_IDS_INVALID_DXT',0x00000583)
		win_const_mgr.add_const('LINEMEDIACONTROL_NONE',0x00000001)
		win_const_mgr.add_const('SPI_SETMENUFADE',0x00001013)
		win_const_mgr.add_const('DSOP_FILTER_UNIVERSAL_GROUPS_DL',0x00000010)
		win_const_mgr.add_const('STGFMT_STORAGE',0x00000000)
		win_const_mgr.add_const('ERROR_CLUSTER_GROUP_MOVING',0x00001714)
		win_const_mgr.add_const('DEBUG_ENGOPT_INITIAL_BREAK',0x00000020)
		win_const_mgr.add_const('CACHEGROUP_SEARCH_BYURL',0x00000001)
		win_const_mgr.add_const('DMDITHER_RESERVED8',0x00000008)
		win_const_mgr.add_const('PHONEERR_REQUESTOVERRUN',0x90000020)
		win_const_mgr.add_const('EM_SCROLLCARET',0x000000B7)
		win_const_mgr.add_const('IMAGE_DLLCHARACTERISTICS_FORCE_INTEGRITY',0x00000080)
		win_const_mgr.add_const('ERROR_OVERRIDE_NOCHANGES',0x000004E4)
		win_const_mgr.add_const('LR_LOADTRANSPARENT',0x00000020)
		win_const_mgr.add_const('SUBLANG_GREEK_GREECE',0x00000001)
		win_const_mgr.add_const('DISPID_NSCOLUMNS',0x00000015)
		win_const_mgr.add_const('MAPI_DEFAULT_STORE',0x00000001)
		win_const_mgr.add_const('PHOTO_EXPOSUREPROGRAM_UNKNOWN',0x00000000)
		win_const_mgr.add_const('CRYPT_RDN_ATTR_OID_GROUP_ID',0x00000005)
		win_const_mgr.add_const('PHYSICAL_SALEVENTRESOURCE_OFFSET',0x0000001F)
		win_const_mgr.add_const('INTERNET_AUTOPROXY_INIT_DOWNLOADSYNC',0x00000002)
		win_const_mgr.add_const('ALG_CLASS_KEY_EXCHANGE',0x00000005)
		win_const_mgr.add_const('DFCS_MENUCHECK',0x00000001)
		win_const_mgr.add_const('NWF_MANDATORY_OID',0x00000001)
		win_const_mgr.add_const('MCI_DGV_STATUS_WINDOW_MAXIMIZED',0x00004023)
		win_const_mgr.add_const('MINSHORT',0x00008000)
		win_const_mgr.add_const('SO_SNDTIMEO',0x00001005)
		win_const_mgr.add_const('IMAGE_REL_EBC_SECREL',0x00000004)
		win_const_mgr.add_const('DWM_BB_ENABLE',0x00000001)
		win_const_mgr.add_const('CTRY_NEW_ZEALAND',0x00000040)
		win_const_mgr.add_const('CHANGER_VOLUME_ASSERT',0x00400000)
		win_const_mgr.add_const('MAXERRORLENGTH',0x00000100)
		win_const_mgr.add_const('EVENT_OBJECT_HELPCHANGE',0x00008010)
		win_const_mgr.add_const('TTFCFP_SUBSET',0x00000000)
		win_const_mgr.add_const('SUB_OBJECTS_ONLY_INHERIT',0x00000001)
		win_const_mgr.add_const('LINEERR_REINIT',0x80000052)
		win_const_mgr.add_const('DDBLT_ZBUFFERSRCOVERRIDE',0x00800000)
		win_const_mgr.add_const('SUBLANG_ENGLISH_AUS',0x00000003)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_OTHERDRIVER',0x00000000)
		win_const_mgr.add_const('WARNING_IPSEC_MM_POLICY_PRUNED',0x000032E0)
		win_const_mgr.add_const('TMT_HALIGN',0x00000FA5)
		win_const_mgr.add_const('LINEERR_INVALAGENTACTIVITY',0x8000005B)
		win_const_mgr.add_const('CM_REGISTER_DEVICE_DRIVER_BITS',0x00000003)
		win_const_mgr.add_const('TPM_VERNEGANIMATION',0x00002000)
		win_const_mgr.add_const('STRING_NAME_OFFSET',0x00000000)
		win_const_mgr.add_const('SIZEOF_RFPO_DATA',0x00000010)
		win_const_mgr.add_const('DTT_COMPOSITED',0x00000001)
		win_const_mgr.add_const('RESOURCETYPE_ANY',0x00000000)
		win_const_mgr.add_const('NETLOGON_CONTROL_TC_QUERY',0x00000006)
		win_const_mgr.add_const('EMR_FILLRGN',0x00000047)
		win_const_mgr.add_const('LANG_WOLOF',0x00000088)
		win_const_mgr.add_const('OID_FDDI_PATH_TRACE_STATUS',0x03030253)
		win_const_mgr.add_const('SV_TYPE_DIALIN_SERVER',0x00000400)
		win_const_mgr.add_const('TAPE_DRIVE_WRITE_PROTECT',0x00001000)
		win_const_mgr.add_const('KAGPROPVAL_CONCUR_VALUES',0x00000002)
		win_const_mgr.add_const('BLKHOLE_BASETYPE',0x00000001)
		win_const_mgr.add_const('GCS_CURSORPOS',0x00000080)
		win_const_mgr.add_const('META_RESIZEPALETTE',0x00000139)
		win_const_mgr.add_const('SQL_API_SQLDISCONNECT',0x00000009)
		win_const_mgr.add_const('SE_DACL_AUTO_INHERIT_REQ',0x00000100)
		win_const_mgr.add_const('WS_EX_NOACTIVATE',0x08000000)
		win_const_mgr.add_const('DI_NOVCP',0x00000008)
		win_const_mgr.add_const('HSHELL_WINDOWREPLACING',0x0000000E)
		win_const_mgr.add_const('LPM_PE_USER_IDENTITY',0x00000002)
		win_const_mgr.add_const('OCR_ICOCUR',0x00007F87)
		win_const_mgr.add_const('DI_ROPS_READ_DESTINATION',0x00000002)
		win_const_mgr.add_const('UNDERSTANDS_LONG_NAMES',0x00000001)
		win_const_mgr.add_const('STAT_CONTENT_OUT_OF_DATE',0x00000020)
		win_const_mgr.add_const('CTRY_EL_SALVADOR',0x000001F7)
		win_const_mgr.add_const('OID_GEN_RCV_ERROR',0x00020104)
		win_const_mgr.add_const('ULONGLONG_MAX',0x00000000)
		win_const_mgr.add_const('ES_READONLY',0x00000800)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2EVENTARGS_LASTREADLBA',0x00000102)
		win_const_mgr.add_const('DEBUG_REGISTERS_ALL',0x00000007)
		win_const_mgr.add_const('ERROR_DBG_TERMINATE_PROCESS',0x000002B4)
		win_const_mgr.add_const('MCI_FORMAT_BYTES',0x00000008)
		win_const_mgr.add_const('MSV1_0_SUBAUTH_ACCOUNT_EXPIRY',0x00000010)
		win_const_mgr.add_const('PRIVACY_TEMPLATE_HIGH',0x00000001)
		win_const_mgr.add_const('PSPCB_ADDREF',0x00000000)
		win_const_mgr.add_const('ERROR_ALREADY_WAITING',0x00000770)
		win_const_mgr.add_const('SHARE_PERMISSIONS_PARMNUM',0x00000005)
		win_const_mgr.add_const('KLF_SUBSTITUTE_OK',0x00000002)
		win_const_mgr.add_const('IDM_SCROLL_PAGERIGHT',0x00000956)
		win_const_mgr.add_const('EMR_ARC',0x0000002D)
		win_const_mgr.add_const('XP1_SAN_SUPPORT_SDP',0x00080000)
		win_const_mgr.add_const('CR_PROP_CAXCHGCERTCOUNT',0x0000000E)
		win_const_mgr.add_const('RPC_BHO_DONTLINGER',0x00000002)
		win_const_mgr.add_const('DNS_TYPE_ISDN',0x00000014)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_DONOTFINALIZEMEDIA',0x00000107)
		win_const_mgr.add_const('DNS_TYPE_IXFR',0x00000000)
		win_const_mgr.add_const('IASSEMBLYCACHE_UNINSTALL_DISPOSITION_DELETE_PENDING',0x00000004)
		win_const_mgr.add_const('AA_A_OPEN',0x00001000)
		win_const_mgr.add_const('SE_ERR_ASSOCINCOMPLETE',0x0000001B)
		win_const_mgr.add_const('IF_TYPE_RFC877_X25',0x00000005)
		win_const_mgr.add_const('EN_DROPFILES',0x00000703)
		win_const_mgr.add_const('DXVA_EXECUTE_RETURN_DATA_ERROR_SEVERE',0x00000003)
		win_const_mgr.add_const('SECPKG_NEGOTIATION_IN_PROGRESS',0x00000002)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_CLIENT_CHIMNEY_OFFLOAD_CHARACTERISTICS',0x00000093)
		win_const_mgr.add_const('DTS_SHOWNONE',0x00000002)
		win_const_mgr.add_const('CLIP_SUS',0x00000020)
		win_const_mgr.add_const('CONNECT_UPDATE_RECENT',0x00000002)
		win_const_mgr.add_const('IDC_CI_CURRENTICON',0x0000007A)
		win_const_mgr.add_const('RI_KEY_MAKE',0x00000000)
		win_const_mgr.add_const('CREATE_FOR_DIR',0x00000002)
		win_const_mgr.add_const('MCI_VCR_SIGNAL_EVERY',0x00020000)
		win_const_mgr.add_const('SQL_ROW_UPDATED',0x00000002)
		win_const_mgr.add_const('WIA_PROPPAGE_CAMERA_ITEM_GENERAL',0x00000002)
		win_const_mgr.add_const('RTL_RESOURCE_TYPE',0x00000001)
		win_const_mgr.add_const('VFT_DLL',0x00000002)
		win_const_mgr.add_const('PERF_DETAIL_WIZARD',0x00000190)
		win_const_mgr.add_const('OBM_LFARROWI',0x00007FDE)
		win_const_mgr.add_const('FF_ROMAN',0x00000001)
		win_const_mgr.add_const('REGDB_S_FIRST',0x00040150)
		win_const_mgr.add_const('MIXERLINE_LINEF_DISCONNECTED',0x00008000)
		win_const_mgr.add_const('CRLF_DELETE_EXPIRED_CRLS',0x00000002)
		win_const_mgr.add_const('PRIMARY_CRED_LOGON_LUA',0x00000020)
		win_const_mgr.add_const('PD_CURRENTPAGE',0x00400000)
		win_const_mgr.add_const('SQL_FETCH_LAST',0x00000003)
		win_const_mgr.add_const('LVIF_GROUPID',0x00000100)
		win_const_mgr.add_const('SQL_ROW_UPDATES',0x0000000B)
		win_const_mgr.add_const('SFVS_SELECT_ALLITEMS',0x00000001)
		win_const_mgr.add_const('XP1_QOS_SUPPORTED',0x00002000)
		win_const_mgr.add_const('SERVICETYPE_NONCONFORMING',0x00000009)
		win_const_mgr.add_const('LANG_PORTUGUESE',0x00000016)
		win_const_mgr.add_const('DPNHCAPSFLAG_GATEWAYPRESENT',0x00000002)
		win_const_mgr.add_const('CDBOSC_RENAME',0x00000003)
		win_const_mgr.add_const('FINDDLGORD',0x00000604)
		win_const_mgr.add_const('AF_IMPLINK',0x00000003)
		win_const_mgr.add_const('TF_COMMANDING_ON',0x00000008)
		win_const_mgr.add_const('WM_SYNCPAINT',0x00000088)
		win_const_mgr.add_const('SCARD_E_SERVICE_STOPPED',0x8010001E)
		win_const_mgr.add_const('PROOF_QUALITY',0x00000002)
		win_const_mgr.add_const('PROC_THREAD_ATTRIBUTE_REPLACE_VALUE',0x00000001)
		win_const_mgr.add_const('SQL_ATTR_CONNECTION_POOLING',0x000000C9)
		win_const_mgr.add_const('HANDLE_PARAM_IS_VIA_PTR',0x00000080)
		win_const_mgr.add_const('URLACTION_LOWRIGHTS',0x00002500)
		win_const_mgr.add_const('COD_PERIPHERAL_MINOR_GAMEPAD',0x00000002)
		win_const_mgr.add_const('USER_HOME_DIRECTORY_REQUIRED',0x00000002)
		win_const_mgr.add_const('SV_OPENSEARCH_PARMNUM',0x000001F7)
		win_const_mgr.add_const('WCT_OUT_OF_PROC_CS_FLAG',0x00000004)
		win_const_mgr.add_const('OBJ_EXTPEN',0x0000000B)
		win_const_mgr.add_const('ERROR_GROUP_NOT_AVAILABLE',0x00001394)
		win_const_mgr.add_const('L2_REASON_CODE_PROFILE_MISSING',0x00000001)
		win_const_mgr.add_const('ERROR_JOURNAL_HOOK_SET',0x00000596)
		win_const_mgr.add_const('USER_PRIV_ADMIN',0x00000002)
		win_const_mgr.add_const('MS_INVERTCOLORS',0x00000004)
		win_const_mgr.add_const('SQL_CP_STRICT_MATCH',0x00000000)
		win_const_mgr.add_const('VAR_TIMEVALUEONLY',0x00000001)
		win_const_mgr.add_const('VPDF_DISABLEPWRMGMT',0x00000001)
		win_const_mgr.add_const('QOSSPBASE',0x0000C350)
		win_const_mgr.add_const('IDC_CI_DEFAULTICON',0x0000007C)
		win_const_mgr.add_const('CERT_REGISTRY_STORE_REMOTE_FLAG',0x00010000)
		win_const_mgr.add_const('SIC_COMPLEX',0x00000001)
		win_const_mgr.add_const('ERROR_INTERNAL_DB_ERROR',0x00000567)
		win_const_mgr.add_const('DRMHANDLE_INVALID',0x00000000)
		win_const_mgr.add_const('LBER_ERROR',0x00000000)
		win_const_mgr.add_const('MCI_VCR_STATUS_VIDEO',0x00004025)
		win_const_mgr.add_const('URLPOLICY_CHANNEL_SOFTDIST_PRECACHE',0x00020000)
		win_const_mgr.add_const('DV_HD',0x00000001)
		win_const_mgr.add_const('ERROR_NETNAME_DELETED',0x00000040)
		win_const_mgr.add_const('PIFDEFPATHSIZE',0x00000040)
		win_const_mgr.add_const('IDM_ISTRUSTEDDLG',0x00000934)
		win_const_mgr.add_const('APPSTATUS_NOTDEFINED',0x00000002)
		win_const_mgr.add_const('MNS_AUTODISMISS',0x10000000)
		win_const_mgr.add_const('STDOLE_MINORVERNUM',0x00000000)
		win_const_mgr.add_const('COLORONCOLOR',0x00000003)
		win_const_mgr.add_const('IPPORT_RESERVED',0x00000400)
		win_const_mgr.add_const('WINDING',0x00000002)
		win_const_mgr.add_const('MAX_KNOWN_INK_ANALYSIS_GUID_INDEX',0x00000080)
		win_const_mgr.add_const('EMARCH_ENC_I17_SIGN_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('CBEIF_INDENT',0x00000010)
		win_const_mgr.add_const('DEVICE_DEFAULT_FONT',0x0000000E)
		win_const_mgr.add_const('IDC_LP_UPDATENOW',0x000003EF)
		win_const_mgr.add_const('IDC_GP_OBJECTLOCATION',0x000003FE)
		win_const_mgr.add_const('GESTURE_DOWN_LEFT',0x00000000)
		win_const_mgr.add_const('ERROR_LB_WITHOUT_TABSTOPS',0x0000059A)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_RECORD',0x00000002)
		win_const_mgr.add_const('ERROR_FAILED_DRIVER_ENTRY',0x00000287)
		win_const_mgr.add_const('DBPROPVAL_NP_FAILEDTODO',0x00000008)
		win_const_mgr.add_const('SUBLANG_BENGALI_INDIA',0x00000001)
		win_const_mgr.add_const('IMAGE_COMPRESSION_CCITT_T6',0x00000004)
		win_const_mgr.add_const('SOCKET_SETTINGS_GUARANTEE_ENCRYPTION',0x00000001)
		win_const_mgr.add_const('IMAGE_COMPRESSION_CCITT_T4',0x00000003)
		win_const_mgr.add_const('IMAGE_COMPRESSION_CCITT_T3',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_PROP',0x00003607)
		win_const_mgr.add_const('NTMS_COMPUTERNAME_LENGTH',0x00000040)
		win_const_mgr.add_const('IT_STATUS_TRANSFER_TO_CLIENT',0x00000004)
		win_const_mgr.add_const('DEVPROP_MASK_TYPE',0x00000FFF)
		win_const_mgr.add_const('LDAP_OPT_AREC_EXCLUSIVE',0x00000098)
		win_const_mgr.add_const('PHONEERR_INVALBUTTONSTATE',0x9000000B)
		win_const_mgr.add_const('PRINTER_STATUS_INITIALIZING',0x00008000)
		win_const_mgr.add_const('MB_DEFBUTTON4',0x00000300)
		win_const_mgr.add_const('ICC_BAR_CLASSES',0x00000004)
		win_const_mgr.add_const('RESTORE',0x00000006)
		win_const_mgr.add_const('KP_PRECOMP_SHA',0x00000019)
		win_const_mgr.add_const('IEIFLAG_ORIGSIZE',0x00000040)
		win_const_mgr.add_const('OFN_EXTENSIONDIFFERENT',0x00000400)
		win_const_mgr.add_const('D3DFVF_XYZW',0x00004002)
		win_const_mgr.add_const('ERROR_CLUSTER_INSTANCE_ID_MISMATCH',0x00001705)
		win_const_mgr.add_const('DEBUG_SYMINFO_BREAKPOINT_SOURCE_LINE',0x00000000)
		win_const_mgr.add_const('NIS_HIDDEN',0x00000001)
		win_const_mgr.add_const('SQL_FB_ON',0x00000001)
		win_const_mgr.add_const('SYMF_OMAP_GENERATED',0x00000001)
		win_const_mgr.add_const('DEBUG_OUTPUT_WARNING',0x00000004)
		win_const_mgr.add_const('SQL_DV_RESTRICT',0x00000002)
		win_const_mgr.add_const('ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY',0x00003ABC)
		win_const_mgr.add_const('FD_MAX_EVENTS',0x0000000A)
		win_const_mgr.add_const('RBS_VARHEIGHT',0x00000200)
		win_const_mgr.add_const('BF_MONO',0x00008000)
		win_const_mgr.add_const('SO_MAXDG',0x00007009)
		win_const_mgr.add_const('TARGET_IS_NT60_OR_LATER',0x00000000)
		win_const_mgr.add_const('SV_COMMENT_PARMNUM',0x00000005)
		win_const_mgr.add_const('PRINTER_ENUM_EXPAND',0x00004000)
		win_const_mgr.add_const('SO_BTH_MTU',0x80000007)
		win_const_mgr.add_const('WLAN_CONNECTION_NOTIFICATION_ADHOC_NETWORK_FORMED',0x00000001)
		win_const_mgr.add_const('SERVICE_LOCAL',0x00000004)
		win_const_mgr.add_const('KF_EXTENDED',0x00000100)
		win_const_mgr.add_const('USER_MAX_STORAGE_PARMNUM',0x00000012)
		win_const_mgr.add_const('REG_BINARY',0x00000003)
		win_const_mgr.add_const('LINEDEVSTATE_CLOSE',0x00000400)
		win_const_mgr.add_const('GL_LEVEL_INFORMATION',0x00000004)
		win_const_mgr.add_const('NDIS_RING_TRANSMIT_BEACON',0x00001000)
		win_const_mgr.add_const('EC_STREAM_ERROR_STOPPED',0x00000006)
		win_const_mgr.add_const('MCI_OVLY_WINDOW_STATE',0x00040000)
		win_const_mgr.add_const('BTH_MFG_MANSELLA',0x00000021)
		win_const_mgr.add_const('DAO_MAXSEEKFIELDS',0x0000000D)
		win_const_mgr.add_const('SHGVSPB_ALLUSERS',0x00000002)
		win_const_mgr.add_const('ACM_METRIC_COUNT_DRIVERS',0x00000001)
		win_const_mgr.add_const('DISPLAYDIB_TEST',0x00000400)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM9D_INST_WORD_POS_X',0x00000012)
		win_const_mgr.add_const('SWP_SHOWWINDOW',0x00000040)
		win_const_mgr.add_const('LVS_ICON',0x00000000)
		win_const_mgr.add_const('PHOTO_ORIENTATION_ROTATE180',0x00000003)
		win_const_mgr.add_const('RPC_C_OPT_MQ_TIME_TO_BE_RECEIVED',0x00000008)
		win_const_mgr.add_const('SQL_FN_TD_TIMESTAMPDIFF',0x00004000)
		win_const_mgr.add_const('SHDID_COMPUTER_REMOVABLE',0x00000007)
		win_const_mgr.add_const('HTTP_QUERY_ACCEPT_ENCODING',0x0000001A)
		win_const_mgr.add_const('CM_DISABLE_POLITE',0x00000000)
		win_const_mgr.add_const('IPV6_UNICAST_HOPS',0x00000004)
		win_const_mgr.add_const('GIL_DEFAULTICON',0x00000040)
		win_const_mgr.add_const('LANG_MACEDONIAN',0x00000002)
		win_const_mgr.add_const('PHONEHOOKSWITCHMODE_UNKNOWN',0x00000010)
		win_const_mgr.add_const('RECO_DRAG',0x00000004)
		win_const_mgr.add_const('SQL_INDEX_OTHER',0x00000003)
		win_const_mgr.add_const('ACTRL_DS_LIST_OBJECT',0x00000080)
		win_const_mgr.add_const('MCI_QUALITY_HANDLE',0x00100000)
		win_const_mgr.add_const('KAGPROP_ACTIVESTATEMENTS',0x00000018)
		win_const_mgr.add_const('DL_STOPCURSOR',0x00000001)
		win_const_mgr.add_const('KRAF_ENABLEFOREIGN',0x00000001)
		win_const_mgr.add_const('EC_USERABORT',0x00000002)
		win_const_mgr.add_const('MCI_DGV_STATUS_KEY_INDEX',0x00004024)
		win_const_mgr.add_const('SECURITY_FLAG_SSL3',0x00000004)
		win_const_mgr.add_const('WSAENOPROTOOPT',0x0000273A)
		win_const_mgr.add_const('WEBPOST_ERROR_SITE_EXISTS',0xC0042109)
		win_const_mgr.add_const('DI_FLAGSEX_FILTERSIMILARDRIVERS',0x02000000)
		win_const_mgr.add_const('RESOURCEUSAGE_ATTACHED',0x00000010)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_PATH_TYPE_WIN32_FILE',0x00000002)
		win_const_mgr.add_const('KP_GET_USE_COUNT',0x0000002A)
		win_const_mgr.add_const('SPI_SETFONTSMOOTHINGTYPE',0x0000200B)
		win_const_mgr.add_const('OID_802_3_CURRENT_ADDRESS',0x01010102)
		win_const_mgr.add_const('SQL_PC_OFF',0x00000000)
		win_const_mgr.add_const('OID_FDDI_SMT_USER_DATA',0x03030206)
		win_const_mgr.add_const('TABLET_DISABLE_TOUCHUIFORCEOFF',0x00000200)
		win_const_mgr.add_const('CM_DRP_UI_NUMBER',0x00000011)
		win_const_mgr.add_const('TVS_NOTOOLTIPS',0x00000080)
		win_const_mgr.add_const('WKSTA_CHARWAIT_PARMNUM',0x0000000A)
		win_const_mgr.add_const('CM_DRP_CLASS',0x00000008)
		win_const_mgr.add_const('FCIDM_BROWSERLAST',0x00000000)
		win_const_mgr.add_const('ERROR_DS_SCHEMA_NOT_LOADED',0x000020DE)
		win_const_mgr.add_const('DS_REPDEL_ASYNCHRONOUS_OPERATION',0x00000001)
		win_const_mgr.add_const('WINEVENT_KEYWORD_RESERVED_48',0x1000000000000)
		win_const_mgr.add_const('PHOTO_FLASH_WITHSTROBE',0x00000007)
		win_const_mgr.add_const('DISKQUOTA_FILESTATE_MASK',0x00000300)
		win_const_mgr.add_const('FILE_UNICODE_ON_DISK',0x00000004)
		win_const_mgr.add_const('RPC_C_AUTHN_LEVEL_PKT_PRIVACY',0x00000006)
		win_const_mgr.add_const('MSIDXSPROP_COMMAND_LOCALE_STRING',0x00000003)
		win_const_mgr.add_const('DBG_ATTACH',0x0000000E)
		win_const_mgr.add_const('STGM_READWRITE',0x00000002)
		win_const_mgr.add_const('DEBUG_SESSION_REBOOT',0x00000005)
		win_const_mgr.add_const('PHOTO_EXPOSUREPROGRAM_NORMAL',0x00000002)
		win_const_mgr.add_const('EMR_RESERVED_105',0x00000069)
		win_const_mgr.add_const('HH_DISPLAY_INDEX',0x00000002)
		win_const_mgr.add_const('CM_DRP_FRIENDLYNAME',0x0000000D)
		win_const_mgr.add_const('NTDSCONN_KCC_INTERSITE_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_POSITION',0x0000000F)
		win_const_mgr.add_const('GESTURE_ASTERISK',0x00000000)
		win_const_mgr.add_const('SMART_NO_IDE_DEVICE',0x0000000A)
		win_const_mgr.add_const('CERT_PVK_FILE_PROP_ID',0x0000000C)
		win_const_mgr.add_const('FWP_CALLOUT_FLAG_CONDITIONAL_ON_FLOW',0x00000001)
		win_const_mgr.add_const('SHGNLI_NOLOCNAME',0x00000010)
		win_const_mgr.add_const('AM_DVD_COPYRIGHT_MASK',0x00000040)
		win_const_mgr.add_const('BLLI_L3_PACKET_64',0x00000006)
		win_const_mgr.add_const('TRANSACTIONMANAGER_RECOVER',0x00000004)
		win_const_mgr.add_const('ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY',0x000000D9)
		win_const_mgr.add_const('IF_TYPE_CCTEMUL',0x0000003D)
		win_const_mgr.add_const('POLICY_QOS_OUTBOUND_INTEGRITY',0x00000002)
		win_const_mgr.add_const('IPP_E_UNSYNCHRONIZED',0xC0048008)
		win_const_mgr.add_const('SRRF_RM_NORMAL',0x00010000)
		win_const_mgr.add_const('CORDLESS_EXTERNAL_NETWORK_OTHER',0x00000007)
		win_const_mgr.add_const('IF_TYPE_HIPPI',0x0000002F)
		win_const_mgr.add_const('HTTP_NULL_ID',0x00000000)
		win_const_mgr.add_const('EMR_INTERSECTCLIPRECT',0x0000001E)
		win_const_mgr.add_const('LINECALLPARAMFLAGS_IDLE',0x00000002)
		win_const_mgr.add_const('MIIM_STRING',0x00000040)
		win_const_mgr.add_const('DBPROPVAL_GB_CONTAINS_SELECT',0x00000004)
		win_const_mgr.add_const('ACS_TRANSPARENT',0x00000002)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGCREATE',0x0000000A)
		win_const_mgr.add_const('AD_GETWP_LAST_APPLIED',0x00000002)
		win_const_mgr.add_const('WTNCA_NOSYSMENU',0x00000004)
		win_const_mgr.add_const('CERT_COMPARE_CERT_ID',0x00000010)
		win_const_mgr.add_const('FPSR_I0',0x00000012)
		win_const_mgr.add_const('SQL_SS_ADDITIONS',0x00000001)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_NAME',0x00000007)
		win_const_mgr.add_const('LINECALLSTATE_CONNECTED',0x00000100)
		win_const_mgr.add_const('FPSR_I1',0x0000001F)
		win_const_mgr.add_const('FACILITY_TERMINAL_SERVER',0x0000000A)
		win_const_mgr.add_const('MCI_VCR_STEP_REVERSE',0x00020000)
		win_const_mgr.add_const('SQL_CDO_CONSTRAINT_NON_DEFERRABLE',0x00000100)
		win_const_mgr.add_const('JOY_BUTTON30',0x20000000)
		win_const_mgr.add_const('JOY_BUTTON31',0x40000000)
		win_const_mgr.add_const('JOY_BUTTON32',0x80000000)
		win_const_mgr.add_const('TTFMFP_SUBSET1',0x00000001)
		win_const_mgr.add_const('FR_NOMATCHCASE',0x00000800)
		win_const_mgr.add_const('PSINJECT_BEGINSETUP',0x00000010)
		win_const_mgr.add_const('SELECT_CAP_SENTENCE',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_SQL_FIPS_TRANSITIONAL',0x00000020)
		win_const_mgr.add_const('WPP_POST_POSTING_NO_RESPONSE_ERROR',0xC0042383)
		win_const_mgr.add_const('NETLOGON_CONTROL_REPLICATE',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_GPRELHI',0x00000017)
		win_const_mgr.add_const('LDAP_SUBSTRING_INITIAL',0x00000080)
		win_const_mgr.add_const('OID_FDDI_SMT_TRACE_MAX_EXPIRATION',0x03030211)
		win_const_mgr.add_const('LINE_AGENTSESSIONSTATUS',0x0000001B)
		win_const_mgr.add_const('DEBUG_CES_CODE_LEVEL',0x00000008)
		win_const_mgr.add_const('MTP_NEXTPHASE_WRITE_DATA',0x00000002)
		win_const_mgr.add_const('LIS_NOGRPCONV',0x00000002)
		win_const_mgr.add_const('SECURITY_INTERACTIVE_RID',0x00000004)
		win_const_mgr.add_const('IDO_SHGIOI_SHARE',0x0FFFFFFF)
		win_const_mgr.add_const('RQ_LOG_REQUEST',0x00000400)
		win_const_mgr.add_const('SQL_CONCAT_NULL_BEHAVIOR',0x00000016)
		win_const_mgr.add_const('DMPAPER_ENV_C4',0x0000001E)
		win_const_mgr.add_const('KS_TVTUNER_CHANGE_BEGIN_TUNE',0x00000001)
		win_const_mgr.add_const('DEBUG_OUTSYM_FORCE_OFFSET',0x00000001)
		win_const_mgr.add_const('IDM_BACKCOLOR',0x00000033)
		win_const_mgr.add_const('CDO_E_UNSUPPORTED_DATASOURCE',0x80040203)
		win_const_mgr.add_const('AM_AC3_SERVICE_COMMENTARY',0x00000005)
		win_const_mgr.add_const('ACM_METRIC_DRIVER_PRIORITY',0x00000065)
		win_const_mgr.add_const('DCX_CLIPSIBLINGS',0x00000010)
		win_const_mgr.add_const('CWP_SKIPINVISIBLE',0x00000001)
		win_const_mgr.add_const('TRUST_ATTRIBUTES_USER',0xFF000000)
		win_const_mgr.add_const('ERROR_BAD_PROFILE',0x000004B6)
		win_const_mgr.add_const('LGRPID_THAI',0x00000000)
		win_const_mgr.add_const('DI_UNREMOVEDEVICE_CONFIGSPECIFIC',0x00000002)
		win_const_mgr.add_const('SM_CMETRICS',0x0000005D)
		win_const_mgr.add_const('CMSG_SIGNED_DATA_V1',0x00000001)
		win_const_mgr.add_const('IDM_FOLLOWLINKC',0x00000858)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_IPSECV1_AH_ENABLED',0x00000002)
		win_const_mgr.add_const('CM_PROB_DEVLOADER_NOT_FOUND',0x00000008)
		win_const_mgr.add_const('SQL_DIAG_DELETE_WHERE',0x00000013)
		win_const_mgr.add_const('WM_HSCROLLCLIPBOARD',0x0000030E)
		win_const_mgr.add_const('ASC_REQ_STREAM',0x00010000)
		win_const_mgr.add_const('MAPI_POST_MESSAGE',0x00000001)
		win_const_mgr.add_const('OLECMDARGINDEX_SHOWPAGEACTIONMENU_Y',0x00000002)
		win_const_mgr.add_const('ITALIC_FONTTYPE',0x00000200)
		win_const_mgr.add_const('DEF_MAX_BADPW',0x00000000)
		win_const_mgr.add_const('IDM_FOLLOWLINKT',0x00000983)
		win_const_mgr.add_const('PWR_SUSPENDRESUME',0x00000002)
		win_const_mgr.add_const('ASYNC_RECO_SETFLAGS_FAILED',0x00000040)
		win_const_mgr.add_const('EVENT_SYSTEM_MENUSTART',0x00000004)
		win_const_mgr.add_const('URL_INTERNAL_PATH',0x00800000)
		win_const_mgr.add_const('HICF_LEAVING',0x00000020)
		win_const_mgr.add_const('WM_MDIGETACTIVE',0x00000229)
		win_const_mgr.add_const('NRC_REMTFUL',0x00000012)
		win_const_mgr.add_const('INTERNET_OPTION_PROXY',0x00000026)
		win_const_mgr.add_const('SQL_ODBC_CURSORS',0x0000006E)
		win_const_mgr.add_const('CLEARTYPE_NATURAL_QUALITY',0x00000006)
		win_const_mgr.add_const('NEWFILEOPENORD',0x0000060B)
		win_const_mgr.add_const('ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED',0x00001B95)
		win_const_mgr.add_const('PROCESSOR_ARM720',0x00000720)
		win_const_mgr.add_const('ERROR_CONNECTED_OTHER_PASSWORD',0x0000083C)
		win_const_mgr.add_const('WNTYPE_DRIVE',0x00000001)
		win_const_mgr.add_const('INF_STYLE_OLDNT',0x00000001)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_PEER_DEAUTHENTICATED_END',0x00000001)
		win_const_mgr.add_const('ISR_CODE_MASK',0x0000FFFF)
		win_const_mgr.add_const('SQL_SR_INSERT_COLUMN',0x00000200)
		win_const_mgr.add_const('FACILITY_SHELL',0x00000027)
		win_const_mgr.add_const('DS_REPSYNC_INITIAL',0x00002000)
		win_const_mgr.add_const('FPS_FATAL_ERROR',0x20000800)
		win_const_mgr.add_const('CRYPT_DECODE_SHARE_OID_STRING_FLAG',0x00000004)
		win_const_mgr.add_const('DCOMSCM_ACTIVATION_USE_ALL_AUTHNSERVICES',0x00000001)
		win_const_mgr.add_const('MCI_WAVE_GETDEVCAPS_INPUTS',0x00004001)
		win_const_mgr.add_const('CS_GLOBALCLASS',0x00004000)
		win_const_mgr.add_const('AUTHZ_COMPUTE_PRIVILEGES',0x00000008)
		win_const_mgr.add_const('DSBI_NOLINESATROOT',0x00000004)
		win_const_mgr.add_const('POLICY_ERRV_UNSUPPORTED_CREDENTIAL_TYPE',0x00000002)
		win_const_mgr.add_const('DSOP_FILTER_CONTACTS',0x00000400)
		win_const_mgr.add_const('SUBLANG_SPANISH_PARAGUAY',0x00000000)
		win_const_mgr.add_const('GMEM_MOVEABLE',0x00000002)
		win_const_mgr.add_const('CMSG_KEY_AGREE_EPHEMERAL_KEY_CHOICE',0x00000001)
		win_const_mgr.add_const('SQL_CACHE_DATA_YES',0x00000001)
		win_const_mgr.add_const('CAL_SLONGDATE',0x00000006)
		win_const_mgr.add_const('LWS_USECUSTOMTEXT',0x00000010)
		win_const_mgr.add_const('WIA_IPS_PREVIEW',0x00000C1C)
		win_const_mgr.add_const('SN_INFLAG_RUNTIME',0x80000000)
		win_const_mgr.add_const('APMMENUSUSPEND_UNDOCKED',0x00000002)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_RELEASEMEDIA',0x00000204)
		win_const_mgr.add_const('IDM_INSINPUTPASSWORD',0x00000909)
		win_const_mgr.add_const('FEI_DIALING',0x00000001)
		win_const_mgr.add_const('MAXIMUM_REPARSE_DATA_BUFFER_SIZE',0x00000010)
		win_const_mgr.add_const('OID_GEN_INTERRUPT_MODERATION',0x00010209)
		win_const_mgr.add_const('SQL_NC_ON',0x00000001)
		win_const_mgr.add_const('SP_COPY_NEWER',0x00000004)
		win_const_mgr.add_const('IDM_ZOOMRATIO',0x00000928)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_CONSTRAINT_COLUMN_USAGE',0x00000004)
		win_const_mgr.add_const('SAFER_TOKEN_COMPARE_ONLY',0x00000002)
		win_const_mgr.add_const('MAX_IRQS',0x00000007)
		win_const_mgr.add_const('SDP_ATTRIB_FAX_CLASS_2_0_SUPPORT',0x00000303)
		win_const_mgr.add_const('LVS_ALIGNMASK',0x00000000)
		win_const_mgr.add_const('CTRY_HONDURAS',0x000001F8)
		win_const_mgr.add_const('ERROR_DS_CONTROL_NOT_FOUND',0x00002042)
		win_const_mgr.add_const('VK_OEM_ATTN',0x000000F0)
		win_const_mgr.add_const('MDM_PROTOCOLID_V110',0x00000004)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_REFERENTIAL_CONSTRAINTS',0x00000003)
		win_const_mgr.add_const('PSINJECT_BEGINDEFAULTS',0x0000000C)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_POWER',0x00000010)
		win_const_mgr.add_const('MCI_DGV_LIST_STILL_ALG',0x00004003)
		win_const_mgr.add_const('BIF_NONEWFOLDERBUTTON',0x00000200)
		win_const_mgr.add_const('DS_REPL_NBR_SELECT_SECRETS',0x00001000)
		win_const_mgr.add_const('CR_PROP_CASIGCERTCHAIN',0x0000000D)
		win_const_mgr.add_const('CMC_FAIL_POP_REQUIRED',0x00000008)
		win_const_mgr.add_const('AM_CONTENTPROPERTY_TITLE',0x00000001)
		win_const_mgr.add_const('IKEEXT_CERT_HASH_LEN',0x00000014)
		win_const_mgr.add_const('LOCALE_RETURN_NUMBER',0x20000000)
		win_const_mgr.add_const('SW_OTHERZOOM',0x00000002)
		win_const_mgr.add_const('BACKUP_DATA',0x00000001)
		win_const_mgr.add_const('MAPI_NOTRECIP',0x00000040)
		win_const_mgr.add_const('WTS_SESSION_UNLOCK',0x00000008)
		win_const_mgr.add_const('PERF_COUNTER_BASE',0x00030000)
		win_const_mgr.add_const('IMAGE_DLLCHARACTERISTICS_WDM_DRIVER',0x00002000)
		win_const_mgr.add_const('OF_CAP_CANSWITCHTO',0x00000001)
		win_const_mgr.add_const('HANDLE_FLAG_PROTECT_FROM_CLOSE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA',0x00002111)
		win_const_mgr.add_const('UPNP_PROTOCOL_UUID16',0x00000010)
		win_const_mgr.add_const('SIF_RANGE',0x00000001)
		win_const_mgr.add_const('GRADIENT_FILL_RECT_V',0x00000001)
		win_const_mgr.add_const('MUI_QUERY_RESOURCE_TYPES',0x00000008)
		win_const_mgr.add_const('DDSCAPS2_TEXTUREMANAGE',0x00000010)
		win_const_mgr.add_const('IDD_PASTESPECIAL',0x000003EB)
		win_const_mgr.add_const('LDAP_OPT_REBIND_FN',0x00000006)
		win_const_mgr.add_const('DBPROPVAL_GB_NOT_SUPPORTED',0x00000001)
		win_const_mgr.add_const('ERROR_CTX_LICENSE_CLIENT_INVALID',0x00001B8F)
		win_const_mgr.add_const('LANG_BRETON',0x00000007)
		win_const_mgr.add_const('ADS_JOB_ERROR',0x00000002)
		win_const_mgr.add_const('WPF_NO_PROGRESS_DLGS',0x00000200)
		win_const_mgr.add_const('LINE_DEVSPECIFICFEATURE',0x00000005)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_PAIR',0x0000000C)
		win_const_mgr.add_const('MQ_LOOKUP_RECEIVE_ALLOW_PEEK',0x40000120)
		win_const_mgr.add_const('RPC_IF_ALLOW_SECURE_ONLY',0x00000008)
		win_const_mgr.add_const('RSA_KEY_LEN',0x00000040)
		win_const_mgr.add_const('SQL_NC_OFF',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_PRIVATE_IN_PROC',0x00020000)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_EXTERNAL_UPLEVEL_DOMAIN',0x00000020)
		win_const_mgr.add_const('BF_RIGHT',0x00000004)
		win_const_mgr.add_const('WKSTA_NUMWORKBUF_PARMNUM',0x00000010)
		win_const_mgr.add_const('ATSC_ETT_TID',0x000000CC)
		win_const_mgr.add_const('DBPROPVAL_NT_MULTIPLEROWS',0x00000002)
		win_const_mgr.add_const('DEBUG_EVENT_LOAD_MODULE',0x00000040)
		win_const_mgr.add_const('HH_GET_WIN_HANDLE',0x00000006)
		win_const_mgr.add_const('OFN_ENABLETEMPLATEHANDLE',0x00000080)
		win_const_mgr.add_const('ERROR_NONE_MAPPED',0x00000534)
		win_const_mgr.add_const('SPI_GETSCREENSAVEACTIVE',0x00000010)
		win_const_mgr.add_const('OFFLOAD_OUTBOUND_SA',0x00000002)
		win_const_mgr.add_const('PROPID_QUERY_RANK',0x00000003)
		win_const_mgr.add_const('DFM_GETHELPTEXTW',0x0000000B)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_206',0x801900CE)
		win_const_mgr.add_const('EAP_CONFIG_INPUT_FIELD_PROPS_DEFAULT',0x00000000)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_204',0x801900CC)
		win_const_mgr.add_const('HSE_URL_FLAGS_SSL',0x00000008)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_202',0x801900CA)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_201',0x801900C9)
		win_const_mgr.add_const('ARCONTENT_DVDMOVIE',0x00000008)
		win_const_mgr.add_const('LCMAP_KATAKANA',0x00200000)
		win_const_mgr.add_const('MCI_DGV_STATUS_COLOR',0x00004006)
		win_const_mgr.add_const('HKCOMB_S',0x00000002)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_GUIDMAP',0x0000000A)
		win_const_mgr.add_const('PRIVACY_URLHASPOLICYREFLINK',0x00100000)
		win_const_mgr.add_const('PRJOB_NOTIFY',0x00000080)
		win_const_mgr.add_const('DISPID_FONT_CHARSET',0x00000008)
		win_const_mgr.add_const('ISFB_MASK_IDLIST',0x00000010)
		win_const_mgr.add_const('OBM_CHECKBOXES',0x00007FF7)
		win_const_mgr.add_const('RR_SIZE',0x00000008)
		win_const_mgr.add_const('DMDO_DEFAULT',0x00000000)
		win_const_mgr.add_const('VK_CONTROL',0x00000011)
		win_const_mgr.add_const('IRLMP_IAS_QUERY',0x00000012)
		win_const_mgr.add_const('EMR_SETICMPROFILEA',0x00000070)
		win_const_mgr.add_const('CHANGER_VOLUME_IDENTIFICATION',0x00100000)
		win_const_mgr.add_const('MDMEMBER_TYPE_MEASURE',0x00000003)
		win_const_mgr.add_const('LINECALLFEATURE_ANSWER',0x00000004)
		win_const_mgr.add_const('ULONG_PTR_MAX',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_MM_HPF',0x0000000E)
		win_const_mgr.add_const('EMR_SETICMPROFILEW',0x00000071)
		win_const_mgr.add_const('DS_REPADD_ASYNCHRONOUS_OPERATION',0x00000001)
		win_const_mgr.add_const('DV_AUDIOMODE',0x00000000)
		win_const_mgr.add_const('SCARD_STATE_EXCLUSIVE',0x00000080)
		win_const_mgr.add_const('WMS_ASF_THRESHOLD_DURATION',0x000001F4)
		win_const_mgr.add_const('RPC_DE_USE_CURRENT_EEINFO',0x00000001)
		win_const_mgr.add_const('ICM_DONE_OUTSIDEDC',0x00000004)
		win_const_mgr.add_const('MCS_NOTODAY',0x00000008)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_RECOVER_QUERY',0x00000800)
		win_const_mgr.add_const('OPPROGDLG_DONTDISPLAYSOURCEPATH',0x00000200)
		win_const_mgr.add_const('LAYOUT_BITMAPORIENTATIONPRESERVED',0x00000008)
		win_const_mgr.add_const('SERVICE_MULTIPLE',0x00000001)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_SAMPLE_INPUT_FRAME',0x00000001)
		win_const_mgr.add_const('SYMOPT_AUTO_PUBLICS',0x00010000)
		win_const_mgr.add_const('D3DPCMPCAPS_LESSEQUAL',0x00000008)
		win_const_mgr.add_const('ERROR_DISK_RECALIBRATE_FAILED',0x00000466)
		win_const_mgr.add_const('SV_TYPE_WINDOWS',0x00400000)
		win_const_mgr.add_const('MAPI_E_AMBIGUOUS_RECIPIENT',0x00000015)
		win_const_mgr.add_const('FILE_DEVICE_BUS_EXTENDER',0x00000002)
		win_const_mgr.add_const('SQL_PARAM_SUCCESS',0x00000000)
		win_const_mgr.add_const('CONFIGFLAG_FAILEDINSTALL',0x00000040)
		win_const_mgr.add_const('WM_GETMINMAXINFO',0x00000024)
		win_const_mgr.add_const('PROFILE_FILENAME',0x00000001)
		win_const_mgr.add_const('MD_CHANGE_TYPE_RESTORE',0x00000020)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCDEVENTARGS_ESTIMATEDTOTALTIME',0x00000302)
		win_const_mgr.add_const('TXFS_TRANSACTION_STATE_PREPARED',0x00000002)
		win_const_mgr.add_const('AUTH_REQ_ALLOW_S4U_DELEGATE',0x00000800)
		win_const_mgr.add_const('TMT_CSSNAME',0x00000579)
		win_const_mgr.add_const('DNS_ERROR_UNKNOWN_RECORD_TYPE',0x000025E8)
		win_const_mgr.add_const('TMT_MENUBARHEIGHT',0x000004B9)
		win_const_mgr.add_const('SAFER_POLICY_JOBID_MASK',0xFF000000)
		win_const_mgr.add_const('DNS_FILTEROFF',0x00000008)
		win_const_mgr.add_const('HKCOMB_A',0x00000008)
		win_const_mgr.add_const('DDSVCAPS_STEREOSEQUENTIAL',0x00000010)
		win_const_mgr.add_const('SECBUFFER_MECHLIST',0x0000000B)
		win_const_mgr.add_const('SSPROP_QUOTEDCATALOGNAMES',0x00000002)
		win_const_mgr.add_const('CERT_STORE_DELTA_CRL_FLAG',0x00000200)
		win_const_mgr.add_const('PRODUCT_CLUSTER_SERVER',0x00000012)
		win_const_mgr.add_const('SMTO_NORMAL',0x00000000)
		win_const_mgr.add_const('HKCOMB_C',0x00000004)
		win_const_mgr.add_const('RTCAU_BASIC',0x00000001)
		win_const_mgr.add_const('RPC_C_OPT_TRUST_PEER',0x0000000E)
		win_const_mgr.add_const('PARTITION_XINT13_EXTENDED',0x0000000F)
		win_const_mgr.add_const('PSP_HIDEHEADER',0x00000800)
		win_const_mgr.add_const('GTL_CLOSE',0x00000004)
		win_const_mgr.add_const('SN_CMP_DIFFERENT',0x00000000)
		win_const_mgr.add_const('FACILITY_RPC_STUBS',0x00000003)
		win_const_mgr.add_const('WMPGC_FLAGS_IGNORE_AV_SYNC',0x00000004)
		win_const_mgr.add_const('URLACTION_AUTOMATIC_ACTIVEX_UI',0x00002201)
		win_const_mgr.add_const('SSPROP_AUTH_REPL_SERVER_NAME',0x0000000E)
		win_const_mgr.add_const('CLCTL_INTERNAL_MASK',0x00000001)
		win_const_mgr.add_const('NET_IFLUID_UNSPECIFIED',0x00000000)
		win_const_mgr.add_const('SECTION_MAP_READ',0x00000004)
		win_const_mgr.add_const('DCTT_BITMAP',0x00000001)
		win_const_mgr.add_const('ACM_FORMATSUGGESTF_NCHANNELS',0x00020000)
		win_const_mgr.add_const('PORT_AUTH',0x00000071)
		win_const_mgr.add_const('MSIM_DISPID_ONNEWSESSIONMEMBER',0x00000E0C)
		win_const_mgr.add_const('CHANNEL_RC_BAD_INIT_HANDLE',0x00000009)
		win_const_mgr.add_const('PSN_FIRST',0x00000000)
		win_const_mgr.add_const('IDM_DYNSRCPLAY',0x000008DF)
		win_const_mgr.add_const('KSPROPERTY_TYPE_TOPOLOGY',0x10000000)
		win_const_mgr.add_const('OF_REOPEN',0x00008000)
		win_const_mgr.add_const('OPATH_TOK_HEXINT',0x00000067)
		win_const_mgr.add_const('ERROR_EVT_CHANNEL_CANNOT_ACTIVATE',0x00003AB1)
		win_const_mgr.add_const('SV_SECURITY_NETWARE',0x00000003)
		win_const_mgr.add_const('WIA_DIP_REMOTE_DEV_ID',0x00000009)
		win_const_mgr.add_const('SQL_BS_ROW_COUNT_PROC',0x00000008)
		win_const_mgr.add_const('URLACTION_HTML_MIXED_CONTENT',0x00001609)
		win_const_mgr.add_const('META_PAINTREGION',0x0000012B)
		win_const_mgr.add_const('PPP_CCP_ENCRYPTION40BITOLD',0x00000010)
		win_const_mgr.add_const('EMR_RESERVED_107',0x0000006B)
		win_const_mgr.add_const('EMR_RESERVED_106',0x0000006A)
		win_const_mgr.add_const('DEBUG_ATTACH_NONINVASIVE_NO_SUSPEND',0x00000004)
		win_const_mgr.add_const('PAN_XHEIGHT_DUCKING_STD',0x00000006)
		win_const_mgr.add_const('IPX_ADDRESS_NOTIFY',0x0000400C)
		win_const_mgr.add_const('ACL_REVISION_DS',0x00000004)
		win_const_mgr.add_const('ERROR_OBJECT_NOT_FOUND',0x000010D8)
		win_const_mgr.add_const('REGDF_NOTDETIRQ',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_ORS_HISTOGRAM',0x00000008)
		win_const_mgr.add_const('RESOURCEMANAGER_REGISTER_PROTOCOL',0x00000020)
		win_const_mgr.add_const('LOCALE_ICALENDARTYPE',0x00001009)
		win_const_mgr.add_const('EAP_E_USER_CERT_NOT_FOUND',0x80420100)
		win_const_mgr.add_const('SERVICETYPE_NOTRAFFIC',0x00000000)
		win_const_mgr.add_const('SUBLANG_YI_PRC',0x00000001)
		win_const_mgr.add_const('RF_UI_ONLY',0x01000000)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_PRODUCTID',0x00000202)
		win_const_mgr.add_const('IF_TYPE_GR303_RDT',0x000000B1)
		win_const_mgr.add_const('X509_ASN_ENCODING',0x00000001)
		win_const_mgr.add_const('ERROR_SEM_OWNER_DIED',0x00000069)
		win_const_mgr.add_const('DCI_STATUS_SURFACEINFOCHANGED',0x00000008)
		win_const_mgr.add_const('URLACTION_CHANNEL_SOFTDIST_PERMISSIONS',0x00001E05)
		win_const_mgr.add_const('ACM_DRIVERADDF_TYPEMASK',0x00000007)
		win_const_mgr.add_const('RPC_S_ADDRESS_ERROR',0x000006E8)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_FILTER_ATTRIBUTES',0x0000008D)
		win_const_mgr.add_const('KP_CERTIFICATE',0x0000001A)
		win_const_mgr.add_const('PIDASI_CHANNEL_COUNT',0x00000007)
		win_const_mgr.add_const('RTM_VIEW_ID_UCAST',0x00000000)
		win_const_mgr.add_const('FORCE_IMMEDIATE_REFRESH',0x00000001)
		win_const_mgr.add_const('TXFS_RM_FLAG_PRESERVE_CHANGES',0x00002000)
		win_const_mgr.add_const('SFGAO_STORAGEANCESTOR',0x00800000)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_GLOBALATOMS',0x00000020)
		win_const_mgr.add_const('WSA_E_NO_MORE',0x0000277E)
		win_const_mgr.add_const('DV_SD',0x00000000)
		win_const_mgr.add_const('DCB_ACCUMULATE',0x00000002)
		win_const_mgr.add_const('FS_USER_ABORT',0x20200000)
		win_const_mgr.add_const('PDH_CANNOT_CONNECT_MACHINE',0xC0000BC3)
		win_const_mgr.add_const('DMTT_DOWNLOAD_OUTLINE',0x00000004)
		win_const_mgr.add_const('NOTIFY_POST',0x00000002)
		win_const_mgr.add_const('DV_SL',0x00000002)
		win_const_mgr.add_const('SND_MEMORY',0x00000004)
		win_const_mgr.add_const('DISPID_IMIMEEDIT_BASE',0x00000064)
		win_const_mgr.add_const('POLICY_ERRV_UNKNOWN_USER',0x00000031)
		win_const_mgr.add_const('STATE_SYSTEM_SIZEABLE',0x00020000)
		win_const_mgr.add_const('VER_SERVICEPACKMINOR',0x00000010)
		win_const_mgr.add_const('SCRIPTPROC_HOSTMANAGESSOURCE',0x00000080)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_DAY',0x00000020)
		win_const_mgr.add_const('ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION',0x000005B3)
		win_const_mgr.add_const('D3DSP_TEXTURETYPE_SHIFT',0x0000001B)
		win_const_mgr.add_const('STRSAFE_IGNORE_NULLS',0x00000100)
		win_const_mgr.add_const('ACTRL_PERM_9',0x00000100)
		win_const_mgr.add_const('SERVICE_CONTROL_NETBINDDISABLE',0x0000000A)
		win_const_mgr.add_const('IDM_TEXTAREA',0x00000872)
		win_const_mgr.add_const('PID_REVNUMBER',0x00000009)
		win_const_mgr.add_const('LINEDISCONNECTMODE_FORWARDED',0x00000010)
		win_const_mgr.add_const('IDM_MENUEXT_COUNT',0x00000E95)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_REDIRECT',0x00004000)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_AVERAGE_PPM',0x00000015)
		win_const_mgr.add_const('INTERNET_OPTION_CALLBACK_FILTER',0x00000036)
		win_const_mgr.add_const('ICDRAW_ANIMATE',0x00000008)
		win_const_mgr.add_const('QITIPF_LINKUSETARGET',0x00000004)
		win_const_mgr.add_const('SCESTATUS_MOD_NOT_FOUND',0x0000000F)
		win_const_mgr.add_const('BZ_DISABLESWITCHTOBUTTON',0x00000002)
		win_const_mgr.add_const('EC_BUFFERING_DATA',0x00000011)
		win_const_mgr.add_const('MSGF_COMMCTRL_TOOLBARCUST',0x00004203)
		win_const_mgr.add_const('SBS_RIGHTALIGN',0x00000004)
		win_const_mgr.add_const('SQL_GD_BOUND',0x00000008)
		win_const_mgr.add_const('ERROR_DS_DUPLICATE_ID_FOUND',0x0000219D)
		win_const_mgr.add_const('ERROR_INCORRECT_ADDRESS',0x000004D9)
		win_const_mgr.add_const('SAFER_CRITERIA_IMAGEHASH',0x00000004)
		win_const_mgr.add_const('MIXERCONTROL_CT_UNITS_DECIBELS',0x00040000)
		win_const_mgr.add_const('RESTART_NO_CRASH',0x00000001)
		win_const_mgr.add_const('CM_SET_DEVNODE_PROBLEM_OVERRIDE',0x00000001)
		win_const_mgr.add_const('D3DPMISCCAPS_CLIPPLANESCALEDPOINTS',0x00000100)
		win_const_mgr.add_const('IDM_OUTDENT',0x0000088B)
		win_const_mgr.add_const('MDM_PROTOCOLID_X75',0x00000003)
		win_const_mgr.add_const('SNMP_ERROR_AUTHORIZATIONERROR',0x00000010)
		win_const_mgr.add_const('PP_CLIENT_HWND',0x00000001)
		win_const_mgr.add_const('SBM_SETPOS',0x000000E0)
		win_const_mgr.add_const('DEBUG_ATTACH_EXISTING',0x00000002)
		win_const_mgr.add_const('SHUTDOWN_POWEROFF',0x00000008)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_4BYTES',0x00300000)
		win_const_mgr.add_const('OPTION_IEN116_NAME_SERVERS',0x00000005)
		win_const_mgr.add_const('NFS_EDIT',0x00000001)
		win_const_mgr.add_const('SCHEME_EDIT',0x00000002)
		win_const_mgr.add_const('EDITF_DISABLEEXTENSIONLIST',0x00000004)
		win_const_mgr.add_const('GD_USERDEFINED',0x00000000)
		win_const_mgr.add_const('ALG_SID_3DES',0x00000003)
		win_const_mgr.add_const('MP_STATUS_RETRY',0x00000001)
		win_const_mgr.add_const('MB_ABORTRETRYIGNORE',0x00000002)
		win_const_mgr.add_const('CRED_TI_ONLY_PASSWORD_REQUIRED',0x00000004)
		win_const_mgr.add_const('IDTR_IGN0',0x00000030)
		win_const_mgr.add_const('IDS_CAP_AVI_DRAWDIB_ERROR',0x000001B7)
		win_const_mgr.add_const('BIF_EDITBOX',0x00000010)
		win_const_mgr.add_const('WINHTTP_HANDLE_TYPE_CONNECT',0x00000002)
		win_const_mgr.add_const('CBES_EX_CASESENSITIVE',0x00000010)
		win_const_mgr.add_const('WMDM_FILE_ATTR_VIDEO',0x00000040)
		win_const_mgr.add_const('SQL_NOT_DEFERRABLE',0x00000007)
		win_const_mgr.add_const('UDP_NOCHECKSUM',0x00000001)
		win_const_mgr.add_const('UNDNAME_NO_THROW_SIGNATURES',0x00000100)
		win_const_mgr.add_const('JOY_CAL_READYONLY',0x00200000)
		win_const_mgr.add_const('KSFRAMETIME_VARIABLESIZE',0x00000001)
		win_const_mgr.add_const('ERROR_UNKNOWN_COMPONENT',0x00000647)
		win_const_mgr.add_const('SQL_PC_NOT_PSEUDO',0x00000001)
		win_const_mgr.add_const('KERB_CHECKSUM_NONE',0x00000000)
		win_const_mgr.add_const('BL_SAL_INDEX',0x00000000)
		win_const_mgr.add_const('CSIDL_MYMUSIC',0x00000000)
		win_const_mgr.add_const('AM_DVD_CGMS_RESERVED_MASK',0x00000078)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_WMI',0x00000015)
		win_const_mgr.add_const('WINHTTP_ACCESS_TYPE_NO_PROXY',0x00000001)
		win_const_mgr.add_const('ERROR_DS_ATT_SCHEMA_REQ_ID',0x000020CF)
		win_const_mgr.add_const('NOTIFIER_FLAG_NEW_THREAD',0x00000001)
		win_const_mgr.add_const('LINECALLSELECT_LINE',0x00000001)
		win_const_mgr.add_const('FLAG_FORCE_CREATENAMESPACE',0x00000004)
		win_const_mgr.add_const('SECPKG_CRED_ATTR_SSI_PROVIDER',0x00000002)
		win_const_mgr.add_const('CRYPT_MESSAGE_SILENT_KEYSET_FLAG',0x00000040)
		win_const_mgr.add_const('IDM_EDITMODE',0x0000084F)
		win_const_mgr.add_const('CHANNEL_EVENT_DATA_RECEIVED',0x0000000A)
		win_const_mgr.add_const('DDENUMSURFACES_MATCH',0x00000002)
		win_const_mgr.add_const('CERT_ENCIPHER_ONLY_KEY_USAGE',0x00000001)
		win_const_mgr.add_const('WAIT_TIMEOUT',0x00000102)
		win_const_mgr.add_const('ERRCLASS_TEMPSIT',0x00000002)
		win_const_mgr.add_const('HTTP_QUERY_ALLOW',0x00000007)
		win_const_mgr.add_const('SPI_SETDRAGFULLWINDOWS',0x00000025)
		win_const_mgr.add_const('DTR_DRIVER1_INDEX',0x00000003)
		win_const_mgr.add_const('SHARD_PIDL',0x00000001)
		win_const_mgr.add_const('SFVM_BACKGROUNDENUMDONE',0x00000030)
		win_const_mgr.add_const('COLOR_LUMACCEL',0x000002D5)
		win_const_mgr.add_const('HELP_SETPOPUP_POS',0x00000000)
		win_const_mgr.add_const('MCI_DGV_OPEN_PARENT',0x00020000)
		win_const_mgr.add_const('SBS_HORZ',0x00000000)
		win_const_mgr.add_const('PFA_FULL_SCALED',0x00000006)
		win_const_mgr.add_const('NFS_STATIC',0x00000002)
		win_const_mgr.add_const('CDS_DISABLE_UNSAFE_MODES',0x00000200)
		win_const_mgr.add_const('PORT_CMIPAGENT',0x000000A4)
		win_const_mgr.add_const('MAX_MIB_OFFSET',0x00000008)
		win_const_mgr.add_const('DISPID_IWBSCRIPTCONTROL_FROZEN',0x00000005)
		win_const_mgr.add_const('PIDISF_CACHEIMAGES',0x00000010)
		win_const_mgr.add_const('TMT_SIZINGMARGINS',0x00000E11)
		win_const_mgr.add_const('CRR_MEMORY_LIMIT',0xFFFFFFFC)
		win_const_mgr.add_const('CDDS_PREERASE',0x00000003)
		win_const_mgr.add_const('HFRMREG_DEFAULT',0x00000000)
		win_const_mgr.add_const('DDFXCAPS_BLTSTRETCHXN',0x00008000)
		win_const_mgr.add_const('AUTODIAL_MODE_ALWAYS',0x00000002)
		win_const_mgr.add_const('LOGON_NOENCRYPTION',0x00000002)
		win_const_mgr.add_const('FACILITY_FVE',0x00000031)
		win_const_mgr.add_const('MD_FILTER_STATE_LOADED',0x00000001)
		win_const_mgr.add_const('CERT_STORE_ADD_NEW',0x00000001)
		win_const_mgr.add_const('WIA_DPC_EXPOSURE_METERING_MODE',0x00000824)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_RCV_ERROR',0x00000020)
		win_const_mgr.add_const('RPC_C_QOS_CAPABILITIES_IGNORE_DELEGATE_FAILURE',0x00000008)
		win_const_mgr.add_const('SEL_TEXT',0x00000001)
		win_const_mgr.add_const('KSAUDIO_STEREO_SPEAKER_GEOMETRY_NARROW',0x0000000A)
		win_const_mgr.add_const('SQL_CT_COLUMN_CONSTRAINT',0x00000200)
		win_const_mgr.add_const('IME_ENABLE_CONVERT',0x00000002)
		win_const_mgr.add_const('ACCESS_DENIED_CALLBACK_OBJECT_ACE_TYPE',0x0000000C)
		win_const_mgr.add_const('ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION',0x0000171B)
		win_const_mgr.add_const('CERT_VERIFY_ALLOW_MORE_USAGE_FLAG',0x00000008)
		win_const_mgr.add_const('DFS_VOLUME_STATE_STANDBY',0x00000020)
		win_const_mgr.add_const('SPMODE_DEBUGOUT',0x00000002)
		win_const_mgr.add_const('WIA_NUM_DIP',0x00000010)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_INVALID_BASIC_CONSTRAINTS_FLAG',0x00000008)
		win_const_mgr.add_const('SPI_SETLOWPOWERACTIVE',0x00000055)
		win_const_mgr.add_const('MAX_ISCSI_NAME_LEN',0x000000DF)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_INSTALLATION',0x00000002)
		win_const_mgr.add_const('FILE_DEVICE_DFS_VOLUME',0x00000036)
		win_const_mgr.add_const('MDM_V110_SPEED_12DOT0K',0x00000005)
		win_const_mgr.add_const('PIDVSI_STREAM_NUMBER',0x0000000B)
		win_const_mgr.add_const('SPI_GETBLOCKSENDINPUTRESETS',0x00001026)
		win_const_mgr.add_const('SEM_NOALIGNMENTFAULTEXCEPT',0x00000004)
		win_const_mgr.add_const('IDM_VERTSPACECONCATENATE',0x0000002E)
		win_const_mgr.add_const('SVSI_NOSTATECHANGE',0x80000000)
		win_const_mgr.add_const('RUSSIAN_CHARSET',0x000000CC)
		win_const_mgr.add_const('AF_HYLINK',0x0000000F)
		win_const_mgr.add_const('ERROR_DS_GC_REQUIRED',0x00002163)
		win_const_mgr.add_const('CMSG_CTRL_ADD_CRL',0x0000000C)
		win_const_mgr.add_const('BG_E_TOO_MANY_FILES_IN_JOB',0x80200051)
		win_const_mgr.add_const('MD_LOGCUSTOM_DATATYPE_LPSTR',0x00000006)
		win_const_mgr.add_const('STGM_TRANSACTED',0x00010000)
		win_const_mgr.add_const('RAS_EAP_ROLE_EXCLUDE_IN_EAP',0x00000004)
		win_const_mgr.add_const('COOKIEACTION_ACCEPT',0x00000001)
		win_const_mgr.add_const('SECBUFFER_NEGOTIATION_INFO',0x00000008)
		win_const_mgr.add_const('PP_ENUMELECTROOTS',0x0000001A)
		win_const_mgr.add_const('IDD_INSERTFILEBROWSE',0x000003F2)
		win_const_mgr.add_const('CM_DRP_DEVTYPE',0x0000001A)
		win_const_mgr.add_const('BTH_ERROR_INVALID_LMP_PARAMETERS',0x00000001)
		win_const_mgr.add_const('MD_ERROR_SUB404_REQUEST_HEADER_TOO_LONG',0x0000000A)
		win_const_mgr.add_const('HDI_IMAGE',0x00000020)
		win_const_mgr.add_const('BI_RLE8',0x00000001)
		win_const_mgr.add_const('IPX_SERVICE_FILTER_INFO_TYPE',0x00000004)
		win_const_mgr.add_const('MCI_VD_STEP_REVERSE',0x00020000)
		win_const_mgr.add_const('KEY_QUERY_VALUE',0x00000001)
		win_const_mgr.add_const('CRYPT_DECRYPT',0x00000002)
		win_const_mgr.add_const('BI_RLE4',0x00000002)
		win_const_mgr.add_const('D3DPRASTERCAPS_WBUFFER',0x00040000)
		win_const_mgr.add_const('CDRF_NEWFONT',0x00000002)
		win_const_mgr.add_const('CSIDL_COMMON_FAVORITES',0x00000001)
		win_const_mgr.add_const('SPI_GETWORKAREA',0x00000030)
		win_const_mgr.add_const('LWS_RIGHT',0x00000020)
		win_const_mgr.add_const('SERVICE_ACCEPT_STOP',0x00000001)
		win_const_mgr.add_const('IF_TYPE_TUNNEL',0x00000083)
		win_const_mgr.add_const('HDFT_ISNUMBER',0x00000001)
		win_const_mgr.add_const('SYSTEM_MANDATORY_LABEL_NO_WRITE_UP',0x00000001)
		win_const_mgr.add_const('VER_ERR_ITEM_F',0x00000200)
		win_const_mgr.add_const('OQWF_LOADQUERY',0x00000008)
		win_const_mgr.add_const('IF_TYPE_DVBRCC_MACLAYER',0x00000092)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_MYSELF',0x00000040)
		win_const_mgr.add_const('SCARD_E_UNKNOWN_CARD',0x8010000D)
		win_const_mgr.add_const('DEBUG_SERVERS_DEBUGGER',0x00000001)
		win_const_mgr.add_const('NTDSCONN_KCC_SERVER_FAILOVER_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('MDM_MASK_X75_DATA',0x00000007)
		win_const_mgr.add_const('L2CAP_PROTOCOL_UUID16',0x00000100)
		win_const_mgr.add_const('EVENT_HEADER_EXT_TYPE_RELATED_ACTIVITYID',0x00000001)
		win_const_mgr.add_const('PSP_USECALLBACK',0x00000080)
		win_const_mgr.add_const('DDPF_RGB',0x00000040)
		win_const_mgr.add_const('DISPID_IWBSCRIPTCONTROL_RAISEEVENT',0x00000001)
		win_const_mgr.add_const('AC_LINE_OFFLINE',0x00000000)
		win_const_mgr.add_const('OID_TCP_TASK_IPSEC_ADD_UDPESP_SA',0xFC010205)
		win_const_mgr.add_const('IPPORT_TTYLINK',0x00000057)
		win_const_mgr.add_const('CLR_DEFAULT',0xFF000000)
		win_const_mgr.add_const('FILE_DEVICE_DISK_FILE_SYSTEM',0x00000008)
		win_const_mgr.add_const('CLFS_SCAN_INITIALIZED',0x00000010)
		win_const_mgr.add_const('INDEX_GUID_WORDLIST',0x00000008)
		win_const_mgr.add_const('MCI_DGV_WINDOW_TEXT',0x00080000)
		win_const_mgr.add_const('RPC_IF_AUTOLISTEN',0x00000001)
		win_const_mgr.add_const('WM_WNT_CONVERTREQUESTEX',0x00000109)
		win_const_mgr.add_const('PIDSI_COMMENT',0x00000006)
		win_const_mgr.add_const('C3_KATAKANA',0x00000010)
		win_const_mgr.add_const('RECO_COPY',0x00000002)
		win_const_mgr.add_const('NORM_IGNOREKANATYPE',0x00010000)
		win_const_mgr.add_const('ERROR_SXS_XML_E_BADCHARDATA',0x000036D4)
		win_const_mgr.add_const('SMART_INVALID_FLAG',0x00000002)
		win_const_mgr.add_const('SEL_MULTICHAR',0x00000004)
		win_const_mgr.add_const('DVB_NIT_OTHER_TID',0x00000041)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_FORWARD_WMI',0x40000000)
		win_const_mgr.add_const('ERROR_WMI_INVALID_REGINFO',0x00001073)
		win_const_mgr.add_const('SQL_DB_RETURN_TO_POOL',0x00000000)
		win_const_mgr.add_const('WIA_IPS_DOCUMENT_HANDLING_SELECT',0x00000C10)
		win_const_mgr.add_const('DWN_DOWNLOADONLY',0x00000040)
		win_const_mgr.add_const('SNMP_LOG_ERROR',0x00000002)
		win_const_mgr.add_const('ISCSI_SECURITY_FLAG_TUNNEL_MODE_PREFERRED',0x00000040)
		win_const_mgr.add_const('BG_E_TOO_MANY_JOBS_PER_USER',0x80200049)
		win_const_mgr.add_const('PORT_METER',0x0000023A)
		win_const_mgr.add_const('INTERNET_OPTION_CACHE_STREAM_HANDLE',0x0000001B)
		win_const_mgr.add_const('TXTBIT_WORDWRAP',0x00000400)
		win_const_mgr.add_const('CTFMODEBIAS_READING',0x00000003)
		win_const_mgr.add_const('DISPID_PICT_HEIGHT',0x00000005)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_TRUSTEE',0x00000004)
		win_const_mgr.add_const('DMPAPER_B5_EXTRA',0x00000041)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_TM_ONLINE',0x02000000)
		win_const_mgr.add_const('USE_DEFAULT_CREDENTIALS',0x00000004)
		win_const_mgr.add_const('WSAEHOSTDOWN',0x00002750)
		win_const_mgr.add_const('RBBS_NOGRIPPER',0x00000100)
		win_const_mgr.add_const('DCI_OFFSCREEN',0x00000001)
		win_const_mgr.add_const('IDC_VP_SPIN',0x000003EE)
		win_const_mgr.add_const('IPV6_DEL_IFLIST',0x0000001E)
		win_const_mgr.add_const('MD_CPU_ENABLE_PROC_TYPE',0x00000002)
		win_const_mgr.add_const('SQL_POS_REFRESH',0x00000002)
		win_const_mgr.add_const('PORT_RRH',0x000002F1)
		win_const_mgr.add_const('D3DDTCAPS_SHORT4N',0x00000008)
		win_const_mgr.add_const('CERT_CHAIN_OPTION_DISABLE_AIA_URL_RETRIEVAL',0x00000002)
		win_const_mgr.add_const('DN_NO_SHOW_IN_DM',0x40000000)
		win_const_mgr.add_const('LB_INSERTSTRING',0x00000181)
		win_const_mgr.add_const('CB_FINDSTRING',0x0000014C)
		win_const_mgr.add_const('DBFLAGS_LOGBUFFERSHUGE',0x00000080)
		win_const_mgr.add_const('CMSG_SIGNED_AND_ENVELOPED',0x00000004)
		win_const_mgr.add_const('RPC_S_NO_PROTSEQS_REGISTERED',0x000006B2)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_ENABLE_BIDI',0x00000800)
		win_const_mgr.add_const('SPLITSYM_REMOVE_PRIVATE',0x00000001)
		win_const_mgr.add_const('SNAPSHOT_POLICY_UNPLANNED',0x00000002)
		win_const_mgr.add_const('DL_MOVECURSOR',0x00000003)
		win_const_mgr.add_const('CBS_OWNERDRAWVARIABLE',0x00000020)
		win_const_mgr.add_const('BCRYPT_DH_PRIVATE_MAGIC',0x56504844)
		win_const_mgr.add_const('MIXERLINE_COMPONENTTYPE_DST_FIRST',0x00000000)
		win_const_mgr.add_const('ERROR_FILEMARK_DETECTED',0x0000044D)
		win_const_mgr.add_const('CERT_SUBJECT_NAME_MD5_HASH_PROP_ID',0x0000001D)
		win_const_mgr.add_const('VK_MULTIPLY',0x0000006A)
		win_const_mgr.add_const('MCHT_CALENDAR',0x00020000)
		win_const_mgr.add_const('DATE_LTRREADING',0x00000010)
		win_const_mgr.add_const('IDM_SHOWMISCTAGS',0x00000910)
		win_const_mgr.add_const('COMP_ELEM_ORIGINAL_CSI',0x00001000)
		win_const_mgr.add_const('CSS_ENABLEHOOK',0x00000002)
		win_const_mgr.add_const('OID_FDDI_IF_IN_ERRORS',0x03030285)
		win_const_mgr.add_const('PORT_GACP',0x000000BE)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYARITHSTRETCHY',0x00040000)
		win_const_mgr.add_const('LOGON_WITH_PROFILE',0x00000001)
		win_const_mgr.add_const('DXVA_BITSTREAM_CONCEALMENT_METHOD_INTRA',0x00000001)
		win_const_mgr.add_const('GLEX_LINEFEED',0x00000010)
		win_const_mgr.add_const('ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE',0x0000370A)
		win_const_mgr.add_const('IDF_NOSKIP',0x00000002)
		win_const_mgr.add_const('DRM_EL_CLIENTLICENSOR_LID',0x00000100)
		win_const_mgr.add_const('IMAGE_REL_IA64_IMM14',0x00000001)
		win_const_mgr.add_const('BLLI_L3_SIO_8473',0x00000009)
		win_const_mgr.add_const('MIIM_FTYPE',0x00000100)
		win_const_mgr.add_const('SQL_INFO_FIRST',0x00000000)
		win_const_mgr.add_const('MIXERCONTROL_CT_CLASS_NUMBER',0x30000000)
		win_const_mgr.add_const('HELP_CONTEXT',0x00000001)
		win_const_mgr.add_const('LCS_CALIBRATED_RGB',0x00000000)
		win_const_mgr.add_const('D3D10_SRGB_TO_FLOAT_OFFSET',0x00000000)
		win_const_mgr.add_const('SUBLANG_KASHMIRI_SASIA',0x00000002)
		win_const_mgr.add_const('DS_REPDEL_IGNORE_ERRORS',0x00000008)
		win_const_mgr.add_const('LINECALLTREATMENT_MUSIC',0x00000004)
		win_const_mgr.add_const('OID_TAPI_GET_LINE_DEV_STATUS',0x07030114)
		win_const_mgr.add_const('TOKEN_MANDATORY_POLICY_NEW_PROCESS_MIN',0x00000002)
		win_const_mgr.add_const('SMTO_ERRORONEXIT',0x00000020)
		win_const_mgr.add_const('MAXVENDORINFO',0x00000020)
		win_const_mgr.add_const('TC_NONCONF_BORROW',0x00000000)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_MONITORING_USERS',0x0000022E)
		win_const_mgr.add_const('ASN_CONTEXT',0x00000080)
		win_const_mgr.add_const('RPC_C_QOS_CAPABILITIES_ANY_AUTHORITY',0x00000004)
		win_const_mgr.add_const('PDK3_SPI_VERSION',0x00010010)
		win_const_mgr.add_const('SV_TYPE_SERVER_VMS',0x00200000)
		win_const_mgr.add_const('TASKSTATUS_DEFERRED',0x00000004)
		win_const_mgr.add_const('IDM_EDITSOURCE',0x0000084A)
		win_const_mgr.add_const('META_CREATEPENINDIRECT',0x000002FA)
		win_const_mgr.add_const('CRYPT_SGCKEY',0x00002000)
		win_const_mgr.add_const('DNS_RCLASS_ALL',0x00000000)
		win_const_mgr.add_const('INTERNET_STATUS_RESOLVING_NAME',0x0000000A)
		win_const_mgr.add_const('MB_ERR_INVALID_CHARS',0x00000008)
		win_const_mgr.add_const('IP_TOS',0x00000003)
		win_const_mgr.add_const('NDIS_OFFLOAD_REVISION_1',0x00000001)
		win_const_mgr.add_const('IDM_BACKGROUNDIMAGECACHE',0x0000097E)
		win_const_mgr.add_const('OID_FDDI_PORT_BS_FLAG',0x03030269)
		win_const_mgr.add_const('LINEERR_INCOMPATIBLEAPIVERSION',0x8000000C)
		win_const_mgr.add_const('ERROR_DS_CANT_MOVE_APP_BASIC_GROUP',0x000021A0)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_IHV_END',0x00000000)
		win_const_mgr.add_const('CTFMODEBIAS_HIRAGANA',0x00000007)
		win_const_mgr.add_const('DEBUG_MANSTR_LOAD_STATUS',0x00000002)
		win_const_mgr.add_const('SQL_CONVERT_LONGVARBINARY',0x00000047)
		win_const_mgr.add_const('SECPKG_OPTIONS_TYPE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('ERROR_SUCCESS_REBOOT_INITIATED',0x00000669)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_DIRECTORY',0x00000020)
		win_const_mgr.add_const('SUBLANG_SPANISH_ECUADOR',0x00000000)
		win_const_mgr.add_const('SEE_MASK_FLAG_LOG_USAGE',0x04000000)
		win_const_mgr.add_const('ERROR_TOKEN_ALREADY_IN_USE',0x0000055F)
		win_const_mgr.add_const('DBPROPVAL_OO_IPERSIST',0x00000002)
		win_const_mgr.add_const('D3DSTENCILCAPS_TWOSIDED',0x00000100)
		win_const_mgr.add_const('IDC_CV_ACTIVATEAS',0x0000009C)
		win_const_mgr.add_const('IDM_TABORDER',0x00000029)
		win_const_mgr.add_const('MDPROPVAL_MF_CREATE_NAMEDSETS',0x00000008)
		win_const_mgr.add_const('ICU_ESCAPE',0x80000000)
		win_const_mgr.add_const('ERRLOG_BASE',0x00000C1C)
		win_const_mgr.add_const('SUBLANG_DUTCH_BELGIAN',0x00000002)
		win_const_mgr.add_const('OID_TAPI_MAKE_CALL',0x07030115)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_FLAG11',0x00000800)
		win_const_mgr.add_const('SQL_FN_NUM_POWER',0x00100000)
		win_const_mgr.add_const('PORT_LPD724',0x000002D4)
		win_const_mgr.add_const('MIB_IF_TYPE_SLIP',0x0000001C)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_FULL_MEMORY',0x00000001)
		win_const_mgr.add_const('DISPID_GETALWAYSSHOWLOCKSTATE',0x00000017)
		win_const_mgr.add_const('IPV6_PROTECTION_LEVEL',0x00000017)
		win_const_mgr.add_const('IRLMP_IAS_SET',0x00000011)
		win_const_mgr.add_const('TCP_MAXRT',0x00000005)
		win_const_mgr.add_const('PORT_ATECHO',0x000000CC)
		win_const_mgr.add_const('LINEERR_INVALTONELIST',0x8000003D)
		win_const_mgr.add_const('SERVICE_ADDRESS_FLAG_RPC_CN',0x00000001)
		win_const_mgr.add_const('ADS_JOB_PAPEROUT',0x00000040)
		win_const_mgr.add_const('VER_PRODUCTBUILD_QFE',0x00000000)
		win_const_mgr.add_const('DIIRFLAG_HW_USING_THE_INF',0x00000004)
		win_const_mgr.add_const('PSD_INHUNDREDTHSOFMILLIMETERS',0x00000008)
		win_const_mgr.add_const('IPPORT_FTP',0x00000015)
		win_const_mgr.add_const('DEBUG_EVENT_CHANGE_DEBUGGEE_STATE',0x00000400)
		win_const_mgr.add_const('IDM_TRISTATEBOLD',0x0000005F)
		win_const_mgr.add_const('DMPAPER_9X11',0x0000002C)
		win_const_mgr.add_const('HCN_PROTOCOL_UUID16',0x00000016)
		win_const_mgr.add_const('CBEIF_LPARAM',0x00000020)
		win_const_mgr.add_const('DBPROMPT_NOPROMPT',0x00000004)
		win_const_mgr.add_const('ST_KEEPUNDO',0x00000001)
		win_const_mgr.add_const('DEBUG_FIND_SOURCE_NO_SRCSRV',0x00000004)
		win_const_mgr.add_const('PHONEHOOKSWITCHDEV_HANDSET',0x00000001)
		win_const_mgr.add_const('GMEM_INVALID_HANDLE',0x00008000)
		win_const_mgr.add_const('BAUD_300',0x00000010)
		win_const_mgr.add_const('STARTDOC',0x0000000A)
		win_const_mgr.add_const('MAPI_LOGOFF_SHARED',0x00000001)
		win_const_mgr.add_const('MAX_FILTER_NAME',0x00000080)
		win_const_mgr.add_const('PERM_FILE_READ',0x00000001)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_MAX_CUSTOM',0x0000FFFF)
		win_const_mgr.add_const('MF_API_VERSION',0x00000070)
		win_const_mgr.add_const('OID_FDDI_MAC_T_NEG',0x03030231)
		win_const_mgr.add_const('RAS_EAP_FLAG_PREVIEW',0x00000008)
		win_const_mgr.add_const('FO_COPY',0x00000002)
		win_const_mgr.add_const('BTH_ERROR_UNSUPPORTED_REMOTE_FEATURE',0x00000001)
		win_const_mgr.add_const('CLUSCTL_FUNCTION_SHIFT',0x00000002)
		win_const_mgr.add_const('WNODE_FLAG_NO_HEADER',0x00200000)
		win_const_mgr.add_const('MCI_SET_TIME_FORMAT',0x00000400)
		win_const_mgr.add_const('LB_GETCARETINDEX',0x0000019F)
		win_const_mgr.add_const('DEBUG_MODNAME_MAPPED_IMAGE',0x00000004)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_RX_ENABLED_TX_DISABLED',0x00000003)
		win_const_mgr.add_const('WINHTTP_OPTION_PROXY_PASSWORD',0x00001003)
		win_const_mgr.add_const('IDM_MULTIPLESELECTION',0x00000959)
		win_const_mgr.add_const('MDPROPVAL_MS_SINGLETUPLE',0x00000002)
		win_const_mgr.add_const('NCBSEND',0x00000014)
		win_const_mgr.add_const('COPYFLG_WARN_IF_SKIP',0x00000001)
		win_const_mgr.add_const('WM_CHILDACTIVATE',0x00000022)
		win_const_mgr.add_const('GPO_INFO_FLAG_MACHINE',0x00000001)
		win_const_mgr.add_const('ADS_PRINTER_OFFLINE',0x00000008)
		win_const_mgr.add_const('SPOST_URL',0x00000002)
		win_const_mgr.add_const('OID_ATM_PARTY_ALERTING',0x0801020D)
		win_const_mgr.add_const('HH_RESERVED2',0x0000000B)
		win_const_mgr.add_const('DRV_ENABLE',0x00000002)
		win_const_mgr.add_const('LINEDISCONNECTMODE_NUMBERCHANGED',0x00002000)
		win_const_mgr.add_const('ERROR_DS_INSTALL_NO_SRC_SCH_VERSION',0x0000213F)
		win_const_mgr.add_const('RDW_INTERNALPAINT',0x00000002)
		win_const_mgr.add_const('PROTO_IP_DNS_PROXY',0x00002713)
		win_const_mgr.add_const('LPM_OK',0x00000000)
		win_const_mgr.add_const('MM_SNDBLST_SYNTH',0x00000005)
		win_const_mgr.add_const('FACILITY_GRAPHICS',0x00000026)
		win_const_mgr.add_const('POLICY_LOCATOR_SUB_TYPE_ASCII_DN',0x00000001)
		win_const_mgr.add_const('IDM_CREATESHORTCUT',0x000008DA)
		win_const_mgr.add_const('CRYPT_USER_DEFAULT',0x00000002)
		win_const_mgr.add_const('GESTURE_CIRCLE_LINE_HORZ',0x00000000)
		win_const_mgr.add_const('UINT_PTR_ERROR',0x00000000)
		win_const_mgr.add_const('VOS_WINCE',0x00050000)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2_WRITESECTION',0x00000200)
		win_const_mgr.add_const('TRACE_ON',0x00000001)
		win_const_mgr.add_const('MCI_DEVTYPE_OVERLAY',0x00000203)
		win_const_mgr.add_const('CM_PROB_TOO_EARLY',0x0000001A)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NEGOTIATION_DISABLED',0x0000363B)
		win_const_mgr.add_const('OPATH_TOK_IDENT',0x00000064)
		win_const_mgr.add_const('DFM_MERGECONTEXTMENU_BOTTOM',0x00000011)
		win_const_mgr.add_const('FILE_DEVICE_BATTERY',0x00000029)
		win_const_mgr.add_const('DBPROPVAL_NC_HIGH',0x00000002)
		win_const_mgr.add_const('LMEM_INVALID_HANDLE',0x00008000)
		win_const_mgr.add_const('SQL_SR_UPDATE_TABLE',0x00002000)
		win_const_mgr.add_const('SQL_UNBIND',0x00000002)
		win_const_mgr.add_const('IDM_ALIGNTOP',0x00000006)
		win_const_mgr.add_const('DB_BINDFLAGS_COLLECTION',0x00000010)
		win_const_mgr.add_const('REO_DYNAMICSIZE',0x00000008)
		win_const_mgr.add_const('LINECONNECTEDMODE_ACTIVE',0x00000001)
		win_const_mgr.add_const('TTFCFP_UNICODE_PLATFORMID',0x00000000)
		win_const_mgr.add_const('EFFECTMODE_STANDARD',0x00000001)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_4096BYTES',0x00D00000)
		win_const_mgr.add_const('INTERNET_REQFLAG_ASYNC',0x00000002)
		win_const_mgr.add_const('CRYPT_NOT_MODIFIED_RETRIEVAL',0x00400000)
		win_const_mgr.add_const('CRYPTDLG_REVOCATION_NONE',0x20000000)
		win_const_mgr.add_const('DEVPROP_TYPEMOD_ARRAY',0x00001000)
		win_const_mgr.add_const('MIN_IDD_DYNAWIZ_RESOURCE_ID',0x00002710)
		win_const_mgr.add_const('SMART_EXTENDED_SELFTEST_CAPTIVE',0x00000082)
		win_const_mgr.add_const('FWP_OPTION_VALUE_ALLOW_GLOBAL_MULTICAST_STATE',0x00000002)
		win_const_mgr.add_const('DOSOPTGF_DEFCLEAN',0x00000001)
		win_const_mgr.add_const('IDM_TRIED_DELETE',0x00000020)
		win_const_mgr.add_const('TF_RP_HIDDENINSETTINGUI',0x00000002)
		win_const_mgr.add_const('DXVA_BITSTREAM_DATA_BUFFER',0x00000007)
		win_const_mgr.add_const('ROT_COMPARE_MAX',0x00000800)
		win_const_mgr.add_const('LBN_SELCHANGE',0x00000001)
		win_const_mgr.add_const('CMSG_ENCODED_SIGNER',0x0000001C)
		win_const_mgr.add_const('SUBLANG_INUKTITUT_CANADA',0x00000001)
		win_const_mgr.add_const('ERROR_SERVICE_START_HANG',0x0000042E)
		win_const_mgr.add_const('CREDENTIAL_SUB_TYPE_UNICODE_ID',0x00000002)
		win_const_mgr.add_const('OPTION_TTL',0x00000025)
		win_const_mgr.add_const('BN_PAINT',0x00000001)
		win_const_mgr.add_const('ERROR_NO_SITENAME',0x0000077F)
		win_const_mgr.add_const('USN_REASON_SECURITY_CHANGE',0x00000800)
		win_const_mgr.add_const('WST_TVTUNER_CHANGE_BEGIN_TUNE',0x00001000)
		win_const_mgr.add_const('DS_REPSYNC_ALL_SOURCES',0x00000010)
		win_const_mgr.add_const('SMC_SFDDRESTRICTED',0x00000030)
		win_const_mgr.add_const('PROFILE_READ',0x00000001)
		win_const_mgr.add_const('DBMAXCHAR',0x00001F40)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATAEVENTARGS_ELAPSEDTIME',0x00000300)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_ASSOCIATION_RESPONSE_END',0x00000003)
		win_const_mgr.add_const('CSF_VALIDSOURCE',0x00000002)
		win_const_mgr.add_const('DF_TRACELESS',0x40000000)
		win_const_mgr.add_const('RBN_FIRST',0x00000000)
		win_const_mgr.add_const('DEBUG_DUMP_DEFAULT',0x00000401)
		win_const_mgr.add_const('LINEGROUPSTATUS_GROUPREMOVED',0x00000002)
		win_const_mgr.add_const('MAXUIDLEN',0x00000040)
		win_const_mgr.add_const('ETW_REDUCED_STRING_TYPE_VALUE',0x00000072)
		win_const_mgr.add_const('WIA_PAGE_JIS_B8',0x0000002F)
		win_const_mgr.add_const('IMGDECODE_EVENT_BEGINBITS',0x00000004)
		win_const_mgr.add_const('CHANGER_VOLUME_SEARCH',0x00200000)
		win_const_mgr.add_const('IT_STATUS_TRANSFER_FROM_DEVICE',0x00000001)
		win_const_mgr.add_const('KS_VBIDATARATE_NABTS',0x00576428)
		win_const_mgr.add_const('APPCOMMAND_SAVE',0x00000020)
		win_const_mgr.add_const('WSAETOOMANYREFS',0x0000274B)
		win_const_mgr.add_const('KSWAVE_COMPATCAPS_INPUT',0x00000000)
		win_const_mgr.add_const('D3D10_SHADER_NO_PRESHADER',0x00000001)
		win_const_mgr.add_const('ACCESS_MIN_MS_ACE_TYPE',0x00000000)
		win_const_mgr.add_const('CFM_FACE',0x20000000)
		win_const_mgr.add_const('RPC_S_NAME_SERVICE_UNAVAILABLE',0x000006E2)
		win_const_mgr.add_const('DDSD_LINEARSIZE',0x00080000)
		win_const_mgr.add_const('DSBS_CHECKED',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_IDLE_STATE',0x00000033)
		win_const_mgr.add_const('AI_ADDRCONFIG',0x00000400)
		win_const_mgr.add_const('APPCOMMAND_MIC_ON_OFF_TOGGLE',0x0000002C)
		win_const_mgr.add_const('AUDIO_MAX_CHANNELS',0x00001000)
		win_const_mgr.add_const('SQL_BIND_BY_COLUMN',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_OP_EQUAL',0x00000001)
		win_const_mgr.add_const('TTFCFP_DONT_CARE',0x0000FFFF)
		win_const_mgr.add_const('WLX_SAS_TYPE_USER_LOGOFF',0x00000004)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_STATIONSPEED',0x0000002A)
		win_const_mgr.add_const('JOB_EXEC_ERROR',0x00000002)
		win_const_mgr.add_const('SP_PROT_TLS1_CLIENT',0x00000080)
		win_const_mgr.add_const('FAX_ERR_DEVICE_NUM_LIMIT_EXCEEDED',0x00001B62)
		win_const_mgr.add_const('GOPHER_TYPE_TEXT_FILE',0x00000001)
		win_const_mgr.add_const('FACILITY_WINDOWS_DEFENDER',0x00000050)
		win_const_mgr.add_const('DNS_ERROR_CNAME_COLLISION',0x000025ED)
		win_const_mgr.add_const('MB_HELP',0x00004000)
		win_const_mgr.add_const('INTERNET_STATUS_RECEIVING_RESPONSE',0x00000028)
		win_const_mgr.add_const('WM_KEYLAST',0x00000108)
		win_const_mgr.add_const('ERROR_BAD_THREADID_ADDR',0x0000009F)
		win_const_mgr.add_const('CMSG_HASHED',0x00000005)
		win_const_mgr.add_const('DDFXCAPS_BLTSTRETCHY',0x00010000)
		win_const_mgr.add_const('DDFXCAPS_BLTSTRETCHX',0x00004000)
		win_const_mgr.add_const('TKF_INDICATOR',0x00000020)
		win_const_mgr.add_const('FWPM_NET_EVENT_IKEEXT_EM_FAILURE_FLAG_MULTIPLE',0x00000001)
		win_const_mgr.add_const('SUBLANG_SYRIAC_SYRIA',0x00000001)
		win_const_mgr.add_const('FILE_READ_ACCESS',0x00000001)
		win_const_mgr.add_const('SCESTATUS_TRUST_FAIL',0x00000013)
		win_const_mgr.add_const('IKEEXT_NTLM_V2_AUTH_DONT_ACCEPT_EXPLICIT_CREDENTIALS',0x00000001)
		win_const_mgr.add_const('PKCS12_INCLUDE_EXTENDED_PROPERTIES',0x00000010)
		win_const_mgr.add_const('MCI_STEP',0x0000080E)
		win_const_mgr.add_const('DSBF_STATE',0x00000001)
		win_const_mgr.add_const('TMT_FLATMENUS',0x000003E9)
		win_const_mgr.add_const('TCIF_IMAGE',0x00000002)
		win_const_mgr.add_const('WIA_PAGE_ISO_C10',0x00000026)
		win_const_mgr.add_const('CERT_STORE_ENUM_ARCHIVED_FLAG',0x00000200)
		win_const_mgr.add_const('TCIS_HIGHLIGHTED',0x00000002)
		win_const_mgr.add_const('VMRBITMAP_ENTIREDDS',0x00000004)
		win_const_mgr.add_const('MNGO_NOINTERFACE',0x00000000)
		win_const_mgr.add_const('VCAPS_CAN_SCALE',0x00000008)
		win_const_mgr.add_const('RTM_CHANGE_TYPE_FORWARDING',0x00000004)
		win_const_mgr.add_const('CSIDL_STARTMENU',0x00000000)
		win_const_mgr.add_const('PDH_FMT_LONG',0x00000100)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGKCBDELETE',0x00000017)
		win_const_mgr.add_const('FLG_ADDPROPERTY_NOCLOBBER',0x00000001)
		win_const_mgr.add_const('SQL_SRJO_CORRESPONDING_CLAUSE',0x00000001)
		win_const_mgr.add_const('DEBUG_CES_EXPRESSION_SYNTAX',0x00002000)
		win_const_mgr.add_const('SQL_CB_CLOSE',0x00000001)
		win_const_mgr.add_const('RTM_MAX_VIEWS',0x00000020)
		win_const_mgr.add_const('OPTION_CLIENT_ID',0x0000003D)
		win_const_mgr.add_const('CSBACKUP_TYPE_MASK',0x00000003)
		win_const_mgr.add_const('PXE_PROV_ATTR_FILTER',0x00000000)
		win_const_mgr.add_const('IDM_TRIED_REMOVEFORMAT',0x00000035)
		win_const_mgr.add_const('PROGDLG_MARQUEEPROGRESS',0x00000020)
		win_const_mgr.add_const('ERROR_VIOKBD_REQUEST',0x00000074)
		win_const_mgr.add_const('CHANNEL_OPTION_INITIALIZED',0x80000000)
		win_const_mgr.add_const('CERT_STORE_SAVE_AS_STORE',0x00000001)
		win_const_mgr.add_const('SECPKG_CONTEXT_EXPORT_TO_KERNEL',0x00000004)
		win_const_mgr.add_const('SQL_MAX_IDENTIFIER_LEN',0x00002715)
		win_const_mgr.add_const('VK_OEM_BACKTAB',0x000000F5)
		win_const_mgr.add_const('MCI_DEVTYPE_DIGITAL_VIDEO',0x00000208)
		win_const_mgr.add_const('MCM_FIRST',0x00001000)
		win_const_mgr.add_const('ACTCTX_FLAG_ASSEMBLY_DIRECTORY_VALID',0x00000004)
		win_const_mgr.add_const('CM_DRP_MIN',0x00000001)
		win_const_mgr.add_const('SHACF_AUTOAPPEND_FORCE_ON',0x40000000)
		win_const_mgr.add_const('MCAST_BLOCK_SOURCE',0x0000002B)
		win_const_mgr.add_const('CACHE_CONFIG_QUOTA_FC',0x00000800)
		win_const_mgr.add_const('GESTURE_PARAGRAPH',0x00000000)
		win_const_mgr.add_const('ET_ATTRIBUTES',0x00002000)
		win_const_mgr.add_const('IF_TYPE_ATM_VIRTUAL',0x00000095)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_PROMISCUOUS_MGMT',0x00200000)
		win_const_mgr.add_const('STDINDEXSIZE',0x00004000)
		win_const_mgr.add_const('OID_CO_TAPI_REPORT_DIGITS',0xFE001008)
		win_const_mgr.add_const('SNMP_PDUAPI_INVALID_ES',0x00000015)
		win_const_mgr.add_const('SUBLANG_MAPUDUNGUN_CHILE',0x00000001)
		win_const_mgr.add_const('LANG_HUNGARIAN',0x00000000)
		win_const_mgr.add_const('CONVERT10_E_LAST',0x800401CF)
		win_const_mgr.add_const('CDIS_DROPHILITED',0x00001000)
		win_const_mgr.add_const('FLG_ADDPROPERTY_AND',0x00000010)
		win_const_mgr.add_const('PST_PC_PCMCIA',0x00000008)
		win_const_mgr.add_const('INHERITED_GRANDPARENT',0x20000000)
		win_const_mgr.add_const('ERROR_LOG_EPHEMERAL',0x000019EA)
		win_const_mgr.add_const('V86FLAGS_INTERRUPT',0x00000200)
		win_const_mgr.add_const('MCI_DGV_METHOD_PRE',0x00000000)
		win_const_mgr.add_const('WSA_QOS_BAD_STYLE',0x00002B04)
		win_const_mgr.add_const('EMR_EOF',0x0000000E)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_NSI_COMPARTMENT_RW_STRUCT',0x000000AD)
		win_const_mgr.add_const('SQL_CVT_WLONGVARCHAR',0x00400000)
		win_const_mgr.add_const('WIA_USE_SEGMENTATION_FILTER',0x00000000)
		win_const_mgr.add_const('TRACE_HEADER_FLAG_TRACED_GUID',0x00020000)
		win_const_mgr.add_const('IDM_ENDUSERACTION',0x00000981)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_HISTORY',0x00000002)
		win_const_mgr.add_const('DEBUG_STACK_FRAME_ADDRESSES_RA_ONLY',0x00000100)
		win_const_mgr.add_const('WM_IME_REQUEST',0x00000288)
		win_const_mgr.add_const('OID_GEN_MEDIA_DUPLEX_STATE',0x0001028C)
		win_const_mgr.add_const('IME_CMODE_NOCONVERSION',0x00000100)
		win_const_mgr.add_const('OFN_SHAREAWARE',0x00004000)
		win_const_mgr.add_const('SQL_FN_STR_BIT_LENGTH',0x00080000)
		win_const_mgr.add_const('LBS_SORT',0x00000002)
		win_const_mgr.add_const('DISPID_XOBJ_MAX',0x0001FFFF)
		win_const_mgr.add_const('OID_GEN_DIRECTED_BYTES_RCV',0x00020207)
		win_const_mgr.add_const('TASK_FOURTH_WEEK',0x00000004)
		win_const_mgr.add_const('FOF_NOERRORUI',0x00000400)
		win_const_mgr.add_const('RPC_S_ZERO_DIVIDE',0x000006E7)
		win_const_mgr.add_const('SI_TEMPORARY',0x80000000)
		win_const_mgr.add_const('KS_DVD_CGMS_NO_COPY',0x00000018)
		win_const_mgr.add_const('ISMEX_REPLIED',0x00000008)
		win_const_mgr.add_const('DBPROPVAL_LM_INTENT',0x00000004)
		win_const_mgr.add_const('D3DUSAGE_TEXTAPI',0x10000000)
		win_const_mgr.add_const('MDM_PROTOCOLID_ANALOG',0x00000007)
		win_const_mgr.add_const('IF_TYPE_PROP_DOCS_WIRELESS_DOWNSTREAM',0x000000B5)
		win_const_mgr.add_const('DNS_TYPE_MF',0x00000004)
		win_const_mgr.add_const('D3DPCMPCAPS_NOTEQUAL',0x00000020)
		win_const_mgr.add_const('HTTP_ADDREQ_FLAG_COALESCE_WITH_COMMA',0x40000000)
		win_const_mgr.add_const('KSDATAFORMAT_BIT_ATTRIBUTES',0x00000001)
		win_const_mgr.add_const('D3DPS20_MIN_DYNAMICFLOWCONTROLDEPTH',0x00000000)
		win_const_mgr.add_const('URLPOLICY_CREDENTIALS_CONDITIONAL_PROMPT',0x00020000)
		win_const_mgr.add_const('FR_MATCHKASHIDA',0x40000000)
		win_const_mgr.add_const('HTTP_QUERY_AGE',0x00000030)
		win_const_mgr.add_const('KSPIN_FLAG_FIXED_FORMAT',0x00100000)
		win_const_mgr.add_const('EAP_CREDENTIAL_VERSION',0x00000001)
		win_const_mgr.add_const('IPX_RERIPNETNUMBER',0x0000400E)
		win_const_mgr.add_const('MDFF_STRIKEOUT',0x00000008)
		win_const_mgr.add_const('DBPROPVAL_CU_DML_STATEMENTS',0x00000001)
		win_const_mgr.add_const('CDRF_NOTIFYSUBITEMDRAW',0x00000020)
		win_const_mgr.add_const('SQL_DIAG_SQLSTATE',0x00000004)
		win_const_mgr.add_const('RATING_UNRATED_MIN',0x00000000)
		win_const_mgr.add_const('PAGEMASK_4MB',0x00000003)
		win_const_mgr.add_const('EDITED_CACHE_ENTRY',0x00000008)
		win_const_mgr.add_const('STD_REPLACE',0x0000000D)
		win_const_mgr.add_const('CERT_REGISTRY_STORE_MY_IE_DIRTY_FLAG',0x00080000)
		win_const_mgr.add_const('ERROR_INVALID_BLOCK_LENGTH',0x00000452)
		win_const_mgr.add_const('PFD_DRAW_TO_BITMAP',0x00000008)
		win_const_mgr.add_const('CAUSE_UNALLOCATED_NUMBER',0x00000001)
		win_const_mgr.add_const('MD_WARNING_DUP_NAME',0x000CC804)
		win_const_mgr.add_const('SQL_OU_DML_STATEMENTS',0x00000001)
		win_const_mgr.add_const('DFS_PROPERTY_FLAG_CLUSTER_ENABLED',0x00000010)
		win_const_mgr.add_const('SQL_DESC_ARRAY_STATUS_PTR',0x00000015)
		win_const_mgr.add_const('DXVA_SLICE_CONTROL_BUFFER',0x00000006)
		win_const_mgr.add_const('LUP_CONTAINERS',0x00000002)
		win_const_mgr.add_const('TXFS_RM_FLAG_LOG_NO_CONTAINER_COUNT_MIN',0x00000100)
		win_const_mgr.add_const('SQL_OJ_NESTED',0x00000008)
		win_const_mgr.add_const('BL_128M',0x08000000)
		win_const_mgr.add_const('DS_REPSYNC_USE_COMPRESSION',0x00004000)
		win_const_mgr.add_const('OID_TAPI_GET_CALL_ADDRESS_ID',0x0703010D)
		win_const_mgr.add_const('CDIS_GRAYED',0x00000002)
		win_const_mgr.add_const('DISPID_QUIT',0x00000067)
		win_const_mgr.add_const('LINETOLLLISTOPTION_REMOVE',0x00000002)
		win_const_mgr.add_const('SERVICE_WIN32_OWN_PROCESS',0x00000010)
		win_const_mgr.add_const('SM_FOCUS_TYPE_NT_DOMAIN',0x00000001)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_REQUEST_ERROR',0x00200000)
		win_const_mgr.add_const('PORT_WPGS',0x0000030C)
		win_const_mgr.add_const('TVS_NONEVENHEIGHT',0x00004000)
		win_const_mgr.add_const('SQL_MAX_COLUMNS_IN_TABLE',0x00000065)
		win_const_mgr.add_const('DLCTL_NOFRAMES',0x00080000)
		win_const_mgr.add_const('CMSG_LENGTH_ONLY_FLAG',0x00000002)
		win_const_mgr.add_const('SQL_ATTR_CONNECTION_DEAD',0x000004B9)
		win_const_mgr.add_const('DI_DIDCOMPAT',0x00000010)
		win_const_mgr.add_const('RTCTR_TLS',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_TR_ABORT_DC',0x00000008)
		win_const_mgr.add_const('VK_XBUTTON1',0x00000005)
		win_const_mgr.add_const('SUBLANG_SINDHI_PAKISTAN',0x00000002)
		win_const_mgr.add_const('PBT_APMSTANDBY',0x00000005)
		win_const_mgr.add_const('SMC_GETINFO',0x00000005)
		win_const_mgr.add_const('SCARD_UNKNOWN',0x00000000)
		win_const_mgr.add_const('ATE_MASK0',0x00000621)
		win_const_mgr.add_const('ERROR_INVALID_HW_PROFILE',0x0000026B)
		win_const_mgr.add_const('FWPM_NET_EVENT_FLAG_USER_ID_SET',0x00000040)
		win_const_mgr.add_const('WIA_DPS_GLOBAL_IDENTITY',0x00000C2B)
		win_const_mgr.add_const('SRRF_RT_REG_NONE',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_DWORD_VALUE_TOO_SMALL',0x0000255E)
		win_const_mgr.add_const('IDTB_TOC_NEXT',0x000000DF)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_MSGWAITON',0x00000008)
		win_const_mgr.add_const('PORT_HMMP_OPERATION',0x00000265)
		win_const_mgr.add_const('TF_LBI_STATUS_HIDDEN',0x00000001)
		win_const_mgr.add_const('SECURITY_REMOTE_LOGON_RID',0x0000000E)
		win_const_mgr.add_const('SETABORTPROC',0x00000009)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_FILE_REQUEST',0x0000000E)
		win_const_mgr.add_const('SCARD_ATR_LENGTH',0x00000021)
		win_const_mgr.add_const('CR_BUFFER_SMALL',0x0000001A)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_CANCELLED',0x00000005)
		win_const_mgr.add_const('DDCKEYCAPS_DESTOVERLAY',0x00000010)
		win_const_mgr.add_const('JOB_OBJECT_MSG_ACTIVE_PROCESS_ZERO',0x00000004)
		win_const_mgr.add_const('DS_REPL_NBR_WRITEABLE',0x00000010)
		win_const_mgr.add_const('IDM_SAVEPRETRANSFORMSOURCE',0x00000942)
		win_const_mgr.add_const('MCS_NOSELCHANGEONNAV',0x00000100)
		win_const_mgr.add_const('DEBUG_FILTER_LOAD_MODULE',0x00000004)
		win_const_mgr.add_const('SDP_ATTRIB_SERVICE_VERSION',0x00000300)
		win_const_mgr.add_const('WMDRM_QUERY_CLIENT_INDIVSTATUS',0x00000008)
		win_const_mgr.add_const('SFGAO_SHARE',0x00020000)
		win_const_mgr.add_const('CMIC_MASK_CONTROL_DOWN',0x40000000)
		win_const_mgr.add_const('PDTIMER_RESUME',0x00000003)
		win_const_mgr.add_const('ERROR_DS_USER_BUFFER_TO_SMALL',0x00002075)
		win_const_mgr.add_const('NT_CONSOLE_PROPS_SIG',0xA0000002)
		win_const_mgr.add_const('ERROR_DOMAIN_CTRLR_CONFIG_ERROR',0x00000245)
		win_const_mgr.add_const('OFFLINEAVAILABILITY_NOT_AVAILABLE',0x00000000)
		win_const_mgr.add_const('SDP_DEFAULT_INQUIRY_MAX_RESPONSES',0x000000FF)
		win_const_mgr.add_const('BCRYPT_ECDSA_PUBLIC_P256_MAGIC',0x31534345)
		win_const_mgr.add_const('SCH_CRED_AUTO_CRED_VALIDATION',0x00000020)
		win_const_mgr.add_const('WINEVENT_INCONTEXT',0x00000004)
		win_const_mgr.add_const('SNMPAPI_SESSION_INVALID',0x0000000D)
		win_const_mgr.add_const('ERROR_SETMARK_DETECTED',0x0000044F)
		win_const_mgr.add_const('CF_PRIVATEFIRST',0x00000200)
		win_const_mgr.add_const('ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION',0x000032DB)
		win_const_mgr.add_const('MAX_REASON_BUGID_LEN',0x00000020)
		win_const_mgr.add_const('TMMIGRATE',0x00100000)
		win_const_mgr.add_const('IMAGE_SCN_MEM_NOT_PAGED',0x08000000)
		win_const_mgr.add_const('RPC_QUERY_CLIENT_PRINCIPAL_NAME',0x00000004)
		win_const_mgr.add_const('TXTLOG_INFDB',0x00000400)
		win_const_mgr.add_const('ISR_NAT_REG',0x00000001)
		win_const_mgr.add_const('SQL_DRIVER_HLIB',0x0000004C)
		win_const_mgr.add_const('SQL_AF_MIN',0x00000008)
		win_const_mgr.add_const('GESTURE_LETTER_V',0x00000000)
		win_const_mgr.add_const('CHANGER_PREMOUNT_EJECT_REQUIRED',0x00080000)
		win_const_mgr.add_const('OID_FDDI_LONG_MULTICAST_LIST',0x03010103)
		win_const_mgr.add_const('DPNHQUERYADDRESS_CACHENOTFOUND',0x00000004)
		win_const_mgr.add_const('SP_COPY_REPLACEONLY',0x00000002)
		win_const_mgr.add_const('ARW_HIDE',0x00000008)
		win_const_mgr.add_const('VIF_CANNOTREADSRC',0x00010000)
		win_const_mgr.add_const('PSP_USEREFPARENT',0x00000040)
		win_const_mgr.add_const('CERT_INFO_SERIAL_NUMBER_FLAG',0x00000002)
		win_const_mgr.add_const('RBBS_HIDDEN',0x00000008)
		win_const_mgr.add_const('WIA_DEVICE_COMMANDS',0x00000001)
		win_const_mgr.add_const('INTERNET_DEFAULT_HTTPS_PORT',0x000001BB)
		win_const_mgr.add_const('ILD_BLEND25',0x00000002)
		win_const_mgr.add_const('COMPRESSION_FORMAT_LZNT1',0x00000002)
		win_const_mgr.add_const('TASKSTATUS_NOTSTARTED',0x00000000)
		win_const_mgr.add_const('MCI_TEST',0x00000020)
		win_const_mgr.add_const('D3D10_FLOAT_TO_SRGB_SCALE_2',0x00000001)
		win_const_mgr.add_const('NCBCHAINSEND',0x00000017)
		win_const_mgr.add_const('MQMSG_ACKNOWLEDGMENT_NONE',0x00000000)
		win_const_mgr.add_const('NOM_BS5',0x00000020)
		win_const_mgr.add_const('NOM_BS4',0x00000010)
		win_const_mgr.add_const('NOM_BS3',0x00000008)
		win_const_mgr.add_const('NOM_BS2',0x00000004)
		win_const_mgr.add_const('SERVICE_CTRL_REDIR_COMM',0x00000004)
		win_const_mgr.add_const('NOM_BS0',0x00000001)
		win_const_mgr.add_const('DNS_TYPE_MR',0x00000009)
		win_const_mgr.add_const('LINEERR_INIFILECORRUPT',0x8000000E)
		win_const_mgr.add_const('MD_ERROR_SUB500_UNC_ACCESS',0x00000010)
		win_const_mgr.add_const('SQL_SERVER_NAME',0x0000000D)
		win_const_mgr.add_const('MCI_VCR_SETTUNER_CHANNEL_SEEK_DOWN',0x00100000)
		win_const_mgr.add_const('IITWBC_EXTDATA_CHARTABLE',0x00000000)
		win_const_mgr.add_const('ALG_SID_DSS_DMS',0x00000002)
		win_const_mgr.add_const('DM_DEFAULTSOURCE',0x00000200)
		win_const_mgr.add_const('CTRY_POLAND',0x00000030)
		win_const_mgr.add_const('CDIS_MARKED',0x00000080)
		win_const_mgr.add_const('VECTOR_RANK_DICE',0x00000003)
		win_const_mgr.add_const('CERT_STORE_PROV_DELETE_CRL_FUNC',0x00000007)
		win_const_mgr.add_const('DI_FLAGSEX_PREINSTALLBACKUP',0x00080000)
		win_const_mgr.add_const('INTERNET_SCHEME_HTTPS',0x00000002)
		win_const_mgr.add_const('NETERR_RING_STOP_CAPTURE',0x00008E00)
		win_const_mgr.add_const('INTERNET_CACHE_CONTAINER_NODESKTOPINIT',0x00000008)
		win_const_mgr.add_const('ERROR_DRIVER_CANCEL_TIMEOUT',0x00000252)
		win_const_mgr.add_const('IME_CMODE_ALPHANUMERIC',0x00000000)
		win_const_mgr.add_const('DDCAPS2_COPYFOURCC',0x00008000)
		win_const_mgr.add_const('GESTURE_LETTER_B',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_IMAGE_LOAD',0x00000004)
		win_const_mgr.add_const('CR_DEVLOADER_NOT_READY',0x00000021)
		win_const_mgr.add_const('ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED',0x000013D9)
		win_const_mgr.add_const('HTTP_QUERY_DATE',0x00000009)
		win_const_mgr.add_const('ISC_REQ_DELEGATE',0x00000001)
		win_const_mgr.add_const('RPC_NCA_FLAGS_IDEMPOTENT',0x00000001)
		win_const_mgr.add_const('SQL_COLUMN_NAME',0x00000001)
		win_const_mgr.add_const('LOCALE_SSHORTDATE',0x0000001F)
		win_const_mgr.add_const('TRUSTERROR_STEP_MSG_SIGNERCOUNT',0x00000009)
		win_const_mgr.add_const('SQL_PRED_CHAR',0x00000001)
		win_const_mgr.add_const('SQL_SOPT_SS_BASE',0x000004C9)
		win_const_mgr.add_const('IDM_SETDESKTOPITEM',0x000008E6)
		win_const_mgr.add_const('FRS_ERR_STARTING_SERVICE',0x00001F42)
		win_const_mgr.add_const('ALG_SID_DES',0x00000001)
		win_const_mgr.add_const('D3DPMISCCAPS_MASKZ',0x00000002)
		win_const_mgr.add_const('RESTORE_TYPE_AUTHORATATIVE',0x00000001)
		win_const_mgr.add_const('NTDSCONN_KCC_GC_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('SCESTATUS_CANT_DELETE',0x0000000A)
		win_const_mgr.add_const('SW_SMOOTHSCROLL',0x00000010)
		win_const_mgr.add_const('DDSCAPS3_READONLYRESOURCE',0x00004000)
		win_const_mgr.add_const('PP_KEYSET_SEC_DESCR',0x00000008)
		win_const_mgr.add_const('URLHISTORY_CACHE_ENTRY',0x00200000)
		win_const_mgr.add_const('ICDRAW_UPDATING',0x00000040)
		win_const_mgr.add_const('SNMP_BERAPI_INVALID_OBJELEM',0x0000000E)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_DOWNLEVEL_JOINED_DOMAIN',0x00000004)
		win_const_mgr.add_const('MK_E_FIRST',0x800401E0)
		win_const_mgr.add_const('FOF_NORECURSEREPARSE',0x00008000)
		win_const_mgr.add_const('ACM_METRIC_COUNT_LOCAL_FILTERS',0x00000017)
		win_const_mgr.add_const('TAPE_DRIVE_GET_ABSOLUTE_BLK',0x00100000)
		win_const_mgr.add_const('LDAP_OPT_REBIND_ARG',0x00000007)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_UNION',0x00000009)
		win_const_mgr.add_const('SQL_DESC_OCTET_LENGTH_PTR',0x000003EC)
		win_const_mgr.add_const('GESTURE_LETTER_L',0x00000000)
		win_const_mgr.add_const('SQL_FN_STR_RTRIM',0x00000400)
		win_const_mgr.add_const('BST_UNCHECKED',0x00000000)
		win_const_mgr.add_const('GESTURE_DOUBLE_DOWN',0x00000000)
		win_const_mgr.add_const('SQL_API_SQLGETDESCREC',0x000003F1)
		win_const_mgr.add_const('LVS_SHAREIMAGELISTS',0x00000040)
		win_const_mgr.add_const('GS_LOOKASIDE_INFO',0x00000004)
		win_const_mgr.add_const('WM_CHANGECBCHAIN',0x0000030D)
		win_const_mgr.add_const('ISCSI_LOGIN_OPTIONS_VERSION',0x00000000)
		win_const_mgr.add_const('WSAEWOULDBLOCK',0x00002733)
		win_const_mgr.add_const('PRINTACTION_DOCUMENTDEFAULTS',0x00000006)
		win_const_mgr.add_const('SQL_CV_LOCAL',0x00000008)
		win_const_mgr.add_const('OID_WAN_CO_GET_LINK_INFO',0x04010182)
		win_const_mgr.add_const('IT_TYPICAL',0x00000001)
		win_const_mgr.add_const('EM_CANUNDO',0x000000C6)
		win_const_mgr.add_const('DBPROPVAL_OS_AGR_AFTERSESSION',0x00000008)
		win_const_mgr.add_const('SERVICE_NOTIFY_DELETED',0x00000100)
		win_const_mgr.add_const('SYMFLAG_LOCAL',0x00000080)
		win_const_mgr.add_const('DNS_OPCODE_UPDATE',0x00000005)
		win_const_mgr.add_const('DDF_JUSTDRAWIT',0x00000080)
		win_const_mgr.add_const('PTE_DIRTY_MASK',0x00000040)
		win_const_mgr.add_const('MCI_ANIM_GETDEVCAPS_PALETTES',0x00004006)
		win_const_mgr.add_const('MCI_DGV_STATUS_REFERENCE',0x00040000)
		win_const_mgr.add_const('XP1_UNI_SEND',0x00008000)
		win_const_mgr.add_const('GESTURE_UP_ARROW_RIGHT',0x00000000)
		win_const_mgr.add_const('FILE_READ_ONLY_VOLUME',0x00080000)
		win_const_mgr.add_const('NCRYPTBUFFER_SSL_CLEAR_KEY',0x00000017)
		win_const_mgr.add_const('CMSG_ENCODING_TYPE_MASK',0xFFFF0000)
		win_const_mgr.add_const('LVNI_FOCUSED',0x00000001)
		win_const_mgr.add_const('EN_PAGECHANGE',0x00000070)
		win_const_mgr.add_const('TBS_VERT',0x00000002)
		win_const_mgr.add_const('BF_FLAT',0x00004000)
		win_const_mgr.add_const('MB_ICONEXCLAMATION',0x00000030)
		win_const_mgr.add_const('APPCOMMAND_LAUNCH_MAIL',0x0000000F)
		win_const_mgr.add_const('CERT_NAME_STR_SEMICOLON_FLAG',0x40000000)
		win_const_mgr.add_const('CICAT_NO_QUERY',0x00000008)
		win_const_mgr.add_const('COPYFLG_PROTECTED_WINDOWS_DRIVER_FILE',0x00000100)
		win_const_mgr.add_const('FEI_ABORTING',0x00000000)
		win_const_mgr.add_const('SND_APPLICATION',0x00000080)
		win_const_mgr.add_const('SQL_USE_BOOKMARKS',0x0000000C)
		win_const_mgr.add_const('D3D10_DEFAULT_SLOPE_SCALED_DEPTH_BIAS',0x00000000)
		win_const_mgr.add_const('WLX_OPTION_NO_SWITCH_ON_SAS',0x00000009)
		win_const_mgr.add_const('DISPLAY_DEVICE_ACTIVE',0x00000001)
		win_const_mgr.add_const('SYSAUDIO_FLAGS_DONT_COMBINE_PINS',0x00000001)
		win_const_mgr.add_const('KS_NABTS_GROUPID_LOCAL_CABLE_SYSTEM_CONTENT_BASE',0x000008A0)
		win_const_mgr.add_const('DI_IMAGE',0x00000002)
		win_const_mgr.add_const('PS_COMPONENT_CONFORMER',0x00000003)
		win_const_mgr.add_const('SVSI_KEYBOARDSELECT',0x00000401)
		win_const_mgr.add_const('FILE_PREFETCH_TYPE_FOR_DIRENUM_EX',0x00000004)
		win_const_mgr.add_const('DS_ROLE_PDC_OWNER',0x00000002)
		win_const_mgr.add_const('SQL_SQL92_DATETIME_FUNCTIONS',0x0000009B)
		win_const_mgr.add_const('LINETRANSFERMODE_TRANSFER',0x00000001)
		win_const_mgr.add_const('ERROR_DRIVER_PROCESS_TERMINATED',0x0000050B)
		win_const_mgr.add_const('SWP_DEFERERASE',0x00002000)
		win_const_mgr.add_const('ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE',0x00003AAF)
		win_const_mgr.add_const('PIDISM_DONTWATCH',0x00000002)
		win_const_mgr.add_const('SET_FEATURE_ON_THREAD_LOCALMACHINE',0x00000008)
		win_const_mgr.add_const('SQLBITN',0x00000068)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_PROPERTIES',0x00000009)
		win_const_mgr.add_const('URL_ESCAPE_SEGMENT_ONLY',0x00002000)
		win_const_mgr.add_const('TMT_ALPHALEVEL',0x00000962)
		win_const_mgr.add_const('LDAP_SCOPE_SUBTREE',0x00000002)
		win_const_mgr.add_const('WM_CANCELJOURNAL',0x0000004B)
		win_const_mgr.add_const('TRUSTERROR_STEP_FINAL_SIGPROV',0x00000021)
		win_const_mgr.add_const('SDP_ATTRIB_DI_VERSION',0x00000203)
		win_const_mgr.add_const('COOKIEACTION_SUPPRESS',0x00000010)
		win_const_mgr.add_const('DISPID_ABSOLUTEDROPMODE',0x00000012)
		win_const_mgr.add_const('TVGN_DROPHILITE',0x00000008)
		win_const_mgr.add_const('EC_MARKER_HIT',0x00000042)
		win_const_mgr.add_const('VK_DECIMAL',0x0000006E)
		win_const_mgr.add_const('BTH_ERROR_SCO_AIRMODE_REJECTED',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_BAD_SPI',0x00003656)
		win_const_mgr.add_const('POLICY_SHOWREASONUI_SERVERONLY',0x00000003)
		win_const_mgr.add_const('SQL_POS_UPDATE',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_SQ_EXISTS',0x00000004)
		win_const_mgr.add_const('ES_NOHIDESEL',0x00000100)
		win_const_mgr.add_const('MCI_ANIM_OPEN_WS',0x00010000)
		win_const_mgr.add_const('TC_NONCONF_BORROW_PLUS',0x00000003)
		win_const_mgr.add_const('HSE_URL_FLAGS_SCRIPT',0x00000200)
		win_const_mgr.add_const('FILE_COMPRESSION_MSZIP',0x00000002)
		win_const_mgr.add_const('MHDR_ISSTRM',0x00000008)
		win_const_mgr.add_const('CM_PROB_FAILED_FILTER',0x00000007)
		win_const_mgr.add_const('AEC_MAX_SYSTEM_MODES',0x00000006)
		win_const_mgr.add_const('LOAD_TLB_AS_32BIT',0x00000020)
		win_const_mgr.add_const('NETE_NAMENOTFOUND',0x0000000D)
		win_const_mgr.add_const('ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED',0x0000078E)
		win_const_mgr.add_const('UINT8_ERROR',0x00000000)
		win_const_mgr.add_const('SUBLANG_DANISH_DENMARK',0x00000001)
		win_const_mgr.add_const('NET_VALIDATE_BAD_PASSWORD_COUNT',0x00000008)
		win_const_mgr.add_const('SERVICE_IP_CHKPT_NUM',0x000000FF)
		win_const_mgr.add_const('CQPM_SETDEFAULTPARAMETERS',0x00000009)
		win_const_mgr.add_const('RPC_C_STATS_CALLS_IN',0x00000000)
		win_const_mgr.add_const('DR_IG',0x0000003C)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_NETWORK_TCPIP',0x00010000)
		win_const_mgr.add_const('PSH_NOAPPLYNOW',0x00000080)
		win_const_mgr.add_const('WMDM_RIGHTS_FREESERIALIDS',0x00000008)
		win_const_mgr.add_const('LB_SETHORIZONTALEXTENT',0x00000194)
		win_const_mgr.add_const('NETERR_RING_STATUS_TRANSMIT_BEACON',0x00001000)
		win_const_mgr.add_const('SSF_SERVERADMINUI',0x00000004)
		win_const_mgr.add_const('CHANGER_MOVE_EXTENDS_IEPORT',0x80000200)
		win_const_mgr.add_const('ISC_REQ_RESERVED1',0x00100000)
		win_const_mgr.add_const('GCPCLASS_ARABIC',0x00000002)
		win_const_mgr.add_const('ERROR_UNABLE_TO_LOCK_MEDIA',0x00000454)
		win_const_mgr.add_const('DNS_ERROR_NON_RFC_NAME',0x00002554)
		win_const_mgr.add_const('MCI_VCR_SET_COUNTER_FORMAT',0x00080000)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_EFI_APPLICATION',0x0000000A)
		win_const_mgr.add_const('DB_MODE_READWRITE',0x00000003)
		win_const_mgr.add_const('SECBUFFER_PKG_PARAMS',0x00000003)
		win_const_mgr.add_const('MONITOR_DEFAULTTONULL',0x00000000)
		win_const_mgr.add_const('SV_TYPE_PARMNUM',0x00000069)
		win_const_mgr.add_const('PHOTO_FLASH_WITHOUTSTROBE',0x00000005)
		win_const_mgr.add_const('FILE_PREFETCH_TYPE_MAX',0x00000004)
		win_const_mgr.add_const('TURKISH_CHARSET',0x000000A2)
		win_const_mgr.add_const('SQLAOPANY',0x00000053)
		win_const_mgr.add_const('TC_NOTIFY_IFC_UP',0x00000001)
		win_const_mgr.add_const('PSR_PP',0x00000015)
		win_const_mgr.add_const('IME_ESC_PRIVATE_FIRST',0x00000800)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_SCHEDULING_CLASS',0x00000080)
		win_const_mgr.add_const('WM_NCMOUSELEAVE',0x000002A2)
		win_const_mgr.add_const('DPAMM_INSERT',0x00000003)
		win_const_mgr.add_const('DNS_TYPE_MX',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_INFO',0x00000000)
		win_const_mgr.add_const('ED_RIGHT',0x00000400)
		win_const_mgr.add_const('LINEDEVSTATE_MAINTENANCE',0x00000100)
		win_const_mgr.add_const('SCRIPTTEXT_ISVISIBLE',0x00000002)
		win_const_mgr.add_const('SECPKG_CONTEXT_EXPORT_DELETE_OLD',0x00000002)
		win_const_mgr.add_const('FTP_TRANSFER_TYPE_BINARY',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_OS_TXNENLISTMENT',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_MATCH',0x0000000D)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_SPLIT_IO',0x00200000)
		win_const_mgr.add_const('IF_TYPE_STANDALONE_WORKSTATION_DIALOUT',0x00000008)
		win_const_mgr.add_const('GGI_MARK_NONEXISTING_GLYPHS',0x00000000)
		win_const_mgr.add_const('DDCKEYCAPS_DESTBLT',0x00000001)
		win_const_mgr.add_const('OID_1394_VC_INFO',0x0C010102)
		win_const_mgr.add_const('PORT_ISOTSAP',0x00000066)
		win_const_mgr.add_const('VK_JUNJA',0x00000017)
		win_const_mgr.add_const('APMMENUSUSPEND_NOCHANGE',0x00000080)
		win_const_mgr.add_const('LANG_GALICIAN',0x00000056)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_WANT_DOWNLEVEL_BUILTIN_PATH',0x00000020)
		win_const_mgr.add_const('DEBUG_VALUE_FLOAT32',0x00000005)
		win_const_mgr.add_const('TTI_NONE',0x00000000)
		win_const_mgr.add_const('EDD_GET_DEVICE_INTERFACE_NAME',0x00000001)
		win_const_mgr.add_const('URLACTION_ACTIVEX_OVERRIDE_OPTIN',0x00001208)
		win_const_mgr.add_const('SQL_DIAG_CREATE_VIEW',0x00000054)
		win_const_mgr.add_const('DNS_ERROR_NODE_IS_DNAME',0x000025F8)
		win_const_mgr.add_const('CE_DNS',0x00000800)
		win_const_mgr.add_const('SCARD_W_CANCELLED_BY_USER',0x8010006E)
		win_const_mgr.add_const('XP1_SUPPORT_MULTIPOINT',0x00000400)
		win_const_mgr.add_const('SDP_ERROR_INVALID_PDU_SIZE',0x00000004)
		win_const_mgr.add_const('ICC_NATIVEFNTCTL_CLASS',0x00002000)
		win_const_mgr.add_const('MCI_DGV_MONITOR_FILE',0x00004001)
		win_const_mgr.add_const('CERT_RDN_NUMERIC_STRING',0x00000003)
		win_const_mgr.add_const('PROTO_TYPE_MS0',0x00000002)
		win_const_mgr.add_const('MCI_CONFIGURE',0x00000087)
		win_const_mgr.add_const('WM_POWERBROADCAST',0x00000218)
		win_const_mgr.add_const('LCMAP_SORTKEY',0x00000400)
		win_const_mgr.add_const('SUBLANG_URDU_INDIA',0x00000002)
		win_const_mgr.add_const('USER_DEFAULT_SCREEN_DPI',0x00000060)
		win_const_mgr.add_const('ACCESS_COUNT_PARMNUM',0x00000003)
		win_const_mgr.add_const('SPDRP_COMPATIBLEIDS',0x00000002)
		win_const_mgr.add_const('IF_CHECK_NONE',0x00000000)
		win_const_mgr.add_const('DXVA_MV_PRECISION_AND_CHROMA_RELATION_H263',0x00000001)
		win_const_mgr.add_const('RASLCPAP_PAP',0x0000C023)
		win_const_mgr.add_const('DNS_ERROR_INVALID_PROPERTY',0x00002551)
		win_const_mgr.add_const('OID_802_11_RADIO_STATUS',0x0D010125)
		win_const_mgr.add_const('DISPATCH_PROPERTYPUTREF',0x00000008)
		win_const_mgr.add_const('CE_OOP',0x00001000)
		win_const_mgr.add_const('KSEVENT_TYPE_SETSUPPORT',0x00000100)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_ASSEMBLY_INFORMATION',0x00000001)
		win_const_mgr.add_const('WINEVENT_SKIPOWNTHREAD',0x00000001)
		win_const_mgr.add_const('KERB_ETYPE_RSA_PUB_SHA1',0x0000000C)
		win_const_mgr.add_const('DI_REMOVEDEVICE_CONFIGSPECIFIC',0x00000002)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H264_F',0x00000069)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H264_D',0x00000067)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H264_E',0x00000068)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H264_B',0x00000065)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H264_C',0x00000066)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H264_A',0x00000064)
		win_const_mgr.add_const('BSF_LUID',0x00000400)
		win_const_mgr.add_const('INTERNET_DIAL_FORCE_PROMPT',0x00002000)
		win_const_mgr.add_const('TBDDRET_DEFAULT',0x00000000)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_ENCODE',0x00000008)
		win_const_mgr.add_const('ICW_LAUNCHEDFULL',0x00000100)
		win_const_mgr.add_const('ERROR_CARDBUS_NOT_SUPPORTED',0x000002D4)
		win_const_mgr.add_const('NDIS_PROTOCOL_ID_TCP_IP',0x00000002)
		win_const_mgr.add_const('SQL_CODE_DAY_TO_SECOND',0x0000000A)
		win_const_mgr.add_const('PROCESS_QUERY_INFORMATION',0x00000400)
		win_const_mgr.add_const('MB_PRECOMPOSED',0x00000001)
		win_const_mgr.add_const('DISPLAYDIB_NOCENTER',0x00000020)
		win_const_mgr.add_const('SQL_CA1_RELATIVE',0x00000004)
		win_const_mgr.add_const('TMT_INTEGRALSIZING',0x000008A3)
		win_const_mgr.add_const('SI_USER_PASSED',0x00000001)
		win_const_mgr.add_const('RTCMT_VIDEO_SEND',0x00000004)
		win_const_mgr.add_const('SV_TYPE_DOMAIN_CTRL',0x00000008)
		win_const_mgr.add_const('SQL_ATTR_PARAM_OPERATION_PTR',0x00000013)
		win_const_mgr.add_const('SERVICETYPE_NETWORK_CONTROL',0x0000000A)
		win_const_mgr.add_const('DN_NOT_FIRST_TIMEE',0x00080000)
		win_const_mgr.add_const('UNION_SMALL_ARMS',0x00000002)
		win_const_mgr.add_const('LAYOUT_RTL',0x00000001)
		win_const_mgr.add_const('RP_DSN_NOTIFY_NEVER',0x08000000)
		win_const_mgr.add_const('WSADESCRIPTION_LEN',0x00000100)
		win_const_mgr.add_const('WINHTTP_OPTION_USERNAME',0x00001000)
		win_const_mgr.add_const('DBTF_MEDIA',0x00000001)
		win_const_mgr.add_const('D3DFMT_X8R8G8B8',0x00000016)
		win_const_mgr.add_const('CMSG_SIGNER_UNAUTH_ATTR_PARAM',0x0000000A)
		win_const_mgr.add_const('SCARD_READER_TYPE_VENDOR',0x000000F0)
		win_const_mgr.add_const('HELP_HELPONHELP',0x00000004)
		win_const_mgr.add_const('WMSZ_TOPLEFT',0x00000004)
		win_const_mgr.add_const('WINHTTP_ADDREQ_FLAG_COALESCE_WITH_SEMICOLON',0x01000000)
		win_const_mgr.add_const('MDM_CELLULAR',0x00000008)
		win_const_mgr.add_const('GGL_STRING',0x00000003)
		win_const_mgr.add_const('D3DFVF_XYZB5',0x00000000)
		win_const_mgr.add_const('D3DFVF_XYZB4',0x00000000)
		win_const_mgr.add_const('D3DFVF_XYZB3',0x00000000)
		win_const_mgr.add_const('GUIDSTRING_MAX',0x00000001)
		win_const_mgr.add_const('D3DFVF_XYZB1',0x00000006)
		win_const_mgr.add_const('ILC_ORIGINALSIZE',0x00010000)
		win_const_mgr.add_const('HH_RESERVED1',0x0000000A)
		win_const_mgr.add_const('HH_RESERVED3',0x0000000C)
		win_const_mgr.add_const('SCARD_E_DIR_NOT_FOUND',0x80100023)
		win_const_mgr.add_const('MAX_VOLUME_TEMPLATE_SIZE',0x00000028)
		win_const_mgr.add_const('EDITF_ENABLEAKICRITICAL',0x00002000)
		win_const_mgr.add_const('DEBUG_INTERRUPT_EXIT',0x00000002)
		win_const_mgr.add_const('COLOR_WINDOWTEXT',0x00000008)
		win_const_mgr.add_const('DRM_SIGN_ONLINE',0x00000001)
		win_const_mgr.add_const('PDH_CALC_NEGATIVE_TIMEBASE',0x800007D7)
		win_const_mgr.add_const('CERT_RDN_DISABLE_IE4_UTF8_FLAG',0x01000000)
		win_const_mgr.add_const('COLOR_INACTIVEBORDER',0x0000000B)
		win_const_mgr.add_const('MDPROPVAL_MSF_BOTTOMSUM',0x00000008)
		win_const_mgr.add_const('SQL_HC_ON',0x00000001)
		win_const_mgr.add_const('MAPI_AB_NOMODIFY',0x00000400)
		win_const_mgr.add_const('HTTP_PROTOCOL_UUID16',0x0000000C)
		win_const_mgr.add_const('WLX_SAS_ACTION_SHUTDOWN_SLEEP2',0x0000000D)
		win_const_mgr.add_const('DMDUP_VERTICAL',0x00000002)
		win_const_mgr.add_const('ERROR_DS_NO_MSDS_INTID',0x00002194)
		win_const_mgr.add_const('PIFSHDATASIZE',0x00000040)
		win_const_mgr.add_const('DBPROPVAL_BD_REORGANIZATION',0x00000003)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_FADE_TO_COLOR',0x00000010)
		win_const_mgr.add_const('LR_MONOCHROME',0x00000001)
		win_const_mgr.add_const('SQL_DS_DROP_SCHEMA',0x00000001)
		win_const_mgr.add_const('EMR_SETWORLDTRANSFORM',0x00000023)
		win_const_mgr.add_const('FCT_CONFIGABLE',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INVALID_VERSION',0x000036F8)
		win_const_mgr.add_const('DNS_ERROR_RCODE_YXDOMAIN',0x0000232E)
		win_const_mgr.add_const('SHUTDOWN_NOREBOOT',0x00000010)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_COLUMN_DOMAIN_USAGE',0x00000004)
		win_const_mgr.add_const('SECPKG_ATTR_SASL_CONTEXT',0x00010000)
		win_const_mgr.add_const('ERROR_PATCH_NO_SEQUENCE',0x00000670)
		win_const_mgr.add_const('MOVEFILE_WRITE_THROUGH',0x00000008)
		win_const_mgr.add_const('DMPAPER_ENV_C3',0x0000001D)
		win_const_mgr.add_const('STM_ORDER_BY_INTERFACE_TYPE_NAME',0x00000001)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H263_E',0x00000007)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H263_D',0x00000006)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H263_F',0x00000008)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H263_A',0x00000003)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H263_C',0x00000005)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H263_B',0x00000004)
		win_const_mgr.add_const('SYMF_FORWARDER',0x00000400)
		win_const_mgr.add_const('URLACTION_SHELL_RTF_OBJECTS_LOAD',0x0000180A)
		win_const_mgr.add_const('VIDCF_QUALITY',0x00000001)
		win_const_mgr.add_const('WIA_DPS_PAGE_WIDTH',0x00000C1A)
		win_const_mgr.add_const('IMAGE_REL_CEF_SECREL',0x00000005)
		win_const_mgr.add_const('SQL_TIME_LEN',0x00000008)
		win_const_mgr.add_const('IDS_CAP_CANTOPEN',0x00000199)
		win_const_mgr.add_const('RATING_FIVE_STARS_MAX',0x00000063)
		win_const_mgr.add_const('ACCESS_MAX_MS_V2_ACE_TYPE',0x00000003)
		win_const_mgr.add_const('EVENT_SYSTEM_DIALOGSTART',0x00000010)
		win_const_mgr.add_const('PFNS_PERIOD',0x00000200)
		win_const_mgr.add_const('SSF_SHOWTYPEOVERLAY',0x02000000)
		win_const_mgr.add_const('PAN_BENT_ARMS_SINGLE_SERIF',0x0000000A)
		win_const_mgr.add_const('DXVA_DPXD_SURFACE_BUFFER',0x0000000A)
		win_const_mgr.add_const('FS_NOT_FAX_CALL',0x20001000)
		win_const_mgr.add_const('DSF_SHOW_OFFLINE',0x00020000)
		win_const_mgr.add_const('MCI_LOAD_FILE',0x00000100)
		win_const_mgr.add_const('MD_ERROR_SUB403_DIR_LIST_DENIED',0x0000000E)
		win_const_mgr.add_const('DNS_OPCODE_NOTIFY',0x00000004)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_VALID_FLAGS',0x00000007)
		win_const_mgr.add_const('WM_MEASUREITEM',0x0000002C)
		win_const_mgr.add_const('APPCOMMAND_LAUNCH_APP1',0x00000011)
		win_const_mgr.add_const('POLICY_ERRV_EXPIRED_USER_TOKEN',0x00000033)
		win_const_mgr.add_const('IITWBC_BREAKTYPE_EPOCH',0x00000004)
		win_const_mgr.add_const('ERROR_DS_WRONG_OM_OBJ_CLASS',0x0000211C)
		win_const_mgr.add_const('APPCOMMAND_LAUNCH_APP2',0x00000012)
		win_const_mgr.add_const('CONTEXT_MENU_TEXTSELECT',0x00000004)
		win_const_mgr.add_const('FLAG_NO_GPO_FILTER',0x80000000)
		win_const_mgr.add_const('WIA_COMPRESSION_BI_RLE8',0x00000002)
		win_const_mgr.add_const('SECPKG_ALT_ATTR',0x80000000)
		win_const_mgr.add_const('PROP_ID_SECURE_MAX',0x000067FF)
		win_const_mgr.add_const('AGP_FLAG_NO_FW_ENABLE',0x00000200)
		win_const_mgr.add_const('NDR64_FC_EXPLICIT_HANDLE',0x00000000)
		win_const_mgr.add_const('VIEW_PRIORITY_CACHEHIT',0x00000050)
		win_const_mgr.add_const('SQL_SP_ISNULL',0x00000004)
		win_const_mgr.add_const('CONSOLE_FULLSCREEN_HARDWARE',0x00000002)
		win_const_mgr.add_const('CERT_TRUST_INVALID_POLICY_CONSTRAINTS',0x00000200)
		win_const_mgr.add_const('MARSHAL_E_LAST',0x8004012F)
		win_const_mgr.add_const('MCI_WAVE_GETDEVCAPS_OUTPUTS',0x00004002)
		win_const_mgr.add_const('COPYFLG_FORCE_FILE_IN_USE',0x00000008)
		win_const_mgr.add_const('ERROR_NETWORK_BUSY',0x00000036)
		win_const_mgr.add_const('ERROR_LOG_METADATA_FLUSH_FAILED',0x000019F5)
		win_const_mgr.add_const('RTS_CONTROL_ENABLE',0x00000001)
		win_const_mgr.add_const('PHOTOACQ_DISABLE_DUPLICATE_DETECTION',0x00000040)
		win_const_mgr.add_const('IOF_DISABLEDISPLAYASICON',0x00000400)
		win_const_mgr.add_const('MAXCHAR',0x00000007)
		win_const_mgr.add_const('DISPID_IHTMLDLGSAFEHELPER_CHOOSECOLORDLG',0x00000001)
		win_const_mgr.add_const('MDPROPVAL_MC_SEARCHEDCASE',0x00000002)
		win_const_mgr.add_const('ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION',0x0000030F)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_FILE_IO',0x02000000)
		win_const_mgr.add_const('HEAP_REALLOC_IN_PLACE_ONLY',0x00000010)
		win_const_mgr.add_const('SQL_PS_SELECT_FOR_UPDATE',0x00000004)
		win_const_mgr.add_const('WLX_OPTION_USE_SMART_CARD',0x00000003)
		win_const_mgr.add_const('NCRYPTBUFFER_SSL_KEY_ARG_DATA',0x00000018)
		win_const_mgr.add_const('ERROR_PIPE_LOCAL',0x000000E5)
		win_const_mgr.add_const('SQL_FN_NUM_DEGREES',0x00040000)
		win_const_mgr.add_const('ERROR_LOG_CONTAINER_WRITE_FAILED',0x000019F0)
		win_const_mgr.add_const('IDI_RESOURCEFIRST',0x0000009F)
		win_const_mgr.add_const('IDTB_CONTENTS',0x000000D5)
		win_const_mgr.add_const('OID_TAPI_CLOSE_CALL',0x07030104)
		win_const_mgr.add_const('WM_NCMOUSEMOVE',0x000000A0)
		win_const_mgr.add_const('NDIS_802_11_AUTH_REQUEST_REAUTH',0x00000001)
		win_const_mgr.add_const('MCI_DGV_OPEN_NOSTATIC',0x00040000)
		win_const_mgr.add_const('VER_ERR_ADDL_MSG',0x00008000)
		win_const_mgr.add_const('HTTP_LOG_FIELD_HOST',0x00100000)
		win_const_mgr.add_const('EVENTLOG_SEEK_READ',0x00000002)
		win_const_mgr.add_const('SECQOP_WRAP_NO_ENCRYPT',0x80000001)
		win_const_mgr.add_const('GL_PRE_BEGIN_REQUEST',0x00000100)
		win_const_mgr.add_const('IDD_GNRLPROPS4',0x00000452)
		win_const_mgr.add_const('WMS_DATA_CONTAINER_NONSEEKABLE',0xFFFFFFFFFFFFFFFF)
		win_const_mgr.add_const('IDH_HELP',0x00006F1D)
		win_const_mgr.add_const('TASK_DECEMBER',0x00000800)
		win_const_mgr.add_const('MCI_VCR_SIGNAL_USERVAL',0x00040000)
		win_const_mgr.add_const('SN_CODE',0x00000000)
		win_const_mgr.add_const('MDPROPVAL_MD_SELF',0x00000001)
		win_const_mgr.add_const('LABEL_SECURITY_INFORMATION',0x00000010)
		win_const_mgr.add_const('AD_APPLY_SAVE',0x00000001)
		win_const_mgr.add_const('PMSF_DONT_STRIP_SPACES',0x00010000)
		win_const_mgr.add_const('LBS_MULTIPLESEL',0x00000008)
		win_const_mgr.add_const('SYNCMGRREGISTERFLAGS_MASK',0x00000007)
		win_const_mgr.add_const('WMDRM_DEVICE_ISWMDRM',0x00000001)
		win_const_mgr.add_const('VIDEO_DLG_QUERY',0x00000010)
		win_const_mgr.add_const('EDITF_AUDITCERTTEMPLATELOAD',0x00200000)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_SAVEPOINT',0x00080000)
		win_const_mgr.add_const('CERT_NO_AUTO_EXPIRE_CHECK_PROP_ID',0x0000004D)
		win_const_mgr.add_const('CRYPT_RC2_56BIT_VERSION',0x00000034)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_NO_MACHINE_LUID_VERIFY',0x00000020)
		win_const_mgr.add_const('IDS_CAP_AUDIO_DROP_ERROR',0x000001B9)
		win_const_mgr.add_const('IDC_CV_RESULTTEXT',0x0000009D)
		win_const_mgr.add_const('DOT11_STATUS_UNSUPPORTED_PRIORITY',0x00000004)
		win_const_mgr.add_const('TMT_AUTHOR',0x0000025C)
		win_const_mgr.add_const('ICW_LAUNCHMANUAL',0x00000200)
		win_const_mgr.add_const('SSIZE_T_MAX',0x7FFFFFFF)
		win_const_mgr.add_const('BITS_MC_JOB_CANCELLED',0x80194000)
		win_const_mgr.add_const('CRYPTDLG_REVOCATION_DEFAULT',0x00000000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_FWDNUMRINGS',0x00000001)
		win_const_mgr.add_const('IME_MODE_DBCSCHAR',0x00000010)
		win_const_mgr.add_const('DDSCL_CREATEDEVICEWINDOW',0x00000200)
		win_const_mgr.add_const('CR_FLG_SUBJECTUNMODIFIED',0x00000020)
		win_const_mgr.add_const('OFFLINESTATUS_OFFLINE_SLOW',0x00000003)
		win_const_mgr.add_const('DVB_SDT_OTHER_TID',0x00000046)
		win_const_mgr.add_const('DNS_TYPE_A',0x00000001)
		win_const_mgr.add_const('SSF_SHOWATTRIBCOL',0x00000100)
		win_const_mgr.add_const('SSPROPVAL_USEPROCFORPREP_ON_DROP',0x00000002)
		win_const_mgr.add_const('HTTP_QUERY_ACCEPT_RANGES',0x0000002A)
		win_const_mgr.add_const('LDAP_MOD_ADD',0x00000000)
		win_const_mgr.add_const('TXTBIT_CLIENTRECTCHANGE',0x00100000)
		win_const_mgr.add_const('WMI_GLOBAL_LOGGER_ID',0x00000001)
		win_const_mgr.add_const('USE_DISKDEV',0x00000000)
		win_const_mgr.add_const('ERROR_DS_GCVERIFY_ERROR',0x000020E1)
		win_const_mgr.add_const('SECURITY_MANDATORY_HIGH_RID',0x00003000)
		win_const_mgr.add_const('PORT_VMNET',0x000000AF)
		win_const_mgr.add_const('IDENTIFIER_SDK_ERROR',0x10000000)
		win_const_mgr.add_const('COOKIE_ALLOW_ALL',0x00000004)
		win_const_mgr.add_const('RESOURCEMANAGER_COMPLETE_PROPAGATION',0x00000040)
		win_const_mgr.add_const('MD_ACR_ENUM_KEYS',0x00000008)
		win_const_mgr.add_const('SEC_NOCACHE',0x10000000)
		win_const_mgr.add_const('SCARD_UNPOWER_CARD',0x00000002)
		win_const_mgr.add_const('PROPCALLER_EXIT',0x00000300)
		win_const_mgr.add_const('INTERNET_OPTION_MAX_CONNS_PER_1_0_SERVER',0x0000004A)
		win_const_mgr.add_const('RES_SERVICE',0x00000004)
		win_const_mgr.add_const('PER_USER_AUDIT_SUCCESS_INCLUDE',0x00000001)
		win_const_mgr.add_const('SUBLANG_SPANISH_US',0x00000015)
		win_const_mgr.add_const('TMT_TEXTCOLORHINT',0x00000EF0)
		win_const_mgr.add_const('DSBI_CHECKBOXES',0x00000100)
		win_const_mgr.add_const('WSA_QOS_EFILTERTYPE',0x00002B0C)
		win_const_mgr.add_const('RTCMT_AUDIO_RECEIVE',0x00000002)
		win_const_mgr.add_const('DNS_RTYPE_SRV',0x00002100)
		win_const_mgr.add_const('AVIFILECAPS_NOCOMPRESSION',0x00000020)
		win_const_mgr.add_const('SQL_DYNAMIC_CURSOR_ATTRIBUTES1',0x00000090)
		win_const_mgr.add_const('IDC_OLEUIHELP',0x00000063)
		win_const_mgr.add_const('ERROR_TOO_MANY_OPEN_FILES',0x00000004)
		win_const_mgr.add_const('WNTYPE_COMM',0x00000004)
		win_const_mgr.add_const('POLICY_ERRV_NO_MEMORY',0x00000038)
		win_const_mgr.add_const('SHUTDOWN_RESTART',0x00000004)
		win_const_mgr.add_const('SQL_QU_INDEX_DEFINITION',0x00000008)
		win_const_mgr.add_const('ROTFLAGS_REGISTRATIONKEEPSALIVE',0x00000001)
		win_const_mgr.add_const('INET_ADDRSTRLEN',0x00000016)
		win_const_mgr.add_const('NTMS_OMID_TYPE_RAW_LABEL',0x00000001)
		win_const_mgr.add_const('EVENT_ACTIVITY_CTRL_CREATE_SET_ID',0x00000005)
		win_const_mgr.add_const('IDM_CODE',0x0000000E)
		win_const_mgr.add_const('PROXY_TYPE_AUTO_PROXY_URL',0x00000004)
		win_const_mgr.add_const('DDSD_SRCVBHANDLE',0x00400000)
		win_const_mgr.add_const('FILE_PREFETCH_TYPE_FOR_CREATE',0x00000001)
		win_const_mgr.add_const('ERROR_DS_TREE_DELETE_NOT_FINISHED',0x000020CD)
		win_const_mgr.add_const('PHONEERR_INVALBUTTONLAMPID',0x90000009)
		win_const_mgr.add_const('LR_COPYRETURNORG',0x00000004)
		win_const_mgr.add_const('SC_PREVWINDOW',0x0000F050)
		win_const_mgr.add_const('LDAP_SUBSTRING_FINAL',0x00000082)
		win_const_mgr.add_const('DBPROPVAL_SS_ISTORAGE',0x00000004)
		win_const_mgr.add_const('WIA_IPA_GAMMA_CURVES',0x00001013)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_CLEARINTERVAL',0x0000048B)
		win_const_mgr.add_const('IN_CLASSD_NSHIFT',0x0000001C)
		win_const_mgr.add_const('DDSCAPS_PALETTE',0x00000100)
		win_const_mgr.add_const('DBIMF_ALWAYSGRIPPER',0x00001000)
		win_const_mgr.add_const('PCI_OPTIONS_USE_BIOS',0x00000001)
		win_const_mgr.add_const('INTERNET_MAX_USER_NAME_LENGTH',0x00000080)
		win_const_mgr.add_const('COPY_FILE_ALLOW_DECRYPTED_DESTINATION',0x00000008)
		win_const_mgr.add_const('GL_ID_CHOOSECANDIDATE',0x00000028)
		win_const_mgr.add_const('ERROR_RXACT_COMMIT_FAILURE',0x0000055A)
		win_const_mgr.add_const('DC_ENUMRESOLUTIONS',0x0000000D)
		win_const_mgr.add_const('SECURITY_DESCRIPTOR_REVISION',0x00000001)
		win_const_mgr.add_const('AM_QUERY_DECODER_ATSC_HD_SUPPORT',0x00000005)
		win_const_mgr.add_const('SSPROPVAL_COMMANDTYPE_BULKLOAD',0x00000016)
		win_const_mgr.add_const('SIZE_MINIMIZED',0x00000001)
		win_const_mgr.add_const('D3DCREATE_SCREENSAVER',0x10000000)
		win_const_mgr.add_const('DI_CHANNEL',0x00000001)
		win_const_mgr.add_const('TVS_EX_FADEINOUTEXPANDOS',0x00000040)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_HASH_ALG',0x0000362F)
		win_const_mgr.add_const('DISPID_ADDDESKTOPCOMPONENT',0x00000006)
		win_const_mgr.add_const('SENSITIVITY_PROP_CONFIDENTIAL',0x00000003)
		win_const_mgr.add_const('URL_FILE_USE_PATHURL',0x00010000)
		win_const_mgr.add_const('SQL_DESC_DATA_PTR',0x000003F2)
		win_const_mgr.add_const('DDFLIP_INTERVAL4',0x04000000)
		win_const_mgr.add_const('DDFLIP_INTERVAL3',0x03000000)
		win_const_mgr.add_const('DDFLIP_INTERVAL2',0x02000000)
		win_const_mgr.add_const('CD_LBSELADD',0x00000002)
		win_const_mgr.add_const('REG_REFRESH_HIVE',0x00000002)
		win_const_mgr.add_const('CERT_NAME_STR_CRLF_FLAG',0x08000000)
		win_const_mgr.add_const('DDSCAPS2_HINTSTATIC',0x00000008)
		win_const_mgr.add_const('DISPID_ROOT',0x00000010)
		win_const_mgr.add_const('COMMON_LVB_GRID_LVERTICAL',0x00000800)
		win_const_mgr.add_const('IMAGE_SCN_MEM_PURGEABLE',0x00020000)
		win_const_mgr.add_const('OFN_READONLY',0x00000001)
		win_const_mgr.add_const('VP_MODE_WIN_GRAPHICS',0x00000001)
		win_const_mgr.add_const('MDMEASURE_AGGR_MIN',0x00000003)
		win_const_mgr.add_const('METHOD_OUT_DIRECT',0x00000002)
		win_const_mgr.add_const('MAX_EAP_CONFIG_INPUT_FIELD_LENGTH',0x00000100)
		win_const_mgr.add_const('SYMF_REGISTER',0x00000008)
		win_const_mgr.add_const('MAPI_TO',0x00000001)
		win_const_mgr.add_const('ISCSI_LOGIN_FLAG_USE_RADIUS_RESPONSE',0x00000010)
		win_const_mgr.add_const('SHCNF_FLUSHNOWAIT',0x00002000)
		win_const_mgr.add_const('RSC_MODE',0x00000000)
		win_const_mgr.add_const('ISR_ILLEGAL_OP',0x00000000)
		win_const_mgr.add_const('RP_DSN_NOTIFY_DELAY',0x04000000)
		win_const_mgr.add_const('EMR_DELETEOBJECT',0x00000028)
		win_const_mgr.add_const('JS_NOLINE',0x00000010)
		win_const_mgr.add_const('C1_DIGIT',0x00000004)
		win_const_mgr.add_const('PC_NONE',0x00000000)
		win_const_mgr.add_const('SEC_WINNT_AUTH_IDENTITY_MARSHALLED',0x00000004)
		win_const_mgr.add_const('TIME_CALLBACK_EVENT_SET',0x00000010)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_CLOSE',0x00000003)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_MULTICAST_BYTES_XMIT',0x00100000)
		win_const_mgr.add_const('CF_PRINTERFONTS',0x00000002)
		win_const_mgr.add_const('PDH_LOG_CREATE_NEW',0x00000001)
		win_const_mgr.add_const('SQL_CONVERT_INTERVAL_DAY_TIME',0x0000007B)
		win_const_mgr.add_const('NI_IMEMENUSELECTED',0x00000018)
		win_const_mgr.add_const('FCIDM_BROWSERFIRST',0x00000000)
		win_const_mgr.add_const('LINEDEVSTATE_NUMCOMPLETIONS',0x00001000)
		win_const_mgr.add_const('PIR_STATUS_TABLE_NONE',0x00000003)
		win_const_mgr.add_const('PSH_USEHBMHEADER',0x00100000)
		win_const_mgr.add_const('SV_CRITICALTHREADS_PARMNUM',0x0000023C)
		win_const_mgr.add_const('SPINST_PROFILEITEMS',0x00000100)
		win_const_mgr.add_const('WAVE_INVALIDFORMAT',0x00000000)
		win_const_mgr.add_const('CFM_SPACING',0x00200000)
		win_const_mgr.add_const('DLLVER_PLATFORM_NT',0x00000002)
		win_const_mgr.add_const('TRACELOG_REGISTER_GUIDS',0x00000800)
		win_const_mgr.add_const('SP_COPY_INBOX_INF',0x08000000)
		win_const_mgr.add_const('MCI_OPEN_ELEMENT_ID',0x00000800)
		win_const_mgr.add_const('PHONEFEATURE_SETVOLUMESPEAKER',0x04000000)
		win_const_mgr.add_const('DEBUG_VSOURCE_MAPPED_IMAGE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_OBJ_STRING_NAME_EXISTS',0x00002071)
		win_const_mgr.add_const('DPD_DELETE_ALL_FILES',0x00000004)
		win_const_mgr.add_const('SERVICE_STOPPED',0x00000001)
		win_const_mgr.add_const('DMPAPER_ENV_PERSONAL',0x00000026)
		win_const_mgr.add_const('WM_RBUTTONDBLCLK',0x00000206)
		win_const_mgr.add_const('SQL_CURRENT_QUALIFIER',0x0000006D)
		win_const_mgr.add_const('BCRYPT_PAD_PKCS1',0x00000002)
		win_const_mgr.add_const('PDH_SQL_BIND_FAILED',0xC0000BE7)
		win_const_mgr.add_const('GAA_FLAG_SKIP_ANYCAST',0x00000002)
		win_const_mgr.add_const('DEBUG_DUMP_FILE_BASE',0x00000000)
		win_const_mgr.add_const('SOFTDIST_ADSTATE_AVAILABLE',0x00000001)
		win_const_mgr.add_const('TMT_CLASSICVALUE',0x00000C82)
		win_const_mgr.add_const('PSINJECT_ENDPAGECOMMENTS',0x0000006B)
		win_const_mgr.add_const('MDM_FLOWCONTROL_HARD',0x00000010)
		win_const_mgr.add_const('KSRELATIVEEVENT_FLAG_POINTER',0x00000002)
		win_const_mgr.add_const('ERROR_CLUSTER_PARTIAL_SEND',0x0000171A)
		win_const_mgr.add_const('AUTODIAL_MODE_NO_NETWORK_PRESENT',0x00000004)
		win_const_mgr.add_const('AUTO_PROXY_FLAG_MIGRATED',0x00000008)
		win_const_mgr.add_const('LCMAP_SIMPLIFIED_CHINESE',0x02000000)
		win_const_mgr.add_const('ERROR_TRANSACTIONMANAGER_NOT_FOUND',0x00001A3E)
		win_const_mgr.add_const('PERF_DISPLAY_SECONDS',0x30000000)
		win_const_mgr.add_const('DEBUG_REQUEST_GET_ADDITIONAL_CREATE_OPTIONS',0x00000004)
		win_const_mgr.add_const('TMT_GLYPHTRANSPARENTCOLOR',0x00000EEC)
		win_const_mgr.add_const('SNMPAPI_VBL_INVALID',0x0000000F)
		win_const_mgr.add_const('SCRIPTPROC_ISEXPRESSION',0x00000020)
		win_const_mgr.add_const('MCI_GETDEVCAPS_HAS_AUDIO',0x00000002)
		win_const_mgr.add_const('ED_AUDIO_ALL',0x10000000)
		win_const_mgr.add_const('IMAGE_REL_PPC_IMGLUE',0x0000000E)
		win_const_mgr.add_const('CRYPT_CHECK_FRESHNESS_TIME_VALIDITY',0x00000400)
		win_const_mgr.add_const('PHOTO_METERINGMODE_CENTER',0x00000002)
		win_const_mgr.add_const('ERROR_MAX_SESSIONS_REACHED',0x00000161)
		win_const_mgr.add_const('HCBT_QS',0x00000002)
		win_const_mgr.add_const('MDM_V110_SPEED_9DOT6K',0x00000004)
		win_const_mgr.add_const('MD_ERROR_SUB403_SITE_ACCESS_DENIED',0x00000008)
		win_const_mgr.add_const('LVS_REPORT',0x00000001)
		win_const_mgr.add_const('SQL_STATIC_SENSITIVITY',0x00000053)
		win_const_mgr.add_const('ERROR_STACK_OVERFLOW',0x000003E9)
		win_const_mgr.add_const('PERCEIVEDFLAG_ZIPFOLDER',0x00000040)
		win_const_mgr.add_const('EMR_SETPIXELV',0x0000000F)
		win_const_mgr.add_const('ILS_SHADOW',0x00000002)
		win_const_mgr.add_const('ERROR_REQUEST_REFUSED',0x000010E0)
		win_const_mgr.add_const('RANDOM_PADDING',0x00000002)
		win_const_mgr.add_const('RTCIF_DISABLE_STRICT_DNS',0x00000008)
		win_const_mgr.add_const('TA_LEFT',0x00000000)
		win_const_mgr.add_const('THREAD_GET_CONTEXT',0x00000008)
		win_const_mgr.add_const('DDOVERFX_MIRRORUPDOWN',0x00000004)
		win_const_mgr.add_const('OID_CO_TAPI_ADDRESS_CAPS',0xFE001003)
		win_const_mgr.add_const('ETW_WMITIME_TYPE_VALUE',0x00000076)
		win_const_mgr.add_const('PROV_DSS',0x00000003)
		win_const_mgr.add_const('DS_LOCALEDIT',0x00000020)
		win_const_mgr.add_const('IDM_UPDATEPAGESTATUS',0x00000968)
		win_const_mgr.add_const('MCI_ANIM_STATUS_STRETCH',0x00004005)
		win_const_mgr.add_const('WB_CLASSIFY',0x00000003)
		win_const_mgr.add_const('ICINSTALL_DRIVERW',0x00008002)
		win_const_mgr.add_const('LANG_TIGRIGNA',0x00000073)
		win_const_mgr.add_const('PRINTER_STATUS_PAUSED',0x00000001)
		win_const_mgr.add_const('ERROR_FILE_INVALID',0x000003EE)
		win_const_mgr.add_const('SHDID_COMPUTER_DRIVE35',0x00000005)
		win_const_mgr.add_const('ERROR_OPLOCK_NOT_GRANTED',0x0000012C)
		win_const_mgr.add_const('NOTIFIER_TYPE_NOTIFY_EVENT',0x00000004)
		win_const_mgr.add_const('MF_REMOVE',0x00001000)
		win_const_mgr.add_const('MB_DEFMASK',0x00000F00)
		win_const_mgr.add_const('OPERATION_BROADCAST',0x00000002)
		win_const_mgr.add_const('SQL_DESC_COUNT',0x000003E9)
		win_const_mgr.add_const('TBCD_CHANNEL',0x00000003)
		win_const_mgr.add_const('BAUD_USER',0x10000000)
		win_const_mgr.add_const('ICON_BIG',0x00000001)
		win_const_mgr.add_const('SKF_LWINLOCKED',0x00400000)
		win_const_mgr.add_const('OS_ANYSERVER',0x0000001D)
		win_const_mgr.add_const('LUA_TOKEN',0x00000004)
		win_const_mgr.add_const('EMR_PIXELFORMAT',0x00000068)
		win_const_mgr.add_const('NONANTIALIASED_QUALITY',0x00000003)
		win_const_mgr.add_const('TCHT_ONITEMLABEL',0x00000004)
		win_const_mgr.add_const('WM_CHANGEUISTATE',0x00000127)
		win_const_mgr.add_const('SPEAKER_BACK_LEFT',0x00000010)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_SA_REAPED',0x000035F0)
		win_const_mgr.add_const('_INC_MMREG',0x0000009E)
		win_const_mgr.add_const('ERROR_INVALID_ORDINAL',0x000000B6)
		win_const_mgr.add_const('CREATE_EVENT_MANUAL_RESET',0x00000001)
		win_const_mgr.add_const('SV_LINKINFOVALIDTIME_PARMNUM',0x0000022A)
		win_const_mgr.add_const('LINEPARKMODE_DIRECTED',0x00000001)
		win_const_mgr.add_const('KSPIN_FLAG_FRAMES_NOT_REQUIRED_FOR_PROCESSING',0x00000040)
		win_const_mgr.add_const('ED_BOTTOM',0x00000004)
		win_const_mgr.add_const('SECURITY_ENTERPRISE_READONLY_CONTROLLERS_RID',0x00000016)
		win_const_mgr.add_const('SN_DATA',0x00000001)
		win_const_mgr.add_const('SQL_FN_TSI_WEEK',0x00000020)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_AMD64',0x00000009)
		win_const_mgr.add_const('TBIF_STYLE',0x00000008)
		win_const_mgr.add_const('VER_LESS',0x00000004)
		win_const_mgr.add_const('ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD',0x00002151)
		win_const_mgr.add_const('IDM_ZOOMPOPUP',0x0000085C)
		win_const_mgr.add_const('TTF_ABSOLUTE',0x00000080)
		win_const_mgr.add_const('SQL_LOGIN_TIMEOUT',0x00000067)
		win_const_mgr.add_const('DTT_CALCRECT',0x00000001)
		win_const_mgr.add_const('SPI_GETUIEFFECTS',0x0000103E)
		win_const_mgr.add_const('FL_UFI_PRIVATEFONT',0x00000001)
		win_const_mgr.add_const('SQL_FN_NUM_FLOOR',0x00000200)
		win_const_mgr.add_const('DISPID_SELECTIONCHANGE',0x00000002)
		win_const_mgr.add_const('PROTO_IP_IGMP',0x0000000A)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_HWND',0x00000003)
		win_const_mgr.add_const('RTCEF_PARTICIPANT_STATE_CHANGE',0x00000010)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_INSTALLATION',0x00000003)
		win_const_mgr.add_const('PKCS12_ALWAYS_CNG_KSP',0x00000200)
		win_const_mgr.add_const('CYPHER_BLOCK_LENGTH',0x00000008)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_DISCARD_REASON',0x00000001)
		win_const_mgr.add_const('LINECALLREASON_FWDUNCOND',0x00000008)
		win_const_mgr.add_const('DEBUG_ASMOPT_SOURCE_LINE_NUMBER',0x00000008)
		win_const_mgr.add_const('JOB_OBJECT_SECURITY_VALID_FLAGS',0x00000000)
		win_const_mgr.add_const('WMDRM_ACQUIRE_LICENSE_NONSILENT',0x00000002)
		win_const_mgr.add_const('WM_FONTCHANGE',0x0000001D)
		win_const_mgr.add_const('ERROR_TOO_MANY_NAMES',0x00000044)
		win_const_mgr.add_const('AUTH_REQ_ALLOW_RENEWABLE',0x00000008)
		win_const_mgr.add_const('ERROR_DS_NOT_CLOSEST',0x0000218C)
		win_const_mgr.add_const('ISR_IA_VECTOR',0x00000010)
		win_const_mgr.add_const('SCESTATUS_BUFFER_TOO_SMALL',0x00000005)
		win_const_mgr.add_const('CERT_STORE_LOCALIZED_NAME_PROP_ID',0x00001000)
		win_const_mgr.add_const('CMIC_MASK_SHIFT_DOWN',0x10000000)
		win_const_mgr.add_const('WTS_CONSOLE_DISCONNECT',0x00000002)
		win_const_mgr.add_const('WNFMT_ABBREVIATED',0x00000002)
		win_const_mgr.add_const('PORT_NSWFE',0x0000001B)
		win_const_mgr.add_const('SAP_FIELD_ABSENT',0xFFFFFFFE)
		win_const_mgr.add_const('IDM_UNKNOWN',0x00000000)
		win_const_mgr.add_const('MQMSG_AUTHENTICATED_SIG10',0x00000001)
		win_const_mgr.add_const('RTCMT_AUDIO_SEND',0x00000001)
		win_const_mgr.add_const('BAUD_110',0x00000002)
		win_const_mgr.add_const('LV_VIEW_SMALLICON',0x00000002)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_CTL_NOT_TIME_VALID_FLAG',0x00000002)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_ROLLBACK_COMPLETE',0x00000080)
		win_const_mgr.add_const('BITS_MC_PEERCACHING_PORT',0x8019400A)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_RECORDER',0x00000100)
		win_const_mgr.add_const('CS_INSERTCHAR',0x00002000)
		win_const_mgr.add_const('MPR_INTERFACE_SERVICE_PAUSED',0x00000008)
		win_const_mgr.add_const('WINHTTP_OPTION_SECURITY_KEY_BITNESS',0x00000024)
		win_const_mgr.add_const('SCARD_E_TIMEOUT',0x8010000A)
		win_const_mgr.add_const('SPI_GETICONTITLELOGFONT',0x0000001F)
		win_const_mgr.add_const('PDH_LOG_TYPE_UNDEFINED',0x00000000)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_NO_EDITING_CHANNELS',0x00001D01)
		win_const_mgr.add_const('GESTURE_TRIANGLE',0x00000000)
		win_const_mgr.add_const('TLS1_ALERT_DECRYPT_ERROR',0x00000033)
		win_const_mgr.add_const('SQL_INDEX_HASHED',0x00000002)
		win_const_mgr.add_const('PRODUCT_ENTERPRISE_SERVER_CORE',0x0000000E)
		win_const_mgr.add_const('CTL_FIND_SHA1_HASH',0x00000001)
		win_const_mgr.add_const('CRLF_ENFORCE_ENROLLMENT_AGENT',0x00000400)
		win_const_mgr.add_const('KP_RB',0x00000011)
		win_const_mgr.add_const('SQL_API_SQLSETDESCREC',0x000003FA)
		win_const_mgr.add_const('CERT_STORE_CTRL_RESYNC',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_WRONG_OS_VERSION',0x0000170B)
		win_const_mgr.add_const('ERROR_PRIVATE_DIALOG_INDEX',0x00000587)
		win_const_mgr.add_const('WM_MENUCHAR',0x00000120)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_NONREENTRANT',0x00000100)
		win_const_mgr.add_const('ERROR_DBG_CONTROL_BREAK',0x000002B8)
		win_const_mgr.add_const('ERROR_SERVICE_NEVER_STARTED',0x00000435)
		win_const_mgr.add_const('CERT_TRUST_PUB_ALLOW_END_USER_TRUST',0x00000000)
		win_const_mgr.add_const('SQL_CONVERT_BIGINT',0x00000035)
		win_const_mgr.add_const('LINEFEATURE_FORWARD',0x00000004)
		win_const_mgr.add_const('WMDM_MODE_QUERY',0x00000020)
		win_const_mgr.add_const('D3DFVF_DIFFUSE',0x00000040)
		win_const_mgr.add_const('TVIS_EX_DISABLED',0x00000002)
		win_const_mgr.add_const('ERROR_INSTALL_UI_FAILURE',0x00000655)
		win_const_mgr.add_const('OID_FDDI_SHORT_CURRENT_ADDR',0x03010106)
		win_const_mgr.add_const('WKSTA_USE512BYTESMAXTRANSFER_PARMNUM',0x0000003D)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_UNAUTH_USER_FLOW_RATE',0x00000014)
		win_const_mgr.add_const('URLACTION_SHELL_POPUPMGR',0x00001809)
		win_const_mgr.add_const('SUBLANG_SAMI_SOUTHERN_SWEDEN',0x00000007)
		win_const_mgr.add_const('HTTP_QUERY_PROXY_AUTHENTICATE',0x00000029)
		win_const_mgr.add_const('D3DPS20_MAX_DYNAMICFLOWCONTROLDEPTH',0x00000018)
		win_const_mgr.add_const('MS_RLSD_ON',0x00000080)
		win_const_mgr.add_const('RCVD_RESV_TEAR',0x00000002)
		win_const_mgr.add_const('MODALS_FORCE_LOGOFF_PARMNUM',0x00000004)
		win_const_mgr.add_const('MCI_DGV_FF_MPEG',0x00004007)
		win_const_mgr.add_const('PROV_STT_MER',0x00000007)
		win_const_mgr.add_const('WTNCA_NOMIRRORHELP',0x00000008)
		win_const_mgr.add_const('EC_LOADSTATUS',0x00000043)
		win_const_mgr.add_const('GESTURE_DIAGONAL_RIGHTDOWN',0x00000000)
		win_const_mgr.add_const('BLLI_L3_PACKET_2048',0x0000000B)
		win_const_mgr.add_const('DNS_RTYPE_NAPTR',0x00002300)
		win_const_mgr.add_const('PURGE_RXABORT',0x00000002)
		win_const_mgr.add_const('CTRY_JORDAN',0x000003C2)
		win_const_mgr.add_const('FPS_DISCONNECTED',0x20000400)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_ALL_WELLKNOWN_SIDS',0x80020000)
		win_const_mgr.add_const('DISPID_BEGINDRAG',0x000000CC)
		win_const_mgr.add_const('ERROR_REG_NAT_CONSUMPTION',0x000004ED)
		win_const_mgr.add_const('DT_EDITCONTROL',0x00002000)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_IS_TOPL_CLEANUP_DISABLED',0x00000001)
		win_const_mgr.add_const('PROTO_IP_NT_AUTOSTATIC',0x00002712)
		win_const_mgr.add_const('ACM_METRIC_COUNT_FILTERS',0x00000004)
		win_const_mgr.add_const('HELP_CONTENTS',0x00000003)
		win_const_mgr.add_const('HDS_CHECKBOXES',0x00000400)
		win_const_mgr.add_const('MOUSEEVENTF_HWHEEL',0x00001000)
		win_const_mgr.add_const('TAPE_SPACE_SETMARKS',0x00000008)
		win_const_mgr.add_const('NETE_GENERAL',0x0000000B)
		win_const_mgr.add_const('SQL_DBMS_NAME',0x00000011)
		win_const_mgr.add_const('CRED_FLAGS_USERNAME_TARGET',0x00000004)
		win_const_mgr.add_const('ISC_SHOWUIALL',0xC000000F)
		win_const_mgr.add_const('LOCALE_USE_NLS',0x10000000)
		win_const_mgr.add_const('EXPOSUREMODE_PORTRAIT',0x00000007)
		win_const_mgr.add_const('SIGNATURE_RESOURCE_NUMBER',0x0000029A)
		win_const_mgr.add_const('SQL_CP_RELAXED_MATCH',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_SH3_DIRECT8_LONG',0x00000005)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_STATUS_STRING',0x0000000B)
		win_const_mgr.add_const('AF_CCITT',0x0000000A)
		win_const_mgr.add_const('PID_INTSITE_COMMENT',0x00000008)
		win_const_mgr.add_const('DISPID_NOITEMSTATE_CHANGED',0x000000CE)
		win_const_mgr.add_const('LINEQOSREQUESTTYPE_SERVICELEVEL',0x00000001)
		win_const_mgr.add_const('PC_POLYPOLYGON',0x00000100)
		win_const_mgr.add_const('PIDSI_COMMENTS',0x00000006)
		win_const_mgr.add_const('QITIPF_USESLOWTIP',0x00000008)
		win_const_mgr.add_const('RPC_C_MQ_USE_EXISTING_SECURITY',0x00000004)
		win_const_mgr.add_const('USER_WORKSTATION_TRUST_ACCOUNT',0x00000080)
		win_const_mgr.add_const('FEI_ANSWERED',0x00000015)
		win_const_mgr.add_const('LINEAGENTSTATEEX_BUSYACD',0x00000004)
		win_const_mgr.add_const('OID_CO_TAPI_TRANSLATE_TAPI_CALLPARAMS',0xFE001004)
		win_const_mgr.add_const('COLOR_INFOTEXT',0x00000017)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_MSGWAITOFF',0x00000009)
		win_const_mgr.add_const('TMTVS_RESERVEDHIGH',0x00004E1F)
		win_const_mgr.add_const('COLOR_INFOBK',0x00000018)
		win_const_mgr.add_const('META_SETMAPPERFLAGS',0x00000231)
		win_const_mgr.add_const('BLLI_L3_X25',0x00000006)
		win_const_mgr.add_const('IF_ENFORCEENCRYPTICERTADMIN',0x00000400)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_REQUEST_OUTCOME',0x20000000)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_SECRELHI',0x00000012)
		win_const_mgr.add_const('SSF_SEPPROCESS',0x00080000)
		win_const_mgr.add_const('R2_LAST',0x00000010)
		win_const_mgr.add_const('TSF_COPY_CREATION_TIME',0x00000010)
		win_const_mgr.add_const('OLEUI_ERR_CBSTRUCTINCORRECT',0x00000067)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_UPLEVEL_ONLY',0x00000002)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_PRINT_OPS',0x00000226)
		win_const_mgr.add_const('CLIP_MASK',0x00000000)
		win_const_mgr.add_const('ISC_RET_MANUAL_CRED_VALIDATION',0x00080000)
		win_const_mgr.add_const('PORT_LAMAINT',0x00000033)
		win_const_mgr.add_const('DNS_RCODE_BADTIME',0x00000012)
		win_const_mgr.add_const('ERROR_BAD_CONFIGURATION',0x0000064A)
		win_const_mgr.add_const('MD_NETLOGON_WKS_DNS',0x00000002)
		win_const_mgr.add_const('IDC_IO_FILETEXT',0x00000840)
		win_const_mgr.add_const('CM_ADD_ID_HARDWARE',0x00000000)
		win_const_mgr.add_const('ERROR_UNABLE_TO_INVENTORY_SLOT',0x000010E6)
		win_const_mgr.add_const('PROGDLG_NOCANCEL',0x00000040)
		win_const_mgr.add_const('MAPI_DEFAULT_SERVICES',0x00000001)
		win_const_mgr.add_const('IDM_COPYSHORTCUT',0x000008D6)
		win_const_mgr.add_const('DBPROPVAL_SQL_ESCAPECLAUSES',0x00000100)
		win_const_mgr.add_const('SHDID_FS_DIRECTORY',0x00000003)
		win_const_mgr.add_const('CR_INVALID_RANGE',0x00000012)
		win_const_mgr.add_const('RMNAMESZ',0x00000020)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_MINIPORT_PNP_CHARACTERISTICS',0x00000092)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_BROADCAST_BYTES_RCV',0x00040000)
		win_const_mgr.add_const('DEVICE_DRIVER_INSTALL',0x0000000A)
		win_const_mgr.add_const('TF_LBI_STATUS',0x00010000)
		win_const_mgr.add_const('DBPROPVAL_TS_HISTOGRAM',0x00000002)
		win_const_mgr.add_const('PSINJECT_BEGINPROLOG',0x0000000E)
		win_const_mgr.add_const('WTS_SESSION_LOCK',0x00000007)
		win_const_mgr.add_const('CF_DEFER',0x00000002)
		win_const_mgr.add_const('PD_EXCLUSIONFLAGS',0x01000000)
		win_const_mgr.add_const('UDN_LAST',0x00000000)
		win_const_mgr.add_const('DNS_RTYPE_GPOS',0x00000001)
		win_const_mgr.add_const('LINEDEVSTATE_RINGING',0x00000002)
		win_const_mgr.add_const('DTRESULTOK',0x00000000)
		win_const_mgr.add_const('NM_FIRST',0x00000000)
		win_const_mgr.add_const('LVGF_STATE',0x00000004)
		win_const_mgr.add_const('TMT_SIZINGTYPE',0x00000FA4)
		win_const_mgr.add_const('XP_CONNECTIONLESS',0x00000001)
		win_const_mgr.add_const('EAP_E_AUTHENTICATION_FAILED',0x80420015)
		win_const_mgr.add_const('GPO_LIST_FLAG_MACHINE',0x00000001)
		win_const_mgr.add_const('DNS_UPDATE_CACHE_SECURITY_CONTEXT',0x00000200)
		win_const_mgr.add_const('IDS_CAP_WRITEERROR',0x0000019E)
		win_const_mgr.add_const('SPI_GETFONTSMOOTHING',0x0000004A)
		win_const_mgr.add_const('PS_JOIN_MASK',0x0000F000)
		win_const_mgr.add_const('MDPROPVAL_MNF_LINREGPOINT',0x00000400)
		win_const_mgr.add_const('IDM_SHOWALLTAGS',0x00000917)
		win_const_mgr.add_const('LINEAGENTSTATEEX_BUSYOUTGOING',0x00000010)
		win_const_mgr.add_const('MEDIASINK_FIXED_STREAMS',0x00000001)
		win_const_mgr.add_const('PS_DASH',0x00000001)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_WRONGLENGTH',0x00000008)
		win_const_mgr.add_const('OFN_PATHMUSTEXIST',0x00000800)
		win_const_mgr.add_const('HTTP_ADDREQ_FLAGS_MASK',0xFFFF0000)
		win_const_mgr.add_const('D3DPS20_MIN_STATICFLOWCONTROLDEPTH',0x00000000)
		win_const_mgr.add_const('EVENT_OBJECT_TEXTSELECTIONCHANGED',0x00008014)
		win_const_mgr.add_const('SSRVOPT_DWORDPTR',0x00000004)
		win_const_mgr.add_const('RPC_BHO_EXCLUSIVE_AND_GUARANTEED',0x00000004)
		win_const_mgr.add_const('EN_MSGFILTER',0x00000700)
		win_const_mgr.add_const('E_FILTER_SERVERSCRIPT',0x80100002)
		win_const_mgr.add_const('LINEERR_INVALRATE',0x80000037)
		win_const_mgr.add_const('F_DUPLICATE',0x0000000F)
		win_const_mgr.add_const('CB_GETHORIZONTALEXTENT',0x00000015)
		win_const_mgr.add_const('DDSCAPS3_DMAP',0x00001000)
		win_const_mgr.add_const('CS_SAVEBITS',0x00000800)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_NOPSTNADDRESSTRANSLATION',0x80000000)
		win_const_mgr.add_const('MAPI_E_TOO_MANY_SESSIONS',0x00000008)
		win_const_mgr.add_const('HP_HASHSIZE',0x00000004)
		win_const_mgr.add_const('MWT_IDENTITY',0x00000001)
		win_const_mgr.add_const('PRIORITY_EQUAL_FIRST',0x00000008)
		win_const_mgr.add_const('TMT_TEXTGLOW',0x000008A9)
		win_const_mgr.add_const('MDPROPVAL_AU_UNSUPPORTED',0x00000000)
		win_const_mgr.add_const('RPC_C_BINDING_MAX_TIMEOUT',0x00000009)
		win_const_mgr.add_const('CFERR_NOFONTS',0x00002001)
		win_const_mgr.add_const('SYMFLAG_VALUEPRESENT',0x00000001)
		win_const_mgr.add_const('WM_MOUSEHOVER',0x000002A1)
		win_const_mgr.add_const('C2_WHITESPACE',0x0000000A)
		win_const_mgr.add_const('ERROR_INVALID_DOMAIN_ROLE',0x0000054A)
		win_const_mgr.add_const('LVS_EX_SINGLEROW',0x00040000)
		win_const_mgr.add_const('KS_VIDEO_ALLOC_VPE_DISPLAY',0x00000002)
		win_const_mgr.add_const('GESTURE_UP',0x00000000)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_UNPROTECTED_FLAG',0x40000000)
		win_const_mgr.add_const('SERVICE_CONTROL_SHUTDOWN',0x00000005)
		win_const_mgr.add_const('SV_ALERTS_PARMNUM',0x0000000B)
		win_const_mgr.add_const('CRYPT_WIRE_ONLY_RETRIEVAL',0x00000004)
		win_const_mgr.add_const('USER_SMARTCARD_REQUIRED',0x00001000)
		win_const_mgr.add_const('IDD_DYNAWIZ_ANALYZE_PREVPAGE',0x00002713)
		win_const_mgr.add_const('BLUE_SHIFT',0x00000000)
		win_const_mgr.add_const('FWPS_FILTER_FLAG_PERMIT_IF_CALLOUT_UNREGISTERED',0x00000002)
		win_const_mgr.add_const('OUTPUT_DEBUG_STRING_EVENT',0x00000008)
		win_const_mgr.add_const('MD_SERVER_STATE_STOPPED',0x00000004)
		win_const_mgr.add_const('LVFIF_STATE',0x00000002)
		win_const_mgr.add_const('CR_PROP_ADVANCEDSERVER',0x0000001C)
		win_const_mgr.add_const('ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER',0x00002144)
		win_const_mgr.add_const('INTERNET_FLAG_NO_UI',0x00000200)
		win_const_mgr.add_const('MDPROPVAL_MMF_COUSIN',0x00000001)
		win_const_mgr.add_const('MAPI_E_INVALID_MESSAGE',0x00000011)
		win_const_mgr.add_const('DEBUG_OUTSYM_SOURCE_LINE',0x00000002)
		win_const_mgr.add_const('ERROR_ENLISTMENT_NOT_FOUND',0x00001A3D)
		win_const_mgr.add_const('PID_VOLUME_CAPACITY',0x00000003)
		win_const_mgr.add_const('SUBLANG_SOTHO_NORTHERN_SOUTH_AFRICA',0x00000001)
		win_const_mgr.add_const('NT_RR_SIZE',0x00000004)
		win_const_mgr.add_const('RESOURCE_CONTEXT',0x00000005)
		win_const_mgr.add_const('TF_IPSINK_FLAG_ACTIVE',0x00000001)
		win_const_mgr.add_const('LINEADDRESSSHARING_BRIDGEDEXCL',0x00000002)
		win_const_mgr.add_const('RI_MOUSE_MIDDLE_BUTTON_UP',0x00000020)
		win_const_mgr.add_const('OBJ_ENHMETADC',0x0000000C)
		win_const_mgr.add_const('OID_GEN_VENDOR_DRIVER_VERSION',0x00010116)
		win_const_mgr.add_const('WIA_PACKED_PIXEL',0x00000000)
		win_const_mgr.add_const('DLG_COLOR',0x0000000A)
		win_const_mgr.add_const('CERT_TRUST_NO_ISSUANCE_CHAIN_POLICY',0x02000000)
		win_const_mgr.add_const('HANDLE_FLAG_INHERIT',0x00000001)
		win_const_mgr.add_const('SUPPORTS_ANY',0xFFFFFFFF)
		win_const_mgr.add_const('TCP_BSDURGENT',0x00007000)
		win_const_mgr.add_const('WIA_IPS_SEGMENTATION',0x00001814)
		win_const_mgr.add_const('NI_MAXSERV',0x00000020)
		win_const_mgr.add_const('D3DSI_COISSUE',0x40000000)
		win_const_mgr.add_const('AE_SRVSTOP',0x00000003)
		win_const_mgr.add_const('SQL_BP_OTHER_HSTMT',0x00000020)
		win_const_mgr.add_const('SCROLLLOCK_ON',0x00000040)
		win_const_mgr.add_const('ERROR_SERVER_DISABLED',0x0000053D)
		win_const_mgr.add_const('GLOBAL_ALL',0x00000000)
		win_const_mgr.add_const('VSS_SW_BOOTABLE_STATE',0x00000001)
		win_const_mgr.add_const('WIA_DPC_UPLOAD_URL',0x0000082A)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_PREPREPARE',0x00000001)
		win_const_mgr.add_const('FD_ROUTING_INTERFACE_CHANGE',0x00000001)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_IAT',0x0000000C)
		win_const_mgr.add_const('TCIF_RTLREADING',0x00000004)
		win_const_mgr.add_const('IDM_REMOVEFROMGLYPHTABLE',0x00000922)
		win_const_mgr.add_const('DNS_ATMA_MAX_ADDR_LENGTH',0x00000014)
		win_const_mgr.add_const('SBSP_HELPMODE',0x00000040)
		win_const_mgr.add_const('SNMPAPI_UNTRANSLATED_V1',0x00000001)
		win_const_mgr.add_const('SRCLIST_NOSTRIPPLATFORM',0x00000400)
		win_const_mgr.add_const('SQL_OU_TABLE_DEFINITION',0x00000004)
		win_const_mgr.add_const('RC_BITMAP64',0x00000008)
		win_const_mgr.add_const('CM_PROB_FAILED_DRIVER_ENTRY',0x00000025)
		win_const_mgr.add_const('AE_SESSDIS',0x00000001)
		win_const_mgr.add_const('ERROR_UNRECOGNIZED_VOLUME',0x000003ED)
		win_const_mgr.add_const('PROPCALLER_ADMIN',0x00000400)
		win_const_mgr.add_const('PIDSI_ALBUM',0x00000004)
		win_const_mgr.add_const('DNS_ERROR_NODE_CREATION_FAILED',0x000025E7)
		win_const_mgr.add_const('WHITEBALANCE_MANUAL',0x00000001)
		win_const_mgr.add_const('OID_FDDI_PORT_PC_WITHHOLD',0x03030274)
		win_const_mgr.add_const('PCIC_DEFAULT_NUMSOCKETS',0x00000000)
		win_const_mgr.add_const('LINEAGENTSTATUS_GROUPLIST',0x00000020)
		win_const_mgr.add_const('FILE_NOTIFY_CHANGE_LAST_ACCESS',0x00000020)
		win_const_mgr.add_const('ERROR_PORT_NOT_SET',0x00000282)
		win_const_mgr.add_const('ACTRL_DS_LIST',0x00000004)
		win_const_mgr.add_const('SOL_SDP',0x00000101)
		win_const_mgr.add_const('DISPID_EXPANDO_MAX',0x003D08FF)
		win_const_mgr.add_const('PID_KEYWORDS',0x00000005)
		win_const_mgr.add_const('URLOSTRM_USECACHEDCOPY',0x00000002)
		win_const_mgr.add_const('LINEDEVSTATE_OUTOFSERVICE',0x00000080)
		win_const_mgr.add_const('DMPAPER_A4_ROTATED',0x0000004D)
		win_const_mgr.add_const('ERROR_CRASH_DUMP',0x000002F1)
		win_const_mgr.add_const('BSF_FLUSHDISK',0x00000004)
		win_const_mgr.add_const('DAOROWFETCH_FORCEREFRESH',0x00000004)
		win_const_mgr.add_const('OID_FDDI_MAC_ERROR_CT',0x0303023F)
		win_const_mgr.add_const('IF_TYPE_VDSL',0x00000061)
		win_const_mgr.add_const('SUBLANG_SPANISH_PUERTO_RICO',0x00000014)
		win_const_mgr.add_const('PHOTO_WHITEBALANCE_AUTO',0x00000000)
		win_const_mgr.add_const('WAVECAPS_LRVOLUME',0x00000008)
		win_const_mgr.add_const('IMAGE_REL_IA64_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('ERROR_DS_DNS_LOOKUP_FAILURE',0x0000214C)
		win_const_mgr.add_const('OID_FDDI_MAC_T_MAX',0x03030232)
		win_const_mgr.add_const('LINEDEVSTATE_COMPLCANCEL',0x00800000)
		win_const_mgr.add_const('CMC_FAIL_NO_KEY_REUSE',0x0000000A)
		win_const_mgr.add_const('MAXIMUM_CACHE_SIZE',0x00000080)
		win_const_mgr.add_const('SUCCEED',0x00000001)
		win_const_mgr.add_const('URLACTION_MIN',0x00001000)
		win_const_mgr.add_const('INTERNET_OPTION_AUTODIAL_CONNECTION',0x00000053)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('JOY_RETURNCENTERED',0x00000400)
		win_const_mgr.add_const('FIND_POS',0x00000000)
		win_const_mgr.add_const('DCX_EXCLUDERGN',0x00000040)
		win_const_mgr.add_const('EVCF_REMOVEFROMLIST',0x00000004)
		win_const_mgr.add_const('SSRVACTION_EVENTW',0x00000004)
		win_const_mgr.add_const('CERT_RDN_ENABLE_T61_UNICODE_FLAG',0x80000000)
		win_const_mgr.add_const('BTH_ERROR_SCO_INTERVAL_REJECTED',0x00000001)
		win_const_mgr.add_const('CERT_STORE_SAVE_TO_FILENAME_A',0x00000003)
		win_const_mgr.add_const('ERROR_ABANDONED_WAIT_0',0x000002DF)
		win_const_mgr.add_const('SQL_API_SQLGETCURSORNAME',0x00000011)
		win_const_mgr.add_const('UINT8_MAX',0x00000000)
		win_const_mgr.add_const('SERVICE_NO_CHANGE',0x00000000)
		win_const_mgr.add_const('AE_SRVCONT',0x00000002)
		win_const_mgr.add_const('RPC_S_GRP_ELT_NOT_REMOVED',0x00000789)
		win_const_mgr.add_const('ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT',0x0000083D)
		win_const_mgr.add_const('DDGFS_ISFLIPDONE',0x00000002)
		win_const_mgr.add_const('COD_PHONE_MINOR_CELLULAR',0x00000001)
		win_const_mgr.add_const('ACMFORMATDETAILS_FORMAT_CHARS',0x00000080)
		win_const_mgr.add_const('TAPE_SHORT_FILEMARKS',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INCOMPLETE_ENCODING',0x000036DB)
		win_const_mgr.add_const('CTRY_PUERTO_RICO',0x00000001)
		win_const_mgr.add_const('VIF_CANNOTDELETE',0x00001000)
		win_const_mgr.add_const('META_SETROP2',0x00000104)
		win_const_mgr.add_const('IN_CLASSA_HOST',0x00000000)
		win_const_mgr.add_const('DSSI_NO_FILTER',0x00000020)
		win_const_mgr.add_const('DS_REPSYNC_NOTIFICATION',0x00080000)
		win_const_mgr.add_const('RESOURCE_CONNECTED',0x00000001)
		win_const_mgr.add_const('PARTTYPE_FLAG_SUBUNIT',0x00020000)
		win_const_mgr.add_const('CMSG_CTRL_ADD_SIGNER_UNAUTH_ATTR',0x00000008)
		win_const_mgr.add_const('TF_SFT_NOTRANSPARENCY',0x00000010)
		win_const_mgr.add_const('SQL_FN_TD_EXTRACT',0x00100000)
		win_const_mgr.add_const('IDM_HTMLSOURCE',0x0000086D)
		win_const_mgr.add_const('GTL_PRECISE',0x00000002)
		win_const_mgr.add_const('ISSP_LEVEL',0x00000020)
		win_const_mgr.add_const('IF_TYPE_ATM_RADIO',0x000000BD)
		win_const_mgr.add_const('DWFRF_DELETECONFIGDATA',0x00000001)
		win_const_mgr.add_const('ERROR_EAS_DIDNT_FIT',0x00000113)
		win_const_mgr.add_const('VFT2_UNKNOWN',0x00000000)
		win_const_mgr.add_const('IDTR_PS',0x00000002)
		win_const_mgr.add_const('TOKEN_ADJUST_GROUPS',0x00000040)
		win_const_mgr.add_const('TF_SFT_SHOWNORMAL',0x00000001)
		win_const_mgr.add_const('D3D10_MIN_DEPTH',0x00000000)
		win_const_mgr.add_const('ACCESS_ALLOWED_ACE_TYPE',0x00000000)
		win_const_mgr.add_const('PSPROTOCOL_BINARY',0x00000003)
		win_const_mgr.add_const('CERT_FILTER_OP_EQUALITY',0x00000003)
		win_const_mgr.add_const('OBJ_PAL',0x00000005)
		win_const_mgr.add_const('ERROR_WMI_READ_ONLY',0x00001075)
		win_const_mgr.add_const('CR_FLG_VALIDENCRYPTEDKEYHASH',0x00000040)
		win_const_mgr.add_const('NO_INHERITANCE',0x00000000)
		win_const_mgr.add_const('PRIVATEOBJECT_NONE',0x00000001)
		win_const_mgr.add_const('WMDM_FILE_ATTR_DATA',0x00002000)
		win_const_mgr.add_const('LVNI_PREVIOUS',0x00000020)
		win_const_mgr.add_const('INTERNET_OPTION_HTTP_VERSION',0x0000003B)
		win_const_mgr.add_const('RESOURCEUSAGE_CONNECTABLE',0x00000001)
		win_const_mgr.add_const('URLACTION_HTML_META_REFRESH',0x00001608)
		win_const_mgr.add_const('GR_GDIOBJECTS',0x00000000)
		win_const_mgr.add_const('C3_ALPHA',0x00008000)
		win_const_mgr.add_const('DDBLT_DONOTWAIT',0x08000000)
		win_const_mgr.add_const('TAPE_DRIVE_RESERVED_BIT',0x80000000)
		win_const_mgr.add_const('IME_ITHOTKEY_RECONVERTSTRING',0x00000203)
		win_const_mgr.add_const('ACMDRIVERDETAILS_SHORTNAME_CHARS',0x00000020)
		win_const_mgr.add_const('LSFW_LOCK',0x00000001)
		win_const_mgr.add_const('WIA_IPS_XPOS',0x00001805)
		win_const_mgr.add_const('META_SETTEXTCHAREXTRA',0x00000108)
		win_const_mgr.add_const('CAC_PREFIX',0x00000001)
		win_const_mgr.add_const('BL_DRIVER1_INDEX',0x00000003)
		win_const_mgr.add_const('D3DPRESENT_INTERVAL_THREE',0x00000004)
		win_const_mgr.add_const('OID_GEN_RCV_DISCARDS',0x0002021B)
		win_const_mgr.add_const('LVIF_NORECOMPUTE',0x00000800)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETQUEUELIST',0x00000010)
		win_const_mgr.add_const('BSSF_VISIBLE',0x00000001)
		win_const_mgr.add_const('TC_CR_90',0x00000008)
		win_const_mgr.add_const('SP_COPY_RESERVED',0x00020000)
		win_const_mgr.add_const('STI_HW_CONFIG_UNKNOWN',0x00000001)
		win_const_mgr.add_const('PXE_CALLBACK_MAX',0x00000003)
		win_const_mgr.add_const('ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION',0x00001718)
		win_const_mgr.add_const('CLIP_STROKE_PRECIS',0x00000002)
		win_const_mgr.add_const('CRYPT_SILENT',0x00000040)
		win_const_mgr.add_const('PIR_STATUS_MINIPORT_SUCCESS',0x00000006)
		win_const_mgr.add_const('ICMF_CHOOSE_ALLCOMPRESSORS',0x00000008)
		win_const_mgr.add_const('WM_CTLCOLORBTN',0x00000135)
		win_const_mgr.add_const('MCI_VCR_STATUS_POWER_ON',0x0000401B)
		win_const_mgr.add_const('AM_AC3_SERVICE_HEARING_IMPAIRED',0x00000003)
		win_const_mgr.add_const('LINECALLPARAMFLAGS_SECURE',0x00000001)
		win_const_mgr.add_const('GQOS_NO_ERRORVALUE',0x00000000)
		win_const_mgr.add_const('FWPM_CALLOUT_FLAG_REGISTERED',0x00040000)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_HANDLE_CLOSING',0x00000800)
		win_const_mgr.add_const('EXTEND_IEPORT',0x00000002)
		win_const_mgr.add_const('DACL_SECURITY_INFORMATION',0x00000004)
		win_const_mgr.add_const('SIZE_DVINFO',0x00000020)
		win_const_mgr.add_const('MSIASSEMBLYINFO_WIN32ASSEMBLY',0x00000001)
		win_const_mgr.add_const('RENDBIND_DEFAULTDOMAINNAME',0x00000002)
		win_const_mgr.add_const('F_NOTITLE',0x0000000C)
		win_const_mgr.add_const('SUB_CONTAINERS_AND_OBJECTS_INHERIT',0x00000003)
		win_const_mgr.add_const('VIDCF_DRAW',0x00000010)
		win_const_mgr.add_const('STARTF_USESHOWWINDOW',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_CONTEXT_VALUE_OLD',0x0000000A)
		win_const_mgr.add_const('IDN_ALLOW_UNASSIGNED',0x00000001)
		win_const_mgr.add_const('COOKIEACTION_DOWNGRADE',0x00000004)
		win_const_mgr.add_const('APPCOMMAND_VOLUME_DOWN',0x00000009)
		win_const_mgr.add_const('EAP_I_USER_LAST',0x404201FF)
		win_const_mgr.add_const('ERROR_CTX_TD_ERROR',0x00001B69)
		win_const_mgr.add_const('TF_DTLBI_USEPROFILEICON',0x00000001)
		win_const_mgr.add_const('EMBDHLP_INPROC_HANDLER',0x00000000)
		win_const_mgr.add_const('RTCRMF_WATCHER_ROAMING',0x00000002)
		win_const_mgr.add_const('IT_MSG_FILE_PREVIEW_DATA',0x00000006)
		win_const_mgr.add_const('QDI_STRETCHDIB',0x00000008)
		win_const_mgr.add_const('PRIHIGHEST',0x00007FFF)
		win_const_mgr.add_const('DISPID_EXPANDO_BASE',0x002DC6C0)
		win_const_mgr.add_const('TCS_BOTTOM',0x00000002)
		win_const_mgr.add_const('OCR_APPSTARTING',0x00007F8A)
		win_const_mgr.add_const('GT_CODE',0x00000003)
		win_const_mgr.add_const('EMO_EXPANDDOCUMENT',0x00000001)
		win_const_mgr.add_const('CHANNEL_RC_NOT_INITIALIZED',0x00000002)
		win_const_mgr.add_const('KDF_SECRET_PREPEND',0x00000001)
		win_const_mgr.add_const('INDEX_GUID_CONTENTTYPE',0x00000006)
		win_const_mgr.add_const('MM_JOY2MOVE',0x000003A1)
		win_const_mgr.add_const('D3DADAPTER_DEFAULT',0x00000000)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_REMOTE',0x00000020)
		win_const_mgr.add_const('MCI_DGV_FILE_MODE_EDITING',0x00000003)
		win_const_mgr.add_const('SQL_SEARCH_PATTERN_ESCAPE',0x0000000E)
		win_const_mgr.add_const('ERROR_DS_OBJ_CLASS_NOT_SUBCLASS',0x000020B4)
		win_const_mgr.add_const('RTM_VIEW_MASK_ALL',0xFFFFFFFF)
		win_const_mgr.add_const('VS_FF_INFOINFERRED',0x00000010)
		win_const_mgr.add_const('DN_PRIVATE_PROBLEM',0x00008000)
		win_const_mgr.add_const('IDM_CHANGECASE',0x000008C6)
		win_const_mgr.add_const('COMMPROP_INITIALIZED',0xE73CF52E)
		win_const_mgr.add_const('MDM_MASK_HDLCPPP_SPEED',0x00000007)
		win_const_mgr.add_const('FONTDLGORD',0x00000606)
		win_const_mgr.add_const('IDM_ADDTOGLYPHTABLE',0x00000921)
		win_const_mgr.add_const('IS_TEXT_UNICODE_ODD_LENGTH',0x00000200)
		win_const_mgr.add_const('IITR_ATTRIBUTE_PPN_MASK',0x3FFFFFFFFF000)
		win_const_mgr.add_const('ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE',0x000007DF)
		win_const_mgr.add_const('AD_APPLY_HTMLGEN',0x00000002)
		win_const_mgr.add_const('GOPHER_TYPE_BITMAP',0x00004000)
		win_const_mgr.add_const('LPD_SWAP_EXCHANGE',0x00000200)
		win_const_mgr.add_const('META_ESCAPE',0x00000626)
		win_const_mgr.add_const('WIA_DATA_RAW_YUV',0x00000008)
		win_const_mgr.add_const('SECPKG_ATTR_CLIENT_CERT_POLICY',0x00000060)
		win_const_mgr.add_const('TBIF_INTERNETBAR',0x00010000)
		win_const_mgr.add_const('PROPCALLER_SERVER',0x00000100)
		win_const_mgr.add_const('ACM_METRIC_COUNT_CONVERTERS',0x00000003)
		win_const_mgr.add_const('SQL_BATCH_SUPPORT',0x00000079)
		win_const_mgr.add_const('FILE_DIR_DISALLOWED',0x00000009)
		win_const_mgr.add_const('OID_LTALK_COLLISIONS',0x05020202)
		win_const_mgr.add_const('WLX_OPTION_FORCE_LOGOFF_TIME',0x00000004)
		win_const_mgr.add_const('PD_PRINTTOFILE',0x00000020)
		win_const_mgr.add_const('DMPAPER_A3_EXTRA_TRANSVERSE',0x00000044)
		win_const_mgr.add_const('LOGON_NTLMV2_ENABLED',0x00000100)
		win_const_mgr.add_const('RBBS_CHILDEDGE',0x00000004)
		win_const_mgr.add_const('VTDATEGRE_MAX',0x002D2481)
		win_const_mgr.add_const('PFL_RECOMMENDED_PROTO_ENTRY',0x00000002)
		win_const_mgr.add_const('SQL_ATTR_CP_MATCH',0x000000CA)
		win_const_mgr.add_const('WMDM_E_LICENSE_EXPIRED',0x80045012)
		win_const_mgr.add_const('CTRY_MALAYSIA',0x0000003C)
		win_const_mgr.add_const('VT_VERBOSE_ENUM',0x0000004C)
		win_const_mgr.add_const('MDM_SHIFT_V120_ML',0x00000006)
		win_const_mgr.add_const('DBPROP_CI_INCLUDE_SCOPES',0x00000003)
		win_const_mgr.add_const('OID_802_11_RSSI_TRIGGER',0x0D010207)
		win_const_mgr.add_const('SO_SYNCHRONOUS_NONALERT',0x00000020)
		win_const_mgr.add_const('DESKTOP_SWITCHDESKTOP',0x00000100)
		win_const_mgr.add_const('STXTLEN',0x00000100)
		win_const_mgr.add_const('IDM_JUSTIFYRIGHT',0x0000003C)
		win_const_mgr.add_const('METADATA_MAX_NAME_LEN',0x00000100)
		win_const_mgr.add_const('ERROR_MEMBERS_PRIMARY_GROUP',0x0000055E)
		win_const_mgr.add_const('SOCK_DGRAM',0x00000002)
		win_const_mgr.add_const('WIA_IPS_CONTRAST',0x0000180B)
		win_const_mgr.add_const('ERROR_INSTALL_FAILURE',0x00000643)
		win_const_mgr.add_const('KSALLOCATOR_REQUIREMENTF_SYSTEM_MEMORY',0x00000002)
		win_const_mgr.add_const('MCI_VCR_SET_ASSEMBLE_RECORD',0x00200000)
		win_const_mgr.add_const('IDM_FIND',0x00000043)
		win_const_mgr.add_const('DIGCDP_FLAG_ADVANCED',0x00000002)
		win_const_mgr.add_const('ADMIN_STATE_ENABLED_ONLY_FOR_NETBIOS_STATIC_ROUTING',0x00000003)
		win_const_mgr.add_const('SOFTDIST_ADSTATE_NONE',0x00000000)
		win_const_mgr.add_const('WMDM_SEEK_CURRENT',0x00000002)
		win_const_mgr.add_const('ACTRL_SYNCHRONIZE',0x80000000)
		win_const_mgr.add_const('CERT_STORE_CTRL_INHIBIT_DUPLICATE_HANDLE_FLAG',0x00000001)
		win_const_mgr.add_const('COD_SERVICE_AUDIO',0x00000100)
		win_const_mgr.add_const('DNS_ERROR_RCODE_YXRRSET',0x0000232F)
		win_const_mgr.add_const('CTRL_SHUTDOWN_EVENT',0x00000006)
		win_const_mgr.add_const('MSV1_0_MNS_LOGON',0x01000000)
		win_const_mgr.add_const('MULTICLASSINFO_GETIIDPRIMARY',0x00000004)
		win_const_mgr.add_const('VK_RIGHT',0x00000027)
		win_const_mgr.add_const('RC_BANDING',0x00000002)
		win_const_mgr.add_const('MCI_DELETE',0x00000856)
		win_const_mgr.add_const('WSB_PROP_VBKGCOLOR',0x00000040)
		win_const_mgr.add_const('PORT_GARCON',0x000003E7)
		win_const_mgr.add_const('SQL_OSCC_COMPLIANT',0x00000001)
		win_const_mgr.add_const('WM_ACTIVATEAPP',0x0000001C)
		win_const_mgr.add_const('PD_STRETCHDIB_1_2_OK',0x00000008)
		win_const_mgr.add_const('SE_ERR_DDETIMEOUT',0x0000001C)
		win_const_mgr.add_const('WEBPOST_ERROR_BAD_PROV_PTR',0xC0042113)
		win_const_mgr.add_const('MDM_CCITT_OVERRIDE',0x00000040)
		win_const_mgr.add_const('SQL_OU_PROCEDURE_INVOCATION',0x00000002)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_SHX',0x00000004)
		win_const_mgr.add_const('SQL_SCROLL_FORWARD_ONLY',0x00000000)
		win_const_mgr.add_const('CMSG_VERIFY_SIGNER_CHAIN',0x00000003)
		win_const_mgr.add_const('MEM_DECOMMIT',0x00004000)
		win_const_mgr.add_const('CR_NO_MORE_HW_PROFILES',0x00000023)
		win_const_mgr.add_const('IDM_LIST',0x00000887)
		win_const_mgr.add_const('ERROR_MEDIA_CHANGED',0x00000456)
		win_const_mgr.add_const('PORT_DISCARD',0x00000009)
		win_const_mgr.add_const('SW_RESTORE',0x00000009)
		win_const_mgr.add_const('WHDR_BEGINLOOP',0x00000004)
		win_const_mgr.add_const('SCARD_W_WRONG_CHV',0x8010006B)
		win_const_mgr.add_const('CE_RXOVER',0x00000001)
		win_const_mgr.add_const('FILE_TYPE_CHAR',0x00000002)
		win_const_mgr.add_const('OLEDBVER',0x00000270)
		win_const_mgr.add_const('HTTP_QUERY_STATUS_CODE',0x00000013)
		win_const_mgr.add_const('HHWIN_PROP_USER_POS',0x00000001)
		win_const_mgr.add_const('PHOTO_ORIENTATION_FLIPHORIZONTAL',0x00000002)
		win_const_mgr.add_const('IITWBC_BREAKTYPE_NUMBER',0x00000001)
		win_const_mgr.add_const('INTERNET_PER_CONN_AUTOCONFIG_LAST_DETECT_TIME',0x00000008)
		win_const_mgr.add_const('DS_INSTANCETYPE_NC_COMING',0x00000010)
		win_const_mgr.add_const('CRYPT_OID_INFO_CNG_ALGID_KEY',0x00000005)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_SHORT',0x00000003)
		win_const_mgr.add_const('ERROR_ELEVATION_REQUIRED',0x000002E4)
		win_const_mgr.add_const('GD_DIALOG',0x00000005)
		win_const_mgr.add_const('SPI_GETSTICKYKEYS',0x0000003A)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_DELEGATE_COMMIT',0x00000400)
		win_const_mgr.add_const('IMEA_NEXT',0x00000002)
		win_const_mgr.add_const('GESTURE_DOWN_ARROW_LEFT',0x00000000)
		win_const_mgr.add_const('OID_FDDI_IF_OUT_QLEN',0x0303028C)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_FRAMES',0x0000044C)
		win_const_mgr.add_const('DT_DISPFILE',0x00000006)
		win_const_mgr.add_const('GAA_FLAG_SKIP_FRIENDLY_NAME',0x00000020)
		win_const_mgr.add_const('LINECALLFEATURE_MONITORTONES',0x00004000)
		win_const_mgr.add_const('STGM_DELETEONRELEASE',0x04000000)
		win_const_mgr.add_const('DDSPD_VOLATILE',0x00000002)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_408',0x80190198)
		win_const_mgr.add_const('APPCOMMAND_DICTATE_OR_COMMAND_CONTROL_TOGGLE',0x0000002B)
		win_const_mgr.add_const('NO_PRIORITY',0x00000000)
		win_const_mgr.add_const('SO_REGISTER_NAME',0x0000A000)
		win_const_mgr.add_const('HTTP_SERVICE_CONFIG_SSL_FLAG_USE_DS_MAPPER',0x00000001)
		win_const_mgr.add_const('EVENT_HEADER_FLAG_EXTENDED_INFO',0x00000001)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_401',0x80190191)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_400',0x80190190)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_403',0x80190193)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_402',0x80190192)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_405',0x80190195)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_DECODE',0x00000004)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_407',0x80190197)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_406',0x80190196)
		win_const_mgr.add_const('TAPIMEDIATYPE_MULTITRACK',0x00010000)
		win_const_mgr.add_const('ERROR_LONGJUMP',0x000002AA)
		win_const_mgr.add_const('DNS_TYPE_A6',0x00000026)
		win_const_mgr.add_const('CRYPT_KM',0x00000002)
		win_const_mgr.add_const('ERROR_NOACCESS',0x000003E6)
		win_const_mgr.add_const('WINSTA_ACCESSGLOBALATOMS',0x00000020)
		win_const_mgr.add_const('ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE',0x00003AB0)
		win_const_mgr.add_const('GCP_JUSTIFY',0x00010000)
		win_const_mgr.add_const('KSALLOCATOR_REQUIREMENTF_MUST_ALLOCATE',0x00000008)
		win_const_mgr.add_const('CB_SETITEMDATA',0x00000151)
		win_const_mgr.add_const('MDSP_SEEK_EOF',0x00000004)
		win_const_mgr.add_const('INTERNET_SERVICE_GOPHER',0x00000002)
		win_const_mgr.add_const('DISPID_FRAMEBEFORENAVIGATE',0x000000C8)
		win_const_mgr.add_const('DATABITS_7',0x00000004)
		win_const_mgr.add_const('TCN_FIRST',0x00000000)
		win_const_mgr.add_const('TVIF_CHILDREN',0x00000040)
		win_const_mgr.add_const('FILE_SUPPORTS_ENCRYPTION',0x00020000)
		win_const_mgr.add_const('NS_TCPIP_HOSTS',0x0000000B)
		win_const_mgr.add_const('SQL_OWNER_USAGE',0x0000005B)
		win_const_mgr.add_const('IDCLOSE',0x00000008)
		win_const_mgr.add_const('DPROMPT_SUCCESS',0x00000000)
		win_const_mgr.add_const('DAOROWFETCH_DONTADVANCE',0x00000002)
		win_const_mgr.add_const('DIF_NEWDEVICEWIZARD_SELECT',0x0000001B)
		win_const_mgr.add_const('DATABITS_8',0x00000008)
		win_const_mgr.add_const('PBT_APMRESUMECRITICAL',0x00000006)
		win_const_mgr.add_const('FACILITY_FIREWIRE_ERROR_CODE',0x00000012)
		win_const_mgr.add_const('CACHE_NOTIFY_SET_OFFLINE',0x00000200)
		win_const_mgr.add_const('MCI_MCIAVI_PLAY_FULLBY2',0x04000000)
		win_const_mgr.add_const('SSA_LPKANSIFALLBACK',0x08000000)
		win_const_mgr.add_const('DEBUG_OUTSYM_ALLOW_DISPLACEMENT',0x00000004)
		win_const_mgr.add_const('MD_DIRBROW_ENABLED',0x80000000)
		win_const_mgr.add_const('WM_SETICON',0x00000080)
		win_const_mgr.add_const('DEBUG_PROC_DESC_DEFAULT',0x00000000)
		win_const_mgr.add_const('DISPLAY_DEVICE_ATTACHED_TO_DESKTOP',0x00000001)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_8',0x00000008)
		win_const_mgr.add_const('LVS_OWNERDRAWFIXED',0x00000400)
		win_const_mgr.add_const('WMDM_MODE_PROGRESS',0x00000040)
		win_const_mgr.add_const('LG_INCLUDE_INDIRECT',0x00000001)
		win_const_mgr.add_const('NDIS_802_3_MAC_OPTION_PRIORITY',0x00000001)
		win_const_mgr.add_const('D3DLINECAPS_FOG',0x00000010)
		win_const_mgr.add_const('TCP_NODELAY',0x00000001)
		win_const_mgr.add_const('EXPOSUREMETERING_CENTERWEIGHT',0x00000002)
		win_const_mgr.add_const('STARTF_USESIZE',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_CERT_TYPE',0x000035FB)
		win_const_mgr.add_const('LINEERR_INVALCOUNTRYCODE',0x80000022)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_6',0x00000006)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_7',0x00000007)
		win_const_mgr.add_const('SQL_DIAG_SELECT_CURSOR',0x00000055)
		win_const_mgr.add_const('ISSCERT_LDAPURL_OLD',0x00000001)
		win_const_mgr.add_const('LINEMEDIAMODE_MIXED',0x00001000)
		win_const_mgr.add_const('OFFLINESTATUS_OFFLINE_FORCED',0x00000002)
		win_const_mgr.add_const('RTCCS_FAIL_ON_REDIRECT',0x00000002)
		win_const_mgr.add_const('IDM_PASTE',0x0000001A)
		win_const_mgr.add_const('DR_MASK_LEN',0x00000038)
		win_const_mgr.add_const('WNODE_FLAG_INSTANCES_SAME',0x00000040)
		win_const_mgr.add_const('ERROR_DS_UNKNOWN_ERROR',0x000020EF)
		win_const_mgr.add_const('IME_ITHOTKEY_UISTYLE_TOGGLE',0x00000202)
		win_const_mgr.add_const('DIRID_SRCPATH',0x00000001)
		win_const_mgr.add_const('OID_FDDI_PATH_SBA_OVERHEAD',0x03030255)
		win_const_mgr.add_const('WM_CT_BOTTOM_FIELD_FIRST',0x00000020)
		win_const_mgr.add_const('MFE_NO_MULTICAST',0x00000007)
		win_const_mgr.add_const('ERROR_DS_CANT_MOVE_RESOURCE_GROUP',0x00002133)
		win_const_mgr.add_const('DRM_EL_EUL',0x00000020)
		win_const_mgr.add_const('SQL_NEED_DATA',0x00000063)
		win_const_mgr.add_const('CSIDL_FLAG_DONT_UNEXPAND',0x00002000)
		win_const_mgr.add_const('PFD_STEREO',0x00000002)
		win_const_mgr.add_const('SF_NOTIFY_SECURE_PORT',0x00000001)
		win_const_mgr.add_const('CM_DRP_ENUMERATOR_NAME',0x00000017)
		win_const_mgr.add_const('MD_EXTLOG_PROTOCOL_VERSION',0x00080000)
		win_const_mgr.add_const('ERROR_WAKE_SYSTEM_DEBUGGER',0x000002A3)
		win_const_mgr.add_const('HTTP_STATUS_NOT_SUPPORTED',0x000001F5)
		win_const_mgr.add_const('PDCAP_S5_SUPPORTED',0x02000000)
		win_const_mgr.add_const('DEBUG_STATUS_BREAK',0x00000006)
		win_const_mgr.add_const('SNAPSHOT_POLICY_ALWAYS',0x00000001)
		win_const_mgr.add_const('ASN_PRIMITIVE',0x00000000)
		win_const_mgr.add_const('VK_PA1',0x000000FD)
		win_const_mgr.add_const('TRANSPARENCY_STATIC_FRAME_SUPPORT',0x00000002)
		win_const_mgr.add_const('MEDIASINK_REQUIRE_REFERENCE_MEDIATYPE',0x00000020)
		win_const_mgr.add_const('BLLI_L3_PACKET_256',0x00000008)
		win_const_mgr.add_const('VER_NT_DOMAIN_CONTROLLER',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_RPC_DELETE',0x00003635)
		win_const_mgr.add_const('PAPS_POSTSAVE',0x00000001)
		win_const_mgr.add_const('HDS_BUTTONS',0x00000002)
		win_const_mgr.add_const('KSAC3_SERVICE_EMERGENCY_FLASH',0x00000006)
		win_const_mgr.add_const('SCF_SELECTION',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_IT_OTHER',0x00000004)
		win_const_mgr.add_const('ERRCLASS_UNK',0x0000000D)
		win_const_mgr.add_const('STREAM_MODIFIED_WHEN_READ',0x00000001)
		win_const_mgr.add_const('SENSITIVITY_PROP_NORMAL',0x00000000)
		win_const_mgr.add_const('SERVICE_INTERROGATE',0x00000080)
		win_const_mgr.add_const('VK_BROWSER_FORWARD',0x000000A7)
		win_const_mgr.add_const('IDM_BLOCKDIRLTR',0x00000930)
		win_const_mgr.add_const('RF_LATTICE',0x00000800)
		win_const_mgr.add_const('ICC_LISTVIEW_CLASSES',0x00000001)
		win_const_mgr.add_const('IF_TYPE_AFLANE_8023',0x0000003B)
		win_const_mgr.add_const('SECPKG_ATTR_KEY_INFO',0x00000005)
		win_const_mgr.add_const('LM20_PATHLEN',0x00000100)
		win_const_mgr.add_const('SQL_NULL_HANDLE',0x00000000)
		win_const_mgr.add_const('OID_FDDI_MAC_TVX_CAPABILITY',0x03030222)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_CONNECT',0x00000007)
		win_const_mgr.add_const('PROPID_QUERY_HITCOUNT',0x00000004)
		win_const_mgr.add_const('PDH_PLA_ERROR_SCHEDULE_OVERLAP',0xC0000BEA)
		win_const_mgr.add_const('CRYPT_SERVER',0x00000400)
		win_const_mgr.add_const('SPI_SETMOUSEVANISH',0x00001021)
		win_const_mgr.add_const('PHONEERR_UNINITIALIZED',0x90000022)
		win_const_mgr.add_const('DBFLAGS_DISABLESNAPSHOTBACKUP',0x00000400)
		win_const_mgr.add_const('TVGN_PARENT',0x00000003)
		win_const_mgr.add_const('KSEG3_RID',0x00000000)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_BLUR',0x00000487)
		win_const_mgr.add_const('USER_TEMP_DUPLICATE_ACCOUNT',0x00000008)
		win_const_mgr.add_const('IME_ESC_PRIVATE_LAST',0x00000FFF)
		win_const_mgr.add_const('WM_CTLCOLOR',0x00000019)
		win_const_mgr.add_const('SNMP_GENERICTRAP_WARMSTART',0x00000001)
		win_const_mgr.add_const('CM_SET_DEVNODE_PROBLEM_NORMAL',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_M32R_SECREL32',0x0000000D)
		win_const_mgr.add_const('PERF_COUNTER_PRECISION',0x00070000)
		win_const_mgr.add_const('BIF_VALIDATE',0x00000020)
		win_const_mgr.add_const('ERROR_WINDOW_NOT_COMBOBOX',0x0000058F)
		win_const_mgr.add_const('WPF_FIRST_FILE_AS_DEFAULT',0x00000008)
		win_const_mgr.add_const('INTERNET_STATUS_COOKIE_RECEIVED',0x00000141)
		win_const_mgr.add_const('STRSAFE_FILL_BEHIND_NULL',0x00000200)
		win_const_mgr.add_const('XP_SUPPORTS_MULTICAST',0x00000400)
		win_const_mgr.add_const('TF_TMAE_NOACTIVATETIP',0x00000001)
		win_const_mgr.add_const('LVHT_EX_ONCONTENTS',0x04000000)
		win_const_mgr.add_const('WMDM_STORAGECAP_FOLDERSINROOT',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_PROXY_AUTHORIZATION',0x0000003D)
		win_const_mgr.add_const('DOT11_STATUS_AUTH_FAILED',0x00020000)
		win_const_mgr.add_const('ERROR_CLUSTER_OLD_VERSION',0x00001710)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_OTHER',0x00010000)
		win_const_mgr.add_const('SV_TYPE_DOMAIN_MASTER',0x00080000)
		win_const_mgr.add_const('CF_DISABLEDISPLAYASICON',0x00000020)
		win_const_mgr.add_const('SPINT_DEFAULT',0x00000002)
		win_const_mgr.add_const('DEBUG_OUTPUT_SYMBOLS_NO_VALUES',0x00000004)
		win_const_mgr.add_const('BDR_SUNKENINNER',0x00000008)
		win_const_mgr.add_const('ISCSI_LOGIN_OPTIONS_DATA_DIGEST',0x00000002)
		win_const_mgr.add_const('SES_CTFALLOWSMARTTAG',0x00400000)
		win_const_mgr.add_const('MAX_PATH',0x00000104)
		win_const_mgr.add_const('STATE_SYSTEM_INVISIBLE',0x00008000)
		win_const_mgr.add_const('MDMVOL_HIGH',0x00000002)
		win_const_mgr.add_const('BIND_NO_BOUND_IMPORTS',0x00000001)
		win_const_mgr.add_const('CM_PROB_BOOT_CONFIG_CONFLICT',0x00000006)
		win_const_mgr.add_const('ERROR_DBG_CONTINUE',0x000002FF)
		win_const_mgr.add_const('INTERNET_PER_CONN_PROXY_SERVER',0x00000002)
		win_const_mgr.add_const('SCH_CRED_NO_DEFAULT_CREDS',0x00000010)
		win_const_mgr.add_const('TAPE_SETMARKS',0x00000000)
		win_const_mgr.add_const('WKSTA_USEUNLOCKBEHIND_PARMNUM',0x00000031)
		win_const_mgr.add_const('MSV1_0_SUBAUTHENTICATION_DLL_SHIFT',0x00000018)
		win_const_mgr.add_const('MIXERCONTROL_CT_SC_SWITCH_BOOLEAN',0x00000000)
		win_const_mgr.add_const('ERROR_META_EXPANSION_TOO_LONG',0x000000D0)
		win_const_mgr.add_const('UNDNAME_NO_CV_THISTYPE',0x00000040)
		win_const_mgr.add_const('TBSTATE_CHECKED',0x00000001)
		win_const_mgr.add_const('EV_CTS',0x00000008)
		win_const_mgr.add_const('SERVICE_PAUSE_STATE',0x0000000C)
		win_const_mgr.add_const('HTTP_QUERY_MAX',0x0000004E)
		win_const_mgr.add_const('CERT_COMPARE_NAME',0x00000002)
		win_const_mgr.add_const('DNS_QUERY_ACCEPT_TRUNCATED_RESPONSE',0x00000001)
		win_const_mgr.add_const('FR_PROP_FAILINFO',0x00000007)
		win_const_mgr.add_const('SP_ALTPLATFORM_FLAGS_VERSION_RANGE',0x00000001)
		win_const_mgr.add_const('RETRACT_IEPORT',0x00000003)
		win_const_mgr.add_const('ERROR_EVT_QUERY_RESULT_INVALID_POSITION',0x00003AA4)
		win_const_mgr.add_const('PDH_FUNCTION_NOT_FOUND',0xC0000BBE)
		win_const_mgr.add_const('VIETNAMESE_CHARSET',0x000000A3)
		win_const_mgr.add_const('RESOURCE_RECENT',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_GB_NO_RELATION',0x00000008)
		win_const_mgr.add_const('MD_ERROR_SUB401_APPLICATION',0x00000005)
		win_const_mgr.add_const('IASSEMBLYCACHEITEM_COMMIT_FLAG_FORCE_REFRESH',0x00000002)
		win_const_mgr.add_const('ERROR_SERVICE_NOTIFY_CLIENT_LAGGING',0x0000050E)
		win_const_mgr.add_const('SQL_CVT_GUID',0x01000000)
		win_const_mgr.add_const('WLX_CREDENTIAL_TYPE_V2_0',0x00000002)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY6',0x00200000)
		win_const_mgr.add_const('USN_SOURCE_AUXILIARY_DATA',0x00000002)
		win_const_mgr.add_const('WM_MOUSEFIRST',0x00000200)
		win_const_mgr.add_const('RTUTILS_MAX_PROTOCOL_DLL_LEN',0x00000030)
		win_const_mgr.add_const('DRAGDROP_S_LAST',0x0004010F)
		win_const_mgr.add_const('EN_KILLFOCUS',0x00000200)
		win_const_mgr.add_const('CSCONTROL_SUSPEND',0x00000002)
		win_const_mgr.add_const('OID_TAPI_GATHER_DIGITS',0x07030123)
		win_const_mgr.add_const('PLAL_ALERT_CMD_LINE_SINGLE',0x00000100)
		win_const_mgr.add_const('SP_COPY_WARNIFSKIP',0x00004000)
		win_const_mgr.add_const('DMDITHER_GRAYSCALE',0x0000000A)
		win_const_mgr.add_const('ICACHE_SIZE',0x00000004)
		win_const_mgr.add_const('TMT_COMPOSITEDOPAQUE',0x000008AB)
		win_const_mgr.add_const('CERT_STORE_PROV_WRITE_ADD_FLAG',0x00000001)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_CONFERENCE',0x00000001)
		win_const_mgr.add_const('MAX_LEADBYTES',0x0000000C)
		win_const_mgr.add_const('DNS_UPDATE_TRY_ALL_MASTER_SERVERS',0x00001000)
		win_const_mgr.add_const('KSPROPERTY_MEMBER_FLAG_DEFAULT',0x00000001)
		win_const_mgr.add_const('PSINJECT_VMRESTORE',0x000000C9)
		win_const_mgr.add_const('WM_IME_KEYDOWN',0x00000290)
		win_const_mgr.add_const('IME_CMODE_SOFTKBD',0x00000080)
		win_const_mgr.add_const('TF_IPPMF_DISABLEPROFILE',0x00000002)
		win_const_mgr.add_const('PSBTN_HELP',0x00000006)
		win_const_mgr.add_const('IDC_BZ_ICON',0x00000259)
		win_const_mgr.add_const('VS_FFI_STRUCVERSION',0x00010000)
		win_const_mgr.add_const('IDM_TRIED_ACTIVATEDTCS',0x00000019)
		win_const_mgr.add_const('PHOTO_SHARPNESS_HARD',0x00000002)
		win_const_mgr.add_const('INTERNET_PER_CONN_AUTOCONFIG_RELOAD_DELAY_MINS',0x00000007)
		win_const_mgr.add_const('ERROR_DUPLICATE_SERVICE_NAME',0x00000436)
		win_const_mgr.add_const('SDP_ATTRIB_ICON_URL',0x0000000C)
		win_const_mgr.add_const('DI_DONOTCALLCONFIGMG',0x00020000)
		win_const_mgr.add_const('SBSP_DEFBROWSER',0x00000000)
		win_const_mgr.add_const('SQL_CB_NON_NULL',0x00000001)
		win_const_mgr.add_const('ERROR_INSTALL_NOTUSED',0x00000662)
		win_const_mgr.add_const('DEBUG_ECREATE_PROCESS_INHERIT_HANDLES',0x00000001)
		win_const_mgr.add_const('SQLBIGVARBINARY',0x00000000)
		win_const_mgr.add_const('ABE_RIGHT',0x00000002)
		win_const_mgr.add_const('DOSOPTF_ALWAYSUSE',0x00000004)
		win_const_mgr.add_const('VDMDBG_TRACE_HISTORY',0x00000080)
		win_const_mgr.add_const('SQL_CVT_INTERVAL_YEAR_MONTH',0x00080000)
		win_const_mgr.add_const('MCI_OVLY_STATUS_HWND',0x00004001)
		win_const_mgr.add_const('SERVICE_DEFAULT_STORE',0x00000001)
		win_const_mgr.add_const('DEVPROP_TYPE_DECIMAL',0x0000000C)
		win_const_mgr.add_const('WM_WINDOWPOSCHANGED',0x00000047)
		win_const_mgr.add_const('WSDAPI_ADDRESSFAMILY_IPV6',0x00000002)
		win_const_mgr.add_const('SHACF_AUTOSUGGEST_FORCE_OFF',0x20000000)
		win_const_mgr.add_const('WSDAPI_ADDRESSFAMILY_IPV4',0x00000001)
		win_const_mgr.add_const('DMPAPER_10X11',0x0000002D)
		win_const_mgr.add_const('RPC_QUERY_NO_AUTH_REQUIRED',0x00000040)
		win_const_mgr.add_const('SQL_PARAM_INPUT',0x00000001)
		win_const_mgr.add_const('CRYPT_VERIFY_CONTEXT_SIGNATURE',0x00000020)
		win_const_mgr.add_const('MDM_ANALOG_RLP_ON',0x00000000)
		win_const_mgr.add_const('TOKEN_ADJUST_SESSIONID',0x00000100)
		win_const_mgr.add_const('CMSG_BARE_CONTENT_PARAM',0x00000003)
		win_const_mgr.add_const('DOT11_STATUS_WEP_KEY_UNAVAILABLE',0x00000400)
		win_const_mgr.add_const('SB_CTL',0x00000002)
		win_const_mgr.add_const('SQL_SRJO_INNER_JOIN',0x00000010)
		win_const_mgr.add_const('ERROR_METAFILE_NOT_SUPPORTED',0x000007D3)
		win_const_mgr.add_const('ERROR_BAD_RECOVERY_POLICY',0x0000177C)
		win_const_mgr.add_const('SPI_GETACTIVEWNDTRKZORDER',0x0000100C)
		win_const_mgr.add_const('SQL_CVT_WVARCHAR',0x00800000)
		win_const_mgr.add_const('PRESENTATION_CURRENT_POSITION',0x00000007)
		win_const_mgr.add_const('TT_CBR',0x00000004)
		win_const_mgr.add_const('SQL_CT_CONSTRAINT_DEFERRABLE',0x00000080)
		win_const_mgr.add_const('ERROR_RM_DISCONNECTED',0x00001AA3)
		win_const_mgr.add_const('MQ_DENY_RECEIVE_SHARE',0x00000001)
		win_const_mgr.add_const('IMAGE_COMPRESSION_LZW',0x00000005)
		win_const_mgr.add_const('ACMFORMATCHOOSE_STYLEF_CONTEXTHELP',0x00000080)
		win_const_mgr.add_const('LIST_MODULES_32BIT',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_SH3_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('ATSC_VCT_CABL_TID',0x000000C9)
		win_const_mgr.add_const('SUBLANG_KAZAK_KAZAKHSTAN',0x00000001)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_ALPC',0x00100000)
		win_const_mgr.add_const('SQL_FN_TD_MINUTE',0x00000800)
		win_const_mgr.add_const('BM_SETSTATE',0x000000F3)
		win_const_mgr.add_const('HTMINBUTTON',0x00000008)
		win_const_mgr.add_const('IDM_UNDERLINE',0x0000003F)
		win_const_mgr.add_const('DN_DISABLEABLE',0x00002000)
		win_const_mgr.add_const('KERB_CERTIFICATE_S4U_LOGON_FLAG_CHECK_DUPLICATES',0x00000001)
		win_const_mgr.add_const('VER_SERVICEPACKMAJOR',0x00000020)
		win_const_mgr.add_const('PSINJECT_VMSAVE',0x000000C8)
		win_const_mgr.add_const('WIA_AUTO_DESKEW_OFF',0x00000001)
		win_const_mgr.add_const('MD_ACCESS_WRITE',0x00000002)
		win_const_mgr.add_const('SQL_SG_REFERENCES_TABLE',0x00000100)
		win_const_mgr.add_const('COLOR_ACTIVEBORDER',0x0000000A)
		win_const_mgr.add_const('SECPKG_CLIENT_PROCESS_TERMINATED',0x00000001)
		win_const_mgr.add_const('HTTP_LOG_FIELD_WIN32_STATUS',0x00000800)
		win_const_mgr.add_const('ERROR_REVISION_MISMATCH',0x0000051A)
		win_const_mgr.add_const('CCITT_A_CPU',0x00000018)
		win_const_mgr.add_const('SOFTDIST_ADSTATE_INSTALLED',0x00000003)
		win_const_mgr.add_const('SQL_BS_SELECT_PROC',0x00000004)
		win_const_mgr.add_const('SQL_CA2_LOCK_CONCURRENCY',0x00000002)
		win_const_mgr.add_const('ERROR_NO_WILDCARD_CHARACTERS',0x00000589)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_INDEXES',0x00000005)
		win_const_mgr.add_const('MAPI_E_BAD_RECIPTYPE',0x0000000F)
		win_const_mgr.add_const('DDOVER_INTERLEAVED',0x00800000)
		win_const_mgr.add_const('ISR_LP_TRAP',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLSETPOS',0x00000044)
		win_const_mgr.add_const('CONTEXT_MENU_IMAGE',0x00000001)
		win_const_mgr.add_const('ASSERT_ALTERNATE',0x00000009)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_PNP',0x00000016)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_QUEUE_DROP_MM',0x000035F3)
		win_const_mgr.add_const('ICERR_OK',0x00000000)
		win_const_mgr.add_const('WSAEINVAL',0x00002726)
		win_const_mgr.add_const('CC_SHOWHELP',0x00000008)
		win_const_mgr.add_const('SCARD_W_EOF',0x8010006D)
		win_const_mgr.add_const('FILE_DEVICE_KSEC',0x00000039)
		win_const_mgr.add_const('SQL_DIAG_NUMBER',0x00000002)
		win_const_mgr.add_const('MOD_FMSYNTH',0x00000004)
		win_const_mgr.add_const('CR_PROP_CACERTSTATE',0x00000013)
		win_const_mgr.add_const('PORT_SFTP',0x00000073)
		win_const_mgr.add_const('ASC_REQ_ALLOCATE_MEMORY',0x00000100)
		win_const_mgr.add_const('DS_DIRECTORY_SERVICE_REQUIRED',0x00000010)
		win_const_mgr.add_const('PHOTO_GAINCONTROL_HIGHGAINUP',0x00000002)
		win_const_mgr.add_const('CMSG_CTRL_ADD_CERT',0x0000000A)
		win_const_mgr.add_const('ERROR_SXS_PROTECTION_CATALOG_NOT_VALID',0x000036FC)
		win_const_mgr.add_const('WM_ICONERASEBKGND',0x00000027)
		win_const_mgr.add_const('FWPM_NET_EVENT_FLAG_IP_PROTOCOL_SET',0x00000001)
		win_const_mgr.add_const('PDTIMER_RESET',0x00000001)
		win_const_mgr.add_const('WINSTATIONNAME_LENGTH',0x00000020)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_PUBLISHED',0x00002000)
		win_const_mgr.add_const('ERROR_DS_REPLICATOR_ONLY',0x000020B2)
		win_const_mgr.add_const('TF_TMAE_WOW16',0x00000010)
		win_const_mgr.add_const('IME_HOTKEY_PRIVATE_FIRST',0x00000200)
		win_const_mgr.add_const('LBER_USE_INDEFINITE_LEN',0x00000002)
		win_const_mgr.add_const('PIDMSI_OWNER',0x00000008)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SOURCE',0x00004004)
		win_const_mgr.add_const('OID_ATM_SIGNALING_VPIVCI',0x08010201)
		win_const_mgr.add_const('LMEM_DISCARDED',0x00004000)
		win_const_mgr.add_const('IMAGE_REL_ARM_BLX24',0x00000008)
		win_const_mgr.add_const('WH_MOUSE_LL',0x0000000E)
		win_const_mgr.add_const('MIXERLINE_COMPONENTTYPE_SRC_FIRST',0x00001000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_SECURE',0x00000004)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_PATH_TYPE_ASSEMBLYREF',0x00000004)
		win_const_mgr.add_const('DDENUMRET_OK',0x00000001)
		win_const_mgr.add_const('PSINJECT_DOCUMENTPROCESSCOLORS',0x0000000A)
		win_const_mgr.add_const('AUTO_PROXY_FLAG_ALWAYS_DETECT',0x00000002)
		win_const_mgr.add_const('SAFER_TOKEN_WANT_FLAGS',0x00000008)
		win_const_mgr.add_const('SERVICE_ERROR_IGNORE',0x00000000)
		win_const_mgr.add_const('DMPAPER_USER',0x00000100)
		win_const_mgr.add_const('MMIO_DENYWRITE',0x00000020)
		win_const_mgr.add_const('DS_DOMAIN_TREE_ROOT',0x00000004)
		win_const_mgr.add_const('VK_SELECT',0x00000029)
		win_const_mgr.add_const('FACILITY_SIP_STATUS_CODE',0x000000EF)
		win_const_mgr.add_const('VK_FINAL',0x00000018)
		win_const_mgr.add_const('DISPID_EVENTHOOK_SENSITIVE_BASE',0x003D0900)
		win_const_mgr.add_const('CDB2GVF_NOSELECTVERB',0x00000008)
		win_const_mgr.add_const('DDSD_PITCH',0x00000008)
		win_const_mgr.add_const('CHANNEL_RC_BAD_CHANNEL_HANDLE',0x00000007)
		win_const_mgr.add_const('WMS_STREAM_HAS_NON_KEY_FRAMES',0x00000001)
		win_const_mgr.add_const('CR_FLG_CACROSSCERT',0x00000080)
		win_const_mgr.add_const('TF_TRANSITORYEXTENSION_FLOATING',0x00000001)
		win_const_mgr.add_const('SPQ_SCAN_USE_CALLBACKEX',0x00000008)
		win_const_mgr.add_const('OID_FDDI_SMT_MSG_TIME_STAMP',0x0303021B)
		win_const_mgr.add_const('ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ',0x00002170)
		win_const_mgr.add_const('UM_SELTYPE_USER',0x00000010)
		win_const_mgr.add_const('SETUP_UPDATE_CAOBJECT_SVRTYPE',0x00000200)
		win_const_mgr.add_const('PORT_ACI',0x000000BB)
		win_const_mgr.add_const('MONO_FONT',0x00000008)
		win_const_mgr.add_const('WMDRM_QUERY_DEVICE_ISWMDRM',0x00000001)
		win_const_mgr.add_const('DCOMSCM_ACTIVATION_DISALLOW_UNSECURE_CALL',0x00000002)
		win_const_mgr.add_const('RI_MOUSE_BUTTON_5_UP',0x00000200)
		win_const_mgr.add_const('RPC_S_CANNOT_SUPPORT',0x000006E4)
		win_const_mgr.add_const('CMF_INCLUDESTATIC',0x00000040)
		win_const_mgr.add_const('WIA_DIP_STI_DRIVER_VERSION',0x00000011)
		win_const_mgr.add_const('SQL_DIAG_DROP_VIEW',0x00000024)
		win_const_mgr.add_const('EM_GETIMESTATUS',0x000000D9)
		win_const_mgr.add_const('CM_HIDE_ADVANCEPAGE',0x00000010)
		win_const_mgr.add_const('WINHTTP_ADDREQ_FLAG_ADD',0x20000000)
		win_const_mgr.add_const('MCI_GETDEVCAPS',0x0000080B)
		win_const_mgr.add_const('CVT_WEEKS',0x00000007)
		win_const_mgr.add_const('IDM_IME_ENABLE_RECONVERSION',0x00000969)
		win_const_mgr.add_const('SPI_GETPOWEROFFTIMEOUT',0x00000050)
		win_const_mgr.add_const('ADS_PRINTER_OUT_OF_MEMORY',0x00200000)
		win_const_mgr.add_const('ERROR_DS_SEC_DESC_TOO_SHORT',0x000020A1)
		win_const_mgr.add_const('SSF_SHOWINFOTIP',0x00002000)
		win_const_mgr.add_const('IMAGE_ORDINAL_FLAG64',0x8000000000000000)
		win_const_mgr.add_const('USER_PRIV_GUEST',0x00000000)
		win_const_mgr.add_const('IMAGE_WEAK_EXTERN_SEARCH_NOLIBRARY',0x00000001)
		win_const_mgr.add_const('LINEANSWERMODE_DROP',0x00000002)
		win_const_mgr.add_const('OPTION_DOMAIN_NAME',0x0000000F)
		win_const_mgr.add_const('SPI_GETKEYBOARDDELAY',0x00000016)
		win_const_mgr.add_const('IME_PROP_SPECIAL_UI',0x00020000)
		win_const_mgr.add_const('TRACELOG_GUID_ENABLE',0x00000080)
		win_const_mgr.add_const('D3DPTEXTURECAPS_NONPOW2CONDITIONAL',0x00000100)
		win_const_mgr.add_const('CHANGER_SLOTS_USE_TRAYS',0x80000010)
		win_const_mgr.add_const('ILC_COLORDDB',0x000000FE)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_FTP_FIND',0x00000005)
		win_const_mgr.add_const('MD_AUTH_NT',0x00000004)
		win_const_mgr.add_const('DAO_CANTCOERCE',0x00000000)
		win_const_mgr.add_const('WINDOWS_VERSION_UNKNOWN',0x00000000)
		win_const_mgr.add_const('SCARD_E_NO_DIR',0x80100025)
		win_const_mgr.add_const('CERT_FILTER_VALID_SIGNATURE',0x00000004)
		win_const_mgr.add_const('CACHE_CONFIG_CONTENT_PATHS_FC',0x00000100)
		win_const_mgr.add_const('MDM_HDLCPPP_SPEED_56K',0x00000002)
		win_const_mgr.add_const('IF_TYPE_L3_IPXVLAN',0x00000089)
		win_const_mgr.add_const('MMIO_GETTEMP',0x00020000)
		win_const_mgr.add_const('RPC_QUERY_CALL_LOCAL_ADDRESS',0x00000008)
		win_const_mgr.add_const('FWPM_ACTRL_WRITE',0x00000400)
		win_const_mgr.add_const('GCS_COMPREADCLAUSE',0x00000004)
		win_const_mgr.add_const('SPDRP_SECURITY_SDS',0x00000018)
		win_const_mgr.add_const('BATTERY_CLASS_MAJOR_VERSION',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_INPUT',0x02000000)
		win_const_mgr.add_const('DBPROPVAL_DST_DOCSOURCE',0x00000004)
		win_const_mgr.add_const('NET_DFS_SETDC_TIMEOUT',0x00000001)
		win_const_mgr.add_const('CPS_CONVERT',0x00000002)
		win_const_mgr.add_const('MCGIP_CALENDARCONTROL',0x00000000)
		win_const_mgr.add_const('LANG_SPANISH',0x00000000)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_RESOURCE',0x00000002)
		win_const_mgr.add_const('IDM_GOBACKWARD',0x000008EA)
		win_const_mgr.add_const('PLAL_ALERT_CMD_LINE_D_TIME',0x00000800)
		win_const_mgr.add_const('RBBS_GRIPPERALWAYS',0x00000080)
		win_const_mgr.add_const('POLICY_QOS_OUTBOUND_CONFIDENTIALITY',0x00000004)
		win_const_mgr.add_const('IMF_IMECANCELCOMPLETE',0x00000004)
		win_const_mgr.add_const('PCMCIA_OPT_NO_APMREMOVE',0x00000020)
		win_const_mgr.add_const('IMN_SETSTATUSWINDOWPOS',0x0000000C)
		win_const_mgr.add_const('SYSTEM_FONT',0x0000000D)
		win_const_mgr.add_const('ARCONTENT_DVDAUDIO',0x00001000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_MM_DELAY_DROP',0x000035F6)
		win_const_mgr.add_const('SPSVCINST_NOCLOBBER_DEPENDENCIES',0x00000080)
		win_const_mgr.add_const('ERROR_EVT_UNRESOLVED_VALUE_INSERT',0x00003AB5)
		win_const_mgr.add_const('IDM_IMAGE',0x00000878)
		win_const_mgr.add_const('LVS_SHOWSELALWAYS',0x00000008)
		win_const_mgr.add_const('SQL_CACHE_DATA_NO',0x00000000)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_DIRECTED',0x00000001)
		win_const_mgr.add_const('CERT_STORE_PROV_EXTERNAL_FLAG',0x00000001)
		win_const_mgr.add_const('FC_POINTER_DEREF',0x00000010)
		win_const_mgr.add_const('IF_TYPE_ISO88025_CRFPRINT',0x00000062)
		win_const_mgr.add_const('DISPID_ITEMSETOPERATIONSDONE',0x000000D8)
		win_const_mgr.add_const('DB_COLLATION_ASC',0x00000001)
		win_const_mgr.add_const('DISPID_CHANGE',0x00000005)
		win_const_mgr.add_const('SUF_INSETUP',0x00000010)
		win_const_mgr.add_const('WAVE_FORMAT_1S08',0x00000002)
		win_const_mgr.add_const('DBG_TEMPBP',0x00000012)
		win_const_mgr.add_const('SERVICE_REGISTER',0x00000001)
		win_const_mgr.add_const('LOG_POLICY_OVERWRITE',0x00000001)
		win_const_mgr.add_const('CAT_E_LAST',0x80040161)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_DESTINATION_INTERFACE_INDEX',0x00000200)
		win_const_mgr.add_const('LGRPID_KOREAN',0x00000008)
		win_const_mgr.add_const('BATTERY_DISCHARGE_FLAGS_EVENTCODE_MASK',0x00000007)
		win_const_mgr.add_const('ULW_EX_NORESIZE',0x00000008)
		win_const_mgr.add_const('SNMP_PDUAPI_INVALID_GT',0x00000016)
		win_const_mgr.add_const('CERT_STORE_PROV_FREE_FIND_CERT_FUNC',0x0000000F)
		win_const_mgr.add_const('PAGE4K_SHIFT',0x0000000C)
		win_const_mgr.add_const('SQL_AO_ON',0x00000001)
		win_const_mgr.add_const('PROTECTION_LEVEL_RESTRICTED',0x0000001E)
		win_const_mgr.add_const('SQLBIGVARCHAR',0x00000000)
		win_const_mgr.add_const('OLECREATE_LEAVERUNNING',0x00000001)
		win_const_mgr.add_const('MD_COMMENTS',0x00002706)
		win_const_mgr.add_const('HELP_FORCEFILE',0x00000009)
		win_const_mgr.add_const('ERROR_SERVER_SID_MISMATCH',0x00000274)
		win_const_mgr.add_const('IDM_2D_ELEMENT',0x0000095B)
		win_const_mgr.add_const('IMGCHG_ANIMATE',0x00000008)
		win_const_mgr.add_const('ERROR_INVALID_FLAG_NUMBER',0x000000BA)
		win_const_mgr.add_const('TP_ELEMENT_EOP',0x00000004)
		win_const_mgr.add_const('DPROMPT_CANCEL',0x00000001)
		win_const_mgr.add_const('DMPAPER_A4SMALL',0x0000000A)
		win_const_mgr.add_const('PAN_LETT_NORMAL_BOXED',0x00000004)
		win_const_mgr.add_const('CONNECT_CURRENT_MEDIA',0x00000200)
		win_const_mgr.add_const('DTT_CALLBACK',0x00000001)
		win_const_mgr.add_const('LINEGATHERTERM_CANCEL',0x00000010)
		win_const_mgr.add_const('WMDM_FILE_ATTR_CANRENAME',0x00020000)
		win_const_mgr.add_const('PHONEERR_OPERATIONUNAVAIL',0x9000001D)
		win_const_mgr.add_const('DISPID_NORMAL_FIRST',0x000003E8)
		win_const_mgr.add_const('WCM_SETTINGS_ID_FLAG_REFERENCE',0x00000000)
		win_const_mgr.add_const('IPV6_ADDRESS_LEN_IN_BYTES',0x00000010)
		win_const_mgr.add_const('VER_ERR_FATAL',0x80000000)
		win_const_mgr.add_const('NETLOGON_CONTROL_REDISCOVER',0x00000005)
		win_const_mgr.add_const('LANG_IGBO',0x00000070)
		win_const_mgr.add_const('MD_ACCESS_NO_REMOTE_READ',0x00001000)
		win_const_mgr.add_const('SM_CYVTHUMB',0x00000009)
		win_const_mgr.add_const('TVS_HASBUTTONS',0x00000001)
		win_const_mgr.add_const('FR_ENABLETEMPLATE',0x00000200)
		win_const_mgr.add_const('KSEVENT_ENTRY_ONESHOT',0x00000002)
		win_const_mgr.add_const('DXGI_USAGE_SHADER_INPUT',0x00000001)
		win_const_mgr.add_const('DNS_RTYPE_DNAME',0x00002700)
		win_const_mgr.add_const('DXVA_QUERYORREPLYFUNCFLAG_ACCEL_LOCK_FALSE_PLUS',0x00FFFFFF)
		win_const_mgr.add_const('NETSH_MAX_TOKEN_LENGTH',0x00000040)
		win_const_mgr.add_const('SAP_INTERFACE_TABLE',0x00000001)
		win_const_mgr.add_const('SERVICE_CTRL_UNINSTALL',0x00000003)
		win_const_mgr.add_const('PDCAP_S4_SUPPORTED',0x01000000)
		win_const_mgr.add_const('HHWIN_BUTTON_INDEX',0x00000001)
		win_const_mgr.add_const('CTRL_CLOSE_EVENT',0x00000002)
		win_const_mgr.add_const('IF_TYPE_ISO88022_LLC',0x00000029)
		win_const_mgr.add_const('TMT_HEADING2TEXTCOLOR',0x00000EF2)
		win_const_mgr.add_const('SPI_SETFOREGROUNDLOCKTIMEOUT',0x00002001)
		win_const_mgr.add_const('DEBUG_LOG_APPEND',0x00000001)
		win_const_mgr.add_const('FWPM_LAYER_FLAG_KERNEL',0x00000001)
		win_const_mgr.add_const('DEFAULT_SNMP_PORT_UDP',0x000000A1)
		win_const_mgr.add_const('FAX_ERR_DIRECTORY_IN_USE',0x00001B5F)
		win_const_mgr.add_const('HANJA_WINDOW',0x00000002)
		win_const_mgr.add_const('ENABLE_PROCESSED_INPUT',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_DIAGNOSTIC_SOCKET_INFO',0x00000043)
		win_const_mgr.add_const('HTTP_STATUS_GONE',0x0000019A)
		win_const_mgr.add_const('ILR_HORIZONTAL_RIGHT',0x00000002)
		win_const_mgr.add_const('TCS_TOOLTIPS',0x00004000)
		win_const_mgr.add_const('ERRCLASS_HRDFAIL',0x00000005)
		win_const_mgr.add_const('ERROR_CLUSTER_INVALID_NODE',0x000013AF)
		win_const_mgr.add_const('DOT11_FLAGS_80211G_BARKER_PREAMBLE_MODE',0x00000080)
		win_const_mgr.add_const('MINIDUMP_THREAD_INFO_EXITED_THREAD',0x00000004)
		win_const_mgr.add_const('SQL_BRC_EXPLICIT',0x00000002)
		win_const_mgr.add_const('DEBUG_FILTER_INITIAL_BREAKPOINT',0x00000007)
		win_const_mgr.add_const('LIS_ENABLED',0x00000002)
		win_const_mgr.add_const('ATSC_MGT_TID',0x000000C7)
		win_const_mgr.add_const('ASYNC_RECO_SETWORDLIST_FAILED',0x00000200)
		win_const_mgr.add_const('PHONEERR_INVALDATAID',0x9000000C)
		win_const_mgr.add_const('CERT_CREATE_CONTEXT_SORTED_FLAG',0x00000002)
		win_const_mgr.add_const('VIEW_NETCONNECT',0x00000009)
		win_const_mgr.add_const('DBG_DLLSTOP',0x0000000D)
		win_const_mgr.add_const('MUI_LANGUAGE_LICENSED',0x00000040)
		win_const_mgr.add_const('MM_STREAM_DONE',0x000003D6)
		win_const_mgr.add_const('DISPID_LOCATION',0x00000001)
		win_const_mgr.add_const('DDD_NO_BROADCAST_SYSTEM',0x00000008)
		win_const_mgr.add_const('DISPID_BUSY',0x00000021)
		win_const_mgr.add_const('INTERNET_FLAG_RELOAD',0x80000000)
		win_const_mgr.add_const('TMT_TRANSPARENTCOLOR',0x00000EE1)
		win_const_mgr.add_const('D3D9_RESOURCE_PRIORITY_NORMAL',0x78000000)
		win_const_mgr.add_const('DEVICEDATA',0x00000013)
		win_const_mgr.add_const('AVIFILEINFO_WASCAPTUREFILE',0x00010000)
		win_const_mgr.add_const('RPC_EEINFO_VERSION',0x00000001)
		win_const_mgr.add_const('CMSG_KEY_AGREE_ENCRYPT_FREE_OBJID_FLAG',0x00000020)
		win_const_mgr.add_const('TF_TMAE_SECUREMODE',0x00000002)
		win_const_mgr.add_const('FMEVENT_LOAD',0x00000064)
		win_const_mgr.add_const('WIA_PROP_READ',0x00000001)
		win_const_mgr.add_const('NRC_DUPENV',0x00000030)
		win_const_mgr.add_const('DEVPROP_TYPE_GUID',0x0000000D)
		win_const_mgr.add_const('D3DTEXOPCAPS_BLENDTEXTUREALPHAPM',0x00004000)
		win_const_mgr.add_const('SNMP_ERROR_RESOURCEUNAVAILABLE',0x0000000D)
		win_const_mgr.add_const('PORT_GENRADMUX',0x000000B0)
		win_const_mgr.add_const('IPPORT_BIFFUDP',0x00000200)
		win_const_mgr.add_const('OPTION_PERFORM_ROUTER_DISCOVERY',0x0000001F)
		win_const_mgr.add_const('ERROR_IS_JOIN_TARGET',0x00000085)
		win_const_mgr.add_const('COLOR_REDACCEL',0x000002D6)
		win_const_mgr.add_const('FILE_TYPE_REMOTE',0x00008000)
		win_const_mgr.add_const('D3DUSAGE_RENDERTARGET',0x00000001)
		win_const_mgr.add_const('SECPKG_CALL_NETWORK_ONLY',0x00000400)
		win_const_mgr.add_const('MD_NOTIFY_SEND_RESPONSE',0x00000040)
		win_const_mgr.add_const('IDM_LAUNCHDEBUGGER',0x00000906)
		win_const_mgr.add_const('CF_NOSTYLESEL',0x00100000)
		win_const_mgr.add_const('EDITF_ENABLELDAPREFERRALS',0x00080000)
		win_const_mgr.add_const('ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT',0x000036C4)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_PRIORITY_CLASS',0x00000020)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_SDMI',0x00000040)
		win_const_mgr.add_const('DWM_TNP_RECTDESTINATION',0x00000001)
		win_const_mgr.add_const('STATE_SYSTEM_MOVEABLE',0x00040000)
		win_const_mgr.add_const('TMT_AUTOSIZE',0x0000089A)
		win_const_mgr.add_const('IDM_HORIZSPACEDECREASE',0x00000016)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_SHARE',0x00000003)
		win_const_mgr.add_const('ERROR_DS_SCHEMA_UPDATE_DISALLOWED',0x0000213D)
		win_const_mgr.add_const('STD_REDOW',0x00000004)
		win_const_mgr.add_const('MMIO_SHAREMODE',0x00000070)
		win_const_mgr.add_const('WINEVENT_OPCODE_SUSPEND',0x00000008)
		win_const_mgr.add_const('KP_MODE',0x00000004)
		win_const_mgr.add_const('PSR_UP',0x00000002)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_CUBES',0x00000003)
		win_const_mgr.add_const('DISPID_IADCCTL_DEFAULTCAT',0x00000106)
		win_const_mgr.add_const('IDM_PERSISTDEFAULTVALUES',0x00001BBC)
		win_const_mgr.add_const('SQL_DI_CREATE_INDEX',0x00000001)
		win_const_mgr.add_const('CMSG_KEY_AGREE_ORIGINATOR_PUBLIC_KEY',0x00000002)
		win_const_mgr.add_const('FACILITY_MEDIASERVER',0x0000000D)
		win_const_mgr.add_const('RBBIM_COLORS',0x00000002)
		win_const_mgr.add_const('IDM_STRIKETHROUGH',0x0000005B)
		win_const_mgr.add_const('IDTB_FORWARD',0x000000D1)
		win_const_mgr.add_const('DIIDFLAG_NOFINISHINSTALLUI',0x00000002)
		win_const_mgr.add_const('TIMEMEDIAPLAYERSITE_OFFSET',0x00001200)
		win_const_mgr.add_const('ERROR_NODE_CANT_HOST_RESOURCE',0x000013CF)
		win_const_mgr.add_const('LEFT_ALT_PRESSED',0x00000002)
		win_const_mgr.add_const('SQL_SYSTEM_FUNCTIONS',0x00000033)
		win_const_mgr.add_const('ERROR_BOOT_ALREADY_ACCEPTED',0x00000434)
		win_const_mgr.add_const('WTS_EVENT_NONE',0x00000000)
		win_const_mgr.add_const('ERROR_WRITE_FAULT',0x0000001D)
		win_const_mgr.add_const('POWERMODE_BATTERY',0x00000002)
		win_const_mgr.add_const('SO_OOBINLINE',0x00000100)
		win_const_mgr.add_const('MAX_EAP_CONFIG_INPUT_FIELD_VALUE_LENGTH',0x00000400)
		win_const_mgr.add_const('SQL_ENTIRE_ROWSET',0x00000000)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_LOCAL',0x00000010)
		win_const_mgr.add_const('DDF_ANIMATE',0x00000020)
		win_const_mgr.add_const('ODDPARITY',0x00000001)
		win_const_mgr.add_const('COD_MAJOR_MASK',0x00001F00)
		win_const_mgr.add_const('TUISPIDLL_OBJECT_PROVIDERID',0x00000003)
		win_const_mgr.add_const('LDAP_DIRSYNC_INCREMENTAL_VALUES',0x80000000)
		win_const_mgr.add_const('SBT_TOOLTIPS',0x00000800)
		win_const_mgr.add_const('VT_STORED_PROPSET',0x0000004A)
		win_const_mgr.add_const('DEBUG_ASMOPT_VERBOSE',0x00000001)
		win_const_mgr.add_const('CMSG_ENCODE_HASHED_SUBJECT_IDENTIFIER_FLAG',0x00000002)
		win_const_mgr.add_const('ERROR_FILE_OFFLINE',0x000010FE)
		win_const_mgr.add_const('FOREST_USER_RID_MAX',0x000001F3)
		win_const_mgr.add_const('META_EXTFLOODFILL',0x00000548)
		win_const_mgr.add_const('EC_BUILT',0x00000300)
		win_const_mgr.add_const('IDM_REFRESH_THIS',0x0000179A)
		win_const_mgr.add_const('CLFS_FLAG_HIDDEN_SYSTEM_LOG',0x00000200)
		win_const_mgr.add_const('IF_TYPE_OTHER',0x00000001)
		win_const_mgr.add_const('SHCNE_ALLEVENTS',0x7FFFFFFF)
		win_const_mgr.add_const('REGDF_NODETCONFIG',0x00008000)
		win_const_mgr.add_const('ERROR_CURRENT_TRANSACTION_NOT_VALID',0x00001A3A)
		win_const_mgr.add_const('MCI_VD_STATUS_FORWARD',0x00004003)
		win_const_mgr.add_const('FOCUSMODE_AUTO',0x00000002)
		win_const_mgr.add_const('INFO_NOT_AVAILABLE',0xFFFFFFFF)
		win_const_mgr.add_const('WM_SHOWWINDOW',0x00000018)
		win_const_mgr.add_const('SURFACE_LOCK_EXCLUSIVE',0x00000001)
		win_const_mgr.add_const('FLAGSTATUS_NOTFLAGGED',0x00000000)
		win_const_mgr.add_const('ACTRL_DS_CREATE_CHILD',0x00000001)
		win_const_mgr.add_const('BAUD_2400',0x00000100)
		win_const_mgr.add_const('STRM_CONFIGURED',0x00000002)
		win_const_mgr.add_const('KS_VIDEOSTREAM_PREVIEW',0x00000001)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW3_SHOWMODELESSDIALOG',0x00000498)
		win_const_mgr.add_const('SQL_TC_ALL',0x00000002)
		win_const_mgr.add_const('POWER_ACTION_OVERRIDE_APPS',0x00000004)
		win_const_mgr.add_const('DBPROP_CI_DEPTHS',0x00000004)
		win_const_mgr.add_const('WINHTTP_OPTION_SECURITY_CERTIFICATE_STRUCT',0x00000020)
		win_const_mgr.add_const('WM_RBUTTONUP',0x00000205)
		win_const_mgr.add_const('WINHTTP_AUTOLOGON_SECURITY_LEVEL_MEDIUM',0x00000000)
		win_const_mgr.add_const('HDI_DI_SETITEM',0x00000040)
		win_const_mgr.add_const('DOT11_STATUS_GENERATE_AUTH_FAILED',0x00004000)
		win_const_mgr.add_const('PPP_LCP_AES_128',0x00000040)
		win_const_mgr.add_const('PDH_PLA_ERROR_ALREADY_EXISTS',0xC0000BEE)
		win_const_mgr.add_const('EMR_POLYLINE16',0x00000057)
		win_const_mgr.add_const('ACM_MPEG_ID_MPEG1',0x00000010)
		win_const_mgr.add_const('MAX_LANGUAGES',0x00000040)
		win_const_mgr.add_const('IP_HDRLEN_SHIFT',0x00000000)
		win_const_mgr.add_const('EDITF_ATTRIBUTEENDDATE',0x00000020)
		win_const_mgr.add_const('MCI_DGV_PASTE_OVERWRITE',0x00100000)
		win_const_mgr.add_const('PRIVACY_URLHASP3PHEADER',0x00400000)
		win_const_mgr.add_const('SERVICETYPE_BESTEFFORT',0x00000001)
		win_const_mgr.add_const('SORT_CHINESE_UNICODE',0x00000001)
		win_const_mgr.add_const('TBS_COMMAND_PRIORITY_LOW',0x00000064)
		win_const_mgr.add_const('SM_CXSMSIZE',0x00000034)
		win_const_mgr.add_const('CHANGER_STORAGE_IEPORT',0x00002000)
		win_const_mgr.add_const('DEBUG_USER_WINDOWS_PROCESS',0x00000000)
		win_const_mgr.add_const('SQL_CA1_ABSOLUTE',0x00000002)
		win_const_mgr.add_const('NETINFO_PRINTERRED',0x00000008)
		win_const_mgr.add_const('BOE_CONTEXTREADING',0x00000008)
		win_const_mgr.add_const('CRYTPDLG_FLAGS_MASK',0x00000000)
		win_const_mgr.add_const('PERF_AGGREGATE_TOTAL',0x00000001)
		win_const_mgr.add_const('WSDAPI_OPTION_MAX_INBOUND_MESSAGE_SIZE',0x00000001)
		win_const_mgr.add_const('EDITF_ENABLEREQUESTEXTENSIONS',0x00000001)
		win_const_mgr.add_const('PORT_REMOTEEFS',0x0000022C)
		win_const_mgr.add_const('IME_RS_DISKERROR',0x00000000)
		win_const_mgr.add_const('D3DLINECAPS_TEXTURE',0x00000001)
		win_const_mgr.add_const('TTS_USEVISUALSTYLE',0x00000100)
		win_const_mgr.add_const('DISPID_VERBINVOKED',0x000000CA)
		win_const_mgr.add_const('ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION',0x000032DC)
		win_const_mgr.add_const('OID_FFP_FLUSH',0xFC010211)
		win_const_mgr.add_const('IMAGE_REL_IA64_PCREL60B',0x00000016)
		win_const_mgr.add_const('DMPAPER_A3_EXTRA',0x0000003F)
		win_const_mgr.add_const('CERT_TRUST_NO_ERROR',0x00000000)
		win_const_mgr.add_const('SESS_NOENCRYPTION',0x00000002)
		win_const_mgr.add_const('FIND_LENGTH',0x00001000)
		win_const_mgr.add_const('MM_MOM_CLOSE',0x000003C8)
		win_const_mgr.add_const('PHOTO_SATURATION_NORMAL',0x00000000)
		win_const_mgr.add_const('BROADCAST_NODETYPE',0x00000001)
		win_const_mgr.add_const('DST_COMPLEX',0x00000000)
		win_const_mgr.add_const('ACM_STREAMSIZEF_DESTINATION',0x00000001)
		win_const_mgr.add_const('CM_CUSTOMDEVPROP_MERGE_MULTISZ',0x00000001)
		win_const_mgr.add_const('MFASYNC_SIGNAL_CALLBACK',0x00000002)
		win_const_mgr.add_const('LINEFORWARDMODE_UNCOND',0x00000001)
		win_const_mgr.add_const('PRINTER_STATUS_DOOR_OPEN',0x00400000)
		win_const_mgr.add_const('ERROR_DS_EXISTS_IN_AUX_CLS',0x000020C9)
		win_const_mgr.add_const('CF_FIXEDPITCHONLY',0x00004000)
		win_const_mgr.add_const('SQL_LCK_EXCLUSIVE',0x00000002)
		win_const_mgr.add_const('ERROR_CANTREAD',0x000003F4)
		win_const_mgr.add_const('SQL_DIAG_DYNAMIC_UPDATE_CURSOR',0x00000051)
		win_const_mgr.add_const('PER_USER_AUDIT_NONE',0x00000010)
		win_const_mgr.add_const('LANG_CORSICAN',0x00000083)
		win_const_mgr.add_const('ERROR_DS_DRA_SCHEMA_CONFLICT',0x0000215F)
		win_const_mgr.add_const('FILE_SYSTEM_ATTR',0x00000002)
		win_const_mgr.add_const('MCI_VCR_SEEK_AT',0x00040000)
		win_const_mgr.add_const('PARTITION_FAT32_XINT13',0x0000000C)
		win_const_mgr.add_const('C3_LEXICAL',0x00000400)
		win_const_mgr.add_const('PIDISF_RECENTLYCHANGED',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_LINK',0x00000010)
		win_const_mgr.add_const('VOS_OS232',0x00030000)
		win_const_mgr.add_const('RAS_EAP_FLAG_ROUTER',0x00000001)
		win_const_mgr.add_const('MIDIPROP_TIMEDIV',0x00000001)
		win_const_mgr.add_const('ISFB_MASK_STATE',0x00000001)
		win_const_mgr.add_const('DMPAPER_EXECUTIVE',0x00000007)
		win_const_mgr.add_const('STI_ONLINESTATE_PAPER_PROBLEM',0x00000020)
		win_const_mgr.add_const('MCI_SEQ_STATUS_MASTER',0x00004008)
		win_const_mgr.add_const('LVFIS_FOCUSED',0x00000001)
		win_const_mgr.add_const('CTRY_SWITZERLAND',0x00000029)
		win_const_mgr.add_const('LOCALE_IMONLZERO',0x00000027)
		win_const_mgr.add_const('LGRPID_GEORGIAN',0x00000010)
		win_const_mgr.add_const('CB_SETLOCALE',0x00000159)
		win_const_mgr.add_const('LDAP_CHASE_SUBORDINATE_REFERRALS',0x00000020)
		win_const_mgr.add_const('FEI_NO_DIAL_TONE',0x00000008)
		win_const_mgr.add_const('WT_EXECUTEINUITHREAD',0x00000002)
		win_const_mgr.add_const('ERROR_LOGON_SESSION_COLLISION',0x00000556)
		win_const_mgr.add_const('CRL_FIND_ISSUED_BY',0x00000001)
		win_const_mgr.add_const('IPP_S_WEAKRESERVE',0x00048104)
		win_const_mgr.add_const('SQL_ISV_VIEW_TABLE_USAGE',0x00200000)
		win_const_mgr.add_const('WIA_DPC_PICTURES_TAKEN',0x00000802)
		win_const_mgr.add_const('HTTB_BACKGROUNDSEG',0x00000000)
		win_const_mgr.add_const('VK_DBE_FLUSHSTRING',0x00000000)
		win_const_mgr.add_const('RI_KEY_E0',0x00000002)
		win_const_mgr.add_const('DDLOCK_NOSYSLOCK',0x00000800)
		win_const_mgr.add_const('ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE',0x000013A9)
		win_const_mgr.add_const('IPPORT_SUPDUP',0x0000005F)
		win_const_mgr.add_const('MMIOM_OPEN',0x00000003)
		win_const_mgr.add_const('ERROR_I24_SEEK',0x00000006)
		win_const_mgr.add_const('PTR_WIRE_SIZE',0x00000004)
		win_const_mgr.add_const('COLOR_CUSTOM1',0x000002D1)
		win_const_mgr.add_const('DM_MEDIATYPE',0x02000000)
		win_const_mgr.add_const('INTERNET_OPTION_READ_BUFFER_SIZE',0x0000000C)
		win_const_mgr.add_const('SSPROP_INIT_TAGCOLUMNCOLLATION',0x0000000F)
		win_const_mgr.add_const('ILD_PRESERVEALPHA',0x00001000)
		win_const_mgr.add_const('SEE_MASK_HOTKEY',0x00000020)
		win_const_mgr.add_const('BTH_LINK_KEY_LENGTH',0x00000010)
		win_const_mgr.add_const('MAPI_P1',0x10000000)
		win_const_mgr.add_const('SQL_LOCK_NO_CHANGE',0x00000000)
		win_const_mgr.add_const('ERROR_NO_TRUST_SAM_ACCOUNT',0x000006FB)
		win_const_mgr.add_const('DIF_SELECTDEVICE',0x00000001)
		win_const_mgr.add_const('CS_DROPSHADOW',0x00020000)
		win_const_mgr.add_const('PATCH_OPTION_NO_BINDFIX',0x00010000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2ERASE_FULLERASE',0x00000101)
		win_const_mgr.add_const('CHANNEL_RC_TOO_MANY_CHANNELS',0x00000005)
		win_const_mgr.add_const('SUBLANG_ARABIC_IRAQ',0x00000002)
		win_const_mgr.add_const('DISPID_ONKEYPRESS',0x0000000D)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_CURRENTWRITESPEED',0x00000111)
		win_const_mgr.add_const('RBBIM_STYLE',0x00000001)
		win_const_mgr.add_const('IPPROTO_RM',0x00000071)
		win_const_mgr.add_const('WMDRM_RESTORE_INDIVIDUALIZE',0x00000002)
		win_const_mgr.add_const('CMSG_CTRL_ADD_ATTR_CERT',0x0000000E)
		win_const_mgr.add_const('WIA_PAGE_JIS_B1',0x00000028)
		win_const_mgr.add_const('TLS1_ALERT_DECODE_ERROR',0x00000032)
		win_const_mgr.add_const('ERROR_DS_EXISTS_IN_MUST_HAVE',0x000020C1)
		win_const_mgr.add_const('NETE_CANTCONNECT',0x00000011)
		win_const_mgr.add_const('MCI_DGV_MONITOR_INPUT',0x00004000)
		win_const_mgr.add_const('WIA_PAGE_JIS_B2',0x00000029)
		win_const_mgr.add_const('RATING_ONE_STAR_MAX',0x0000000C)
		win_const_mgr.add_const('TMT_WIDTH',0x00000970)
		win_const_mgr.add_const('WIA_PAGE_JIS_B3',0x0000002A)
		win_const_mgr.add_const('SCH_CRED_NO_SYSTEM_MAPPER',0x00000002)
		win_const_mgr.add_const('DDFXALPHACAPS_BLTALPHAPIXELS',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_NC_END',0x00000001)
		win_const_mgr.add_const('OID_GEN_XMIT_LINK_SPEED',0x00010284)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_PROCESS_COUNTERS',0x00000008)
		win_const_mgr.add_const('MM_ACM_FILTERCHOOSE',0x00008000)
		win_const_mgr.add_const('RPC_S_SEND_INCOMPLETE',0x00000779)
		win_const_mgr.add_const('DRM_SERVICE_LOCATION_INTERNET',0x00000001)
		win_const_mgr.add_const('IDI_CLASSICON_OVERLAYFIRST',0x000001F4)
		win_const_mgr.add_const('MFRR_INFO_VERSION',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_IA64_LTOFF22',0x0000000A)
		win_const_mgr.add_const('ERROR_OPEN_FAILED',0x0000006E)
		win_const_mgr.add_const('SQL_CA2_MAX_ROWS_INSERT',0x00000100)
		win_const_mgr.add_const('COMPRESSION_FORMAT_SPARSE',0x00004000)
		win_const_mgr.add_const('SQL_MAX_LENGTH_DEFAULT',0x00000000)
		win_const_mgr.add_const('DBC_GS_IDEAL',0x00000000)
		win_const_mgr.add_const('NTDSDSA_OPT_DISABLE_OUTBOUND_REPL',0x00000001)
		win_const_mgr.add_const('SHCNE_GLOBALEVENTS',0x0C0581E0)
		win_const_mgr.add_const('DRAGDROP_E_LAST',0x8004010F)
		win_const_mgr.add_const('DEBUG_DATA_BASE_TRANSLATION_VIRTUAL_OFFSET',0x00000003)
		win_const_mgr.add_const('POWER_ACTION_DISABLE_WAKES',0x40000000)
		win_const_mgr.add_const('EVENT_OBJECT_REORDER',0x00008004)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_RCV_DISCARDS',0x00000010)
		win_const_mgr.add_const('NRB_FUNCTION_NVCACHE_INFO',0x000000EC)
		win_const_mgr.add_const('MCI_ANIM_GETDEVCAPS_CAN_STRETCH',0x00004007)
		win_const_mgr.add_const('SCARD_E_INVALID_HANDLE',0x80100003)
		win_const_mgr.add_const('DDF_2000',0x00002000)
		win_const_mgr.add_const('WINHTTP_OPTION_CONTEXT_VALUE',0x0000002D)
		win_const_mgr.add_const('NUMPRS_STD',0x00001FFF)
		win_const_mgr.add_const('SECBUFFER_STREAM',0x0000000A)
		win_const_mgr.add_const('AM_VIDEO_FLAG_P_SAMPLE',0x00000010)
		win_const_mgr.add_const('WMP_MDRT_FLAGS_UNREPORTED_ADDED_ITEMS',0x00000002)
		win_const_mgr.add_const('SQL_CA_CONSTRAINT_NON_DEFERRABLE',0x00000080)
		win_const_mgr.add_const('EMR_SAVEDC',0x00000021)
		win_const_mgr.add_const('COD_LAN_ACCESS_50_USED',0x00000003)
		win_const_mgr.add_const('SO_PAP_GET_SERVER_STATUS',0x0000A008)
		win_const_mgr.add_const('CRYPT_STRING_HEXASCIIADDR',0x00000000)
		win_const_mgr.add_const('DEBUG_STACK_COLUMN_NAMES',0x00000010)
		win_const_mgr.add_const('MDMSPKR_CALLSETUP',0x00000003)
		win_const_mgr.add_const('WT_EXECUTEONLYONCE',0x00000008)
		win_const_mgr.add_const('SME_VERSION',0x00000000)
		win_const_mgr.add_const('VARCMP_NULL',0x00000003)
		win_const_mgr.add_const('IDD_ACMFILTERCHOOSE_CMB_CUSTOM',0x00000064)
		win_const_mgr.add_const('IF_MIB_STATS_ID',0x00000001)
		win_const_mgr.add_const('CRYPTUI_SELECT_FRIENDLYNAME_COLUMN',0x00000008)
		win_const_mgr.add_const('OID_FDDI_SMT_MIB_VERSION_ID',0x03030207)
		win_const_mgr.add_const('WHDR_INQUEUE',0x00000010)
		win_const_mgr.add_const('DBIMF_UNDELETEABLE',0x00000010)
		win_const_mgr.add_const('ERROR_CONTROL_ID_NOT_FOUND',0x0000058D)
		win_const_mgr.add_const('DLCTL_RESYNCHRONIZE',0x00002000)
		win_const_mgr.add_const('DBPROPVAL_GU_SUFFIX',0x00000002)
		win_const_mgr.add_const('_MM_HINT_T0',0x00000001)
		win_const_mgr.add_const('VIF_WRITEPROT',0x00000040)
		win_const_mgr.add_const('_MM_HINT_T2',0x00000003)
		win_const_mgr.add_const('DISPID_PICT_TYPE',0x00000003)
		win_const_mgr.add_const('PDH_PATH_WBEM_INPUT',0x00000002)
		win_const_mgr.add_const('NET_IF_OID_IF_ALIAS',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_VOLUME',0x00004002)
		win_const_mgr.add_const('MAX_PORT_NAME',0x00000010)
		win_const_mgr.add_const('DNS_QUERY_NO_WIRE_QUERY',0x00000010)
		win_const_mgr.add_const('PORT_NNTP',0x00000077)
		win_const_mgr.add_const('ERROR_I24_CRC',0x00000004)
		win_const_mgr.add_const('MDPROPVAL_MSF_TOGGLEDRILLSTATE',0x00040000)
		win_const_mgr.add_const('OF_CREATE',0x00001000)
		win_const_mgr.add_const('IMAGE_FILE_LOCAL_SYMS_STRIPPED',0x00000008)
		win_const_mgr.add_const('BACKGROUND_GREEN',0x00000020)
		win_const_mgr.add_const('CERT_STORE_CERTIFICATE_CONTEXT',0x00000001)
		win_const_mgr.add_const('MD_APP_POOL_RECYCLE_ON_DEMAND',0x00000020)
		win_const_mgr.add_const('SE_PRIVILEGE_ENABLED',0x00000002)
		win_const_mgr.add_const('ERROR_NOT_FOUND',0x00000490)
		win_const_mgr.add_const('MCI_SEEK',0x00000807)
		win_const_mgr.add_const('PAN_PROP_VERY_EXPANDED',0x00000007)
		win_const_mgr.add_const('OID_ATM_GET_NEAREST_FLOW',0x08010207)
		win_const_mgr.add_const('PIDDSI_DOCPARTS',0x0000000D)
		win_const_mgr.add_const('EC_VMR_RECONNECTION_FAILED',0x00000055)
		win_const_mgr.add_const('VECTOR_SEARCH',0x00000008)
		win_const_mgr.add_const('SE_SACL_PROTECTED',0x00002000)
		win_const_mgr.add_const('WM_DWMWINDOWMAXIMIZEDCHANGE',0x00000321)
		win_const_mgr.add_const('AE_SERVICESTAT',0x0000000B)
		win_const_mgr.add_const('SUBLANG_ENGLISH_SINGAPORE',0x00000012)
		win_const_mgr.add_const('WAVE_FORMAT_4S16',0x00000800)
		win_const_mgr.add_const('HELP_CONTEXTMENU',0x00000000)
		win_const_mgr.add_const('MSV1_0_CLEARTEXT_PASSWORD_SUPPLIED',0x00004000)
		win_const_mgr.add_const('SE_MAX_GENERIC_AUDIT_PARAMETERS',0x0000001C)
		win_const_mgr.add_const('WM_PAINT',0x0000000F)
		win_const_mgr.add_const('LINEDIALTONEMODE_UNKNOWN',0x00000010)
		win_const_mgr.add_const('TMASYNC',0x80000000)
		win_const_mgr.add_const('D3D_SDK_VERSION',0x0000001F)
		win_const_mgr.add_const('SQL_API_SQLCOLUMNS',0x00000028)
		win_const_mgr.add_const('CERT_TRUST_DO_FULL_SEARCH',0x00000001)
		win_const_mgr.add_const('SC_DLG_FORCE_UI',0x00000004)
		win_const_mgr.add_const('DVM_CONFIGURE_START',0x00001000)
		win_const_mgr.add_const('IMAGE_COMDAT_SELECT_SAME_SIZE',0x00000003)
		win_const_mgr.add_const('OID_FDDI_SMT_HOLD_STATE',0x03030217)
		win_const_mgr.add_const('DDBLT_WAIT',0x01000000)
		win_const_mgr.add_const('TBIMHT_BACKGROUND',0x00000002)
		win_const_mgr.add_const('LINGUISTIC_IGNORECASE',0x00000010)
		win_const_mgr.add_const('DDOSDCAPS_MONOLITHICMIPMAP',0x00000004)
		win_const_mgr.add_const('LANG_MALAY',0x00000003)
		win_const_mgr.add_const('RPCFLG_AUTO_COMPLETE',0x08000000)
		win_const_mgr.add_const('TBIF_IMAGE',0x00000001)
		win_const_mgr.add_const('DDCKEYCAPS_SRCBLT',0x00000200)
		win_const_mgr.add_const('ASYNC_RECO_SETCACMODE_FAILED',0x00000008)
		win_const_mgr.add_const('SQL_ATTR_READWRITE_UNKNOWN',0x00000002)
		win_const_mgr.add_const('SSM_CLEAR',0x00000000)
		win_const_mgr.add_const('UNDEFINE_ALTERNATE',0x0000000D)
		win_const_mgr.add_const('CB_SELECTSTRING',0x0000014D)
		win_const_mgr.add_const('WM_QUERYENDSESSION',0x00000011)
		win_const_mgr.add_const('SP_COPY_NODECOMP',0x00000010)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_COMMIT',0x00000004)
		win_const_mgr.add_const('OUT_OUTLINE_PRECIS',0x00000008)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_TRANSFERMAKE',0x00002000)
		win_const_mgr.add_const('RPCFLG_ACCESSIBILITY_BIT1',0x00100000)
		win_const_mgr.add_const('RPCFLG_ACCESSIBILITY_BIT2',0x00200000)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_LOCAL',0x00002000)
		win_const_mgr.add_const('BG_E_TEST_OPTION_BLOCKED_DOWNLOAD',0x80200046)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_DEQUEUE',0x00000007)
		win_const_mgr.add_const('CSURL_PUBLISHRETRY',0x00000010)
		win_const_mgr.add_const('WNCON_SLOWLINK',0x00000004)
		win_const_mgr.add_const('IMN_OPENCANDIDATE',0x00000005)
		win_const_mgr.add_const('OID_FDDI_PORT_PCM_STATE',0x03030273)
		win_const_mgr.add_const('COD_AUDIO_MINOR_CAMCORDER',0x0000000D)
		win_const_mgr.add_const('DBDTF_RETURNEXTERNAL',0x00000004)
		win_const_mgr.add_const('ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME',0x00003700)
		win_const_mgr.add_const('DEBUG_DISASM_SOURCE_LINE_NUMBER',0x00000004)
		win_const_mgr.add_const('IF_TYPE_VOICEOVERFRAMERELAY',0x00000099)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_MASK',0x3FFFFFFF)
		win_const_mgr.add_const('SQL_FN_TD_MONTHNAME',0x00010000)
		win_const_mgr.add_const('SFVM_UPDATESTATUSBAR',0x0000001F)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR',0x00003612)
		win_const_mgr.add_const('TMT_TEXT',0x00000C81)
		win_const_mgr.add_const('ISC_REQ_ALLOCATE_MEMORY',0x00000100)
		win_const_mgr.add_const('RPC_C_AUTHZ_NONE',0x00000000)
		win_const_mgr.add_const('SC_HOTKEY',0x0000F150)
		win_const_mgr.add_const('MAXINFOSIZE',0x00000100)
		win_const_mgr.add_const('KSPROPERTY_MEMBER_FLAG_BASICSUPPORT_UNIFORM',0x00000004)
		win_const_mgr.add_const('COPY_FILE_RESTARTABLE',0x00000002)
		win_const_mgr.add_const('ADS_SERVICE_CONTINUE_PENDING',0x00000005)
		win_const_mgr.add_const('SM_FOCUS_TYPE_UNKNOWN_SERVER',0x00000007)
		win_const_mgr.add_const('BSM_INSTALLABLEDRIVERS',0x00000004)
		win_const_mgr.add_const('LINEMEDIACONTROL_RATEDOWN',0x00000040)
		win_const_mgr.add_const('WINHTTP_OPTION_WORKER_THREAD_COUNT',0x00000050)
		win_const_mgr.add_const('MM_STREAM_OPEN',0x000003D4)
		win_const_mgr.add_const('CERT_NCRYPT_KEY_SPEC',0xFFFFFFFF)
		win_const_mgr.add_const('ERROR_INTERRUPT',0x0000005F)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW3_SCREENTOP',0x00000493)
		win_const_mgr.add_const('MDMEMBER_TYPE_ALL',0x00000002)
		win_const_mgr.add_const('MCI_SEEK_TO_START',0x00000100)
		win_const_mgr.add_const('DS_REPDEL_INTERSITE_MESSAGING',0x00000004)
		win_const_mgr.add_const('NF_QUERY',0x00000003)
		win_const_mgr.add_const('WEBPOST_ERROR_LIST_SITES',0xC0042108)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SRC_STEREO_S',0x00008023)
		win_const_mgr.add_const('ERROR_EVT_EVENT_DEFINITION_NOT_FOUND',0x00003AB8)
		win_const_mgr.add_const('PDH_OS_LATER_VERSION',0xC0000BF9)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_244',0x00000000)
		win_const_mgr.add_const('DISABLE_TAR_FIX',0x00000000)
		win_const_mgr.add_const('MD_SERVER_STATE_CONTINUING',0x00000007)
		win_const_mgr.add_const('DDCAPS2_COLORCONTROLOVERLAY',0x00000040)
		win_const_mgr.add_const('SCARD_E_NO_MEMORY',0x80100006)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_WMV8_A',0x00000080)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_WMV8_B',0x00000081)
		win_const_mgr.add_const('PDH_WBEM_ERROR',0xC0000BDA)
		win_const_mgr.add_const('NMP_PROCESS_POST',0x00000001)
		win_const_mgr.add_const('ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD',0x000020B8)
		win_const_mgr.add_const('VK_LAUNCH_MAIL',0x000000B4)
		win_const_mgr.add_const('GL_CACHE_OPERATION',0x00000010)
		win_const_mgr.add_const('WIA_TRANSFER_MSG_NEW_PAGE',0x00000006)
		win_const_mgr.add_const('C1_ALPHA',0x00000100)
		win_const_mgr.add_const('IGIMII_CMODE',0x00000001)
		win_const_mgr.add_const('WNODE_FLAG_STATIC_INSTANCE_NAMES',0x00000080)
		win_const_mgr.add_const('SQLMONEY4',0x00000007)
		win_const_mgr.add_const('HSR_CHUNKED',0x00000020)
		win_const_mgr.add_const('PERF_AGGREGATE_AVG',0x00000002)
		win_const_mgr.add_const('SES_EMULATE10',0x00000010)
		win_const_mgr.add_const('META_CREATEBRUSHINDIRECT',0x000002FC)
		win_const_mgr.add_const('IMAGE_OS2_SIGNATURE',0x00004E45)
		win_const_mgr.add_const('DSOP_FLAG_SKIP_TARGET_COMPUTER_DC_CHECK',0x00000002)
		win_const_mgr.add_const('ET_PLATFORM',0x00000200)
		win_const_mgr.add_const('IDM_DEFAULTBLOCK',0x0000179E)
		win_const_mgr.add_const('ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER',0x00002131)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_DIMENSIONS',0x00000005)
		win_const_mgr.add_const('WPWIZ_ERROR_LAST',0x400420FF)
		win_const_mgr.add_const('NTMS_POOLHIERARCHY_LENGTH',0x00000200)
		win_const_mgr.add_const('ERROR_DS_NAME_ERROR_NOT_UNIQUE',0x00002117)
		win_const_mgr.add_const('DNS_ERROR_RCODE_BADSIG',0x00002338)
		win_const_mgr.add_const('WM_MDIICONARRANGE',0x00000228)
		win_const_mgr.add_const('SNMPAPI_M2M_SUPPORT',0x00000003)
		win_const_mgr.add_const('DXVA_READ_BACK_BUFFER',0x0000000F)
		win_const_mgr.add_const('SNMP_ERROR_INCONSISTENTNAME',0x00000012)
		win_const_mgr.add_const('DIGCF_PRESENT',0x00000002)
		win_const_mgr.add_const('DOT11_STATUS_UNAVAILABLE_SERVICE_CLASS',0x00000020)
		win_const_mgr.add_const('IDC_CI_DEFAULT',0x0000007B)
		win_const_mgr.add_const('GRAY_BRUSH',0x00000002)
		win_const_mgr.add_const('WIA_DPC_EXPOSURE_MODE',0x00000804)
		win_const_mgr.add_const('MD_ERROR_SUB404_URL_HAS_HIGH_BIT_CHARS',0x0000000C)
		win_const_mgr.add_const('PDH_PLA_ERROR_TYPE_MISMATCH',0xC0000BEF)
		win_const_mgr.add_const('CRL_REASON_KEY_COMPROMISE_FLAG',0x00000040)
		win_const_mgr.add_const('AF_SNA',0x0000000B)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_MIPSFPU',0x00000366)
		win_const_mgr.add_const('DS_REPL_NBR_IGNORE_CHANGE_NOTIFICATIONS',0x04000000)
		win_const_mgr.add_const('PSTF_BEST_ENCRYPTION',0x20000000)
		win_const_mgr.add_const('OFN_DONTADDTORECENT',0x02000000)
		win_const_mgr.add_const('BAUD_150',0x00000008)
		win_const_mgr.add_const('KF_FLAG_DONT_VERIFY',0x00004000)
		win_const_mgr.add_const('DNS_TYPE_ATMA',0x00000022)
		win_const_mgr.add_const('WMDM_E_INCORRECT_RIGHTS',0x80045011)
		win_const_mgr.add_const('PSD_DEFAULTMINMARGINS',0x00000000)
		win_const_mgr.add_const('KSPROPERTY_MEMBER_STEPPEDRANGES',0x00000002)
		win_const_mgr.add_const('DCIESCAPE',0x00000005)
		win_const_mgr.add_const('APPCOMMAND_FORWARD_MAIL',0x00000028)
		win_const_mgr.add_const('DEBUG_VALUE_INVALID',0x00000000)
		win_const_mgr.add_const('AM_DVD_CGMS_COPY_PERMITTED',0x00000000)
		win_const_mgr.add_const('WMDM_E_NORIGHTS',0x80045006)
		win_const_mgr.add_const('SFGAO_FOLDER',0x20000000)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_AUTHORIZATIONERROR',0x00000010)
		win_const_mgr.add_const('PSP_USETITLE',0x00000008)
		win_const_mgr.add_const('DIRID_PRINTPROCESSOR',0x00000037)
		win_const_mgr.add_const('TRUSTERROR_STEP_SIPSUBJINFO',0x00000005)
		win_const_mgr.add_const('GD_ERRTABLE',0x0000000B)
		win_const_mgr.add_const('TMT_UNIFORMSIZING',0x000008A2)
		win_const_mgr.add_const('USER_LOGON_HOURS_PARMNUM',0x00000014)
		win_const_mgr.add_const('NOTIFIER_TYPE_HANDLE_WAIT',0x00000002)
		win_const_mgr.add_const('LINEMEDIACONTROL_PAUSE',0x00000008)
		win_const_mgr.add_const('RATING_TWO_STARS_SET',0x00000019)
		win_const_mgr.add_const('LVSIL_NORMAL',0x00000000)
		win_const_mgr.add_const('AF_MAX',0x00000021)
		win_const_mgr.add_const('RATING_TWO_STARS_MIN',0x0000000D)
		win_const_mgr.add_const('ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4',0x0000217C)
		win_const_mgr.add_const('CONFIGFLAG_VERIFY_HARDWARE',0x00008000)
		win_const_mgr.add_const('BAUD_19200',0x00002000)
		win_const_mgr.add_const('ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS',0x00001A9C)
		win_const_mgr.add_const('DISPID_NAVIGATEANDFIND',0x00000008)
		win_const_mgr.add_const('TAPI_CURRENT_VERSION',0x00030001)
		win_const_mgr.add_const('BG_E_COMMIT_IN_PROGRESS',0x80200043)
		win_const_mgr.add_const('SSPROP_FASTLOADKEEPNULLS',0x0000000A)
		win_const_mgr.add_const('PSH_NOCONTEXTHELP',0x02000000)
		win_const_mgr.add_const('SQL_SP_IN',0x00000400)
		win_const_mgr.add_const('EC_STEP_COMPLETE',0x00000024)
		win_const_mgr.add_const('DIOD_CANCEL_REMOVE',0x00000004)
		win_const_mgr.add_const('BITS_MC_JOB_NOTIFICATION_FAILURE',0x80194006)
		win_const_mgr.add_const('DEVPROP_TYPE_DATE',0x0000000F)
		win_const_mgr.add_const('MDM_PROTOCOLID_HDLCPPP',0x00000001)
		win_const_mgr.add_const('RESOURCE_MANAGER_COMMUNICATION',0x00000002)
		win_const_mgr.add_const('WTS_EVENT_LICENSE',0x00000100)
		win_const_mgr.add_const('IDC_CV_OBJECTTYPE',0x00000096)
		win_const_mgr.add_const('CRYPT_ENCODE_DECODE_NONE',0x00000000)
		win_const_mgr.add_const('DM_SCALE',0x00000010)
		win_const_mgr.add_const('DISPID_ONMOUSEOUT',0x00000008)
		win_const_mgr.add_const('VK_KANA',0x00000015)
		win_const_mgr.add_const('OBJECT_PUSH_FORMAT_VCAL_1_0',0x00000003)
		win_const_mgr.add_const('FACILTIY_MUI_ERROR_CODE',0x0000000B)
		win_const_mgr.add_const('PATCH_OPTION_RESERVED1',0x80000000)
		win_const_mgr.add_const('HANGUP_COMPLETE',0x00000005)
		win_const_mgr.add_const('OS_PERSONALTERMINALSERVER',0x00000019)
		win_const_mgr.add_const('WLX_SAS_ACTION_LOGON',0x00000001)
		win_const_mgr.add_const('WPF_SHOWPAGE_PROVIDER',0x00080000)
		win_const_mgr.add_const('MD_LOAD_BALANCER_CAPABILITIES_BASIC',0x00000001)
		win_const_mgr.add_const('DEVICE_FONTTYPE',0x00000002)
		win_const_mgr.add_const('LUP_SECURE',0x00008000)
		win_const_mgr.add_const('BCP_FMT_INDICATOR_LEN',0x00000002)
		win_const_mgr.add_const('ACMSTREAMHEADER_STATUSF_DONE',0x00010000)
		win_const_mgr.add_const('DISPID_IADCCTL_DIRTY',0x00000100)
		win_const_mgr.add_const('DEBUG_FILTER_IGNORE',0x00000003)
		win_const_mgr.add_const('QS_MOUSEBUTTON',0x00000004)
		win_const_mgr.add_const('SQL_INTERVAL_YEAR',0x00000064)
		win_const_mgr.add_const('ERROR_IO_REISSUE_AS_CACHED',0x00000F6E)
		win_const_mgr.add_const('SPFILENOTIFY_ENDSUBQUEUE',0x00000004)
		win_const_mgr.add_const('CLEAR_BLOCK_LENGTH',0x00000008)
		win_const_mgr.add_const('VK_F22',0x00000085)
		win_const_mgr.add_const('IDM_TRIED_FORECOLOR',0x00000026)
		win_const_mgr.add_const('MCIWNDF_NOTIFYERROR',0x00001000)
		win_const_mgr.add_const('MAX_RESOURCEMANAGER_DESCRIPTION_LENGTH',0x00000040)
		win_const_mgr.add_const('OFN_NOREADONLYRETURN',0x00008000)
		win_const_mgr.add_const('CRL_DIST_POINT_ERR_INDEX_MASK',0x0000007F)
		win_const_mgr.add_const('SKF_LALTLOCKED',0x00100000)
		win_const_mgr.add_const('RRF_RT_REG_DWORD',0x00000010)
		win_const_mgr.add_const('ALG_TYPE_DH',0x00000005)
		win_const_mgr.add_const('MCI_QUALITY_ITEM_VIDEO',0x00004002)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_NOT_READY',0x000013D0)
		win_const_mgr.add_const('SCESTATUS_NO_TEMPLATE_GIVEN',0x00000011)
		win_const_mgr.add_const('TMT_STREAM',0x000000D6)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CHECKPOINT',0x00000008)
		win_const_mgr.add_const('BL_DECOMPRESS_INDEX',0x00000004)
		win_const_mgr.add_const('DIF_POWERMESSAGEWAKE',0x00000027)
		win_const_mgr.add_const('PERF_COUNTERSET_FLAG_MULTIPLE',0x00000002)
		win_const_mgr.add_const('GCPCLASS_PREBOUNDRTL',0x00000040)
		win_const_mgr.add_const('CRYPTPROTECT_PROMPT_STRONG',0x00000008)
		win_const_mgr.add_const('EVENT_OBJECT_SELECTIONREMOVE',0x00008008)
		win_const_mgr.add_const('SOUND_SYSTEM_RESTOREUP',0x0000000A)
		win_const_mgr.add_const('MSV1_0_RETURN_USER_PARAMETERS',0x00000008)
		win_const_mgr.add_const('X3_OPCODE_SIGN_VAL_POS_X',0x00000000)
		win_const_mgr.add_const('TMT_OFFSETTYPE',0x00000FA8)
		win_const_mgr.add_const('INTERNET_STATUS_PREFETCH',0x0000002B)
		win_const_mgr.add_const('HSE_EXEC_URL_HTTP_CACHE_ELIGIBLE',0x00000080)
		win_const_mgr.add_const('KS_DVD_COPYRIGHTED',0x00000040)
		win_const_mgr.add_const('SQL_CT_TABLE_CONSTRAINT',0x00001000)
		win_const_mgr.add_const('DPNHREGISTERPORTS_SHAREDPORTS',0x00000004)
		win_const_mgr.add_const('PORT_ERPC',0x00000079)
		win_const_mgr.add_const('ITR_EPC_INDEX',0x00000000)
		win_const_mgr.add_const('PERF_REMOVE_COUNTER',0x00000002)
		win_const_mgr.add_const('ERROR_TM_INITIALIZATION_FAILED',0x00001A32)
		win_const_mgr.add_const('NUMPRS_LEADING_WHITE',0x00000001)
		win_const_mgr.add_const('ERROR_DS_MUST_BE_RUN_ON_DST_DC',0x0000216E)
		win_const_mgr.add_const('CQPM_PERSIST',0x00000007)
		win_const_mgr.add_const('DNS_RTYPE_OPT',0x00002900)
		win_const_mgr.add_const('WM_INPUT',0x000000FF)
		win_const_mgr.add_const('MCGIP_NEXT',0x00000001)
		win_const_mgr.add_const('NDIS_PROTOCOL_ID_IPX',0x00000006)
		win_const_mgr.add_const('MAPI_COMPOUND',0x00000080)
		win_const_mgr.add_const('KP_SERVER_RANDOM',0x00000016)
		win_const_mgr.add_const('UDS_ALIGNLEFT',0x00000008)
		win_const_mgr.add_const('POLLHUP',0x00000002)
		win_const_mgr.add_const('AI_ALL',0x00000100)
		win_const_mgr.add_const('SM_CYDLGFRAME',0x00000008)
		win_const_mgr.add_const('OID_FDDI_IF_OUT_ERRORS',0x0303028B)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_CROSS_ORGANIZATION',0x00000010)
		win_const_mgr.add_const('ASC_RET_USE_SESSION_KEY',0x00000020)
		win_const_mgr.add_const('IDM_CAPTIONINSERT',0x0000089B)
		win_const_mgr.add_const('SCH_CRED_MANUAL_CRED_VALIDATION',0x00000008)
		win_const_mgr.add_const('WMDM_DEVICECAP_HASSECURECLOCK',0x00000100)
		win_const_mgr.add_const('SQL_ATTR_ROW_OPERATION_PTR',0x00000018)
		win_const_mgr.add_const('DBPROP_FIRSTROWS',0x00000007)
		win_const_mgr.add_const('RTS_CONTROL_DISABLE',0x00000000)
		win_const_mgr.add_const('LB_SETTOPINDEX',0x00000197)
		win_const_mgr.add_const('EN_STOPNOUNDO',0x00000706)
		win_const_mgr.add_const('IMAGE_FILE_32BIT_MACHINE',0x00000100)
		win_const_mgr.add_const('DEBUG_SYMBOL_IS_FLOAT',0x00000080)
		win_const_mgr.add_const('SQL_INDEX_KEYWORDS',0x00000094)
		win_const_mgr.add_const('WMDRM_METER_RESPONSE_ALL',0x00000000)
		win_const_mgr.add_const('ALG_CLASS_ANY',0x00000000)
		win_const_mgr.add_const('SCF_ASSOCIATEFONT2',0x00000040)
		win_const_mgr.add_const('OF_CANCEL',0x00000800)
		win_const_mgr.add_const('BSIM_STYLE',0x00000002)
		win_const_mgr.add_const('NDIS_MAC_OPTION_RECEIVE_AT_DPC',0x00000100)
		win_const_mgr.add_const('RQ_RELEASE_REQUEST_STATE',0x00000100)
		win_const_mgr.add_const('IR_IMESELECT',0x00000130)
		win_const_mgr.add_const('MMIO_ALLOCBUF',0x00010000)
		win_const_mgr.add_const('SCARD_E_FILE_NOT_FOUND',0x80100024)
		win_const_mgr.add_const('MFBYTESTREAM_IS_REMOTE',0x00000008)
		win_const_mgr.add_const('IIS_MD_ID_END_RESERVED',0x00000007)
		win_const_mgr.add_const('RP_ENPANDED',0x00002010)
		win_const_mgr.add_const('MUTZ_ISFILE',0x00000002)
		win_const_mgr.add_const('USER_MARSHAL_UNIQUE',0x00000080)
		win_const_mgr.add_const('OID_802_11_BSSID_LIST',0x0D010217)
		win_const_mgr.add_const('DEBUG_VALUE_FLOAT82',0x00000008)
		win_const_mgr.add_const('DOMAIN_PASSWORD_NO_ANON_CHANGE',0x00000002)
		win_const_mgr.add_const('SM_SLOWMACHINE',0x00000049)
		win_const_mgr.add_const('FILE_VOLUME_IS_COMPRESSED',0x00008000)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_BLUESCREEN',0x0000000F)
		win_const_mgr.add_const('APPCOMMAND_HELP',0x0000001B)
		win_const_mgr.add_const('MAX_ISCSI_HBANAME_LEN',0x00000100)
		win_const_mgr.add_const('CMSG_KEY_AGREE_ENCRYPT_FREE_PUBKEY_BITS_FLAG',0x00000010)
		win_const_mgr.add_const('ADOX_MAJOR',0x00000006)
		win_const_mgr.add_const('DTT_SHADOWCOLOR',0x00000001)
		win_const_mgr.add_const('RPC_C_PROFILE_ALL_ELT',0x00000001)
		win_const_mgr.add_const('SPCRP_SECURITY_SDS',0x00000018)
		win_const_mgr.add_const('FIND_ANY',0x00000020)
		win_const_mgr.add_const('TVSIL_NORMAL',0x00000000)
		win_const_mgr.add_const('MD_CHANGE_TYPE_RENAME_OBJECT',0x00000010)
		win_const_mgr.add_const('ERROR_EC_CREDSTORE_FULL',0x00003AEB)
		win_const_mgr.add_const('HDF_LEFT',0x00000000)
		win_const_mgr.add_const('SUBSMGRENUM_TEMP',0x00000001)
		win_const_mgr.add_const('DDOVERFX_DEINTERLACE',0x00000008)
		win_const_mgr.add_const('MCS_NOTODAYCIRCLE',0x00000008)
		win_const_mgr.add_const('GD_STRING',0x00000006)
		win_const_mgr.add_const('MQMSG_SEND_ROUTE_TO_REPORT_QUEUE',0x00000001)
		win_const_mgr.add_const('SQL_NULL_COLLATION',0x00000055)
		win_const_mgr.add_const('AUTHZ_NO_FAILURE_AUDIT',0x00000002)
		win_const_mgr.add_const('TXFS_RM_STATE_STARTING',0x00000001)
		win_const_mgr.add_const('OS_MEORGREATER',0x00000011)
		win_const_mgr.add_const('VK_ICO_CLEAR',0x000000E6)
		win_const_mgr.add_const('MD_ERROR_SUB403_MAPPER_DENY_ACCESS',0x0000000C)
		win_const_mgr.add_const('SQL_FN_NUM_RAND',0x00020000)
		win_const_mgr.add_const('SPI_GETKEYBOARDPREF',0x00000044)
		win_const_mgr.add_const('DNS_TYPE_MINFO',0x00000000)
		win_const_mgr.add_const('GESTURE_QUAD_TAP',0x00000000)
		win_const_mgr.add_const('ERROR_PWD_TOO_RECENT',0x00000268)
		win_const_mgr.add_const('SIF_DISABLENOSCROLL',0x00000008)
		win_const_mgr.add_const('MCI_DEVTYPE_OTHER',0x00000209)
		win_const_mgr.add_const('OID_FDDI_PORT_LEM_CT',0x0303026F)
		win_const_mgr.add_const('GETCOLORTABLE',0x00000005)
		win_const_mgr.add_const('FILE_DEVICE_DVD',0x00000033)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_CAMPON',0x0000002B)
		win_const_mgr.add_const('TMT_BUTTONALTERNATEFACE',0x0000065A)
		win_const_mgr.add_const('SQL_SRJO_INTERSECT_JOIN',0x00000020)
		win_const_mgr.add_const('PAGE_READONLY',0x00000002)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETGROUPLIST',0x00000013)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_VIEW_PREF_METADATAVIEW',0x00000400)
		win_const_mgr.add_const('BTHPROTO_RFCOMM',0x00000003)
		win_const_mgr.add_const('BTH_ERROR_REMOTE_LOW_RESOURCES',0x00000014)
		win_const_mgr.add_const('DEBUG_STATUS_STEP_OVER',0x00000004)
		win_const_mgr.add_const('WIA_TRANSFER_MSG_END_OF_STREAM',0x00000002)
		win_const_mgr.add_const('TF_LBI_STYLE_BTN_TOGGLE',0x00040000)
		win_const_mgr.add_const('PATCH_OPTION_FAIL_IF_SAME_FILE',0x00080000)
		win_const_mgr.add_const('SDP_ATTRIB_HID_DEVICE_SUBCLASS',0x00000202)
		win_const_mgr.add_const('KSPROPERTY_TYPE_GET',0x00000001)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_COMMITFAILED',0x0000000E)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM9D_VAL_POS_X',0x00000007)
		win_const_mgr.add_const('PKCS_7_ASN_ENCODING',0x00010000)
		win_const_mgr.add_const('ERROR_DS_SUB_CLS_TEST_FAIL',0x000020C7)
		win_const_mgr.add_const('TMT_CAPTIONTEXT',0x0000064A)
		win_const_mgr.add_const('TVIF_SELECTEDIMAGE',0x00000020)
		win_const_mgr.add_const('MCI_ANIM_GETDEVCAPS_CAN_REVERSE',0x00004001)
		win_const_mgr.add_const('OID_GEN_RCV_CRC_ERROR',0x0002020D)
		win_const_mgr.add_const('COOKIE_OP_MODIFY',0x00000002)
		win_const_mgr.add_const('TMT_MENUFONT',0x00000323)
		win_const_mgr.add_const('OPTION_XWINDOW_FONT_SERVER',0x00000030)
		win_const_mgr.add_const('IF_TYPE_G703_64K',0x00000042)
		win_const_mgr.add_const('DBG_MODFREE',0x00000004)
		win_const_mgr.add_const('PPCF_LONGESTPOSSIBLE',0x00000080)
		win_const_mgr.add_const('WSAEMFILE',0x00002728)
		win_const_mgr.add_const('SES_CTFALLOWPROOFING',0x00800000)
		win_const_mgr.add_const('SQL_COLUMN_COUNT',0x00000000)
		win_const_mgr.add_const('OPER_STATE_STOPPING',0x00000005)
		win_const_mgr.add_const('MB_ICONHAND',0x00000010)
		win_const_mgr.add_const('HTTP_QUERY_FORWARDED',0x0000001E)
		win_const_mgr.add_const('ERROR_DEVICE_REMOVED',0x00000651)
		win_const_mgr.add_const('SVSI_FOCUSED',0x00000010)
		win_const_mgr.add_const('LINEBEARERMODE_ALTSPEECHDATA',0x00000010)
		win_const_mgr.add_const('IMAGE_REL_PPC_NEG',0x00000100)
		win_const_mgr.add_const('SFVM_SETPOINTS',0x00000017)
		win_const_mgr.add_const('TRUSTERROR_STEP_MESSAGE',0x00000008)
		win_const_mgr.add_const('LB_SETTABSTOPS',0x00000192)
		win_const_mgr.add_const('SQL_TL_ON',0x00000001)
		win_const_mgr.add_const('SERVICE_FILE_SYSTEM_DRIVER',0x00000002)
		win_const_mgr.add_const('SCRIPTPROP_GCCONTROLSOFTCLOSE',0x00002000)
		win_const_mgr.add_const('OPATH_TOK_OPEN_PAREN',0x0000006A)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_REGISTER_PARAM',0x00000011)
		win_const_mgr.add_const('BITS_MC_JOB_SCAVENGED',0x80194005)
		win_const_mgr.add_const('DNS_RTYPE_RT',0x00001500)
		win_const_mgr.add_const('LANG_KYRGYZ',0x00000040)
		win_const_mgr.add_const('CR_SUCCESS',0x00000000)
		win_const_mgr.add_const('KSNODEPIN_AEC_CAPTURE_IN',0x00000002)
		win_const_mgr.add_const('KSPROPERTY_TYPE_SERIALIZERAW',0x00002000)
		win_const_mgr.add_const('UI_SERVICE',0x00000002)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_BYTES_PRINTED',0x00000019)
		win_const_mgr.add_const('MCI_ANIM_STATUS_SPEED',0x00004001)
		win_const_mgr.add_const('LOGON_CACHED_ACCOUNT',0x00000004)
		win_const_mgr.add_const('SUBSCRIPTION_CAP_PREPAREFORSYNC',0x00000020)
		win_const_mgr.add_const('FS_CYRILLIC',0x00000004)
		win_const_mgr.add_const('OBJ_PEN',0x00000001)
		win_const_mgr.add_const('SSA_HIDEHOTKEY',0x00002000)
		win_const_mgr.add_const('EMR_SETTEXTALIGN',0x00000016)
		win_const_mgr.add_const('MCI_WAVE_SET_SAMPLESPERSEC',0x00040000)
		win_const_mgr.add_const('GPT_ATTRIBUTE_PLATFORM_REQUIRED',0x00000001)
		win_const_mgr.add_const('MD_AUTH_CHANGE_UNSECURE',0x00000001)
		win_const_mgr.add_const('CR_NO_MORE_LOG_CONF',0x0000000E)
		win_const_mgr.add_const('BG_E_INVALID_RANGE',0x8020002B)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_LOG_CONTAINER_COUNT_MAX',0x00000001)
		win_const_mgr.add_const('USER_MARSHAL_FC_USHORT',0x00000007)
		win_const_mgr.add_const('KS_VIDEOSTREAM_STILL',0x00001000)
		win_const_mgr.add_const('ERROR_REPLY_MESSAGE_MISMATCH',0x00000253)
		win_const_mgr.add_const('BCPTEXTFILE',0x0000000E)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_DLL_REDIRECTION',0x00000002)
		win_const_mgr.add_const('URLACTION_JAVA_MAX',0x0000001C)
		win_const_mgr.add_const('ERROR_PNP_IRQ_TRANSLATION_FAILED',0x000002A1)
		win_const_mgr.add_const('ALG_SID_SHA',0x00000004)
		win_const_mgr.add_const('LM20_NNLEN',0x0000000C)
		win_const_mgr.add_const('SP_PROT_ALL',0x00000000)
		win_const_mgr.add_const('CMS_USEHOOK',0x00000080)
		win_const_mgr.add_const('ERROR_SYSTEM_IMAGE_BAD_SIGNATURE',0x0000027D)
		win_const_mgr.add_const('IPPORT_NAMESERVER',0x0000002A)
		win_const_mgr.add_const('SNLEN',0x00000050)
		win_const_mgr.add_const('SUBLANG_TURKISH_TURKEY',0x00000001)
		win_const_mgr.add_const('CM_CREATE_DEVNODE_DO_NOT_INSTALL',0x00000008)
		win_const_mgr.add_const('LINEBEARERMODE_NONCALLSIGNALING',0x00000020)
		win_const_mgr.add_const('ITR_DRIVER1_INDEX',0x00000003)
		win_const_mgr.add_const('GB2312_CHARSET',0x00000086)
		win_const_mgr.add_const('FILE_DEVICE_CHANGER',0x00000030)
		win_const_mgr.add_const('KERB_CHECKSUM_SHA1_NEW',0x0000000E)
		win_const_mgr.add_const('ISC_RET_DATAGRAM',0x00000400)
		win_const_mgr.add_const('D3DPRESENT_INTERVAL_DEFAULT',0x00000000)
		win_const_mgr.add_const('KSRATE_NOPRESENTATIONDURATION',0x00000002)
		win_const_mgr.add_const('ACMDRIVERDETAILS_LONGNAME_CHARS',0x00000080)
		win_const_mgr.add_const('AF_BAN',0x00000015)
		win_const_mgr.add_const('DPNHGETREGISTEREDADDRESSES_LOCALFIREWALLREMAPONLY',0x00000001)
		win_const_mgr.add_const('SHGNLI_NOLNK',0x00000008)
		win_const_mgr.add_const('KSEVENTF_KSWORKITEM',0x00000080)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_LOG_GROWTH_INCREMENT_PERCENT',0x00000010)
		win_const_mgr.add_const('PDCAP_WAKE_FROM_S3_SUPPORTED',0x00800000)
		win_const_mgr.add_const('MDPROPVAL_MS_MULTIPLETUPLES',0x00000001)
		win_const_mgr.add_const('MAPI_TIMEOUT_SHORT',0x00100000)
		win_const_mgr.add_const('FS_TRANSMITTING',0x20000002)
		win_const_mgr.add_const('FPSR_PC1',0x00000015)
		win_const_mgr.add_const('POLICY_LOCATOR_SUB_TYPE_UNICODE_DN_ENC',0x00000004)
		win_const_mgr.add_const('FPSR_PC3',0x0000002F)
		win_const_mgr.add_const('FPSR_PC2',0x00000022)
		win_const_mgr.add_const('METHOD_RIP2_NEIGHBOUR_ADDR',0x00000001)
		win_const_mgr.add_const('STREAM_NORMAL_ATTRIBUTE',0x00000000)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG5',0x00005000)
		win_const_mgr.add_const('EDITF_BASICCONSTRAINTSCRITICAL',0x00000040)
		win_const_mgr.add_const('BALTIC_CHARSET',0x000000BA)
		win_const_mgr.add_const('AIF_QUIET',0x20000000)
		win_const_mgr.add_const('TRACE_MESSAGE_POINTER32',0x00000040)
		win_const_mgr.add_const('SEF_AVOID_PRIVILEGE_CHECK',0x00000008)
		win_const_mgr.add_const('SECURITY_PACKAGE_NTLM_RID',0x0000000A)
		win_const_mgr.add_const('SQL_FETCH_ABSOLUTE',0x00000005)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG6',0x00006000)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNBALANCEDPAREN',0x000036D8)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG1',0x00001000)
		win_const_mgr.add_const('MDMVOLFLAG_HIGH',0x00000004)
		win_const_mgr.add_const('ALG_SID_SAFERSK128',0x00000008)
		win_const_mgr.add_const('DVB_NIT_ACTUAL_TID',0x00000040)
		win_const_mgr.add_const('WM_CTLCOLORDLG',0x00000136)
		win_const_mgr.add_const('TC_SIGNAL',0x00000003)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG3',0x00003000)
		win_const_mgr.add_const('PI_ALLOWED',0x00000000)
		win_const_mgr.add_const('IDM_LISTBOX',0x00000876)
		win_const_mgr.add_const('MARK_HANDLE_PROTECT_CLUSTERS',0x00000001)
		win_const_mgr.add_const('DEBUG_CURRENT_REGISTERS',0x00000004)
		win_const_mgr.add_const('IMAGE_FILE_AGGRESIVE_WS_TRIM',0x00000010)
		win_const_mgr.add_const('MNGOF_TOPGAP',0x00000001)
		win_const_mgr.add_const('BTH_ERROR_UNSPECIFIED',0x000000FF)
		win_const_mgr.add_const('SPREG_REGSVR',0x00000003)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_23',0x00000017)
		win_const_mgr.add_const('CMC_FAIL_BAD_CERT_ID',0x00000004)
		win_const_mgr.add_const('ICMF_COMPVARS_VALID',0x00000001)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_24',0x00000018)
		win_const_mgr.add_const('PIDSI_SONGTITLE',0x00000003)
		win_const_mgr.add_const('KSFILTER_FLAG_HYPERCRITICAL_PROCESSING',0x00000004)
		win_const_mgr.add_const('SF_RTF',0x00000002)
		win_const_mgr.add_const('TC_EA_DOUBLE',0x00000200)
		win_const_mgr.add_const('DDFXALPHACAPS_OVERLAYALPHAEDGEBLEND',0x00000020)
		win_const_mgr.add_const('ERRCLASS_AUTH',0x00000003)
		win_const_mgr.add_const('PHOTOACQ_DISABLE_GROUP_TAG_PROMPT',0x00000008)
		win_const_mgr.add_const('OID_ATM_MAX_ACTIVE_VCI_BITS',0x08010106)
		win_const_mgr.add_const('SV_INITSESSTABLE_PARMNUM',0x0000021F)
		win_const_mgr.add_const('SQL_FILE_TABLE',0x00000001)
		win_const_mgr.add_const('CERT_TRUST_HAS_NOT_DEFINED_NAME_CONSTRAINT',0x00002000)
		win_const_mgr.add_const('CERT_TRUST_HAS_CRL_VALIDITY_EXTENDED',0x00001000)
		win_const_mgr.add_const('VOS_NT_WINDOWS32',0x00040004)
		win_const_mgr.add_const('MP_MSGCLASS_DELIVERY_REPORT',0x00000003)
		win_const_mgr.add_const('DS_REPL_NBR_DISABLE_SCHEDULED_SYNC',0x08000000)
		win_const_mgr.add_const('WSA_FLAG_MULTIPOINT_C_LEAF',0x00000004)
		win_const_mgr.add_const('CE_OVERRUN',0x00000002)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_SERVICE_CC4',0x00000200)
		win_const_mgr.add_const('MC_CAPS_DISPLAY_AREA_SIZE',0x00000100)
		win_const_mgr.add_const('APPSTATUS_RUNNING',0x00000001)
		win_const_mgr.add_const('D3D10_FLOAT32_TO_INTEGER_TOLERANCE_IN_ULP',0x00000000)
		win_const_mgr.add_const('NDF_ERROR_START',0x0000F900)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_SERVICE_CC2',0x00000020)
		win_const_mgr.add_const('CDO_E_SMTP_SERVER_REQUIRED',0x8004020A)
		win_const_mgr.add_const('OLECMDARGINDEX_ACTIVEXINSTALL_DISPLAYNAME',0x00000001)
		win_const_mgr.add_const('DB_OUT',0x00000002)
		win_const_mgr.add_const('ERROR_PRINTQ_FULL',0x0000003D)
		win_const_mgr.add_const('DSA_NOTIFY_DEL',0x00000001)
		win_const_mgr.add_const('SOUND_SYSTEM_MINIMIZE',0x00000009)
		win_const_mgr.add_const('ERROR_INVALID_CURSOR_HANDLE',0x0000057A)
		win_const_mgr.add_const('CERT_STORE_PROV_FIND_CERT_FUNC',0x0000000E)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY',0x00003637)
		win_const_mgr.add_const('TMT_GLYPHONLY',0x0000089F)
		win_const_mgr.add_const('IMAGE_REL_BASED_IA64_IMM64',0x00000009)
		win_const_mgr.add_const('MD_ACCESS_MASK',0x00000000)
		win_const_mgr.add_const('CSIDL_RECENT',0x00000008)
		win_const_mgr.add_const('SERVICE_ERROR_CRITICAL',0x00000003)
		win_const_mgr.add_const('TASK_FLAG_DELETE_WHEN_DONE',0x00000002)
		win_const_mgr.add_const('FS_ANSWERED',0x20800000)
		win_const_mgr.add_const('PHOTO_GAINCONTROL_LOWGAINDOWN',0x00000003)
		win_const_mgr.add_const('ERROR_DS_NOT_SUPPORTED_SORT_ORDER',0x0000217A)
		win_const_mgr.add_const('MEDIA_CURRENTLY_MOUNTED',0x80000000)
		win_const_mgr.add_const('BG_E_CONNECT_FAILURE',0x8020002D)
		win_const_mgr.add_const('DEBUG_PROC_DESC_NO_PATHS',0x00000001)
		win_const_mgr.add_const('SQL_SS_UPDATES',0x00000004)
		win_const_mgr.add_const('ACS_CENTER',0x00000001)
		win_const_mgr.add_const('DXGI_USAGE_RENDER_TARGET_OUTPUT',0x00000001)
		win_const_mgr.add_const('MEM_RESERVE',0x00002000)
		win_const_mgr.add_const('ROTFLAGS_ALLOWANYCLIENT',0x00000002)
		win_const_mgr.add_const('LANG_INDONESIAN',0x00000021)
		win_const_mgr.add_const('DBPROP_MSREMOTE_PROVIDER',0x00000003)
		win_const_mgr.add_const('SQL_CA1_BOOKMARK',0x00000008)
		win_const_mgr.add_const('SQL_SG_UPDATE_COLUMN',0x00001000)
		win_const_mgr.add_const('GL_ID_TYPINGERROR',0x00000021)
		win_const_mgr.add_const('META_DIBBITBLT',0x00000940)
		win_const_mgr.add_const('MCI_SIGNAL',0x00000875)
		win_const_mgr.add_const('MINIDUMP_THREAD_INFO_INVALID_TEB',0x00000020)
		win_const_mgr.add_const('SQL_AF_ALL',0x00000040)
		win_const_mgr.add_const('INTERNET_OPTION_CONNECT_LIMIT',0x0000002E)
		win_const_mgr.add_const('CM_PROB_DEVICE_NOT_THERE',0x00000018)
		win_const_mgr.add_const('SPFILENOTIFY_QUEUESCAN_EX',0x00000018)
		win_const_mgr.add_const('CONSOLE_MOUSE_SELECTION',0x00000004)
		win_const_mgr.add_const('WAB_VCARD_STREAM',0x00000001)
		win_const_mgr.add_const('HHT_BELOW',0x00000200)
		win_const_mgr.add_const('DBPROP_HCHAPTER',0x00000004)
		win_const_mgr.add_const('TKF_AVAILABLE',0x00000002)
		win_const_mgr.add_const('MM_WOM_CLOSE',0x000003BC)
		win_const_mgr.add_const('DISPID_ACTIVATEDTCS',0x00000009)
		win_const_mgr.add_const('ERROR_DS_NTDSCRIPT_PROCESS_ERROR',0x00002190)
		win_const_mgr.add_const('LANG_PERSIAN',0x00000029)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CONLIST_CHANGE_COUNT',0x00000001)
		win_const_mgr.add_const('SHTDN_REASON_MAJOR_SOFTWARE',0x00030000)
		win_const_mgr.add_const('OBJECT_PUSH_FORMAT_ANY',0x000000FF)
		win_const_mgr.add_const('MD_ERROR_SUB500_URLAUTH_NO_STORE',0x00000011)
		win_const_mgr.add_const('DB_LOCAL_SHARED',0x00000002)
		win_const_mgr.add_const('ERROR_SPECIAL_ACCOUNT',0x0000055B)
		win_const_mgr.add_const('DEBUG_ENGOPT_NO_EXECUTE_REPEAT',0x00000100)
		win_const_mgr.add_const('SERVICE2_BASE',0x000015E0)
		win_const_mgr.add_const('PHONESTATE_CONNECTED',0x00000002)
		win_const_mgr.add_const('ACM_DRIVERPRIORITYF_DISABLE',0x00000002)
		win_const_mgr.add_const('LVNI_VISIBLEORDER',0x00000010)
		win_const_mgr.add_const('CERT_STORE_ADD_ALWAYS',0x00000004)
		win_const_mgr.add_const('TMT_GLYPHFONT',0x00000A29)
		win_const_mgr.add_const('DEBUG_SYMTYPE_COFF',0x00000001)
		win_const_mgr.add_const('WM_NCLBUTTONDOWN',0x000000A1)
		win_const_mgr.add_const('START_GLOBAL_RID',0x00000001)
		win_const_mgr.add_const('PSWIZB_NEXT',0x00000002)
		win_const_mgr.add_const('OPAQUE',0x00000002)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_CLEAR_ALL_SAVEPOINTS',0x00400000)
		win_const_mgr.add_const('SAFER_CRITERIA_NOSIGNEDHASH',0x00000002)
		win_const_mgr.add_const('HTBOTTOM',0x0000000F)
		win_const_mgr.add_const('SQL_SPEC_MINOR',0x00000034)
		win_const_mgr.add_const('ERROR_I24_WRITE_PROTECT',0x00000000)
		win_const_mgr.add_const('CMF_DISABLEDVERBS',0x00000200)
		win_const_mgr.add_const('PNRPINFO_HINT',0x00000001)
		win_const_mgr.add_const('IDM_RUNURLSCRIPT',0x00000927)
		win_const_mgr.add_const('PF_COMPARE_EXCHANGE_DOUBLE',0x00000002)
		win_const_mgr.add_const('PKCS12_NO_PERSIST_KEY',0x00008000)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_REDIRECT',0x00002000)
		win_const_mgr.add_const('INDEX_GUID_HOTPOINTS',0x0000000D)
		win_const_mgr.add_const('BG_E_ERROR_CONTEXT_LOCAL_FILE',0x80200009)
		win_const_mgr.add_const('MSI_NULL_INTEGER',0x80000000)
		win_const_mgr.add_const('LINECALLSTATE_ONHOLDPENDCONF',0x00001000)
		win_const_mgr.add_const('D3DPRASTERCAPS_DEPTHBIAS',0x04000000)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_PRE_FETCH_CRL',0x00000002)
		win_const_mgr.add_const('XINPUT_GAMEPAD_LEFT_THUMB',0x00000040)
		win_const_mgr.add_const('IDM_UNDO',0x0000002B)
		win_const_mgr.add_const('PROCESSOR_PPC_603',0x0000025B)
		win_const_mgr.add_const('REGSTR_VAL_MAX_HCID_LEN',0x00000400)
		win_const_mgr.add_const('CRYPT_EXCLUSIVE',0x00000001)
		win_const_mgr.add_const('LCMAP_HIRAGANA',0x00100000)
		win_const_mgr.add_const('D3DPRASTERCAPS_MIPMAPLODBIAS',0x00002000)
		win_const_mgr.add_const('AM_MPEG_AUDIO_DUAL_MERGE',0x00000000)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_NO_CHANNEL_LOGGING',0x00001D06)
		win_const_mgr.add_const('INF_STYLE_WIN4',0x00000002)
		win_const_mgr.add_const('DC_VERSION',0x0000000A)
		win_const_mgr.add_const('AVIIF_CONTROLFRAME',0x00000200)
		win_const_mgr.add_const('TASK_SUNDAY',0x00000001)
		win_const_mgr.add_const('DDSCAPS3_MULTISAMPLE_MASK',0x0000001F)
		win_const_mgr.add_const('IME_JHOTKEY_CLOSE_OPEN',0x00000030)
		win_const_mgr.add_const('ISFB_STATE_FULLOPEN',0x00000040)
		win_const_mgr.add_const('INTERNET_FLAG_NO_AUTH',0x00040000)
		win_const_mgr.add_const('CERT_VALIDITY_SIGNATURE_FAILS',0x00000004)
		win_const_mgr.add_const('LVS_AUTOARRANGE',0x00000100)
		win_const_mgr.add_const('GESTURE_BULLET_CROSS',0x00000000)
		win_const_mgr.add_const('SCS_QUERYRECONVERTSTRING',0x00020000)
		win_const_mgr.add_const('PFM_RTLPARA',0x00010000)
		win_const_mgr.add_const('MCI_ANIM_GETDEVCAPS_MAX_WINDOWS',0x00004008)
		win_const_mgr.add_const('DDWAITVB_BLOCKBEGIN',0x00000001)
		win_const_mgr.add_const('CTLCOLOR_STATIC',0x00000006)
		win_const_mgr.add_const('IMAGE_REL_ARM_BRANCH11',0x00000004)
		win_const_mgr.add_const('SCARD_E_BAD_SEEK',0x80100029)
		win_const_mgr.add_const('FE_FONTSMOOTHINGORIENTATIONBGR',0x00000000)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_PARENT',0x0000000C)
		win_const_mgr.add_const('SSA_FALLBACK',0x00000020)
		win_const_mgr.add_const('LCPRI_LASTSOFTCONFIG',0x00007FFF)
		win_const_mgr.add_const('CLUS_NOT_GLOBAL',0x00000000)
		win_const_mgr.add_const('SQL_FN_CVT_CONVERT',0x00000001)
		win_const_mgr.add_const('IPX_STANDARD_UPDATE',0x00000001)
		win_const_mgr.add_const('MD_ERROR_DATA_NOT_FOUND',0x800CC801)
		win_const_mgr.add_const('PHONEERR_NOTOWNER',0x9000001B)
		win_const_mgr.add_const('LINEERR_INVALADDRESSSTATE',0x80000013)
		win_const_mgr.add_const('MEM_4K',0x00001000)
		win_const_mgr.add_const('DBPROPVAL_TI_ISOLATED',0x00100000)
		win_const_mgr.add_const('MAXLEN_PHYSADDR',0x00000008)
		win_const_mgr.add_const('MCI_VCR_SETVIDEO_MONITOR',0x00040000)
		win_const_mgr.add_const('IDI_APPLICATION',0x00007F00)
		win_const_mgr.add_const('FILE_DEVICE_SERIAL_MOUSE_PORT',0x00000001)
		win_const_mgr.add_const('BUTTON_IMAGELIST_ALIGN_TOP',0x00000002)
		win_const_mgr.add_const('DS_ROLE_RID_OWNER',0x00000003)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_REQUESTEDROTATIONTYPEISPURECAV',0x0000010C)
		win_const_mgr.add_const('KSDSOUND_3D_MODE_DISABLE',0x00000002)
		win_const_mgr.add_const('STDPROP_INDEX_TEXT',0x000000C8)
		win_const_mgr.add_const('LOGTOKEN_SETUPAPI_DEVLOG',0x00000003)
		win_const_mgr.add_const('WSAEFAULT',0x0000271E)
		win_const_mgr.add_const('DXGI_CPU_ACCESS_SCRATCH',0x00000003)
		win_const_mgr.add_const('ERROR_ALREADY_REGISTERED',0x000004DA)
		win_const_mgr.add_const('CBENF_DROPDOWN',0x00000004)
		win_const_mgr.add_const('PDH_INCORRECT_APPEND_TIME',0xC0000BFB)
		win_const_mgr.add_const('SECURITY_IE_STATE_RED',0x00000001)
		win_const_mgr.add_const('IDS_CAP_VIDEO_PREPARE_ERROR',0x000001AA)
		win_const_mgr.add_const('LDAP_FILTER_LE',0x00000000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAOEVENTARGS_ESTIMATEDREMAININGTIME',0x00000303)
		win_const_mgr.add_const('OID_FDDI_MAC_OLD_UPSTREAM_NBR',0x03030227)
		win_const_mgr.add_const('DIF_DETECT',0x0000000F)
		win_const_mgr.add_const('OID_GEN_INTERFACE_INFO',0x00010287)
		win_const_mgr.add_const('ERRCLASS_MEDIA',0x0000000B)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_242',0x00000000)
		win_const_mgr.add_const('PRINTER_ERROR_JAM',0x00000002)
		win_const_mgr.add_const('ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER',0x0000215A)
		win_const_mgr.add_const('SHGFI_OPENICON',0x00000002)
		win_const_mgr.add_const('PAGE_WRITECOMBINE',0x00000400)
		win_const_mgr.add_const('DNS_ERROR_INVALID_ZONE_OPERATION',0x00002583)
		win_const_mgr.add_const('WS_EX_TOPMOST',0x00000008)
		win_const_mgr.add_const('SQL_FN_TSI_DAY',0x00000010)
		win_const_mgr.add_const('DTR_KTBASE_INDEX_TMP',0x00000006)
		win_const_mgr.add_const('DISPID_DOCUMENTTITLE',0x00000019)
		win_const_mgr.add_const('FEI_DISCONNECTED',0x00000009)
		win_const_mgr.add_const('SECURITY_BUILTIN_DOMAIN_RID',0x00000020)
		win_const_mgr.add_const('PFD_TYPE_COLORINDEX',0x00000001)
		win_const_mgr.add_const('WM_PARENTNOTIFY',0x00000210)
		win_const_mgr.add_const('CERT_KEY_PROV_INFO_PROP_ID',0x00000002)
		win_const_mgr.add_const('VK_EXSEL',0x000000F8)
		win_const_mgr.add_const('MDPROPVAL_MSF_DRILLUPLEVEL',0x00020000)
		win_const_mgr.add_const('SQL_NEED_LONG_DATA_LEN',0x0000006F)
		win_const_mgr.add_const('MSV1_0_SUBAUTHENTICATION_DLL',0xFF000000)
		win_const_mgr.add_const('OID_LTALK_CURRENT_NODE_ID',0x05010102)
		win_const_mgr.add_const('DV_DVSD_NTSC_FRAMESIZE',0x0001D4C0)
		win_const_mgr.add_const('DC_DATATYPE_PRODUCED',0x00000015)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_AVGBYTESPERSEC',0x00004006)
		win_const_mgr.add_const('ERROR_INFLOOP_IN_RELOC_CHAIN',0x000000CA)
		win_const_mgr.add_const('CRYPTUI_ACCEPT_DECLINE_STYLE',0x00000040)
		win_const_mgr.add_const('IME_MODE_SBCSCHAR',0x00000008)
		win_const_mgr.add_const('PRIMARY_CRED_UPDATE',0x00000004)
		win_const_mgr.add_const('RESUTIL_PROPITEM_READ_ONLY',0x00000001)
		win_const_mgr.add_const('TXFS_RM_STATE_ACTIVE',0x00000002)
		win_const_mgr.add_const('TRUSTERROR_STEP_MSG_INNERCNT',0x0000000B)
		win_const_mgr.add_const('SAP_FIELD_ANY_AESA_REST',0xFFFFFFFB)
		win_const_mgr.add_const('SQL_FN_NUM_LOG10',0x00080000)
		win_const_mgr.add_const('ERROR_UNABLE_TO_CLEAN',0x000010D7)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_STORE',0x00000002)
		win_const_mgr.add_const('DCB_RESET',0x00000001)
		win_const_mgr.add_const('CM_DISABLE_ABSOLUTE',0x00000001)
		win_const_mgr.add_const('CONTEXT_EXCEPTION_REQUEST',0x40000000)
		win_const_mgr.add_const('LVTVIF_AUTOSIZE',0x00000000)
		win_const_mgr.add_const('WM_AFXLAST',0x0000037F)
		win_const_mgr.add_const('IKEEXT_KERB_AUTH_DISABLE_INITIATOR_TOKEN_GENERATION',0x00000001)
		win_const_mgr.add_const('MODIFY_SETTINGS',0x0000000C)
		win_const_mgr.add_const('ERROR_SXS_VERSION_CONFLICT',0x000036B8)
		win_const_mgr.add_const('SCS_OS216_BINARY',0x00000005)
		win_const_mgr.add_const('FKF_CLICKON',0x00000040)
		win_const_mgr.add_const('BTH_MFG_MITEL',0x00000010)
		win_const_mgr.add_const('DEBUG_CES_ENGINE_OPTIONS',0x00000020)
		win_const_mgr.add_const('SUBLANG_ROMANSH_SWITZERLAND',0x00000001)
		win_const_mgr.add_const('FLG_ADDREG_OVERWRITEONLY',0x00000020)
		win_const_mgr.add_const('STATE_SYSTEM_ALERT_LOW',0x04000000)
		win_const_mgr.add_const('SQLFLTN',0x00000006)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_OS2_CUI',0x00000005)
		win_const_mgr.add_const('FILE_READ_EA',0x00000008)
		win_const_mgr.add_const('VAR_FOURDIGITYEARS',0x00000040)
		win_const_mgr.add_const('CTF_THREAD_REF',0x00000002)
		win_const_mgr.add_const('SQLFLT4',0x00000003)
		win_const_mgr.add_const('SQLFLT8',0x00000003)
		win_const_mgr.add_const('RF_PERSONALIZABLE',0x00004000)
		win_const_mgr.add_const('ERROR_RESOURCE_ONLINE',0x0000139B)
		win_const_mgr.add_const('DS_REPL_NBR_DO_SCHEDULED_SYNCS',0x00000040)
		win_const_mgr.add_const('WM_DISPLAYCHANGE',0x0000007E)
		win_const_mgr.add_const('NDIS_802_11_AI_RESFI_STATUSCODE',0x00000002)
		win_const_mgr.add_const('WINHTTP_OPTION_REDIRECT_POLICY_NEVER',0x00000000)
		win_const_mgr.add_const('FD_CONNECT',0x00000001)
		win_const_mgr.add_const('DE_E_AUTHENTICATION_REQUIRED',0x800C0009)
		win_const_mgr.add_const('KS_DVD_CGMS_COPY_PERMITTED',0x00000000)
		win_const_mgr.add_const('FIND_FROMSTART',0x00400000)
		win_const_mgr.add_const('IDM_INSINPUTIMAGE',0x00000842)
		win_const_mgr.add_const('WLX_SAS_ACTION_NONE',0x00000002)
		win_const_mgr.add_const('SCARD_EJECT_CARD',0x00000003)
		win_const_mgr.add_const('SDP_ATTRIB_HEADSET_REMOTE_AUDIO_VOLUME_CONTROL',0x00000302)
		win_const_mgr.add_const('TBIF_BYINDEX',0x80000000)
		win_const_mgr.add_const('LINECALLPARAMFLAGS_NOHOLDCONFERENCE',0x00000020)
		win_const_mgr.add_const('ICW_USEDEFAULTS',0x00000001)
		win_const_mgr.add_const('HLNF_NEWWINDOWSMANAGED',0x80000000)
		win_const_mgr.add_const('WPF_NO_URL_LOOKUP',0x00000020)
		win_const_mgr.add_const('ISC_REQ_INTEGRITY',0x00010000)
		win_const_mgr.add_const('LPD_TYPE_COLORINDEX',0x00000001)
		win_const_mgr.add_const('SYMF_TLSREL',0x00004000)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_EXTERNAL_DEF',0x00000005)
		win_const_mgr.add_const('DCBA_FACEDOWNCENTER',0x00000101)
		win_const_mgr.add_const('TPM_VERTICAL',0x00000040)
		win_const_mgr.add_const('RIS_INTERFACE_ENABLED',0x00000001)
		win_const_mgr.add_const('PIDSI_CREATE_DTM',0x00000000)
		win_const_mgr.add_const('PORT_NEWACCT',0x00000064)
		win_const_mgr.add_const('SO_DISCOPTLEN',0x00007007)
		win_const_mgr.add_const('DNS_RTYPE_NSAP',0x00001600)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_CATALOGS',0x00000001)
		win_const_mgr.add_const('SEE_MASK_NOQUERYCLASSSTORE',0x01000000)
		win_const_mgr.add_const('WKSTA_PRINTBUFTIME_PARMNUM',0x0000001C)
		win_const_mgr.add_const('ERROR_DS_INVALID_ATTRIBUTE_SYNTAX',0x0000200B)
		win_const_mgr.add_const('SQL_CREATE_CHARACTER_SET',0x00000080)
		win_const_mgr.add_const('IDS_CAP_VIDEO_ALLOC_ERROR',0x000001A9)
		win_const_mgr.add_const('PROXY_TYPE_DIRECT',0x00000001)
		win_const_mgr.add_const('UAS_ROLE_BACKUP',0x00000002)
		win_const_mgr.add_const('DDOSD_OSCAPS',0x00000008)
		win_const_mgr.add_const('WAVE_FORMAT_1M16',0x00000004)
		win_const_mgr.add_const('PERF_WILDCARD_COUNTER',0xFFFFFFFF)
		win_const_mgr.add_const('LB_GETCOUNT',0x0000018B)
		win_const_mgr.add_const('SQL_SQL92_REVOKE',0x000000A2)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_13',0x0000000D)
		win_const_mgr.add_const('TASKSTATUS_WAITING',0x00000003)
		win_const_mgr.add_const('VIF_BUFFTOOSMALL',0x00040000)
		win_const_mgr.add_const('ERROR_FS_DRIVER_REQUIRED',0x0000024C)
		win_const_mgr.add_const('KERB_CERTIFICATE_LOGON_FLAG_CHECK_DUPLICATES',0x00000001)
		win_const_mgr.add_const('GUI_INMOVESIZE',0x00000002)
		win_const_mgr.add_const('URLACTION_COOKIES',0x00001A02)
		win_const_mgr.add_const('SO_CONNECT_TIME',0x0000700C)
		win_const_mgr.add_const('D3DSI_COMMENTSIZE_SHIFT',0x00000010)
		win_const_mgr.add_const('URLMON_OPTION_USERAGENT',0x10000001)
		win_const_mgr.add_const('SUBLANG_OCCITAN_FRANCE',0x00000001)
		win_const_mgr.add_const('FILE_ADD_SUBDIRECTORY',0x00000004)
		win_const_mgr.add_const('SQL_FN_STR_UCASE',0x00001000)
		win_const_mgr.add_const('SQL_SO_DYNAMIC',0x00000004)
		win_const_mgr.add_const('SS_RIGHT',0x00000002)
		win_const_mgr.add_const('HDI_TEXT',0x00000002)
		win_const_mgr.add_const('FACILITY_CLUSTER_ERROR_CODE',0x00000013)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_TOO_MANY_FILTERS',0x00003648)
		win_const_mgr.add_const('HHWIN_PROP_NODEF_STYLES',0x00000001)
		win_const_mgr.add_const('CERT_XML_NAME_STR',0x00000004)
		win_const_mgr.add_const('HDI_FILTER',0x00000100)
		win_const_mgr.add_const('IF_TYPE_X25_MLP',0x00000079)
		win_const_mgr.add_const('DBPROPVAL_SQ_TABLE',0x00000020)
		win_const_mgr.add_const('SECPKG_CRED_RESERVED',0xF0000000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_CANCELWRITE',0x00000201)
		win_const_mgr.add_const('SQL_NONSCROLLABLE',0x00000000)
		win_const_mgr.add_const('DDCKEYCAPS_DESTBLTCLRSPACE',0x00000002)
		win_const_mgr.add_const('DISPID_PEER_HOLDER_BASE',0x004C4B40)
		win_const_mgr.add_const('DETACHED_PROCESS',0x00000008)
		win_const_mgr.add_const('CREDUI_FLAGS_VALIDATE_USERNAME',0x00000400)
		win_const_mgr.add_const('LOCALE_IFIRSTWEEKOFYEAR',0x0000100D)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY1',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE',0x000036DA)
		win_const_mgr.add_const('DCBA_FACEUPRIGHT',0x00000003)
		win_const_mgr.add_const('LINECALLINFOSTATE_CONNECTEDID',0x00020000)
		win_const_mgr.add_const('ERROR_INVALID_FILTER_PROC',0x00000593)
		win_const_mgr.add_const('MDMEASURE_AGGR_CALCULATED',0x00000007)
		win_const_mgr.add_const('DI_FLAGSEX_POWERPAGE_ADDED',0x01000000)
		win_const_mgr.add_const('SPEAKER_FRONT_RIGHT',0x00000002)
		win_const_mgr.add_const('NCRYPT_ALLOW_PLAINTEXT_EXPORT_FLAG',0x00000002)
		win_const_mgr.add_const('DSOP_SCOPE_TYPE_UPLEVEL_JOINED_DOMAIN',0x00000002)
		win_const_mgr.add_const('DI_INSTALLDISABLED',0x00040000)
		win_const_mgr.add_const('MAX_COUNTER_PATH',0x00000100)
		win_const_mgr.add_const('ETDT_ENABLE',0x00000002)
		win_const_mgr.add_const('PPP_LCP_PFC',0x00000002)
		win_const_mgr.add_const('FAPPCOMMAND_OEM',0x00001000)
		win_const_mgr.add_const('OLEOBJ_S_LAST',0x0004018F)
		win_const_mgr.add_const('TCS_FIXEDWIDTH',0x00000400)
		win_const_mgr.add_const('D3D_SPEC_VERSION',0x00000001)
		win_const_mgr.add_const('STREAM_FLAGS_DISALLOW_QUERY',0x00000004)
		win_const_mgr.add_const('SAFER_TOKEN_NULL_IF_EQUAL',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLSETSCROLLOPTIONS',0x00000045)
		win_const_mgr.add_const('IDD_ACMFORMATCHOOSE_CMB_FORMAT',0x00000066)
		win_const_mgr.add_const('SERVICE_BOOT_START',0x00000000)
		win_const_mgr.add_const('LINEDISCONNECTMODE_BADADDRESS',0x00000080)
		win_const_mgr.add_const('PASSWORD_EXPIRED',0x00000002)
		win_const_mgr.add_const('PROP_MED_CXDLG',0x000000E3)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_LINKEDSERVERS',0x00000001)
		win_const_mgr.add_const('SCARD_SWALLOWED',0x00000003)
		win_const_mgr.add_const('SECPKG_FLAG_NEGOTIABLE',0x00000800)
		win_const_mgr.add_const('NRB_FUNCTION_NVCACHE_POWER_MODE_SET',0x00000000)
		win_const_mgr.add_const('WIA_DPS_DOCUMENT_HANDLING_STATUS',0x00000C0F)
		win_const_mgr.add_const('DBPROPVAL_TC_ALL',0x00000008)
		win_const_mgr.add_const('FILE_NAME_NORMALIZED',0x00000000)
		win_const_mgr.add_const('DSSI_NO_EDIT_SACL',0x00000004)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_PREROLL',0x00000002)
		win_const_mgr.add_const('TRUSTERROR_STEP_MSG_SIGNERINFO',0x0000000D)
		win_const_mgr.add_const('IP_TCC_MASK',0xFFFFFF00)
		win_const_mgr.add_const('SI_PERMS_ELEVATION_REQUIRED',0x01000000)
		win_const_mgr.add_const('DBG_SINGLESTEP',0x00000005)
		win_const_mgr.add_const('ELEMENT_STATUS_INVERT',0x00400000)
		win_const_mgr.add_const('FPS_BUSY',0x20000040)
		win_const_mgr.add_const('SPMODE_TEST',0x00000004)
		win_const_mgr.add_const('LINECALLORIGIN_INBOUND',0x00000080)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_SH3DSP',0x00000001)
		win_const_mgr.add_const('SQL_BP_TRANSACTION',0x00000008)
		win_const_mgr.add_const('SECURITY_MANDATORY_PROTECTED_PROCESS_RID',0x00005000)
		win_const_mgr.add_const('LVCDI_ITEM',0x00000000)
		win_const_mgr.add_const('LITTLEENDIAN',0x00000001)
		win_const_mgr.add_const('DDSCAPS_ALLOCONLOAD',0x04000000)
		win_const_mgr.add_const('MCI_INFO',0x0000080A)
		win_const_mgr.add_const('GMEM_LOCKCOUNT',0x000000FF)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2EVENTARGS_USEDDEVICEBUFFER',0x00000105)
		win_const_mgr.add_const('MSV1_0_CHECK_LOGONHOURS_FOR_S4U',0x00040000)
		win_const_mgr.add_const('CLOCK_PRECISION',0x00000004)
		win_const_mgr.add_const('CM_CMYK_COLOR',0x00000004)
		win_const_mgr.add_const('VDMDBG_BREAK_WOWTASK',0x00000002)
		win_const_mgr.add_const('SYMBOLIC_LINK_FLAG_DIRECTORY',0x00000001)
		win_const_mgr.add_const('ISC_REQ_MANUAL_CRED_VALIDATION',0x00080000)
		win_const_mgr.add_const('IDM_DIV',0x0000088F)
		win_const_mgr.add_const('ERROR_CLUSTER_NO_NET_ADAPTERS',0x00001712)
		win_const_mgr.add_const('ENLISTMENT_SUPERIOR',0x00000001)
		win_const_mgr.add_const('POLICY_QOS_INBOUND_CONFIDENTIALITY',0x00000010)
		win_const_mgr.add_const('CACHEGROUP_FLAG_VALID',0x00000007)
		win_const_mgr.add_const('ODBC_BOTH_DSN',0x00000000)
		win_const_mgr.add_const('SHI1005_FLAGS_DFS_ROOT',0x00000002)
		win_const_mgr.add_const('CF_WAVE',0x0000000C)
		win_const_mgr.add_const('DEBUG_CONNECT_SESSION_DEFAULT',0x00000000)
		win_const_mgr.add_const('FOF_SILENT',0x00000004)
		win_const_mgr.add_const('SECPKG_NEGOTIATION_OPTIMISTIC',0x00000001)
		win_const_mgr.add_const('PHONEERR_DISCONNECTED',0x90000024)
		win_const_mgr.add_const('MCIWNDF_NOAUTOSIZEWINDOW',0x00000001)
		win_const_mgr.add_const('PARTITION_NTFT',0x00000080)
		win_const_mgr.add_const('IDM_SIZETOGRID',0x00000027)
		win_const_mgr.add_const('CMF_ITEMMENU',0x00000080)
		win_const_mgr.add_const('WKSTA_SIZCHARBUF_PARMNUM',0x00000017)
		win_const_mgr.add_const('IDC_LP_LINKSOURCE',0x000003F4)
		win_const_mgr.add_const('IDM_APPLYHEADING2',0x000008D0)
		win_const_mgr.add_const('IDM_APPLYHEADING3',0x000008D1)
		win_const_mgr.add_const('SMSET_BOTTOM',0x20000000)
		win_const_mgr.add_const('SUF_FIRSTTIME',0x00000001)
		win_const_mgr.add_const('WPF_MINIMAL_UI',0x00000004)
		win_const_mgr.add_const('SQL_NO_NULLS',0x00000000)
		win_const_mgr.add_const('PHONE_REPLY',0x00000011)
		win_const_mgr.add_const('WLAN_AVAILABLE_NETWORK_HAS_PROFILE',0x00000002)
		win_const_mgr.add_const('APD_STRICT_DOWNGRADE',0x00000002)
		win_const_mgr.add_const('INTERNET_STATE_BUSY',0x00000200)
		win_const_mgr.add_const('ERROR_ROWSNOTRELEASED',0x00000304)
		win_const_mgr.add_const('MDPROPVAL_MNF_CORRELATION',0x00000040)
		win_const_mgr.add_const('PXE_BA_NBP',0x00000001)
		win_const_mgr.add_const('SQL_INTERVAL_HOUR_TO_SECOND',0x00000064)
		win_const_mgr.add_const('DIF_CALCDISKSPACE',0x0000000B)
		win_const_mgr.add_const('IPPROTO_IDP',0x00000016)
		win_const_mgr.add_const('PD_RESULT_PRINT',0x00000001)
		win_const_mgr.add_const('LVS_EX_REGIONAL',0x00000200)
		win_const_mgr.add_const('SQL_ALTER_DOMAIN',0x00000075)
		win_const_mgr.add_const('RPC_BHT_OBJECT_UUID_VALID',0x00000001)
		win_const_mgr.add_const('PHOTO_CONTRAST_HARD',0x00000002)
		win_const_mgr.add_const('SPSVCINST_NOCLOBBER_DESCRIPTION',0x00000100)
		win_const_mgr.add_const('HHWIN_BUTTON_BACK',0x00000001)
		win_const_mgr.add_const('CMC_FAIL_TRY_LATER',0x0000000C)
		win_const_mgr.add_const('BTH_MFG_HITACHI',0x00000029)
		win_const_mgr.add_const('ERROR_INVALID_COLORSPACE',0x000007E1)
		win_const_mgr.add_const('SCRIPT_DIGITSUBSTITUTE_CONTEXT',0x00000000)
		win_const_mgr.add_const('FPS_CALL_BLACKLISTED',0x20004000)
		win_const_mgr.add_const('INTERNET_OPTION_SECONDARY_CACHE_KEY',0x00000035)
		win_const_mgr.add_const('FRAME_TRAP',0x00000001)
		win_const_mgr.add_const('LPD_DOUBLEBUFFER',0x00000001)
		win_const_mgr.add_const('EXPOSUREMODE_PROGRAM_ACTION',0x00000006)
		win_const_mgr.add_const('IDTB_BROWSE_BACK',0x000000D4)
		win_const_mgr.add_const('SQL_FN_STR_DIFFERENCE',0x00008000)
		win_const_mgr.add_const('CR_INVALID_INDEX',0x0000003A)
		win_const_mgr.add_const('IDC_CI_LABELEDIT',0x00000081)
		win_const_mgr.add_const('DISPID_FONT_STRIKE',0x00000006)
		win_const_mgr.add_const('IMF_FORCEINACTIVE',0x00000080)
		win_const_mgr.add_const('ID_CMD',0x000000EC)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_MONTH',0x00000010)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_NOTWRITABLE',0x00000011)
		win_const_mgr.add_const('METHOD_RIP2_ROUTE_TAG',0x00000004)
		win_const_mgr.add_const('IPPORT_EFSSERVER',0x00000208)
		win_const_mgr.add_const('DSF_STI_DEVICES',0x00000008)
		win_const_mgr.add_const('SHCNE_MKDIR',0x00000008)
		win_const_mgr.add_const('IF_TYPE_L3_IPVLAN',0x00000088)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_LEGACYDEVICENUMBER',0x00000207)
		win_const_mgr.add_const('DDPF_COMPRESSED',0x00000080)
		win_const_mgr.add_const('CDERR_MEMALLOCFAILURE',0x00000009)
		win_const_mgr.add_const('FLG_ADDPROPERTY_APPEND',0x00000004)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_CHECK_CONSTRAINTS_BY_TABLE',0x00000006)
		win_const_mgr.add_const('WM_QUERYOPEN',0x00000013)
		win_const_mgr.add_const('DEBUG_CES_EXTENSIONS',0x00000400)
		win_const_mgr.add_const('READ_ATTRIBUTE_BUFFER_SIZE',0x00000200)
		win_const_mgr.add_const('DDSCAPS3_MULTISAMPLE_QUALITY_SHIFT',0x00000005)
		win_const_mgr.add_const('TSF_DELETE_RECYCLE_IF_POSSIBLE',0x00000080)
		win_const_mgr.add_const('PSD_DISABLEORIENTATION',0x00000100)
		win_const_mgr.add_const('IDM_SAVETARGET',0x000008DC)
		win_const_mgr.add_const('CRSWPP_SECURITY_PACKAGE',0xC0042203)
		win_const_mgr.add_const('SQL_DRIVER_ODBC_VER',0x0000004D)
		win_const_mgr.add_const('TBS_TOP',0x00000004)
		win_const_mgr.add_const('DVB_ST_PID_19',0x00000013)
		win_const_mgr.add_const('DVB_ST_PID_18',0x00000012)
		win_const_mgr.add_const('DS_REPADD_DISABLE_NOTIFICATION',0x00000040)
		win_const_mgr.add_const('LVS_EX_HEADERDRAGDROP',0x00000010)
		win_const_mgr.add_const('OLEUI_ERR_HWNDOWNERINVALID',0x00000068)
		win_const_mgr.add_const('DVB_ST_PID_16',0x00000010)
		win_const_mgr.add_const('BCRYPT_PRIVATE_KEY_FLAG',0x00000002)
		win_const_mgr.add_const('DNS_ERROR_CNAME_LOOP',0x000025EB)
		win_const_mgr.add_const('IMAGE_REL_PPC_BRNTAKEN',0x00000400)
		win_const_mgr.add_const('SFC_QUOTA_DEFAULT',0x00000032)
		win_const_mgr.add_const('SCRIPTINFO_ITYPEINFO',0x00000002)
		win_const_mgr.add_const('CERT_LDAP_STORE_UNBIND_FLAG',0x00080000)
		win_const_mgr.add_const('SQL_CP_ONE_PER_DRIVER',0x00000001)
		win_const_mgr.add_const('SHI50F_SYSTEM',0x00000200)
		win_const_mgr.add_const('VP_COMMAND_SET',0x00000002)
		win_const_mgr.add_const('LGRPID_INDIC',0x00000000)
		win_const_mgr.add_const('OID_WAN_CURRENT_ADDRESS',0x04010102)
		win_const_mgr.add_const('PT_LINETO',0x00000002)
		win_const_mgr.add_const('TMPF_VECTOR',0x00000002)
		win_const_mgr.add_const('FAULT_ACTION_SPECIFIC_BASE',0x00000258)
		win_const_mgr.add_const('ERROR_BAD_QUERY_SYNTAX',0x0000064F)
		win_const_mgr.add_const('PID_IS_WHATSNEW',0x0000000A)
		win_const_mgr.add_const('CERT_TRUST_IS_NOT_TIME_VALID',0x00000001)
		win_const_mgr.add_const('RSC_BE_BIG',0x00000001)
		win_const_mgr.add_const('NTDSSITELINK_OPT_USE_NOTIFY',0x00000001)
		win_const_mgr.add_const('WIA_IPS_WARM_UP_TIME',0x00001811)
		win_const_mgr.add_const('TRUSTERROR_STEP_CERTSTORE',0x00000007)
		win_const_mgr.add_const('BS_RADIOBUTTON',0x00000004)
		win_const_mgr.add_const('MCI_RECORD_INSERT',0x00000100)
		win_const_mgr.add_const('IT_MSG_STATUS',0x00000003)
		win_const_mgr.add_const('LINETRANSLATERESULT_DIALDIALTONE',0x00000100)
		win_const_mgr.add_const('BCPHINTSA',0x0000000A)
		win_const_mgr.add_const('WM_IME_NOTIFY',0x00000282)
		win_const_mgr.add_const('RECOCONF_NOTSET',0x00000080)
		win_const_mgr.add_const('LINECALLORIGIN_UNKNOWN',0x00000010)
		win_const_mgr.add_const('PROCESS_MODE_BACKGROUND_BEGIN',0x00100000)
		win_const_mgr.add_const('SNMP_GENERICTRAP_AUTHFAILURE',0x00000004)
		win_const_mgr.add_const('SPC_INC_PE_DEBUG_INFO_FLAG',0x00000040)
		win_const_mgr.add_const('EVENT_OBJECT_CONTENTSCROLLED',0x00008015)
		win_const_mgr.add_const('WM_NCCREATE',0x00000081)
		win_const_mgr.add_const('PAGEMASK_256KB',0x00000003)
		win_const_mgr.add_const('DBC_SHOW',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_FILE_WRITEBACK_FAILED',0x000025B6)
		win_const_mgr.add_const('WNDN_MVDIR',0x00000003)
		win_const_mgr.add_const('APPCOMMAND_MICROPHONE_VOLUME_UP',0x0000001A)
		win_const_mgr.add_const('PERF_PROVIDER_KERNEL_MODE',0x00000001)
		win_const_mgr.add_const('SQL_ODBC_VER',0x0000000A)
		win_const_mgr.add_const('DRM_PROTECTION_SCHEMES_DEFINED',0x00000001)
		win_const_mgr.add_const('BCPHINTSW',0x0000000B)
		win_const_mgr.add_const('SC_MOUSEMENU',0x0000F090)
		win_const_mgr.add_const('CAUSE_UNIMPLEMENTED_IE',0x00000063)
		win_const_mgr.add_const('QS_SENDMESSAGE',0x00000040)
		win_const_mgr.add_const('WINHTTP_AUTH_SCHEME_NTLM',0x00000002)
		win_const_mgr.add_const('ERROR_MUI_INVALID_RC_CONFIG',0x00003AFE)
		win_const_mgr.add_const('CM_REGISTRY_HARDWARE',0x00000000)
		win_const_mgr.add_const('SQL_UNNAMED',0x00000001)
		win_const_mgr.add_const('DNF_COMPATIBLE_DRIVER',0x00000040)
		win_const_mgr.add_const('MQMSG_JOURNAL_NONE',0x00000000)
		win_const_mgr.add_const('TTDT_INITIAL',0x00000003)
		win_const_mgr.add_const('ERROR_LOG_METADATA_INVALID',0x000019D5)
		win_const_mgr.add_const('D3DVS20_MIN_STATICFLOWCONTROLDEPTH',0x00000001)
		win_const_mgr.add_const('BS_DEFPUSHBUTTON',0x00000001)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_SPLIT',0x0000001D)
		win_const_mgr.add_const('MAXIMUM_ENCRYPTION_VALUE',0x00000004)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_PPC',0x00000003)
		win_const_mgr.add_const('SERVICE_SID_TYPE_RESTRICTED',0x00000002)
		win_const_mgr.add_const('AUXCAPS_AUXIN',0x00000002)
		win_const_mgr.add_const('CERT_REGISTRY_STORE_SERIALIZED_FLAG',0x00020000)
		win_const_mgr.add_const('GET_MODULE_HANDLE_EX_FLAG_PIN',0x00000001)
		win_const_mgr.add_const('OCSP_SIG_REQUIRED_RESPONSE',0x00000005)
		win_const_mgr.add_const('PROCESS_TRACE_MODE_EVENT_RECORD',0x10000000)
		win_const_mgr.add_const('EAP_E_USER_ROOT_CERT_EXPIRED',0x80420302)
		win_const_mgr.add_const('MD_NOTIFEXAUTH_NTLMSSL',0x00000001)
		win_const_mgr.add_const('STD_FILEOPEN',0x00000007)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_FLAG2',0x00000004)
		win_const_mgr.add_const('STARTF_USECOUNTCHARS',0x00000008)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_FLAG4',0x00000010)
		win_const_mgr.add_const('ERROR_DS_NAME_NOT_UNIQUE',0x0000217B)
		win_const_mgr.add_const('LVS_EX_TRANSPARENTBKGND',0x00400000)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_FLAG9',0x00000200)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_FLAG8',0x00000100)
		win_const_mgr.add_const('WTPF_OFFLINEOKNBU_COM',0x00002000)
		win_const_mgr.add_const('TAPE_DRIVE_SPACE_IMMEDIATE',0x80800000)
		win_const_mgr.add_const('MM_JOY2BUTTONUP',0x000003B8)
		win_const_mgr.add_const('PROCESSOR_INTEL_PENTIUM',0x0000024A)
		win_const_mgr.add_const('CRYPT_X942_PUB_INFO_BYTE_LENGTH',0x00000200)
		win_const_mgr.add_const('BLLI_L3_MODE_EXT',0x00000080)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_CO_CLIENT_OPTIONAL_HANDLERS',0x000000A6)
		win_const_mgr.add_const('DEV_PORT_COM4',0x00000005)
		win_const_mgr.add_const('APMMENUSUSPEND_ENABLED',0x00000001)
		win_const_mgr.add_const('USER_PROFILE_PARMNUM',0x00000034)
		win_const_mgr.add_const('ERRLOC_UNK',0x00000001)
		win_const_mgr.add_const('ICINSTALL_DRIVER',0x00000002)
		win_const_mgr.add_const('FS_CALL_BLACKLISTED',0x20004000)
		win_const_mgr.add_const('CREDUIWIN_IN_CRED_ONLY',0x00000020)
		win_const_mgr.add_const('FWPM_NET_EVENT_FLAG_REMOTE_PORT_SET',0x00000010)
		win_const_mgr.add_const('CLFS_SCAN_CLOSE',0x00000008)
		win_const_mgr.add_const('LINK_STATUS_BROKEN',0x00000002)
		win_const_mgr.add_const('WM_CL_PROGRESSIVE420',0x00000001)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_LOCAL',0x00000040)
		win_const_mgr.add_const('LPM_PE_ALL_TYPES',0x00000000)
		win_const_mgr.add_const('SETUP_CREATEDB_FLAG',0x00000040)
		win_const_mgr.add_const('SQL_DL_SQL92_DATE',0x00000001)
		win_const_mgr.add_const('IR_CHANGECONVERT',0x00000121)
		win_const_mgr.add_const('SQL_CA2_SIMULATE_NON_UNIQUE',0x00004000)
		win_const_mgr.add_const('REMOTE_NAME_INFO_LEVEL',0x00000002)
		win_const_mgr.add_const('CO_S_FIRST',0x000401F0)
		win_const_mgr.add_const('KERB_ETYPE_RSA_PUB_MD5',0x0000000B)
		win_const_mgr.add_const('LINECALLINFOSTATE_REASON',0x00000200)
		win_const_mgr.add_const('HHT_ABOVE',0x00000100)
		win_const_mgr.add_const('DEV_PORT_COM2',0x00000003)
		win_const_mgr.add_const('TBIF_COMMAND',0x00000020)
		win_const_mgr.add_const('RTCIF_ENABLE_SERVER_CLASS',0x00000004)
		win_const_mgr.add_const('COD_AUDIO_MINOR_HEADSET_HANDS_FREE',0x00000003)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_CODEVIEW',0x00000002)
		win_const_mgr.add_const('SOL_IRLMP',0x000000FF)
		win_const_mgr.add_const('DNS_TYPE_NIMLOC',0x00000020)
		win_const_mgr.add_const('RC_GDI20_OUTPUT',0x00000010)
		win_const_mgr.add_const('RPC_S_INCOMPLETE_NAME',0x000006DB)
		win_const_mgr.add_const('IDM_LINEBREAKBOTH',0x0000086A)
		win_const_mgr.add_const('DDL_EXCLUSIVE',0x00008000)
		win_const_mgr.add_const('OS_WIN2000SERVER',0x00000009)
		win_const_mgr.add_const('CMC_FAIL_POP_FAILED',0x00000009)
		win_const_mgr.add_const('ERROR_MEDIUM_NOT_ACCESSIBLE',0x000010E3)
		win_const_mgr.add_const('WB_MOVEWORDPREV',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_PPC_IFGLUE',0x0000000D)
		win_const_mgr.add_const('IF_TYPE_STARLAN',0x0000000B)
		win_const_mgr.add_const('DLGC_WANTTAB',0x00000002)
		win_const_mgr.add_const('PID_INTSITE_URL',0x0000000F)
		win_const_mgr.add_const('IP_HDRINCL',0x00000002)
		win_const_mgr.add_const('PRESERVEBLACK',0x00100000)
		win_const_mgr.add_const('SQL_TYPE_DATE',0x0000005B)
		win_const_mgr.add_const('SQL_FN_TD_YEAR',0x00000100)
		win_const_mgr.add_const('SQL_NULLABLE',0x00000001)
		win_const_mgr.add_const('MAPI_LOGOFF_UI',0x00000002)
		win_const_mgr.add_const('LVSIL_STATE',0x00000002)
		win_const_mgr.add_const('AF_DATAKIT',0x00000009)
		win_const_mgr.add_const('IP_MULTICAST_TTL',0x0000000A)
		win_const_mgr.add_const('PERF_DETAIL_STANDARD',0x0000FFFF)
		win_const_mgr.add_const('IR_MODEINFO',0x00000190)
		win_const_mgr.add_const('PSR_MBZ2',0x0000001C)
		win_const_mgr.add_const('IDM_PAGESETUP',0x000007D4)
		win_const_mgr.add_const('BM_SETIMAGE',0x000000F7)
		win_const_mgr.add_const('RATING_FIVE_STARS_MIN',0x00000058)
		win_const_mgr.add_const('MQMSG_ACKNOWLEDGMENT_NEG_RECEIVE',0x00000008)
		win_const_mgr.add_const('CERT_CHAIN_TIMESTAMP_TIME',0x00000200)
		win_const_mgr.add_const('RPCFLG_LOCAL_CALL',0x10000000)
		win_const_mgr.add_const('ISO_EXP_DATA_USE',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_FILE_MODE_CIRCULAR',0x00000002)
		win_const_mgr.add_const('LB_SELITEMRANGE',0x0000019B)
		win_const_mgr.add_const('D3DPTEXTURECAPS_SQUAREONLY',0x00000020)
		win_const_mgr.add_const('IPX_ROUTE_FILTER_INFO_TYPE',0x00000005)
		win_const_mgr.add_const('BITS_MC_WSD_PORT',0x8019400B)
		win_const_mgr.add_const('SET_REPAIR_VOLUME_BITMAP_SCAN',0x00000002)
		win_const_mgr.add_const('GROUP_NAME',0x00000080)
		win_const_mgr.add_const('DSSI_NO_READONLY_MESSAGE',0x00000040)
		win_const_mgr.add_const('MCI_INFO_PRODUCT',0x00000100)
		win_const_mgr.add_const('ERROR_MR_MID_NOT_FOUND',0x0000013D)
		win_const_mgr.add_const('DISPID_WORDWHEELEDITED',0x000000DB)
		win_const_mgr.add_const('TAPE_DRIVE_WRITE_SETMARKS',0x81000000)
		win_const_mgr.add_const('ADS_SERVICE_KERNEL_DRIVER',0x00000001)
		win_const_mgr.add_const('WM_RBUTTONDOWN',0x00000204)
		win_const_mgr.add_const('IDTRYAGAIN',0x0000000A)
		win_const_mgr.add_const('DMORIENT_LANDSCAPE',0x00000002)
		win_const_mgr.add_const('NCRYPT_UI_PROTECT_KEY_FLAG',0x00000001)
		win_const_mgr.add_const('SQL_PRED_BASIC',0x00000002)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_GOPHER_FILE_HTML',0x0000000C)
		win_const_mgr.add_const('DISC_NO_FORCE',0x00000040)
		win_const_mgr.add_const('SHGFI_ICONLOCATION',0x00001000)
		win_const_mgr.add_const('WM_SYSCOMMAND',0x00000112)
		win_const_mgr.add_const('SECBUFFER_CHANNEL_BINDINGS',0x0000000E)
		win_const_mgr.add_const('MXDCOP_PRINTTICKET_FIXED_PAGE',0x0000001A)
		win_const_mgr.add_const('SQL_AT_DROP_TABLE_CONSTRAINT_CASCADE',0x00002000)
		win_const_mgr.add_const('SCRIPTPROP_MAJORVERSION',0x00000001)
		win_const_mgr.add_const('NTDSSITECONN_OPT_TWOWAY_SYNC',0x00000001)
		win_const_mgr.add_const('LDAP_OPT_SERVER_CERTIFICATE',0x00000081)
		win_const_mgr.add_const('CRLF_DISABLE_ROOT_CROSS_CERTS',0x00001000)
		win_const_mgr.add_const('CDERR_LOADRESFAILURE',0x00000007)
		win_const_mgr.add_const('PDCAP_D1_SUPPORTED',0x00000002)
		win_const_mgr.add_const('HTTP_STATUS_SERVICE_UNAVAIL',0x000001F7)
		win_const_mgr.add_const('GGL_LEVEL',0x00000001)
		win_const_mgr.add_const('NTMS_MAXATTR_LENGTH',0x00010000)
		win_const_mgr.add_const('SDP_ERROR_INVALID_RECORD_HANDLE',0x00000002)
		win_const_mgr.add_const('SV_NETWORKERRORTHRESHOLD_PARMNUM',0x00000225)
		win_const_mgr.add_const('TKF_CONFIRMHOTKEY',0x00000008)
		win_const_mgr.add_const('OLE_VERS_HIWORD',0x0000001D)
		win_const_mgr.add_const('PWR_CRITICALRESUME',0x00000003)
		win_const_mgr.add_const('GL_LEVEL_ERROR',0x00000002)
		win_const_mgr.add_const('PDH_LOG_OPEN_ALWAYS',0x00000003)
		win_const_mgr.add_const('IF_TYPE_HOSTPAD',0x0000005A)
		win_const_mgr.add_const('METHOD_NEITHER',0x00000003)
		win_const_mgr.add_const('IPP_E_OFFLINE',0xC0048007)
		win_const_mgr.add_const('SPFILEQ_REBOOT_RECOMMENDED',0x00000002)
		win_const_mgr.add_const('MQMSG_DELIVERY_EXPRESS',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_STGM_PRIORITY',0x00100000)
		win_const_mgr.add_const('ERROR_DS_CANT_RETRIEVE_DN',0x000020D5)
		win_const_mgr.add_const('CLIPCAPS',0x00000024)
		win_const_mgr.add_const('PORT_MPMFLAGS',0x0000002C)
		win_const_mgr.add_const('MM_ACM_FORMATCHOOSE',0x00008000)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_18',0x00000012)
		win_const_mgr.add_const('META_DIBSTRETCHBLT',0x00000000)
		win_const_mgr.add_const('PRJOB_DESTOFFLINE',0x00000020)
		win_const_mgr.add_const('BTH_ERROR_NO_CONNECTION',0x00000002)
		win_const_mgr.add_const('ICW_MAX_EMAILADDR',0x00000080)
		win_const_mgr.add_const('IF_TYPE_SONET_PATH',0x00000032)
		win_const_mgr.add_const('OID_ATM_SUPPORTED_AAL_TYPES',0x08010103)
		win_const_mgr.add_const('CRYPTUI_DISABLE_ADDTOSTORE',0x00000010)
		win_const_mgr.add_const('ERROR_PNP_INVALID_ID',0x000002A2)
		win_const_mgr.add_const('SQL_INITIALLY_DEFERRED',0x00000005)
		win_const_mgr.add_const('DRM_LOCKBOXTYPE_NONE',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_BO_NOLOG',0x00000000)
		win_const_mgr.add_const('TMUSEASYNC',0x00000004)
		win_const_mgr.add_const('PO_THROTTLE_DEGRADE',0x00000002)
		win_const_mgr.add_const('KSPIN_FLAG_GENERATE_MAPPINGS',0x00000100)
		win_const_mgr.add_const('WM_GETTEXTLENGTH',0x0000000E)
		win_const_mgr.add_const('SV_DOMAIN_PARMNUM',0x00000207)
		win_const_mgr.add_const('MQMSG_PRIV_LEVEL_BODY_ENHANCED',0x00000003)
		win_const_mgr.add_const('LANG_CHINESE_SIMPLIFIED',0x00000004)
		win_const_mgr.add_const('STM_MSGMAX',0x00000174)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NO_MM_POLICY',0x0000361A)
		win_const_mgr.add_const('IMF_FORCEENABLE',0x00000002)
		win_const_mgr.add_const('SAFER_LEVELID_CONSTRAINED',0x00010000)
		win_const_mgr.add_const('IF_TYPE_ISUP',0x000000B3)
		win_const_mgr.add_const('SQL_API_SQLGETSTMTOPTION',0x0000002E)
		win_const_mgr.add_const('CRL_FIND_ISSUED_FOR',0x00000003)
		win_const_mgr.add_const('DLGC_WANTALLKEYS',0x00000004)
		win_const_mgr.add_const('INDEX_GUID_ROTATEDBOUNDINGBOX',0x00000000)
		win_const_mgr.add_const('URL_APPLY_GUESSFILE',0x00000004)
		win_const_mgr.add_const('TF_RIUIE_MAXREADINGSTRINGLENGTH',0x00000004)
		win_const_mgr.add_const('PID_MISC_STATUS',0x00000002)
		win_const_mgr.add_const('HTTP_STATUS_PARTIAL',0x000000CB)
		win_const_mgr.add_const('WM_ENDSESSION',0x00000016)
		win_const_mgr.add_const('NUMPRS_LEADING_MINUS',0x00000010)
		win_const_mgr.add_const('SQL_DIAG_INSERT',0x00000032)
		win_const_mgr.add_const('AM_VIDEO_FLAG_I_SAMPLE',0x00000000)
		win_const_mgr.add_const('RPC_IF_ASYNC_CALLBACK',0x00000100)
		win_const_mgr.add_const('PROP_ID_SECURE_MIN',0x000067F0)
		win_const_mgr.add_const('IDS_CAP_STAT_OPTPAL_BUILD',0x000001F9)
		win_const_mgr.add_const('PC_PATHS',0x00000200)
		win_const_mgr.add_const('EAP_E_SERVER_FIRST',0x80420200)
		win_const_mgr.add_const('EXITEVENT_STARTUP',0x00000080)
		win_const_mgr.add_const('DISPID_DOUBLECLICK',0x00000003)
		win_const_mgr.add_const('DS_PING_FLAGS',0x000FFFFF)
		win_const_mgr.add_const('IDI_CONFLICT',0x000000A1)
		win_const_mgr.add_const('MCI_COPY',0x00000852)
		win_const_mgr.add_const('BFFM_VALIDATEFAILEDA',0x00000003)
		win_const_mgr.add_const('ERROR_CLUSTER_NULL_DATA',0x00001720)
		win_const_mgr.add_const('NRC_MAXAPPS',0x00000036)
		win_const_mgr.add_const('SUBLANG_ENGLISH_US',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLSETENVATTR',0x000003FB)
		win_const_mgr.add_const('ERROR_DS_CANT_MOVE_ACCOUNT_GROUP',0x00002132)
		win_const_mgr.add_const('CHANGER_VOLUME_REPLACE',0x00800000)
		win_const_mgr.add_const('HTTP_QUERY_REQUEST_METHOD',0x0000002D)
		win_const_mgr.add_const('SUBLANG_ENGLISH_UK',0x00000002)
		win_const_mgr.add_const('DRM_ADD_LICENSE_PERSIST',0x00000001)
		win_const_mgr.add_const('STI_ONLINESTATE_INITIALIZING',0x00000400)
		win_const_mgr.add_const('DXVA_MOTION_VECTOR_BUFFER',0x00000010)
		win_const_mgr.add_const('EVENT_SYSTEM_SCROLLINGSTART',0x00000012)
		win_const_mgr.add_const('OTD_FORCE_RECT_SIZING',0x00000001)
		win_const_mgr.add_const('MCI_CAPTURE',0x00000870)
		win_const_mgr.add_const('BFFM_VALIDATEFAILEDW',0x00000004)
		win_const_mgr.add_const('DLCTL_NO_CLIENTPULL',0x20000000)
		win_const_mgr.add_const('SBSP_RELATIVE',0x00001000)
		win_const_mgr.add_const('NETCON_MAX_NAME_LEN',0x00000100)
		win_const_mgr.add_const('MNS_CHECKORBMP',0x04000000)
		win_const_mgr.add_const('DB_PROT_LEVEL_CALL',0x00000002)
		win_const_mgr.add_const('MSG_SERVICE_UNINSTALL',0x00000005)
		win_const_mgr.add_const('PROPSETHDR_OSVERSION_UNKNOWN',0xFFFFFFFF)
		win_const_mgr.add_const('LPD_SUPPORT_GDI',0x00000010)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_DESTOFFHOOK',0x00000080)
		win_const_mgr.add_const('MCI_VCR_LIST_NUMBER',0x00080000)
		win_const_mgr.add_const('GD_RCDATA',0x0000000A)
		win_const_mgr.add_const('ERROR_HOTKEY_ALREADY_REGISTERED',0x00000581)
		win_const_mgr.add_const('IPPORT_DAYTIME',0x0000000D)
		win_const_mgr.add_const('OID_FFP_PARAMS',0xFC010213)
		win_const_mgr.add_const('PID_EDITTIME',0x0000000A)
		win_const_mgr.add_const('LINEADDRESSSTATE_TERMINALS',0x00000080)
		win_const_mgr.add_const('ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS',0x00002165)
		win_const_mgr.add_const('SQL_FN_NUM_PI',0x00010000)
		win_const_mgr.add_const('DPAMM_DELETE',0x00000002)
		win_const_mgr.add_const('IMPORTANCE_LOW_MAX',0x00000001)
		win_const_mgr.add_const('META_RESTOREDC',0x00000127)
		win_const_mgr.add_const('ILD_SCALE',0x00002000)
		win_const_mgr.add_const('PSF_SHOWHELP',0x00000001)
		win_const_mgr.add_const('DWM_TNP_RECTSOURCE',0x00000002)
		win_const_mgr.add_const('ISC_RET_SEQUENCE_DETECT',0x00000008)
		win_const_mgr.add_const('APPCOMMAND_VOLUME_UP',0x0000000A)
		win_const_mgr.add_const('CRL_REASON_CA_COMPROMISE_FLAG',0x00000020)
		win_const_mgr.add_const('PST_TCPIP_TELNET',0x00000102)
		win_const_mgr.add_const('DEBUG_STATUS_REVERSE_STEP_INTO',0x0000000E)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_DISK_IO',0x00000100)
		win_const_mgr.add_const('META_TEXTOUT',0x00000521)
		win_const_mgr.add_const('MDMEMBER_TYPE_FORMULA',0x00000004)
		win_const_mgr.add_const('IO_REPARSE_TAG_HSM',0xC0000004)
		win_const_mgr.add_const('META_INVERTREGION',0x0000012A)
		win_const_mgr.add_const('SQL_SRVC_ROW_SUBQUERY',0x00000008)
		win_const_mgr.add_const('SPI_GETSNAPTODEFBUTTON',0x0000005F)
		win_const_mgr.add_const('TRACELOG_ACCESS_REALTIME',0x00000400)
		win_const_mgr.add_const('WINHTTP_QUERY_DATE',0x00000009)
		win_const_mgr.add_const('IME_CMODE_RESERVED',0xF0000000)
		win_const_mgr.add_const('BATTERY_FLAG_UNKNOWN',0x000000FF)
		win_const_mgr.add_const('MQMSG_JOURNAL',0x00000002)
		win_const_mgr.add_const('TABLE_ERROR',0x00000002)
		win_const_mgr.add_const('TVS_EX_PARTIALCHECKBOXES',0x00000080)
		win_const_mgr.add_const('IS_TEXT_UNICODE_REVERSE_STATISTICS',0x00000020)
		win_const_mgr.add_const('TMT_BORDERONLY',0x0000089B)
		win_const_mgr.add_const('ERROR_SXS_COMPONENT_STORE_CORRUPT',0x00003712)
		win_const_mgr.add_const('PM_REMOVE',0x00000001)
		win_const_mgr.add_const('LINEDISCONNECTMODE_OUTOFORDER',0x00004000)
		win_const_mgr.add_const('OID_WAN_GET_COMP_INFO',0x0401020C)
		win_const_mgr.add_const('MMSYSERR_BASE',0x00000000)
		win_const_mgr.add_const('FS_DIALING',0x20000001)
		win_const_mgr.add_const('HTTP_LOG_FIELD_USER_AGENT',0x00010000)
		win_const_mgr.add_const('FILE_FLAG_NO_BUFFERING',0x20000000)
		win_const_mgr.add_const('EC_QUALITY_CHANGE',0x0000000B)
		win_const_mgr.add_const('MCI_VCR_SIGNAL_POSITION',0x00100000)
		win_const_mgr.add_const('SI_OWNER_RECURSE',0x00000100)
		win_const_mgr.add_const('CONTEXT_S_FIRST',0x0004E000)
		win_const_mgr.add_const('TBSTYLE_WRAPABLE',0x00000200)
		win_const_mgr.add_const('ERROR_IPSEC_MM_POLICY_IN_USE',0x000032CD)
		win_const_mgr.add_const('BCOB_A',0x00000001)
		win_const_mgr.add_const('IDM_TRIED_SHOWDETAILS',0x00000038)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_SEPFILE',0x00000008)
		win_const_mgr.add_const('OS_MEDIACENTER',0x00000023)
		win_const_mgr.add_const('SQL_CVT_REAL',0x00000040)
		win_const_mgr.add_const('DISPID_IHTMLOPSPROFILE_CLEARREQUEST',0x00000002)
		win_const_mgr.add_const('SV_SESSVCS_PARMNUM',0x000001F6)
		win_const_mgr.add_const('SQL_FN_SYS_USERNAME',0x00000001)
		win_const_mgr.add_const('NDW_INSTALLFLAG_PCMCIADEVICE',0x00020000)
		win_const_mgr.add_const('PD_SELECTION',0x00000001)
		win_const_mgr.add_const('HTTP_STATUS_UNSUPPORTED_MEDIA',0x0000019F)
		win_const_mgr.add_const('LINE_AGENTSTATUS',0x00000016)
		win_const_mgr.add_const('PRINTER_STATUS_OFFLINE',0x00000080)
		win_const_mgr.add_const('D3DCURSOR_IMMEDIATE_UPDATE',0x00000001)
		win_const_mgr.add_const('TVGN_PREVIOUSVISIBLE',0x00000007)
		win_const_mgr.add_const('EV_BREAK',0x00000040)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_FLASH',0x00000017)
		win_const_mgr.add_const('MCI_ANIM_GETDEVCAPS_SLOW_RATE',0x00004003)
		win_const_mgr.add_const('INDEX_GUID_ANALYSISHINT',0x00000003)
		win_const_mgr.add_const('WMDM_SCP_DRMINFO_V1HEADER',0x00000001)
		win_const_mgr.add_const('CRYPT_UPDATE_KEY',0x00000008)
		win_const_mgr.add_const('ALG_SID_HASH_REPLACE_OWF',0x0000000B)
		win_const_mgr.add_const('WINHTTP_DISABLE_AUTHENTICATION',0x00000004)
		win_const_mgr.add_const('POLICY_ERRV_NO_ACCEPTS',0x00000037)
		win_const_mgr.add_const('MF_SDK_VERSION',0x00000001)
		win_const_mgr.add_const('PAN_LETT_OBLIQUE_WEIGHTED',0x0000000A)
		win_const_mgr.add_const('MIN_DEV_VER_FOR_FLAGS',0x00000110)
		win_const_mgr.add_const('ERROR_EXCEPTION_IN_SERVICE',0x00000428)
		win_const_mgr.add_const('SHPPFW_NONE',0x00000000)
		win_const_mgr.add_const('ERROR_INVALID_PROFILE',0x000007DB)
		win_const_mgr.add_const('IF_TYPE_DS3',0x0000001E)
		win_const_mgr.add_const('RTM_VIEW_MASK_SIZE',0x00000020)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_HIERARCHIES',0x00000006)
		win_const_mgr.add_const('SPI_GETLOWPOWERACTIVE',0x00000053)
		win_const_mgr.add_const('LINEERR_LINEMAPPERFAILED',0x80000040)
		win_const_mgr.add_const('SHGFI_ADDOVERLAYS',0x00000020)
		win_const_mgr.add_const('COD_SERVICE_LIMITED',0x00000001)
		win_const_mgr.add_const('LOCALE_ALTERNATE_SORTS',0x00000004)
		win_const_mgr.add_const('WM_ASKCBFORMATNAME',0x0000030C)
		win_const_mgr.add_const('LANG_FRENCH',0x00000000)
		win_const_mgr.add_const('SQL_SR_USAGE_ON_COLLATION',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_OA_NOTSUPPORTED',0x00000001)
		win_const_mgr.add_const('IF_TYPE_DS0',0x00000051)
		win_const_mgr.add_const('FPSR_UD',0x00000004)
		win_const_mgr.add_const('HTMLDLG_MODELESS',0x00000040)
		win_const_mgr.add_const('SPMODE_PROFILE',0x00000100)
		win_const_mgr.add_const('SQL_MULT_RESULT_SETS',0x00000024)
		win_const_mgr.add_const('OID_ATM_MY_IP_NM_ADDRESS',0x0801020F)
		win_const_mgr.add_const('WIA_DIP_BAUDRATE',0x0000000C)
		win_const_mgr.add_const('IMGDECODE_HINT_FULLWIDTH',0x00000004)
		win_const_mgr.add_const('OPERATION_INPUT_SYNC',0x00000008)
		win_const_mgr.add_const('SQL_DRIVER_COMPLETE_REQUIRED',0x00000003)
		win_const_mgr.add_const('IDM_PRINTQUERYJOBSPENDING',0x000008E5)
		win_const_mgr.add_const('EC_VIDEOFRAMEREADY',0x00000049)
		win_const_mgr.add_const('LDAP_VERSION1',0x00000001)
		win_const_mgr.add_const('IDM_ITALIC',0x00000038)
		win_const_mgr.add_const('ACTRL_ACCESS_NO_OPTIONS',0x00000000)
		win_const_mgr.add_const('CERT_STORE_PROV_FIND_CRL_FUNC',0x00000011)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_DISASSOCIATED_BY_RESET',0x00000009)
		win_const_mgr.add_const('ITSS_THREAD_DESTROY_DEFAULT_TIMEOUT',0x0000000A)
		win_const_mgr.add_const('FCONTROL',0x00000008)
		win_const_mgr.add_const('WINHTTP_OPTION_CLIENT_CERT_CONTEXT',0x0000002F)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_DISCONNECT',0x0000000D)
		win_const_mgr.add_const('LINEFORWARDMODE_BUSYINTERNAL',0x00000020)
		win_const_mgr.add_const('BZ_NOTRESPONDINGDIALOG',0x00000008)
		win_const_mgr.add_const('D3D9_RESOURCE_PRIORITY_MINIMUM',0x28000000)
		win_const_mgr.add_const('MSGNAME_FORWARDED_FROM',0x00000010)
		win_const_mgr.add_const('FACILITY_TPM_SERVICES',0x00000028)
		win_const_mgr.add_const('ET_PROFILEFLAGS',0x00000400)
		win_const_mgr.add_const('C3_NONSPACING',0x00000001)
		win_const_mgr.add_const('SPI_SETAUDIODESCRIPTION',0x00000075)
		win_const_mgr.add_const('ETO_GLYPH_INDEX',0x00000010)
		win_const_mgr.add_const('DDENUMOVERLAYZ_BACKTOFRONT',0x00000000)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_MMC',0x00000016)
		win_const_mgr.add_const('GDICOMMENT_UNICODE_STRING',0x00000040)
		win_const_mgr.add_const('LVCFMT_CENTER',0x00000002)
		win_const_mgr.add_const('ISOLATIONAWARE_NOSTATICIMPORT_MANIFEST_RESOURCE_ID',0x00000003)
		win_const_mgr.add_const('LDAP_OPT_GETDSNAME_FLAGS',0x0000003D)
		win_const_mgr.add_const('CM_DRP_MFG',0x0000000C)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_REQUEST_TYPE',0x00000005)
		win_const_mgr.add_const('PDCAP_S0_SUPPORTED',0x00010000)
		win_const_mgr.add_const('CDO_E_HTTP_NOT_FOUND',0x80040218)
		win_const_mgr.add_const('MPR_ENABLE_RAS_ON_DEVICE',0x00000001)
		win_const_mgr.add_const('IPPORT_FINGER',0x0000004F)
		win_const_mgr.add_const('TRACE_MESSAGE_SEQUENCE',0x00000001)
		win_const_mgr.add_const('FPSR_U0',0x00000011)
		win_const_mgr.add_const('FPSR_U1',0x0000001E)
		win_const_mgr.add_const('FPSR_U2',0x0000002B)
		win_const_mgr.add_const('FPSR_U3',0x00000038)
		win_const_mgr.add_const('BACKGROUND_BLUE',0x00000010)
		win_const_mgr.add_const('USER_PSR_INITIAL',0x01013082)
		win_const_mgr.add_const('XP_PSEUDO_STREAM',0x00000010)
		win_const_mgr.add_const('LOCK_UNLOCK_DOOR',0x00000002)
		win_const_mgr.add_const('SKF_STICKYKEYSON',0x00000001)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_TS_LICENSE_SERVERS',0x00000231)
		win_const_mgr.add_const('HIDE_WINDOW',0x00000000)
		win_const_mgr.add_const('PORT_NEXTSTEP',0x000000B2)
		win_const_mgr.add_const('FR_PROP_ISSUEDCERTIFICATECHAIN',0x0000000C)
		win_const_mgr.add_const('PSWIZB_CANCEL',0x00000010)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_MM_FOR_QM',0x00003646)
		win_const_mgr.add_const('SV_MAXFREELFCBS_PARMNUM',0x00000245)
		win_const_mgr.add_const('__RPCNDR_H_VERSION__',0x000001B8)
		win_const_mgr.add_const('MENU_TEXT_LEN',0x00000028)
		win_const_mgr.add_const('HTTP_QUERY_PASSPORT_CONFIG',0x0000004E)
		win_const_mgr.add_const('PIDDSI_NOTECOUNT',0x00000008)
		win_const_mgr.add_const('VP_TV_STANDARD_PAL_G',0x00020000)
		win_const_mgr.add_const('SQL_CA2_SENSITIVITY_ADDITIONS',0x00000010)
		win_const_mgr.add_const('SQL_GD_BLOCK',0x00000004)
		win_const_mgr.add_const('MUTZ_ENFORCERESTRICTED',0x00000100)
		win_const_mgr.add_const('URLACTION_NETWORK_CURR_MAX',0x00001A10)
		win_const_mgr.add_const('VP_TV_STANDARD_PAL_D',0x00000008)
		win_const_mgr.add_const('SV_TYPE_NT',0x00001000)
		win_const_mgr.add_const('CR_SAME_RESOURCES',0x0000002D)
		win_const_mgr.add_const('DEBUG_VSOURCE_INVALID',0x00000000)
		win_const_mgr.add_const('EMR_EXTCREATEFONTINDIRECTW',0x00000052)
		win_const_mgr.add_const('DWFRF_NORMAL',0x00000000)
		win_const_mgr.add_const('SFVM_GETZONE',0x0000003A)
		win_const_mgr.add_const('SQL_CURSOR_COMMIT_BEHAVIOR',0x00000017)
		win_const_mgr.add_const('PP_PIN_PROMPT_STRING',0x0000002C)
		win_const_mgr.add_const('ERRLOC_SERDEV',0x00000004)
		win_const_mgr.add_const('OQWF_DEFAULTFORM',0x00000002)
		win_const_mgr.add_const('VK_MODECHANGE',0x0000001F)
		win_const_mgr.add_const('LINECALLFEATURE2_PARKNONDIRECT',0x00000200)
		win_const_mgr.add_const('SUBLANG_UZBEK_CYRILLIC',0x00000002)
		win_const_mgr.add_const('COLOR_GRAYTEXT',0x00000011)
		win_const_mgr.add_const('WINEVENT_KEYWORD_CORRELATION_HINT',0x40000000000000)
		win_const_mgr.add_const('C3_VOWELMARK',0x00000004)
		win_const_mgr.add_const('DDCKEY_SRCOVERLAY',0x00000010)
		win_const_mgr.add_const('CTRY_ALGERIA',0x000000D5)
		win_const_mgr.add_const('SBSP_ACTIVATE_NOFOCUS',0x00080000)
		win_const_mgr.add_const('SV_DISKSPACETHRESHOLD_PARMNUM',0x00000226)
		win_const_mgr.add_const('MV_FLAG',0x00001000)
		win_const_mgr.add_const('SQLTEXT',0x00000023)
		win_const_mgr.add_const('ERROR_COULD_NOT_INTERPRET',0x00000228)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_SEND',0x0000000A)
		win_const_mgr.add_const('INTERNET_OPTION_POLICY',0x00000030)
		win_const_mgr.add_const('HTTP_CREATE_REQUEST_QUEUE_FLAG_OPEN_EXISTING',0x00000001)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_ALLOCATOR_EXISTS',0x00000800)
		win_const_mgr.add_const('PIDASI_COMPRESSION',0x0000000A)
		win_const_mgr.add_const('RPC_C_MQ_JOURNAL_DEADLETTER',0x00000001)
		win_const_mgr.add_const('DFC_POPUPMENU',0x00000005)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_DATAOFF',0x00000019)
		win_const_mgr.add_const('ERROR_CREATE_FAILED',0x0000065F)
		win_const_mgr.add_const('RDW_NOFRAME',0x00000800)
		win_const_mgr.add_const('TABLE_RELOAD',0x00000009)
		win_const_mgr.add_const('GLEX_CONSUME',0x00000002)
		win_const_mgr.add_const('FW_BOLD',0x000002BC)
		win_const_mgr.add_const('LOCKF_LOGICAL_LOCK',0x00000000)
		win_const_mgr.add_const('KSPROPERTY_TYPE_BASICSUPPORT',0x00000200)
		win_const_mgr.add_const('ERROR_SERVER_SHUTDOWN_IN_PROGRESS',0x000004E7)
		win_const_mgr.add_const('ERROR_RECOVERY_NOT_NEEDED',0x00001AA5)
		win_const_mgr.add_const('DSQPF_NOCHOOSECOLUMNS',0x00000040)
		win_const_mgr.add_const('EM_SETRECT',0x000000B3)
		win_const_mgr.add_const('EM_UNDO',0x000000C7)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_QUARANTINED_DOMAIN',0x00000004)
		win_const_mgr.add_const('CF_SHOWHELPBUTTON',0x00000001)
		win_const_mgr.add_const('DDBD_16',0x00000400)
		win_const_mgr.add_const('OID_TCP_CONNECTION_OFFLOAD_PARAMETERS',0xFC030201)
		win_const_mgr.add_const('WINHTTP_QUERY_RAW_HEADERS_CRLF',0x00000016)
		win_const_mgr.add_const('LINEERR_INVALPOINTER',0x80000035)
		win_const_mgr.add_const('DNS_UPDATE_FORCE_SECURITY_NEGO',0x00000800)
		win_const_mgr.add_const('IPV6_MULTICAST_LOOP',0x0000000B)
		win_const_mgr.add_const('CALLBACK_WINDOW',0x00010000)
		win_const_mgr.add_const('WIA_PAGE_ISO_A10',0x00000010)
		win_const_mgr.add_const('CRLF_REVCHECK_IGNORE_OFFLINE',0x00000008)
		win_const_mgr.add_const('WIA_PAGE_ISO_B6',0x00000017)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_SAMPLE_MOTION',0x00000001)
		win_const_mgr.add_const('XINPUT_GAMEPAD_TRIGGER_THRESHOLD',0x0000001E)
		win_const_mgr.add_const('DDCAPS2_FLIPINTERVAL',0x00200000)
		win_const_mgr.add_const('LOGON_EXTRA_SIDS',0x00000020)
		win_const_mgr.add_const('IR_PROMISCUOUS',0x00000000)
		win_const_mgr.add_const('HFRMREG_PERSONAL',0x00000002)
		win_const_mgr.add_const('DB_BINDFLAGS_OPENIFEXISTS',0x00000020)
		win_const_mgr.add_const('GCP_NUMERICOVERRIDE',0x01000000)
		win_const_mgr.add_const('HC_GETNEXT',0x00000001)
		win_const_mgr.add_const('CREATE_NO_CONNECT',0x00000001)
		win_const_mgr.add_const('SCARD_E_INVALID_CHV',0x8010002A)
		win_const_mgr.add_const('CTRY_NICARAGUA',0x000001F9)
		win_const_mgr.add_const('CDERR_DIALOGFAILURE',0x0000FFFF)
		win_const_mgr.add_const('SSPROP_STREAM_XSL',0x00000010)
		win_const_mgr.add_const('_MM_HINT_T1',0x00000002)
		win_const_mgr.add_const('AIF_NOOVERWRITE',0x00000010)
		win_const_mgr.add_const('IME_ESC_GET_EUDC_DICTIONARY',0x00001003)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_USER_FLOW_DURATION',0x0000000F)
		win_const_mgr.add_const('ERROR_DOMAIN_CONTROLLER_EXISTS',0x000004E2)
		win_const_mgr.add_const('DBG_INIT',0x00000014)
		win_const_mgr.add_const('NS_EMAIL',0x00000025)
		win_const_mgr.add_const('TAPE_UNLOAD',0x00000001)
		win_const_mgr.add_const('USER_CODE_PAGE_PARMNUM',0x00000019)
		win_const_mgr.add_const('ERROR_DS_SOURCE_DOMAIN_IN_FOREST',0x00002156)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_DAY_TO_SECOND',0x00001000)
		win_const_mgr.add_const('SUBLANG_IRISH_IRELAND',0x00000002)
		win_const_mgr.add_const('DFCS_MENUARROW',0x00000000)
		win_const_mgr.add_const('IDD_GNRLPROPS',0x0000044C)
		win_const_mgr.add_const('ACCESS_SUCCESS_OPEN',0x00000010)
		win_const_mgr.add_const('ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE',0x00002140)
		win_const_mgr.add_const('INTERNET_DEFAULT_HTTP_PORT',0x00000050)
		win_const_mgr.add_const('RTM_RESUME_METHODS',0x00000000)
		win_const_mgr.add_const('ILR_HORIZONTAL_LEFT',0x00000000)
		win_const_mgr.add_const('MDPROPVAL_MJC_IMPLICITCUBE',0x00000004)
		win_const_mgr.add_const('IF_TYPE_DOCSCABLE_UPSTREAM',0x00000081)
		win_const_mgr.add_const('MSV1_0_UPDATE_LOGON_STATISTICS',0x00000004)
		win_const_mgr.add_const('STATUSMSG_OPTION_NOANIMATION',0x00000001)
		win_const_mgr.add_const('MIXER_OBJECTF_AUX',0x50000000)
		win_const_mgr.add_const('DXVA_BITSTREAM_CONCEALMENT_NEED_UNLIKELY',0x00000000)
		win_const_mgr.add_const('CSTR_EQUAL',0x00000002)
		win_const_mgr.add_const('ERROR_DATABASE_FAILURE',0x000010D9)
		win_const_mgr.add_const('CM_PROB_NO_VALID_LOG_CONF',0x0000001B)
		win_const_mgr.add_const('RAS_EAP_ROLE_AUTHENTICATEE',0x00000002)
		win_const_mgr.add_const('MPEG2_PROGRAM_STREAM_MAP',0x00000000)
		win_const_mgr.add_const('ERROR_INVALID_HANDLE',0x00000006)
		win_const_mgr.add_const('SPMODE_DBMON',0x00002000)
		win_const_mgr.add_const('DEBUG_DUMP_WINDOWS_CE',0x00000405)
		win_const_mgr.add_const('ERROR_INVALID_FUNCTION',0x00000001)
		win_const_mgr.add_const('TASK_TRIGGER_FLAG_HAS_END_DATE',0x00000001)
		win_const_mgr.add_const('MAXCOMMENTSZ',0x00000100)
		win_const_mgr.add_const('NDIS_MAC_OPTION_8021P_PRIORITY',0x00000040)
		win_const_mgr.add_const('SQL_CODE_SECOND',0x00000006)
		win_const_mgr.add_const('OID_FDDI_PORT_PC_LS',0x0303026A)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_WRITEMEDIAWITHVALIDATION',0x00000202)
		win_const_mgr.add_const('BOOT_LOG_CONF',0x00000003)
		win_const_mgr.add_const('CMSG_CMS_RECIPIENT_ENCRYPTED_KEY_INDEX_PARAM',0x00000023)
		win_const_mgr.add_const('AEC_MODE_HALF_DUPLEX',0x00000001)
		win_const_mgr.add_const('MCI_VCR_STATUS_AUDIO',0x00004026)
		win_const_mgr.add_const('SQLAOPNOOP',0x00000056)
		win_const_mgr.add_const('POLICY_SET_DEFAULT_QUOTA_LIMITS',0x00000080)
		win_const_mgr.add_const('RBBS_FIXEDBMP',0x00000020)
		win_const_mgr.add_const('BS_RIGHT',0x00000200)
		win_const_mgr.add_const('SS_OWNERDRAW',0x0000000D)
		win_const_mgr.add_const('XP1_IFS_HANDLES',0x00020000)
		win_const_mgr.add_const('IP_TIME_OPTS_SHIFT',0x00000000)
		win_const_mgr.add_const('BSIS_NOGRIPPER',0x00000001)
		win_const_mgr.add_const('NRC_NOWILD',0x00000015)
		win_const_mgr.add_const('SQL_ATTR_IMP_PARAM_DESC',0x0000271D)
		win_const_mgr.add_const('NTDSCONN_OPT_IGNORE_SCHEDULE_MASK',0x80000000)
		win_const_mgr.add_const('SQL_ATTR_ROWS_FETCHED_PTR',0x0000001A)
		win_const_mgr.add_const('MD_ERROR_SUB500_URLAUTH_NO_SCOPE',0x00000014)
		win_const_mgr.add_const('PARTITION_IFS',0x00000007)
		win_const_mgr.add_const('PROCESS_NAME_NATIVE',0x00000001)
		win_const_mgr.add_const('WMDM_E_SDMI_NOMORECOPIES',0x8004500D)
		win_const_mgr.add_const('MDM_HDLCPPP_SPEED_64K',0x00000001)
		win_const_mgr.add_const('CAUSE_NUMBER_CHANGED',0x00000016)
		win_const_mgr.add_const('BAUD_1200',0x00000040)
		win_const_mgr.add_const('CERT_LOGOTYPE_TABLE_SIZE_IMAGE_RESOLUTION_CHOICE',0x00000002)
		win_const_mgr.add_const('RTM_ENUM_ALL_ROUTES',0x00000000)
		win_const_mgr.add_const('CRED_TYPE_DOMAIN_VISIBLE_PASSWORD',0x00000004)
		win_const_mgr.add_const('RADIUS_EXTENSION_VERSION',0x00000001)
		win_const_mgr.add_const('URLACTION_COOKIES_SESSION_THIRD_PARTY',0x00001A06)
		win_const_mgr.add_const('MEM_TOP_DOWN',0x00100000)
		win_const_mgr.add_const('SECPKG_ATTR_LIFESPAN',0x00000002)
		win_const_mgr.add_const('WNDN_RMDIR',0x00000002)
		win_const_mgr.add_const('PDH_PLA_ERROR_NOSTART',0xC0000BED)
		win_const_mgr.add_const('CF_GDIOBJFIRST',0x00000300)
		win_const_mgr.add_const('MCI_VCR_SETTUNER_CHANNEL_DOWN',0x00040000)
		win_const_mgr.add_const('VER_PRODUCTBUILD',0x00000BD3)
		win_const_mgr.add_const('RASLCPO_ACFC',0x00000002)
		win_const_mgr.add_const('BCRYPT_PROV_DISPATCH',0x00000001)
		win_const_mgr.add_const('HTTP_QUERY_AUTHORIZATION',0x0000001C)
		win_const_mgr.add_const('PORT_CMIPMANAGE',0x000000A3)
		win_const_mgr.add_const('DEBUG_OUTPUT_PROMPT_REGISTERS',0x00000020)
		win_const_mgr.add_const('C3_HIRAGANA',0x00000020)
		win_const_mgr.add_const('CERT_STORE_CTRL_CANCEL_NOTIFY',0x00000005)
		win_const_mgr.add_const('PHONELAMPMODE_FLASH',0x00000010)
		win_const_mgr.add_const('DBIMF_BKCOLOR',0x00000040)
		win_const_mgr.add_const('ERROR_LOCKED',0x000000D4)
		win_const_mgr.add_const('SPI_SETACCESSTIMEOUT',0x0000003D)
		win_const_mgr.add_const('BANDINFO',0x00000018)
		win_const_mgr.add_const('PRINTER_NOTIFY_OPTIONS_REFRESH',0x00000001)
		win_const_mgr.add_const('X3_BTYPE_QP_INST_VAL_POS_X',0x00000000)
		win_const_mgr.add_const('RSVP_FIXED_FILTER_STYLE',0x00000002)
		win_const_mgr.add_const('ERROR_EVT_MAX_INSERTS_REACHED',0x00003AB7)
		win_const_mgr.add_const('WEBPOST_ERROR_CREATE_SITE',0xC004210A)
		win_const_mgr.add_const('HTTP_QUERY_FLAG_REQUEST_HEADERS',0x80000000)
		win_const_mgr.add_const('JOB_STATUS_ERROR',0x00000002)
		win_const_mgr.add_const('SPIF_UPDATEINIFILE',0x00000001)
		win_const_mgr.add_const('DXGI_USAGE_SHARED',0x00000001)
		win_const_mgr.add_const('FILE_WRITE_EA',0x00000010)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_UNAUTH_USER_SUM_PEAK_RATE',0x00000030)
		win_const_mgr.add_const('RBHT_SPLITTER',0x00000010)
		win_const_mgr.add_const('ERROR_SEVERITY_SUCCESS',0x00000000)
		win_const_mgr.add_const('DISPID_IHTMLOPSPROFILE_DOREADREQUEST',0x00000008)
		win_const_mgr.add_const('PL_KERNEL',0x00000000)
		win_const_mgr.add_const('EVENTLOG_SUCCESS',0x00000000)
		win_const_mgr.add_const('IDC_VP_ICONDISPLAY',0x000003FD)
		win_const_mgr.add_const('IDC_PS_PASTE',0x000001F4)
		win_const_mgr.add_const('FAPPCOMMAND_KEY',0x00000000)
		win_const_mgr.add_const('DWN_COLORMODE',0x0000003F)
		win_const_mgr.add_const('D3DPTEXTURECAPS_MIPVOLUMEMAP',0x00008000)
		win_const_mgr.add_const('ENDSESSION_CLOSEAPP',0x00000001)
		win_const_mgr.add_const('ICC_ANIMATE_CLASS',0x00000080)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_GENERAL_ATTRIBUTES',0x0000009F)
		win_const_mgr.add_const('D3DPRASTERCAPS_SLOPESCALEDEPTHBIAS',0x02000000)
		win_const_mgr.add_const('CREATECOLORSPACE_EMBEDED',0x00000001)
		win_const_mgr.add_const('ERROR_THREAD_ALREADY_IN_TASK',0x00000610)
		win_const_mgr.add_const('DSOP_FILTER_BUILTIN_GROUPS',0x00000004)
		win_const_mgr.add_const('TTF_IDISHWND',0x00000001)
		win_const_mgr.add_const('CRLF_USE_CROSS_CERT_TEMPLATE',0x00008000)
		win_const_mgr.add_const('MCI_NOTIFY_SUPERSEDED',0x00000002)
		win_const_mgr.add_const('MCI_VCR_INFO_VERSION',0x00010000)
		win_const_mgr.add_const('PRIMARY_CACHE_DIRTY_EXCLUSIVE',0x00000003)
		win_const_mgr.add_const('GIL_FORCENOSHIELD',0x00000400)
		win_const_mgr.add_const('MD_EXTLOG_METHOD',0x00000080)
		win_const_mgr.add_const('MDM_V110_SPEED_19DOT2K',0x00000007)
		win_const_mgr.add_const('PIDISF_FOLLOWALLLINKS',0x00000020)
		win_const_mgr.add_const('MUI_QUERY_CHECKSUM',0x00000002)
		win_const_mgr.add_const('CERT_PE_IMAGE_DIGEST_RESOURCES',0x00000002)
		win_const_mgr.add_const('LINEBUSYMODE_UNKNOWN',0x00000004)
		win_const_mgr.add_const('UNDNAME_NO_ACCESS_SPECIFIERS',0x00000080)
		win_const_mgr.add_const('DVD_STREAM_DATA_VMGM',0x00000400)
		win_const_mgr.add_const('INTERNET_FLAG_KEEP_CONNECTION',0x00400000)
		win_const_mgr.add_const('VK_F23',0x00000086)
		win_const_mgr.add_const('BTH_MFG_NEC',0x00000022)
		win_const_mgr.add_const('SCF_ALL',0x00000004)
		win_const_mgr.add_const('QCMINFO_PLACE_BEFORE',0x00000000)
		win_const_mgr.add_const('PARTITION_FAT32',0x0000000B)
		win_const_mgr.add_const('MIB_IPROUTE_TYPE_OTHER',0x00000001)
		win_const_mgr.add_const('CBS_NOINTEGRALHEIGHT',0x00000400)
		win_const_mgr.add_const('BTH_MFG_KC_TECHNOLOGY',0x00000016)
		win_const_mgr.add_const('PRODUCT_STANDARD_SERVER',0x00000007)
		win_const_mgr.add_const('SQL_PRED_NONE',0x00000000)
		win_const_mgr.add_const('ATSC_ETM_LOCATION_IN_PTC_FOR_EVENT',0x00000002)
		win_const_mgr.add_const('BT_PORT_MAX',0x00000000)
		win_const_mgr.add_const('SUPPORTS_RPC',0x00000004)
		win_const_mgr.add_const('IC_E_NO_SUCH_FORMAT',0x83010005)
		win_const_mgr.add_const('ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT',0x00001724)
		win_const_mgr.add_const('LVCFMT_RIGHT',0x00000001)
		win_const_mgr.add_const('SSRVOPT_OLDGUIDPTR',0x00000010)
		win_const_mgr.add_const('SQL_CVT_SMALLINT',0x00000010)
		win_const_mgr.add_const('SUBSCRIPTION_CAP_ALLOWPDATRANSFER',0x00000004)
		win_const_mgr.add_const('MAXOBJIDSTRSIZE',0x00000580)
		win_const_mgr.add_const('PORT_KNETCMP',0x0000009D)
		win_const_mgr.add_const('COMPLEXREGION',0x00000003)
		win_const_mgr.add_const('ERROR_UNCERTAIN_MEDIA',0x000000A3)
		win_const_mgr.add_const('DVB_DIT_PID',0x0000001E)
		win_const_mgr.add_const('PDH_ENTRY_NOT_IN_LOG_FILE',0xC0000BCD)
		win_const_mgr.add_const('LOGON32_LOGON_UNLOCK',0x00000007)
		win_const_mgr.add_const('MD_CHANGE_TYPE_DELETE_DATA',0x00000008)
		win_const_mgr.add_const('CHANNEL_MAX_COUNT',0x0000001E)
		win_const_mgr.add_const('MCI_DGV_STATUS_AUDIO_STREAM',0x00000402)
		win_const_mgr.add_const('ENHMETA_SIGNATURE',0x20454D46)
		win_const_mgr.add_const('REO_HILITED',0x01000000)
		win_const_mgr.add_const('CDDS_SUBITEM',0x00020000)
		win_const_mgr.add_const('VER_AND',0x00000006)
		win_const_mgr.add_const('CONNDLG_CONN_POINT',0x00000002)
		win_const_mgr.add_const('VER_WORKSTATION_NT',0x40000000)
		win_const_mgr.add_const('D3DDTCAPS_UBYTE4',0x00000001)
		win_const_mgr.add_const('TRUSTERROR_STEP_MSG_CERTCHAIN',0x0000000F)
		win_const_mgr.add_const('WNPERMC_AUDIT',0x00000002)
		win_const_mgr.add_const('JOY_CAL_READXONLY',0x00100000)
		win_const_mgr.add_const('LINEERR_INVALCARD',0x8000001E)
		win_const_mgr.add_const('SQL_SQ_EXISTS',0x00000002)
		win_const_mgr.add_const('MCI_VCR_SET_POSTROLL_DURATION',0x20000000)
		win_const_mgr.add_const('ERROR_NOT_LOGON_PROCESS',0x00000552)
		win_const_mgr.add_const('CTRY_PARAGUAY',0x00000253)
		win_const_mgr.add_const('TF_TRANSITORYEXTENSION_NONE',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_SH3_SECTION',0x0000000E)
		win_const_mgr.add_const('IGIMII_TOOLS',0x00000008)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_VIEW_COLUMN_USAGE',0x00000003)
		win_const_mgr.add_const('PSR_BN',0x0000002C)
		win_const_mgr.add_const('X3_P_SIZE_X',0x00000004)
		win_const_mgr.add_const('DXVA_PICTURE_STRUCTURE_BOTTOM_FIELD',0x00000002)
		win_const_mgr.add_const('OPTION_LPR_SERVERS',0x00000009)
		win_const_mgr.add_const('CBS_SIMPLE',0x00000001)
		win_const_mgr.add_const('PSR_BE',0x00000001)
		win_const_mgr.add_const('ERROR_NOT_CHILD_WINDOW',0x000005A2)
		win_const_mgr.add_const('NCRYPTBUFFER_PKCS_ALG_OID',0x00000029)
		win_const_mgr.add_const('OS_WIN95ORGREATER',0x00000002)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_DIRECTED_MGMT',0x00020000)
		win_const_mgr.add_const('CBEIF_OVERLAY',0x00000008)
		win_const_mgr.add_const('ICMODE_INTERNALF_MASK',0x00008000)
		win_const_mgr.add_const('ILC_COLOR8',0x00000008)
		win_const_mgr.add_const('OPERATION_MAYBE',0x00000001)
		win_const_mgr.add_const('SSPROP_STREAM_CONTENTTYPE',0x00000017)
		win_const_mgr.add_const('ILC_COLOR4',0x00000004)
		win_const_mgr.add_const('PXE_BA_REJECTED',0x00000004)
		win_const_mgr.add_const('WSAECONNRESET',0x00002746)
		win_const_mgr.add_const('WM_DDE_FIRST',0x000003E0)
		win_const_mgr.add_const('SV_REMOVEDUPLICATESEARCHES_PARMNUM',0x00000236)
		win_const_mgr.add_const('CP_THREAD_ACP',0x00000003)
		win_const_mgr.add_const('DN_NEED_TO_ENUM',0x00000020)
		win_const_mgr.add_const('RECOFLAG_LINEMODE',0x00000010)
		win_const_mgr.add_const('DNS_TKEY_MODE_RESOLVER_ASSIGN',0x00000004)
		win_const_mgr.add_const('NT64_PTR_SIZE',0x00000008)
		win_const_mgr.add_const('DBIMF_ADDTOFRONT',0x00000200)
		win_const_mgr.add_const('DBPROPVAL_CO_CONTAINS',0x00000010)
		win_const_mgr.add_const('WTS_WSD_FASTREBOOT',0x00000010)
		win_const_mgr.add_const('CF_EFFECTS',0x00000100)
		win_const_mgr.add_const('TMT_TOHUE2',0x0000070F)
		win_const_mgr.add_const('TMT_TOHUE5',0x00000712)
		win_const_mgr.add_const('TMT_TOHUE4',0x00000711)
		win_const_mgr.add_const('DEBUG_SYMBOL_IS_LOCAL',0x00000200)
		win_const_mgr.add_const('AVIFILEINFO_HASINDEX',0x00000010)
		win_const_mgr.add_const('PORT_DEVICE',0x00000321)
		win_const_mgr.add_const('SQL_MAX_COLUMNS_IN_INDEX',0x00000062)
		win_const_mgr.add_const('GOPHER_TYPE_CALENDAR',0x00080000)
		win_const_mgr.add_const('KAGPROP_QUERYBASEDUPDATES',0x00000002)
		win_const_mgr.add_const('CSVER_MINOR_WIN2K',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_NETWORK_NOT_FOUND',0x000013B5)
		win_const_mgr.add_const('GS_NUM_OBJS_ALL',0x00000000)
		win_const_mgr.add_const('DN_STOP_FREE_RES',0x00100000)
		win_const_mgr.add_const('IDM_CELLMERGE',0x0000089C)
		win_const_mgr.add_const('SQL_PERF_START',0x00000001)
		win_const_mgr.add_const('URLACTION_ACTIVEX_SCRIPTLET_RUN',0x00001209)
		win_const_mgr.add_const('DBPROPVAL_OO_SCOPED',0x00000008)
		win_const_mgr.add_const('POLICY_TRUST_ADMIN',0x00000008)
		win_const_mgr.add_const('WIA_IPS_AUTO_DESKEW',0x00000C23)
		win_const_mgr.add_const('WPWIZ_ERROR_OUTOFMEMORY',0xC004200A)
		win_const_mgr.add_const('ES_VERTICAL',0x00400000)
		win_const_mgr.add_const('USN_REASON_FILE_CREATE',0x00000100)
		win_const_mgr.add_const('TRACE_LEVEL_INFORMATION',0x00000004)
		win_const_mgr.add_const('F_WRITE',0x00000003)
		win_const_mgr.add_const('SDP_ATTRIB_PAN_NETWORK_ADDRESS',0x00000306)
		win_const_mgr.add_const('MD_USER_ISOLATION_NONE',0x00000000)
		win_const_mgr.add_const('MMIO_RWMODE',0x00000003)
		win_const_mgr.add_const('SECURITY_LOGON_IDS_RID_COUNT',0x00000003)
		win_const_mgr.add_const('CTRY_CZECH',0x000001A4)
		win_const_mgr.add_const('SURFACE_LOCK_ALLOW_DISCARD',0x00000002)
		win_const_mgr.add_const('ERROR_CANNOT_OPEN_PROFILE',0x000004B5)
		win_const_mgr.add_const('DTT_STATEID',0x00000001)
		win_const_mgr.add_const('WAVERR_BASE',0x00000020)
		win_const_mgr.add_const('DNS_RTYPE_SOA',0x00000600)
		win_const_mgr.add_const('SPCRP_MAXIMUM_PROPERTY',0x0000001C)
		win_const_mgr.add_const('EISA_NO_MAX_FUNCTION',0x000000FF)
		win_const_mgr.add_const('GESTURE_RIGHT_DOWN',0x00000000)
		win_const_mgr.add_const('CLUSAPI_READ_ACCESS',0x00000001)
		win_const_mgr.add_const('MCAST_JOIN_SOURCE_GROUP',0x0000002D)
		win_const_mgr.add_const('PAN_SERIF_FLARED',0x0000000E)
		win_const_mgr.add_const('ERROR_INVALID_MEMBER',0x0000056C)
		win_const_mgr.add_const('TAPE_SPACE_SEQUENTIAL_FMKS',0x00000007)
		win_const_mgr.add_const('NDIS_LINK_STATE_XMIT_LINK_SPEED_AUTO_NEGOTIATED',0x00000001)
		win_const_mgr.add_const('ERROR_LOCK_FAILED',0x000000A7)
		win_const_mgr.add_const('DDFXALPHACAPS_BLTALPHASURFACES',0x00000008)
		win_const_mgr.add_const('SERVICE_BESTEFFORT',0x80010000)
		win_const_mgr.add_const('IDD_BUSY',0x000003EE)
		win_const_mgr.add_const('SQL_MAX_TABLES_IN_SELECT',0x0000006A)
		win_const_mgr.add_const('INTENT_PERCEPTUAL',0x00000000)
		win_const_mgr.add_const('SQL_ISV_COLUMNS',0x00000040)
		win_const_mgr.add_const('SQL_MAX_ROWS',0x00000001)
		win_const_mgr.add_const('RECO_PASTE',0x00000000)
		win_const_mgr.add_const('E_FILTER_SCRIPTTEXTAREA',0x80100020)
		win_const_mgr.add_const('NIIF_NONE',0x00000000)
		win_const_mgr.add_const('DXGI_CPU_ACCESS_READ_WRITE',0x00000002)
		win_const_mgr.add_const('INSTALLFLAG_FORCE',0x00000001)
		win_const_mgr.add_const('EV_DSR',0x00000010)
		win_const_mgr.add_const('NET_STRING_IPV6_SERVICE_NO_SCOPE',0x00000040)
		win_const_mgr.add_const('ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA',0x000010EA)
		win_const_mgr.add_const('IMAGE_REL_CEE_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('MAPIFORM_INSTALL_OVERWRITEONCONFLICT',0x00000010)
		win_const_mgr.add_const('TXFS_TRANSACTED_VERSION_NONTRANSACTED',0xFFFFFFFE)
		win_const_mgr.add_const('DDSMT_ISTESTREQUIRED',0x00000001)
		win_const_mgr.add_const('HDSIL_NORMAL',0x00000000)
		win_const_mgr.add_const('ERROR_BADKEY',0x000003F2)
		win_const_mgr.add_const('DISPID_ONMOUSEUP',0x00000007)
		win_const_mgr.add_const('CERT_COMPARE_PUBLIC_KEY',0x00000006)
		win_const_mgr.add_const('PIR_STATUS_MAX',0x00000003)
		win_const_mgr.add_const('FR_PROP_ISSUEDCERTIFICATECRLCHAIN',0x0000000D)
		win_const_mgr.add_const('GCPCLASS_LATINNUMERICSEPARATOR',0x00000007)
		win_const_mgr.add_const('NDIS_OBJECT_REVISION_1',0x00000001)
		win_const_mgr.add_const('XACT_E_FIRST',0x8004D000)
		win_const_mgr.add_const('REGDF_CONFLICTIRQ',0x00040000)
		win_const_mgr.add_const('DISPID_ENTERPRESSED',0x000000C8)
		win_const_mgr.add_const('MD_LOGCUSTOM_DATATYPE_DOUBLE',0x00000005)
		win_const_mgr.add_const('RIP_EVENT',0x00000009)
		win_const_mgr.add_const('DDEM_MODEPASSED',0x00000001)
		win_const_mgr.add_const('SQL_COLUMN_CASE_SENSITIVE',0x0000000C)
		win_const_mgr.add_const('SMART_EXTENDED_SELFTEST_OFFLINE',0x00000002)
		win_const_mgr.add_const('RAS_EAP_FLAG_8021X_AUTH',0x00000080)
		win_const_mgr.add_const('L2CAP_MAX_MTU',0x0000FFFF)
		win_const_mgr.add_const('SQL_FN_NUM_ASIN',0x00000004)
		win_const_mgr.add_const('TMT_GLOWINTENSITY',0x0000097D)
		win_const_mgr.add_const('TXTLOG_VENDOR',0x80000000)
		win_const_mgr.add_const('ERROR_TRANSACTION_FREEZE_IN_PROGRESS',0x00001AB8)
		win_const_mgr.add_const('BG_E_BUSYCACHERECORD',0x80200048)
		win_const_mgr.add_const('WMDM_E_SDMI_TRIGGER',0x8004500C)
		win_const_mgr.add_const('GOPHER_TYPE_UNKNOWN',0x20000000)
		win_const_mgr.add_const('TXTBIT_MAXLENGTHCHANGE',0x00008000)
		win_const_mgr.add_const('DE_E_DATA_NOT_AVAILABLE',0x800C0007)
		win_const_mgr.add_const('ERROR_CTX_MODEM_RESPONSE_TIMEOUT',0x00001B64)
		win_const_mgr.add_const('SERVICE_CCP_NO_HINT',0x00000000)
		win_const_mgr.add_const('SHGVSPB_NOAUTODEFAULTS',0x80000000)
		win_const_mgr.add_const('SEE_MASK_ICON',0x00000010)
		win_const_mgr.add_const('FLAGCOLOR_RED',0x00000006)
		win_const_mgr.add_const('FCS_FLAG_DRAGDROP',0x00000002)
		win_const_mgr.add_const('CM_CUSTOMDEVPROP_BITS',0x00000001)
		win_const_mgr.add_const('SQL_SG_USAGE_ON_CHARACTER_SET',0x00000002)
		win_const_mgr.add_const('LM20_MAXCOMMENTSZ',0x00000030)
		win_const_mgr.add_const('LR_LOADFROMFILE',0x00000010)
		win_const_mgr.add_const('PID_IS_ICONFILE',0x00000009)
		win_const_mgr.add_const('AW_CENTER',0x00000010)
		win_const_mgr.add_const('FACILITY_CONTROL',0x0000000A)
		win_const_mgr.add_const('DISPID_QUERYSTATUS',0x00000003)
		win_const_mgr.add_const('DISPID_DEFAULTVERBINVOKED',0x000000CB)
		win_const_mgr.add_const('CCHCCCLASS',0x00000020)
		win_const_mgr.add_const('FR_FINDNEXT',0x00000008)
		win_const_mgr.add_const('DMPAPER_JENV_CHOU4_ROTATED',0x00000057)
		win_const_mgr.add_const('IFF_MULTICAST',0x00000010)
		win_const_mgr.add_const('MM_MIM_CLOSE',0x000003C2)
		win_const_mgr.add_const('PAN_SERIF_NORMAL_SANS',0x0000000B)
		win_const_mgr.add_const('MD_BACKUP_SAVE_FIRST',0x00000002)
		win_const_mgr.add_const('SM_SHUTTINGDOWN',0x00002000)
		win_const_mgr.add_const('ERROR_CONNECTION_COUNT_LIMIT',0x000004D6)
		win_const_mgr.add_const('VTBIT_DECIMAL',0x00000001)
		win_const_mgr.add_const('PORT_QUOTAD',0x000002FA)
		win_const_mgr.add_const('URLACTION_SCRIPT_MAX',0x00000015)
		win_const_mgr.add_const('PID_NBF',0x0000003F)
		win_const_mgr.add_const('DDCAPS_PALETTE',0x00008000)
		win_const_mgr.add_const('OID_TCP_CONNECTION_OFFLOAD_HARDWARE_CAPABILITIES',0xFC01020F)
		win_const_mgr.add_const('SQL_OJ_CAPABILITIES',0x0000FDEB)
		win_const_mgr.add_const('DEX_IDS_CLIPTOOSHORT',0x00000582)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_VIDEO',0x0000000E)
		win_const_mgr.add_const('CDS_VIDEOPARAMETERS',0x00000020)
		win_const_mgr.add_const('SQL_API_SQLFREESTMT',0x00000010)
		win_const_mgr.add_const('MRINFO_DISABLED_FLAG',0x00000020)
		win_const_mgr.add_const('IPX_IMMEDIATESPXACK',0x00004010)
		win_const_mgr.add_const('GESTURE_PLUS',0x00000000)
		win_const_mgr.add_const('AUTH_REQ_PREAUTH_REQUIRED',0x00000200)
		win_const_mgr.add_const('DFCS_BUTTONRADIOIMAGE',0x00000001)
		win_const_mgr.add_const('WM_CT_REPEAT_FIRST_FIELD',0x00000010)
		win_const_mgr.add_const('DNSSEC_ALGORITHM_NULL',0x000000FD)
		win_const_mgr.add_const('ERROR_BAD_USERNAME',0x0000089A)
		win_const_mgr.add_const('XECI_CERTREQ',0x00000004)
		win_const_mgr.add_const('ERROR_INFO_NOT_AVAIL',0x000000D3)
		win_const_mgr.add_const('TPM_VERPOSANIMATION',0x00001000)
		win_const_mgr.add_const('ERROR_EFS_SERVER_NOT_TRUSTED',0x0000177B)
		win_const_mgr.add_const('DBPROPVAL_AO_RANDOM',0x00000002)
		win_const_mgr.add_const('FR_NOT_ENUM',0x00000020)
		win_const_mgr.add_const('BCRYPT_HASH_INTERFACE',0x00000002)
		win_const_mgr.add_const('SELCERT_THUMBPRINT',0x0000006B)
		win_const_mgr.add_const('WN_CREDENTIAL_CLASS',0x00000002)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_TX_RX_DISABLED',0x00000001)
		win_const_mgr.add_const('TB_LINEUP',0x00000000)
		win_const_mgr.add_const('SPI_GETBEEP',0x00000001)
		win_const_mgr.add_const('CSIDL_FAVORITES',0x00000006)
		win_const_mgr.add_const('CERT_SIGNATURE_HASH_PROP_ID',0x0000000F)
		win_const_mgr.add_const('PP_UI_PROMPT',0x00000015)
		win_const_mgr.add_const('ACE_OBJECT_TYPE_PRESENT',0x00000001)
		win_const_mgr.add_const('ERROR_DUP_DOMAINNAME',0x000004C5)
		win_const_mgr.add_const('OTHER_USER_CACHE_ENTRY',0x00800000)
		win_const_mgr.add_const('NDR_CUSTOM_OR_DEFAULT_ALLOCATOR',0x10000000)
		win_const_mgr.add_const('PHONE_BUTTON',0x0000000E)
		win_const_mgr.add_const('MAPI_E_INSUFFICIENT_MEMORY',0x00000005)
		win_const_mgr.add_const('BUS_INTERFACE_REFERENCE_VERSION',0x00000100)
		win_const_mgr.add_const('WIA_TRANSFER_MSG_END_OF_TRANSFER',0x00000003)
		win_const_mgr.add_const('SB_CONST_ALPHA',0x00000001)
		win_const_mgr.add_const('WPF_SETMINPOSITION',0x00000001)
		win_const_mgr.add_const('OID_TAPI_GET_DEV_CAPS',0x07030110)
		win_const_mgr.add_const('PDH_FILE_ALREADY_EXISTS',0xC0000BD2)
		win_const_mgr.add_const('DDFXALPHACAPS_BLTALPHAEDGEBLEND',0x00000001)
		win_const_mgr.add_const('TMT_DKSHADOW3D',0x00000656)
		win_const_mgr.add_const('WIA_DPC_FOCUS_MANUAL_DIST',0x0000080A)
		win_const_mgr.add_const('TTDT_AUTOPOP',0x00000002)
		win_const_mgr.add_const('X3_IMM39_2_INST_WORD_POS_X',0x00000010)
		win_const_mgr.add_const('SP_COPY_LANGUAGEAWARE',0x00000020)
		win_const_mgr.add_const('QUERYASMINFO_FLAG_GETSIZE',0x00000002)
		win_const_mgr.add_const('CTRY_GREECE',0x0000001E)
		win_const_mgr.add_const('BS_BITMAP',0x00000080)
		win_const_mgr.add_const('CERT_CREATE_CONTEXT_NO_HCRYPTMSG_FLAG',0x00000004)
		win_const_mgr.add_const('SM_CXCURSOR',0x0000000D)
		win_const_mgr.add_const('OID_802_11_NETWORK_TYPES_SUPPORTED',0x0D010203)
		win_const_mgr.add_const('RTCEF_ALL',0x01FFFFFF)
		win_const_mgr.add_const('SERVICE_ADDRESS_FLAG_RPC_DG',0x00000002)
		win_const_mgr.add_const('ARCONTENT_HDDVD',0x00002000)
		win_const_mgr.add_const('PROP_SM_CYDLG',0x000000BC)
		win_const_mgr.add_const('SQL_AD_ADD_DOMAIN_CONSTRAINT',0x00000002)
		win_const_mgr.add_const('MAX_JOYSTICKOEMVXDNAME',0x00000104)
		win_const_mgr.add_const('EM_SETPASSWORDCHAR',0x000000CC)
		win_const_mgr.add_const('DDSCAPS_NONLOCALVIDMEM',0x20000000)
		win_const_mgr.add_const('NIM_SETVERSION',0x00000004)
		win_const_mgr.add_const('DLCTL_DOWNLOADONLY',0x00000800)
		win_const_mgr.add_const('CMSG_AUTHENTICATED_ATTRIBUTES_FLAG',0x00000008)
		win_const_mgr.add_const('PHONELAMPMODE_UNKNOWN',0x00000080)
		win_const_mgr.add_const('CERT_KEY_IDENTIFIER_PROP_ID',0x00000014)
		win_const_mgr.add_const('VIEW_LARGEICONS',0x00000000)
		win_const_mgr.add_const('SBM_GETSCROLLINFO',0x000000EA)
		win_const_mgr.add_const('SECPKG_CALL_IS_TCB',0x00000200)
		win_const_mgr.add_const('AVDTP_PROTOCOL_UUID16',0x00000019)
		win_const_mgr.add_const('SUBLANG_TATAR_RUSSIA',0x00000001)
		win_const_mgr.add_const('DEBUG_OUTCTL_ALL_OTHER_CLIENTS',0x00000002)
		win_const_mgr.add_const('MAX_DDDEVICEID_STRING',0x00000200)
		win_const_mgr.add_const('USN_REASON_RENAME_NEW_NAME',0x00002000)
		win_const_mgr.add_const('WRITE_DAC',0x00040000)
		win_const_mgr.add_const('BTH_ERROR_SUCCESS',0x00000000)
		win_const_mgr.add_const('SERVER_SEARCH_FLAG_PHANTOM_ROOT',0x00000002)
		win_const_mgr.add_const('SUBLANG_SINDHI_INDIA',0x00000001)
		win_const_mgr.add_const('MCI_WAVE_STATUS_FORMATTAG',0x00004001)
		win_const_mgr.add_const('FIBER_FLAG_FLOAT_SWITCH',0x00000001)
		win_const_mgr.add_const('HKCOMB_SC',0x00000010)
		win_const_mgr.add_const('HKCOMB_SA',0x00000020)
		win_const_mgr.add_const('PROTO_TYPE_MCAST',0x00000001)
		win_const_mgr.add_const('MAX_DESC_W',0x00000100)
		win_const_mgr.add_const('EXT_DEVICE_CAPS',0x00001003)
		win_const_mgr.add_const('TMT_SCALEDBACKGROUND',0x00001B59)
		win_const_mgr.add_const('DDPF_RGBTOYUV',0x00000100)
		win_const_mgr.add_const('AM_GBF_NOTASYNCPOINT',0x00000002)
		win_const_mgr.add_const('MMIO_FINDPROC',0x00040000)
		win_const_mgr.add_const('MSGF_COMMCTRL_DRAGSELECT',0x00004202)
		win_const_mgr.add_const('SPPSR_SELECT_DEVICE_RESOURCES',0x00000001)
		win_const_mgr.add_const('DS_SETFOREGROUND',0x00000200)
		win_const_mgr.add_const('CAL_HIJRI',0x00000006)
		win_const_mgr.add_const('SQL_QU_PRIVILEGE_DEFINITION',0x00000010)
		win_const_mgr.add_const('BCPFILECP_ACP',0x00000000)
		win_const_mgr.add_const('MOD_SQSYNTH',0x00000003)
		win_const_mgr.add_const('SEF_MACL_NO_WRITE_UP',0x00000100)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_MULTIPLE_OUTPUT',0x00000200)
		win_const_mgr.add_const('IS_DIGITAL_CAMERA_VAL',0x00000001)
		win_const_mgr.add_const('ABS_AUTOHIDE',0x00000001)
		win_const_mgr.add_const('PMB_ACTIVE',0x00000001)
		win_const_mgr.add_const('CONNECT_PROMPT',0x00000010)
		win_const_mgr.add_const('MCI_VD_STATUS_SPEED',0x00004002)
		win_const_mgr.add_const('SQL_QUALIFIER_LOCATION',0x00000072)
		win_const_mgr.add_const('SPI_GETSHOWSOUNDS',0x00000038)
		win_const_mgr.add_const('MD_ERROR_SUB404_HIDDEN_SEGMENT',0x00000008)
		win_const_mgr.add_const('RS_READY',0x00000001)
		win_const_mgr.add_const('DUMP_POINTERS_VERSION_2',0x00000002)
		win_const_mgr.add_const('IDC_CI_CURRENT',0x00000079)
		win_const_mgr.add_const('IOF_CREATELINKOBJECT',0x00000080)
		win_const_mgr.add_const('DISPID_DDISCFORMAT2TAOEVENTS_UPDATE',0x00000200)
		win_const_mgr.add_const('ASYNC_MODE_DEFAULT',0x00000000)
		win_const_mgr.add_const('IME_HOTKEY_PRIVATE_LAST',0x0000021F)
		win_const_mgr.add_const('CHANGER_INIT_ELEM_STAT_WITH_RANGE',0x00000002)
		win_const_mgr.add_const('IDTB_STOP',0x000000CA)
		win_const_mgr.add_const('ERROR_RXACT_COMMITTED',0x000002E8)
		win_const_mgr.add_const('JOB_OBJECT_MSG_ABNORMAL_EXIT_PROCESS',0x00000008)
		win_const_mgr.add_const('MAX_GOPHER_CATEGORY_NAME',0x00000080)
		win_const_mgr.add_const('TMPF_FIXED_PITCH',0x00000001)
		win_const_mgr.add_const('KAGPROP_AUTH_TRUSTEDCONNECTION',0x00000002)
		win_const_mgr.add_const('DSS_DISABLED',0x00000020)
		win_const_mgr.add_const('APPCOMMAND_MICROPHONE_VOLUME_DOWN',0x00000019)
		win_const_mgr.add_const('AVI_INDEX_OF_TIMED_CHUNKS',0x00000002)
		win_const_mgr.add_const('SUBLANG_HINDI_INDIA',0x00000001)
		win_const_mgr.add_const('GCPCLASS_LATINNUMERICTERMINATOR',0x00000006)
		win_const_mgr.add_const('BATTERY_FLAG_CRITICAL',0x00000004)
		win_const_mgr.add_const('DEVPROP_TYPE_NTSTATUS',0x00000018)
		win_const_mgr.add_const('WIA_DATA_GRAYSCALE',0x00000002)
		win_const_mgr.add_const('DEBUG_CURRENT_SOURCE_LINE',0x00000008)
		win_const_mgr.add_const('SQL_ROW_PROCEED',0x00000000)
		win_const_mgr.add_const('ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME',0x00003B00)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_GRP_FLOW_COUNT',0x00000002)
		win_const_mgr.add_const('CP_REGION',0x00000002)
		win_const_mgr.add_const('TRUNCATE_EXISTING',0x00000005)
		win_const_mgr.add_const('PERF_DATA_VERSION',0x00000001)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_NETWORKCARD',0x00000009)
		win_const_mgr.add_const('CRED_PERSIST_ENTERPRISE',0x00000003)
		win_const_mgr.add_const('DNS_TYPE_WINS',0x00000000)
		win_const_mgr.add_const('D3DSI_TEXLD_PROJECT',0x00000001)
		win_const_mgr.add_const('WAVEIN_MAPPER_STATUS_FORMAT',0x00000002)
		win_const_mgr.add_const('DISPID_DOM_BASE',0x00000001)
		win_const_mgr.add_const('FACILITY_AAF',0x00000012)
		win_const_mgr.add_const('USER_MARSHAL_FC_SMALL',0x00000003)
		win_const_mgr.add_const('WSA_QOS_GENERIC_ERROR',0x00002B07)
		win_const_mgr.add_const('PORT_DOMAIN',0x00000035)
		win_const_mgr.add_const('OPTION_BE_A_ROUTER',0x00000013)
		win_const_mgr.add_const('PHOTO_PROGRAMMODE_CREATIVE',0x00000005)
		win_const_mgr.add_const('OLEUI_ERR_GLOBALMEMALLOC',0x00000072)
		win_const_mgr.add_const('PHOTO_ORIENTATION_NORMAL',0x00000001)
		win_const_mgr.add_const('LINEERR_DIALQUIET',0x8000000B)
		win_const_mgr.add_const('D3DPMISCCAPS_SEPARATEALPHABLEND',0x00020000)
		win_const_mgr.add_const('SQL_ATTR_ROW_BIND_OFFSET_PTR',0x00000017)
		win_const_mgr.add_const('LINEADDRESSSHARING_BRIDGEDNEW',0x00000004)
		win_const_mgr.add_const('SC_CONTEXTHELP',0x0000F180)
		win_const_mgr.add_const('GENERATE_METHOD_EXACT',0x00000000)
		win_const_mgr.add_const('IDM_CANCEL',0x00000059)
		win_const_mgr.add_const('EVENT_CONSOLE_CARET',0x00004001)
		win_const_mgr.add_const('TRANSACTION_MANAGER_COMMIT_DEFAULT',0x00000000)
		win_const_mgr.add_const('SQL_CREATE_DOMAIN',0x00000082)
		win_const_mgr.add_const('FWPS_CLASSIFY_OUT_FLAG_NO_MORE_DATA',0x00000004)
		win_const_mgr.add_const('PORT_MAITRD',0x000003E5)
		win_const_mgr.add_const('ERROR_INVALID_FIELD',0x00000650)
		win_const_mgr.add_const('PSH_HEADERBITMAP',0x08000000)
		win_const_mgr.add_const('IMAGE_REL_PPC_SECREL16',0x0000000F)
		win_const_mgr.add_const('SNMP_AUTHAPI_INVALID_MSG_TYPE',0x0000001F)
		win_const_mgr.add_const('SQL_OIC_CORE',0x00000001)
		win_const_mgr.add_const('LVHT_EX_GROUP_SUBSETLINK',0x02000000)
		win_const_mgr.add_const('SPI_SETGRADIENTCAPTIONS',0x00001009)
		win_const_mgr.add_const('SPI_SETCURSORS',0x00000057)
		win_const_mgr.add_const('SEC_WINNT_AUTH_IDENTITY_ONLY',0x00000008)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_SERVICEPACK_UNINSTALL',0x00000016)
		win_const_mgr.add_const('EXITEVENT_SHUTDOWN',0x00000040)
		win_const_mgr.add_const('RPC_S_GRP_ELT_NOT_ADDED',0x00000788)
		win_const_mgr.add_const('BIF_BROWSEINCLUDEURLS',0x00000080)
		win_const_mgr.add_const('DISPID_IHTMLFRAMESCOLLECTION2_ITEM',0x00000000)
		win_const_mgr.add_const('LDAP_OPT_SERVER_EXT_ERROR',0x00000034)
		win_const_mgr.add_const('DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE',0x000025F7)
		win_const_mgr.add_const('TRANSACTION_MANAGER_MAXIMUM_OPTION',0x0000003F)
		win_const_mgr.add_const('BATTERY_UNKNOWN_VOLTAGE',0xFFFFFFFF)
		win_const_mgr.add_const('DDSCAPS_FLIP',0x00000010)
		win_const_mgr.add_const('LANG_NEPALI',0x00000061)
		win_const_mgr.add_const('MCI_FORMAT_MILLISECONDS',0x00000000)
		win_const_mgr.add_const('IMF_IMEALWAYSSENDNOTIFY',0x00000008)
		win_const_mgr.add_const('SQL_SRVC_NULL',0x00000002)
		win_const_mgr.add_const('MTP_NEXTPHASE_NO_DATA',0x00000003)
		win_const_mgr.add_const('PHONEFEATURE_SETBUTTONINFO',0x00004000)
		win_const_mgr.add_const('VK_NUMPAD8',0x00000068)
		win_const_mgr.add_const('EVENTLOG_END_ALL_PAIRED_EVENTS',0x00000004)
		win_const_mgr.add_const('CAUSE_CALL_REJECTED',0x00000015)
		win_const_mgr.add_const('ERROR_INVALID_LDT_OFFSET',0x00000233)
		win_const_mgr.add_const('IRLMP_9WIRE_MODE',0x00000016)
		win_const_mgr.add_const('MQ_LOOKUP_PEEK_LAST',0x40000018)
		win_const_mgr.add_const('ACTCTX_FLAG_LANGID_VALID',0x00000002)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_PROCEDURE_PARAMETERS',0x00000004)
		win_const_mgr.add_const('MCI_DGV_LIST_ITEM',0x00010000)
		win_const_mgr.add_const('DEVPROP_TYPE_INT16',0x00000004)
		win_const_mgr.add_const('SFC_DISABLE_NOPOPUPS',0x00000004)
		win_const_mgr.add_const('EXP_SZ_LINK_SIG',0xA0000001)
		win_const_mgr.add_const('DEBUG_FORMAT_WRITE_CAB',0x20000000)
		win_const_mgr.add_const('TCP_STDURG',0x00000006)
		win_const_mgr.add_const('INTERNET_OPTION_CODEPAGE',0x00000044)
		win_const_mgr.add_const('SECURITYMSG_SUCCESS',0x00000001)
		win_const_mgr.add_const('COMPONENT_DEFAULT_LEFT',0x0000FFFF)
		win_const_mgr.add_const('NLS_HIRAGANA',0x00040000)
		win_const_mgr.add_const('BS_DIBPATTERN',0x00000005)
		win_const_mgr.add_const('IDO_SHGIOI_LINK',0x0FFFFFFE)
		win_const_mgr.add_const('NDIS_OFFLOAD_SET_ON',0x00000001)
		win_const_mgr.add_const('WMDRM_SECURITY_PERFORM_REVOCATION_REFRESH',0x00000002)
		win_const_mgr.add_const('ERROR_ACCESS_DISABLED_BY_POLICY',0x000004EC)
		win_const_mgr.add_const('IDM_PARAGRAPH',0x00000884)
		win_const_mgr.add_const('LBS_OWNERDRAWVARIABLE',0x00000020)
		win_const_mgr.add_const('IDM_CELLSELECT',0x0000089E)
		win_const_mgr.add_const('HW_PROFILE_GUIDLEN',0x00000027)
		win_const_mgr.add_const('GRADIENT_FILL_TRIANGLE',0x00000002)
		win_const_mgr.add_const('URLPOLICY_LOG_ON_ALLOW',0x00000040)
		win_const_mgr.add_const('CMS_DISABLERENDERINTENT',0x00000800)
		win_const_mgr.add_const('MAX_SIZE_MPEG1_SEQUENCE_INFO',0x0000008C)
		win_const_mgr.add_const('TASK_FLAG_RUN_IF_CONNECTED_TO_INTERNET',0x00000400)
		win_const_mgr.add_const('KSEVENT_ENTRY_DELETED',0x00000001)
		win_const_mgr.add_const('SERVICE_SYSTEM_START',0x00000001)
		win_const_mgr.add_const('PFM_BOX',0x04000000)
		win_const_mgr.add_const('THREAD_SET_CONTEXT',0x00000010)
		win_const_mgr.add_const('ERR_FILE_MAP_FAILED',0xE000000A)
		win_const_mgr.add_const('DNS_RTYPE_NSAPPTR',0x00001700)
		win_const_mgr.add_const('PROCESS_MODE_BACKGROUND_END',0x00200000)
		win_const_mgr.add_const('LOCALE_SDATE',0x0000001D)
		win_const_mgr.add_const('PRODUCT_UNDEFINED',0x00000000)
		win_const_mgr.add_const('NUMPRS_LEADING_PLUS',0x00000004)
		win_const_mgr.add_const('BCRYPT_SUPPORTED_PAD_OAEP',0x00000008)
		win_const_mgr.add_const('SUBLANG_ICELANDIC_ICELAND',0x00000001)
		win_const_mgr.add_const('SQL_SP_UNIQUE',0x00000100)
		win_const_mgr.add_const('FSB_FLAT_MODE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_NAME_ERROR_DOMAIN_ONLY',0x00002119)
		win_const_mgr.add_const('CTRL_BREAK_EVENT',0x00000001)
		win_const_mgr.add_const('WNTYPE_PRINTER',0x00000003)
		win_const_mgr.add_const('SB_BOTTOM',0x00000007)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_NOSUCHNAME',0x00000002)
		win_const_mgr.add_const('CTRY_ZIMBABWE',0x00000107)
		win_const_mgr.add_const('SQL_SET_DEFAULT',0x00000004)
		win_const_mgr.add_const('FIND_STARTSWITH',0x00100000)
		win_const_mgr.add_const('D3DLINECAPS_ZTEST',0x00000002)
		win_const_mgr.add_const('PDH_COUNTER_ALREADY_IN_QUERY',0xC0000BF6)
		win_const_mgr.add_const('DPROMPT_SKIPFILE',0x00000002)
		win_const_mgr.add_const('FCS_READ',0x00000001)
		win_const_mgr.add_const('AM_LOADSTATUS_CONNECTING',0x00000004)
		win_const_mgr.add_const('MIDIERR_BASE',0x00000040)
		win_const_mgr.add_const('OID_FDDI_PORT_EB_ERROR_CT',0x0303026B)
		win_const_mgr.add_const('CM_HIDE_TRUSTPAGE',0x00000020)
		win_const_mgr.add_const('SCH_CRED_MAX_SUPPORTED_CERTS',0x00000064)
		win_const_mgr.add_const('NTDSCONN_OPT_TWOWAY_SYNC',0x00000001)
		win_const_mgr.add_const('LINEAGENTFEATURE_SETAGENTACTIVITY',0x00000004)
		win_const_mgr.add_const('AAL5_SSCS_SSCOP_ASSURED',0x00000001)
		win_const_mgr.add_const('MCI_SET_AUDIO_RIGHT',0x00000002)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_AUTHENTICATED_USER',0x80000020)
		win_const_mgr.add_const('DNF_DUPDESC',0x00000001)
		win_const_mgr.add_const('SSPROP_UNICODELCID',0x00000002)
		win_const_mgr.add_const('WM_IME_KEYLAST',0x0000010F)
		win_const_mgr.add_const('LOGON_OPTIMIZED',0x00004000)
		win_const_mgr.add_const('MC_SUPPORTED_COLOR_TEMPERATURE_9300K',0x00000020)
		win_const_mgr.add_const('HH_KEYWORD_LOOKUP',0x0000000D)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_CLR_SURROGATES',0x00000009)
		win_const_mgr.add_const('SCH_CRED_MEMORY_STORE_CERT',0x00010000)
		win_const_mgr.add_const('JOB_CONTROL_DELETE',0x00000005)
		win_const_mgr.add_const('ASC_REQ_ALLOW_CONTEXT_REPLAY',0x00400000)
		win_const_mgr.add_const('DBT_DEVTYP_VOLUME',0x00000002)
		win_const_mgr.add_const('OPTION_RENEWAL_TIME',0x0000003A)
		win_const_mgr.add_const('CTRY_GEORGIA',0x000003E3)
		win_const_mgr.add_const('MIDICAPS_STREAM',0x00000008)
		win_const_mgr.add_const('CLIP_EMBEDDED',0x00000008)
		win_const_mgr.add_const('NET_IF_OPER_STATUS_DOWN_NOT_AUTHENTICATED',0x00000001)
		win_const_mgr.add_const('D3DDEVCAPS_RTPATCHHANDLEZERO',0x00800000)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_BUSY',0x0000001D)
		win_const_mgr.add_const('BCPABORT',0x00000006)
		win_const_mgr.add_const('LCPRI_NORMAL',0x00003000)
		win_const_mgr.add_const('TF_USE_SYSTEM_THREAD',0x00000010)
		win_const_mgr.add_const('SQL_UP_ON_DROP',0x00000002)
		win_const_mgr.add_const('OPTION_TIME_SERVERS',0x00000004)
		win_const_mgr.add_const('RBBIM_CHILD',0x00000010)
		win_const_mgr.add_const('COD_SERVICE_MASK',0x00FFE000)
		win_const_mgr.add_const('MD_ERROR_SUB403_EXECUTE_ACCESS_DENIED',0x00000001)
		win_const_mgr.add_const('DI_OVERRIDE_INFFLAGS',0x10000000)
		win_const_mgr.add_const('OBJ_FONT',0x00000006)
		win_const_mgr.add_const('IRTIR_TASK_NOT_RUNNING',0x00000000)
		win_const_mgr.add_const('EMR_POLYDRAW',0x00000038)
		win_const_mgr.add_const('ES_AUTOVSCROLL',0x00000040)
		win_const_mgr.add_const('MF_FLAGS_FILL_IN_UNKNOWN_RESOURCE',0x00000004)
		win_const_mgr.add_const('SKF_RSHIFTLOCKED',0x00020000)
		win_const_mgr.add_const('ERROR_LOG_DEDICATED',0x000019E7)
		win_const_mgr.add_const('WIN_CERT_TYPE_X509',0x00000001)
		win_const_mgr.add_const('OID_TAPI_GET_CALL_INFO',0x0703010E)
		win_const_mgr.add_const('WPC_APP_LAUNCH',0x00000016)
		win_const_mgr.add_const('SPI_GETKEYBOARDCUES',0x0000100A)
		win_const_mgr.add_const('STATE_SYSTEM_BUSY',0x00000800)
		win_const_mgr.add_const('TF_PROPUI_STATUS_SAVETOFILE',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_EXTERNAL',0x00000002)
		win_const_mgr.add_const('CR_PROP_SANITIZEDCANAME',0x00000007)
		win_const_mgr.add_const('SUBLANG_FRENCH_BELGIAN',0x00000002)
		win_const_mgr.add_const('RF_RIGHT_AND_DOWN',0x00000040)
		win_const_mgr.add_const('PDH_LOG_TYPE_TRACE_KERNEL',0x00000004)
		win_const_mgr.add_const('DPNHQUERYADDRESS_CACHEFOUND',0x00000002)
		win_const_mgr.add_const('DDE_FACK',0x00008000)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_MEMBER_OF_UNION',0x0000000B)
		win_const_mgr.add_const('SYMF_REGREL',0x00000010)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_UNAUTH_USER_FLOW_RATE',0x00000018)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_FLAG_CERT_WRONG_USAGE',0x00000040)
		win_const_mgr.add_const('LVIS_DROPHILITED',0x00000008)
		win_const_mgr.add_const('SPFILELOG_SYSTEMLOG',0x00000001)
		win_const_mgr.add_const('CMSG_CTRL_ADD_SIGNER',0x00000006)
		win_const_mgr.add_const('WM_IME_CONTROL',0x00000283)
		win_const_mgr.add_const('GESTURE_UP_ARROW_LEFT',0x00000000)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_MD5',0x00000034)
		win_const_mgr.add_const('CTRY_FRANCE',0x00000021)
		win_const_mgr.add_const('VK_NUMPAD1',0x00000061)
		win_const_mgr.add_const('VK_KANJI',0x00000019)
		win_const_mgr.add_const('KS_VBI_FLAG_FRAME',0x00000000)
		win_const_mgr.add_const('CR_PROP_CATYPE',0x0000000A)
		win_const_mgr.add_const('CTRY_BULGARIA',0x00000167)
		win_const_mgr.add_const('WMDM_RIGHTS_PLAYBACKCOUNT',0x00000001)
		win_const_mgr.add_const('TMT_CONTENTMARGINS',0x00000E12)
		win_const_mgr.add_const('PRINTER_CHANGE_DELETE_JOB',0x00000400)
		win_const_mgr.add_const('TF_DISABLE_SPEECH',0x00000001)
		win_const_mgr.add_const('E_XML_INVALID',0xC00CE225)
		win_const_mgr.add_const('MCI_DGV_RESTORE_FROM',0x00010000)
		win_const_mgr.add_const('LINEERR_INVALEXTVERSION',0x80000029)
		win_const_mgr.add_const('CRED_TYPE_MAXIMUM',0x00000006)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_WINDOWS_GUI',0x00000002)
		win_const_mgr.add_const('DEBUG_TBINFO_PRIORITY',0x00000004)
		win_const_mgr.add_const('INVALID_MEDIA_FORMAT',0x00000000)
		win_const_mgr.add_const('VK_NUMPAD0',0x00000060)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_APPLICATION_SETTINGS',0x0000000A)
		win_const_mgr.add_const('FWP_ACTION_FLAG_NON_TERMINATING',0x00002000)
		win_const_mgr.add_const('SCS_SETRECONVERTSTRING',0x00010000)
		win_const_mgr.add_const('LOCALSTATE_UNINSTALLED',0x00000040)
		win_const_mgr.add_const('D3DPS20_MAX_NUMTEMPS',0x00000020)
		win_const_mgr.add_const('ASYNC_RECO_PROCESS_FAILED',0x00000002)
		win_const_mgr.add_const('SV_TYPE_PRINTQ_SERVER',0x00000200)
		win_const_mgr.add_const('ATADDR_ANY',0x00000000)
		win_const_mgr.add_const('WM_HSCROLL',0x00000114)
		win_const_mgr.add_const('PSPCB_RELEASE',0x00000001)
		win_const_mgr.add_const('SPDSL_IGNORE_DISK',0x00000001)
		win_const_mgr.add_const('SQL_DESC_MAXIMUM_SCALE',0x0000001E)
		win_const_mgr.add_const('MPEGLAYER3_FLAG_PADDING_ISO',0x00000000)
		win_const_mgr.add_const('WM_INTERIM',0x0000010C)
		win_const_mgr.add_const('DSSI_NO_EDIT_OWNER',0x00000008)
		win_const_mgr.add_const('SQL_CCS_LIMITED_COLLATION',0x00000004)
		win_const_mgr.add_const('CRYPT_MODE_CBC',0x00000001)
		win_const_mgr.add_const('SECURITY_NETWORK_DREP',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_DP_DOES_NOT_EXIST',0x000026AD)
		win_const_mgr.add_const('KP_KEYVAL',0x0000001E)
		win_const_mgr.add_const('SQL_SFKU_NO_ACTION',0x00000002)
		win_const_mgr.add_const('INFINFO_INF_SPEC_IS_HINF',0x00000001)
		win_const_mgr.add_const('SCARD_E_INVALID_ATR',0x80100015)
		win_const_mgr.add_const('PORT_MULTIPLEX',0x000000AB)
		win_const_mgr.add_const('TVS_EX_RICHTOOLTIP',0x00000010)
		win_const_mgr.add_const('MAX_FDCONSTRAINTVALUE_LENGTH',0x000003E8)
		win_const_mgr.add_const('TMT_CHARSET',0x00000193)
		win_const_mgr.add_const('CR_QUERY_VETOED',0x0000002A)
		win_const_mgr.add_const('IDC_LP_OPENSOURCE',0x000003EE)
		win_const_mgr.add_const('MCGIF_DATE',0x00000001)
		win_const_mgr.add_const('CAL_SERASTRING',0x00000004)
		win_const_mgr.add_const('PORT_TYPE_WRITE',0x00000001)
		win_const_mgr.add_const('HDF_SPLITBUTTON',0x01000000)
		win_const_mgr.add_const('DFM_GETHELPTEXT',0x00000005)
		win_const_mgr.add_const('OID_FDDI_SMT_OP_VERSION_ID',0x03030202)
		win_const_mgr.add_const('D3D10_SHADER_FORCE_PS_SOFTWARE_NO_OPT',0x00000001)
		win_const_mgr.add_const('PHONEFEATURE_SETLAMP',0x00800000)
		win_const_mgr.add_const('CRYPT_STRING_BASE64REQUESTHEADER',0x00000003)
		win_const_mgr.add_const('DBPROPVAL_CL_START',0x00000001)
		win_const_mgr.add_const('ERROR_DS_CONSTRUCTED_ATT_MOD',0x0000211B)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_SIG',0x0000360E)
		win_const_mgr.add_const('QOS_CLASS1',0x00000001)
		win_const_mgr.add_const('CERT_NAME_ISSUER_FLAG',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_VOID',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_INVALID_ZONE_TYPE',0x0000258B)
		win_const_mgr.add_const('ESLFLAG_NEXT',0x00000008)
		win_const_mgr.add_const('LDAP_FILTER_PRESENT',0x00000087)
		win_const_mgr.add_const('RI_MOUSE_RIGHT_BUTTON_DOWN',0x00000004)
		win_const_mgr.add_const('OFFSET_VECTOR_BREAK',0x00002800)
		win_const_mgr.add_const('FTP_PROTOCOL_UUID16',0x0000000A)
		win_const_mgr.add_const('VK_DBE_DETERMINESTRING',0x00000000)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_ENUM',0x0000000A)
		win_const_mgr.add_const('MEDIA_READ_WRITE',0x00000008)
		win_const_mgr.add_const('CM_PROB_ENTRY_IS_WRONG_TYPE',0x00000004)
		win_const_mgr.add_const('IDC_IO_ICONDISPLAY',0x0000083E)
		win_const_mgr.add_const('LOCK_UNLOCK_KEYPAD',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_LM_READ',0x00000002)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_SH3',0x00000001)
		win_const_mgr.add_const('OPTION_SWAP_SERVER',0x00000010)
		win_const_mgr.add_const('SSTF_CHARS',0x00000001)
		win_const_mgr.add_const('SSRVACTION_QUERYCANCEL',0x00000002)
		win_const_mgr.add_const('ACM_MPEG_COPYRIGHT',0x00000002)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM7B_SIZE_X',0x00000007)
		win_const_mgr.add_const('SS_RIGHTJUST',0x00000400)
		win_const_mgr.add_const('PAN_MIDLINE_INDEX',0x00000008)
		win_const_mgr.add_const('WH_DEBUG',0x00000009)
		win_const_mgr.add_const('DOMAIN_PASSWORD_COMPLEX',0x00000001)
		win_const_mgr.add_const('SQL_MAX_CATALOG_NAME_LEN',0x00000022)
		win_const_mgr.add_const('PORT_X400',0x00000067)
		win_const_mgr.add_const('NRC_CANCEL',0x00000026)
		win_const_mgr.add_const('CHANNEL_OPTION_COMPRESS_RDP',0x00800000)
		win_const_mgr.add_const('RPC_CONTEXT_HANDLE_DEFAULT_FLAGS',0x00000000)
		win_const_mgr.add_const('LDAP_OPT_SOCKET_BIND_ADDRESSES',0x00000044)
		win_const_mgr.add_const('SMC_DISPLAYCHEVRONTIP',0x0000002A)
		win_const_mgr.add_const('FDTF_RELATIVE',0x00000010)
		win_const_mgr.add_const('MCI_STATUS_MODE',0x00000004)
		win_const_mgr.add_const('SECURITY_FLAG_IGNORE_UNKNOWN_CA',0x00000100)
		win_const_mgr.add_const('GCP_JUSTIFYIN',0x00200000)
		win_const_mgr.add_const('BCRYPT_ECDH_PRIVATE_P384_MAGIC',0x344B4345)
		win_const_mgr.add_const('PP_SIG_KEYSIZE_INC',0x00000022)
		win_const_mgr.add_const('EM_LIMITTEXT',0x000000C5)
		win_const_mgr.add_const('FILE_ATTRIBUTE_DIRECTORY',0x00000010)
		win_const_mgr.add_const('CM_PROB_FAILED_ADD',0x0000001F)
		win_const_mgr.add_const('TIMEBODYELEMENT_OFFSET',0x00000200)
		win_const_mgr.add_const('PDCAP_D0_SUPPORTED',0x00000001)
		win_const_mgr.add_const('CRYPT_CACHE_ONLY_RETRIEVAL',0x00000002)
		win_const_mgr.add_const('SM_CYCURSOR',0x0000000E)
		win_const_mgr.add_const('REG_SZ',0x00000001)
		win_const_mgr.add_const('TF_LBI_BMPF_VERTICAL',0x00000001)
		win_const_mgr.add_const('META_REALIZEPALETTE',0x00000035)
		win_const_mgr.add_const('PDH_SQL_ALTER_DETAIL_FAILED',0xC0000BFD)
		win_const_mgr.add_const('DDF_SAME_DRAW',0x00000008)
		win_const_mgr.add_const('SEF_DEFAULT_GROUP_FROM_PARENT',0x00000040)
		win_const_mgr.add_const('SECURITY_PACKAGE_RID_COUNT',0x00000002)
		win_const_mgr.add_const('NTMS_VENDORNAME_LENGTH',0x00000080)
		win_const_mgr.add_const('SQL_PARAM_PROCEED',0x00000000)
		win_const_mgr.add_const('MAPI_E_INVALID_EDITFIELDS',0x00000018)
		win_const_mgr.add_const('PDCAP_WAKE_FROM_D1_SUPPORTED',0x00000020)
		win_const_mgr.add_const('WINHTTP_QUERY_FLAG_SYSTEMTIME',0x40000000)
		win_const_mgr.add_const('PS_DASHDOTDOT',0x00000004)
		win_const_mgr.add_const('RPC_S_BINDING_HAS_NO_AUTH',0x000006D2)
		win_const_mgr.add_const('SORTED_CTL_EXT_MAX_COLLISION_OFFSET',0x00000002)
		win_const_mgr.add_const('ERROR_CTX_CDM_CONNECT',0x00001B9A)
		win_const_mgr.add_const('MD_EXTLOG_REFERER',0x00040000)
		win_const_mgr.add_const('DRM_PLAYLIST_TYPES_DEFINED',0x00000001)
		win_const_mgr.add_const('CBR_600',0x00000258)
		win_const_mgr.add_const('SECURITY_SQOS_PRESENT',0x00100000)
		win_const_mgr.add_const('RPC_C_NS_SYNTAX_DCE',0x00000003)
		win_const_mgr.add_const('EMR_EXCLUDECLIPRECT',0x0000001D)
		win_const_mgr.add_const('WLX_DLG_SCREEN_SAVER_TIMEOUT',0x00000067)
		win_const_mgr.add_const('LINEAGENTSTATE_BUSYOUTBOUND',0x00000020)
		win_const_mgr.add_const('HOVER_DEFAULT',0xFFFFFFFF)
		win_const_mgr.add_const('SHCNE_RENAMEFOLDER',0x00020000)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_PATH_TYPE_NONE',0x00000001)
		win_const_mgr.add_const('AE_USERLIMIT',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_DST_TDP',0x00000001)
		win_const_mgr.add_const('D3DCLEAR_TARGET',0x00000001)
		win_const_mgr.add_const('VER_ERR_LOCAL_SIG',0x02000000)
		win_const_mgr.add_const('ERROR_ACTIVATION_COUNT_EXCEEDED',0x00001B93)
		win_const_mgr.add_const('SQL_DROP',0x00000001)
		win_const_mgr.add_const('PSF_CHECKDISPLAYASICON',0x00000008)
		win_const_mgr.add_const('NUMPRS_HEX_OCT',0x00000040)
		win_const_mgr.add_const('SQL_CVT_INTEGER',0x00000008)
		win_const_mgr.add_const('FILE_DEVICE_CD_ROM',0x00000002)
		win_const_mgr.add_const('SQL_DESC_INDICATOR_PTR',0x000003F1)
		win_const_mgr.add_const('BL_IO_PORT_INDEX',0x00000005)
		win_const_mgr.add_const('PROCESS_SUSPEND_RESUME',0x00000800)
		win_const_mgr.add_const('OID_ATM_SERVICE_ADDRESS',0x0801020A)
		win_const_mgr.add_const('IF_TYPE_INTERLEAVE',0x0000007C)
		win_const_mgr.add_const('USER_MARSHAL_FC_ULONG',0x00000009)
		win_const_mgr.add_const('WMS_CONTAINER_DURATION_HI',0x00000005)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_RECALL',0x00000005)
		win_const_mgr.add_const('ERROR_LOGIN_WKSTA_RESTRICTION',0x000004D8)
		win_const_mgr.add_const('CRYPT_FLAG_PCT1',0x00000001)
		win_const_mgr.add_const('URLACTION_FEATURE_MIME_SNIFFING',0x00002100)
		win_const_mgr.add_const('NIF_MESSAGE',0x00000001)
		win_const_mgr.add_const('NETLOGON_CONTROL_TC_VERIFY',0x0000000A)
		win_const_mgr.add_const('PIR_STATUS_TABLE_MAX',0x00000007)
		win_const_mgr.add_const('FPSR_MBZ0',0x0000003A)
		win_const_mgr.add_const('POWER_LEVEL_USER_NOTIFY_SOUND',0x00000002)
		win_const_mgr.add_const('X3_EMPTY_INST_VAL_POS_X',0x00000000)
		win_const_mgr.add_const('URLPOLICY_CREDENTIALS_SILENT_LOGON_OK',0x00000000)
		win_const_mgr.add_const('UNLOAD_DLL_DEBUG_EVENT',0x00000007)
		win_const_mgr.add_const('GDIPVER',0x00000100)
		win_const_mgr.add_const('VK_MEDIA_PREV_TRACK',0x000000B1)
		win_const_mgr.add_const('LIF_ITEMID',0x00000004)
		win_const_mgr.add_const('PIR_STATUS_MINIPORT_OVERRIDE',0x00000002)
		win_const_mgr.add_const('WM_POWER',0x00000048)
		win_const_mgr.add_const('HTTP_STATUS_ACCEPTED',0x000000CA)
		win_const_mgr.add_const('MDM_X75_DATA_BTX',0x00000004)
		win_const_mgr.add_const('DOCKINFO_DOCKED',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_PPC_SECREL',0x0000000B)
		win_const_mgr.add_const('ERROR_IPSEC_MM_AUTH_PENDING_DELETION',0x000032DE)
		win_const_mgr.add_const('SVSI_SELECT',0x00000001)
		win_const_mgr.add_const('DDOSDCAPS_VALIDOSCAPS',0x00000007)
		win_const_mgr.add_const('OUT_STROKE_PRECIS',0x00000003)
		win_const_mgr.add_const('IDM_TRIED_CONSTRAIN',0x0000000C)
		win_const_mgr.add_const('SMAE_CONTRACTED',0x00000002)
		win_const_mgr.add_const('MCI_DGV_STATUS_TREBLE',0x00004016)
		win_const_mgr.add_const('DDSCAPS_RESERVED2',0x00800000)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_TREE_ROOT',0x00800000)
		win_const_mgr.add_const('MSIM_DISPID_ONLOGONRESULT',0x00000E00)
		win_const_mgr.add_const('DNS_RCODE_NXRRSET',0x00000008)
		win_const_mgr.add_const('AE_ADMINDIS',0x00000003)
		win_const_mgr.add_const('AM_CONTENTPROPERTY_AUTHOR',0x00000002)
		win_const_mgr.add_const('OF_PARSE',0x00000100)
		win_const_mgr.add_const('SHADEBLENDCAPS',0x00000078)
		win_const_mgr.add_const('PS_INSIDEFRAME',0x00000006)
		win_const_mgr.add_const('IP_ADAPTER_NO_MULTICAST',0x00000010)
		win_const_mgr.add_const('D3DVTXPCAPS_TWEENING',0x00000040)
		win_const_mgr.add_const('INTERNET_KEEP_ALIVE_ENABLED',0x00000001)
		win_const_mgr.add_const('ERROR_PER_USER_TRUST_QUOTA_EXCEEDED',0x0000078C)
		win_const_mgr.add_const('FRAMEWORK_ALLOW_DEPRECATED',0x00000000)
		win_const_mgr.add_const('LINECALLSELECT_DEVICEID',0x00000008)
		win_const_mgr.add_const('WSA_PNRP_ERROR_BASE',0x00002CEC)
		win_const_mgr.add_const('SPINST_DEVICEINSTALL',0x00100000)
		win_const_mgr.add_const('DEFAULT_QUALITY',0x00000000)
		win_const_mgr.add_const('WINTRUST_MAX_HEADER_BYTES_TO_MAP_DEFAULT',0x00A00000)
		win_const_mgr.add_const('MD_ERROR_SUB403_WRITE_ACCESS_DENIED',0x00000003)
		win_const_mgr.add_const('INDEX_GUID_MIDLINE',0x0000000A)
		win_const_mgr.add_const('ERROR_BAD_DLL_ENTRYPOINT',0x00000261)
		win_const_mgr.add_const('SECURITY_MANDATORY_MEDIUM_RID',0x00002000)
		win_const_mgr.add_const('CRYPT_ACQUIRE_CACHE_FLAG',0x00000001)
		win_const_mgr.add_const('D3DPBLENDCAPS_INVSRCCOLOR2',0x00008000)
		win_const_mgr.add_const('SPI_SETFONTSMOOTHING',0x0000004B)
		win_const_mgr.add_const('SQL_SRJO_NATURAL_JOIN',0x00000080)
		win_const_mgr.add_const('HCBT_CREATEWND',0x00000003)
		win_const_mgr.add_const('IF_TYPE_FAST',0x0000007D)
		win_const_mgr.add_const('FR_PROP_FULLRESPONSENOPKCS7',0x0000000F)
		win_const_mgr.add_const('SVI1_NUM_ELEMENTS',0x00000005)
		win_const_mgr.add_const('LDAP_MOD_REPLACE',0x00000002)
		win_const_mgr.add_const('SQL_CREATE_TRANSLATION',0x00000085)
		win_const_mgr.add_const('IDM_ALIGNLEFT',0x00000003)
		win_const_mgr.add_const('SQL_PAS_BATCH',0x00000001)
		win_const_mgr.add_const('KSAUDDECOUTMODE_PCM_51',0x00000002)
		win_const_mgr.add_const('CERT_VALIDITY_NO_ISSUER_CERT_FOUND',0x10000000)
		win_const_mgr.add_const('OPTION_REQUESTED_ADDRESS',0x00000032)
		win_const_mgr.add_const('MAXIMUM_SUPPORTED_EXTENSION',0x00000200)
		win_const_mgr.add_const('ILS_SATURATE',0x00000004)
		win_const_mgr.add_const('OID_FDDI_SMT_CONNECTION_POLICY',0x0303020E)
		win_const_mgr.add_const('CLIPBRD_S_FIRST',0x000401D0)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_SIDINFO',0x0000000C)
		win_const_mgr.add_const('OBM_COMBO',0x00007FE2)
		win_const_mgr.add_const('SDP_SERVICE_SEARCH_ATTRIBUTE_REQUEST',0x00000003)
		win_const_mgr.add_const('HC_NOREMOVE',0x00000003)
		win_const_mgr.add_const('PFM_RESERVED2',0x08000000)
		win_const_mgr.add_const('TAPE_DRIVE_FORMAT',0xA0000000)
		win_const_mgr.add_const('NRC_CMDCAN',0x00000000)
		win_const_mgr.add_const('MSV1_0_S4U2SELF',0x00020000)
		win_const_mgr.add_const('TF_RIUIE_ERRORINDEX',0x00000008)
		win_const_mgr.add_const('MF_BYCOMMAND',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_BAD_PACKET',0x0000251E)
		win_const_mgr.add_const('CLEARTYPE_QUALITY',0x00000005)
		win_const_mgr.add_const('BTH_MFG_BROADCOM',0x0000000F)
		win_const_mgr.add_const('SERVICE_NOTIFY_STATUS_CHANGE_2',0x00000002)
		win_const_mgr.add_const('WLAN_CONNECTION_HIDDEN_NETWORK',0x00000001)
		win_const_mgr.add_const('PP_CERTCHAIN',0x00000009)
		win_const_mgr.add_const('STD_FIND',0x0000000C)
		win_const_mgr.add_const('PRINTER_ENUM_DEFAULT',0x00000001)
		win_const_mgr.add_const('INPUT_HARDWARE',0x00000002)
		win_const_mgr.add_const('ERROR_INVALID_VARIANT',0x0000025C)
		win_const_mgr.add_const('ONESTOPBIT',0x00000000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM',0x000035F4)
		win_const_mgr.add_const('DNS_CLASS_CHAOS',0x00000003)
		win_const_mgr.add_const('DEBUG_DUMP_FILE_LOAD_FAILED_INDEX',0x00000000)
		win_const_mgr.add_const('HP_HMAC_INFO',0x00000005)
		win_const_mgr.add_const('DRM_AL_NOUI',0x00000010)
		win_const_mgr.add_const('NCRYPTBUFFER_SSL_CLIENT_RANDOM',0x00000014)
		win_const_mgr.add_const('LDAP_MSG_RECEIVED',0x00000002)
		win_const_mgr.add_const('SMTP_MD_ID_BEGIN_RESERVED',0x00009000)
		win_const_mgr.add_const('CERT_PROT_ROOT_DISABLE_CURRENT_USER_FLAG',0x00000001)
		win_const_mgr.add_const('CM_ADD_RANGE_BITS',0x00000001)
		win_const_mgr.add_const('VER_NT_SERVER',0x00000003)
		win_const_mgr.add_const('BATTERY_TAG_INVALID',0x00000000)
		win_const_mgr.add_const('ISC_REQ_DATAGRAM',0x00000400)
		win_const_mgr.add_const('CTRY_URUGUAY',0x00000256)
		win_const_mgr.add_const('MFE_BOUNDARY_REACHED',0x00000006)
		win_const_mgr.add_const('MD_APPPOOL_STATE_STARTING',0x00000001)
		win_const_mgr.add_const('PICKLING_HAS_COMM_OR_FAULT',0x00000040)
		win_const_mgr.add_const('IDM_FIRE_PRINTTEMPLATEUP',0x00003A98)
		win_const_mgr.add_const('LDAP_OPT_REFERRAL_HOP_LIMIT',0x00000010)
		win_const_mgr.add_const('PBST_ERROR',0x00000002)
		win_const_mgr.add_const('VP_FLAGS_TV_MODE',0x00000001)
		win_const_mgr.add_const('CVT_SECONDS',0x00000001)
		win_const_mgr.add_const('LBS_COMBOBOX',0x00008000)
		win_const_mgr.add_const('PO_TRANSITION_VETO_TYPE_WINDOW',0x00000001)
		win_const_mgr.add_const('DEBUG_OUT_TEXT_REPL_DEFAULT',0x00000000)
		win_const_mgr.add_const('TRUSTERROR_STEP_MSG_STORE',0x0000000C)
		win_const_mgr.add_const('ILIF_ALPHA',0x00000001)
		win_const_mgr.add_const('WTS_EVENT_RENAME',0x00000004)
		win_const_mgr.add_const('SQL_VARCHAR',0x0000000C)
		win_const_mgr.add_const('SUBLANG_KASHMIRI_INDIA',0x00000002)
		win_const_mgr.add_const('LINEAGENTSTATE_UNKNOWN',0x00000100)
		win_const_mgr.add_const('PLATFORM_IE3',0x00000001)
		win_const_mgr.add_const('CERT_NAME_STR_ENABLE_UTF8_UNICODE_FLAG',0x00040000)
		win_const_mgr.add_const('PSP_DLGINDIRECT',0x00000001)
		win_const_mgr.add_const('DC_ORIENTATION',0x00000011)
		win_const_mgr.add_const('ADS_SERVICE_PAUSED',0x00000007)
		win_const_mgr.add_const('WM_CODEC_TWOPASS_VBR_PEAKCONSTRAINED',0x00000010)
		win_const_mgr.add_const('AAL5_MODE_MESSAGE',0x00000001)
		win_const_mgr.add_const('IIS_MD_GLOBAL_BASE',0x000023F0)
		win_const_mgr.add_const('DISABLE_IA32BR_FIX',0x00000008)
		win_const_mgr.add_const('PHONEERR_INVALPHONEHANDLE',0x90000013)
		win_const_mgr.add_const('WNODE_FLAG_EVENT_REFERENCE',0x00002000)
		win_const_mgr.add_const('SV_SERVERSIZE_PARMNUM',0x00000231)
		win_const_mgr.add_const('DOT11_STATUS_UNSUPPORTED_SERVICE_CLASS',0x00000008)
		win_const_mgr.add_const('IMF_FORCEREMEMBER',0x00000100)
		win_const_mgr.add_const('CRYPT_SIGN_ALG_OID_GROUP_ID',0x00000004)
		win_const_mgr.add_const('IPPORT_MICROSOFT_DS',0x000001BD)
		win_const_mgr.add_const('HTTP_QUERY_CONNECTION',0x00000017)
		win_const_mgr.add_const('SYMF_FUNCTION',0x00000800)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_DIE_ON_UNHANDLED_EXCEPTION',0x00000400)
		win_const_mgr.add_const('CM_RESDES_WIDTH_64',0x00000002)
		win_const_mgr.add_const('CMS_SETPROOFINTENT',0x00000008)
		win_const_mgr.add_const('MD_IMPORT_NODE_ONLY',0x00000002)
		win_const_mgr.add_const('GL_HEALTH_CHECK',0x00000020)
		win_const_mgr.add_const('WM_CTLCOLORSTATIC',0x00000138)
		win_const_mgr.add_const('FLAGS_ERROR_UI_FLAGS_NO_UI',0x00000008)
		win_const_mgr.add_const('ATSC_ETM_LOCATION_IN_PTC_FOR_PSIP',0x00000001)
		win_const_mgr.add_const('SUBLANG_BELARUSIAN_BELARUS',0x00000001)
		win_const_mgr.add_const('MCI_ANIM_OPEN_PARENT',0x00020000)
		win_const_mgr.add_const('ERROR_EVT_FILTER_UNSUPPORTEDOP',0x00003AAC)
		win_const_mgr.add_const('CRYPT_AIA_RETRIEVAL',0x00080000)
		win_const_mgr.add_const('TTS_NOPREFIX',0x00000002)
		win_const_mgr.add_const('OID_FDDI_PORT_MAINT_LS',0x03030268)
		win_const_mgr.add_const('MCI_DGV_LIST_ALG',0x00080000)
		win_const_mgr.add_const('N_BTMASK',0x0000000F)
		win_const_mgr.add_const('MCI_VCR_RECORD_AT',0x00020000)
		win_const_mgr.add_const('FDTF_LTRDATE',0x00000100)
		win_const_mgr.add_const('PRIVACY_TEMPLATE_MEDIUM_HIGH',0x00000002)
		win_const_mgr.add_const('FORMAT_MESSAGE_FROM_HMODULE',0x00000800)
		win_const_mgr.add_const('CERT_FIND_PROP_ONLY_ENHKEY_USAGE_FLAG',0x00000004)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_PEER_DISASSOCIATED',0x00020000)
		win_const_mgr.add_const('ITR_DRIVER0_INDEX',0x00000002)
		win_const_mgr.add_const('DMPAPER_A4_PLUS',0x0000003C)
		win_const_mgr.add_const('ERROR_PWD_HISTORY_CONFLICT',0x00000269)
		win_const_mgr.add_const('SV_CONNECTIONS_PARMNUM',0x0000019C)
		win_const_mgr.add_const('DISPID_WINDOWSETLEFT',0x00000108)
		win_const_mgr.add_const('MDMEMBER_TYPE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('NDIS_ENCAPSULATION_IEEE_802_3_P_AND_Q_IN_OOB',0x00000008)
		win_const_mgr.add_const('NUM_RESOURCE_MAP',0x00000100)
		win_const_mgr.add_const('ERROR_SERVICE_DEPENDENCY_FAIL',0x0000042C)
		win_const_mgr.add_const('MF_INSERT',0x00000000)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_SENDING_REQUEST',0x00000010)
		win_const_mgr.add_const('ACCESS_PROPERTY_SET_GUID',0x00000001)
		win_const_mgr.add_const('SUBLANG_ZULU_SOUTH_AFRICA',0x00000001)
		win_const_mgr.add_const('LVGS_COLLAPSIBLE',0x00000008)
		win_const_mgr.add_const('CAL_SDAYNAME3',0x00000009)
		win_const_mgr.add_const('DEBUG_EXTENSION_AT_ENGINE',0x00000000)
		win_const_mgr.add_const('RSC_FLAG_NGCONV',0x00000008)
		win_const_mgr.add_const('SO_RCVLOWAT',0x00001004)
		win_const_mgr.add_const('ERROR_RXACT_COMMIT_NECESSARY',0x000002A6)
		win_const_mgr.add_const('DIRID_PROGRAM_FILES_COMMONX86',0x0000402C)
		win_const_mgr.add_const('SUBLANG_ALBANIAN_ALBANIA',0x00000001)
		win_const_mgr.add_const('CRED_TYPE_DOMAIN_CERTIFICATE',0x00000003)
		win_const_mgr.add_const('IDENTITY_CHANGED',0x00000005)
		win_const_mgr.add_const('PP_SMARTCARD_READER',0x0000002B)
		win_const_mgr.add_const('SN_INFLAG_ALL_ACCESS',0x00000010)
		win_const_mgr.add_const('IMAGE_REL_PPC_GPREL',0x00000015)
		win_const_mgr.add_const('SCRIPTTEXT_ISEXPRESSION',0x00000020)
		win_const_mgr.add_const('KSPIN_FLAG_DO_NOT_USE_STANDARD_TRANSPORT',0x00080000)
		win_const_mgr.add_const('LOGTOKEN_NO_LOG',0x00000001)
		win_const_mgr.add_const('ADOX_MINOR',0x00000000)
		win_const_mgr.add_const('IDM_SCROLL_RIGHTEDGE',0x00000954)
		win_const_mgr.add_const('CMSG_MAIL_LIST_RECIPIENT',0x00000003)
		win_const_mgr.add_const('DM_DISPLAYFLAGS',0x00200000)
		win_const_mgr.add_const('PXE_REG_INDEX_TOP',0x00000000)
		win_const_mgr.add_const('CERT_COMPARE_EXISTING',0x0000000D)
		win_const_mgr.add_const('WIA_BASIC_PREVIEW',0x00000001)
		win_const_mgr.add_const('POST_RESPONSE_CACHE_ENTRY',0x04000000)
		win_const_mgr.add_const('LVNI_BELOW',0x00000200)
		win_const_mgr.add_const('D3DFVF_LASTBETA_D3DCOLOR',0x00008000)
		win_const_mgr.add_const('BTH_MFG_PARTHUS',0x0000000E)
		win_const_mgr.add_const('ERROR_FT_READ_RECOVERY_FROM_BACKUP',0x000002C0)
		win_const_mgr.add_const('MIDI_UNCACHE',0x00000004)
		win_const_mgr.add_const('DNS_ERROR_DP_ALREADY_EXISTS',0x000026AE)
		win_const_mgr.add_const('SPI_GETFILTERKEYS',0x00000032)
		win_const_mgr.add_const('UPDP_UPLOAD_ALWAYS',0x00000002)
		win_const_mgr.add_const('DDSCAPS3_OPENSHAREDRESOURCE',0x00008000)
		win_const_mgr.add_const('SQL_DATA_SOURCE_READ_ONLY',0x00000019)
		win_const_mgr.add_const('IDI_CLASSICON_OVERLAYLAST',0x000001F6)
		win_const_mgr.add_const('OUT_TT_PRECIS',0x00000004)
		win_const_mgr.add_const('ERROR_DBG_CONTROL_C',0x000002B5)
		win_const_mgr.add_const('CRYPT_ASN_ENCODING',0x00000001)
		win_const_mgr.add_const('LANG_BASE_ENCODING_INDEX',0x00000001)
		win_const_mgr.add_const('REO_GETOBJ_PSTG',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN',0x00003615)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_PRIMARY_KEYS',0x00000003)
		win_const_mgr.add_const('DNS_RTYPE_CERT',0x00002500)
		win_const_mgr.add_const('CRED_CACHE_TARGET_INFORMATION',0x00000001)
		win_const_mgr.add_const('NCBTRACE',0x00000079)
		win_const_mgr.add_const('DEBUG_SYMBOL_READ_ONLY',0x00000020)
		win_const_mgr.add_const('AVI_INDEX_SUB_2FIELD',0x00000001)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_USERS_ID',0x00000006)
		win_const_mgr.add_const('ICT_RESULTREADSTR',0x00000001)
		win_const_mgr.add_const('MDMVOL_MEDIUM',0x00000001)
		win_const_mgr.add_const('IDD_LINKTYPECHANGEDW',0x000003FE)
		win_const_mgr.add_const('DDSCAPS2_CUBEMAP_NEGATIVEX',0x00000800)
		win_const_mgr.add_const('DDSCAPS2_CUBEMAP_NEGATIVEY',0x00002000)
		win_const_mgr.add_const('DEBUG_OUTPUT_SYMBOLS_NO_TYPES',0x00000010)
		win_const_mgr.add_const('WHITEBALANCE_TUNGSTEN',0x00000006)
		win_const_mgr.add_const('MIXERCONTROL_CT_UNITS_UNSIGNED',0x00030000)
		win_const_mgr.add_const('IDM_VIEWSOURCE',0x0000085B)
		win_const_mgr.add_const('DXGI_PRESENT_TEST',0x00000001)
		win_const_mgr.add_const('CDIS_INDETERMINATE',0x00000100)
		win_const_mgr.add_const('TBS_IN_OUT_BUF_SIZE_MAX',0x00001000)
		win_const_mgr.add_const('ERROR_BAD_STACK',0x0000021F)
		win_const_mgr.add_const('IDD_LINKTYPECHANGEDA',0x00000402)
		win_const_mgr.add_const('DMPAPER_B5',0x0000000D)
		win_const_mgr.add_const('DEX_IDS_INVALID_AUDIO_FX',0x0000058C)
		win_const_mgr.add_const('JIFMK_SOF13',0x0000FFCD)
		win_const_mgr.add_const('JIFMK_SOF10',0x0000FFCA)
		win_const_mgr.add_const('DXVA_QUERYORREPLYFUNCFLAG_ACCEL_LOCK_OK_COPY',0x00FFFFFC)
		win_const_mgr.add_const('INPLACE_S_FIRST',0x000401A0)
		win_const_mgr.add_const('JIFMK_SOF14',0x0000FFCE)
		win_const_mgr.add_const('JIFMK_SOF15',0x0000FFCF)
		win_const_mgr.add_const('CONFIRMSAFETYACTION_LOADOBJECT',0x00000001)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_FTP_FIND_HTML',0x00000006)
		win_const_mgr.add_const('DKGRAY_BRUSH',0x00000003)
		win_const_mgr.add_const('FACILITY_STORAGE',0x00000003)
		win_const_mgr.add_const('AC_LINE_BACKUP_POWER',0x00000002)
		win_const_mgr.add_const('TF_CLUIE_STRING',0x00000008)
		win_const_mgr.add_const('MAXPROPPAGES',0x00000064)
		win_const_mgr.add_const('IDM_PRINTTARGET',0x000008E1)
		win_const_mgr.add_const('DDF_DONTDRAW',0x00000010)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME13',0x0000100F)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME12',0x0000004F)
		win_const_mgr.add_const('MCI_DGV_STATUS_SMPTE',0x00004013)
		win_const_mgr.add_const('REPORT_NO_PRIVATE_KEY',0x00000001)
		win_const_mgr.add_const('ERROR_JOURNAL_NOT_ACTIVE',0x0000049B)
		win_const_mgr.add_const('DEBUG_SYMTYPE_DEFERRED',0x00000005)
		win_const_mgr.add_const('PD_NOCURRENTPAGE',0x00800000)
		win_const_mgr.add_const('SQL_SVE_NULLIF',0x00000008)
		win_const_mgr.add_const('USE_SPOOLDEV',0x00000001)
		win_const_mgr.add_const('RRF_ZEROONFAILURE',0x20000000)
		win_const_mgr.add_const('IDS_CAP_WAVE_SIZE_ERROR',0x000001A7)
		win_const_mgr.add_const('ERROR_MORE_WRITES',0x00000460)
		win_const_mgr.add_const('RI_MOUSE_RIGHT_BUTTON_UP',0x00000008)
		win_const_mgr.add_const('SV_IDLETHREADTIMEOUT_PARMNUM',0x00000255)
		win_const_mgr.add_const('KSDSOUND_3D_MODE_HEADRELATIVE',0x00000001)
		win_const_mgr.add_const('BL_64M',0x04000000)
		win_const_mgr.add_const('PS_ENDCAP_SQUARE',0x00000100)
		win_const_mgr.add_const('IF_TYPE_ULTRA',0x0000001D)
		win_const_mgr.add_const('SEF_MACL_NO_EXECUTE_UP',0x00000400)
		win_const_mgr.add_const('WTPF_IGNOREREVOKATION',0x00000200)
		win_const_mgr.add_const('LINEMEDIAMODE_TELETEX',0x00000200)
		win_const_mgr.add_const('CM_PROB_PARTIAL_LOG_CONF',0x00000010)
		win_const_mgr.add_const('BCRYPT_ASYMMETRIC_ENCRYPTION_OPERATION',0x00000004)
		win_const_mgr.add_const('REQDISP_PENDING',0x00000000)
		win_const_mgr.add_const('SQL_TYPE_TIME',0x0000005C)
		win_const_mgr.add_const('LANG_TAMIL',0x00000049)
		win_const_mgr.add_const('DS_REPSYNC_INTERSITE_MESSAGING',0x00000008)
		win_const_mgr.add_const('AUTH_FLAG_RESET',0x00000000)
		win_const_mgr.add_const('IMF_AUTOFONTSIZEADJUST',0x00000010)
		win_const_mgr.add_const('TARGET_IS_NT351_OR_WIN95_OR_LATER',0x00000000)
		win_const_mgr.add_const('HH_CLOSE_ALL',0x00000012)
		win_const_mgr.add_const('SM_ARRANGE',0x00000038)
		win_const_mgr.add_const('WINEVENT_OPCODE_STOP',0x00000002)
		win_const_mgr.add_const('INVALID_TRACEID',0xFFFFFFFF)
		win_const_mgr.add_const('OID_TAPI_GET_ADDRESS_CAPS',0x0703010A)
		win_const_mgr.add_const('X3_TMPLT_INST_WORD_POS_X',0x00000000)
		win_const_mgr.add_const('VP_TV_STANDARD_SECAM_L1',0x00080000)
		win_const_mgr.add_const('RPC_C_OPT_MQ_AUTHN_LEVEL',0x00000006)
		win_const_mgr.add_const('DRIVER_W9X_SUSPECT_RANK',0x0000C000)
		win_const_mgr.add_const('EVENT_OBJECT_SELECTIONADD',0x00008007)
		win_const_mgr.add_const('SNMP_ERROR_WRONGENCODING',0x00000009)
		win_const_mgr.add_const('SQL_CA2_MAX_ROWS_SELECT',0x00000080)
		win_const_mgr.add_const('LV_MAX_WORKAREAS',0x00000010)
		win_const_mgr.add_const('LOCALE_SCOUNTRY',0x00000006)
		win_const_mgr.add_const('LINEBUSYMODE_STATION',0x00000001)
		win_const_mgr.add_const('ICCOMPRESS_KEYFRAME',0x00000001)
		win_const_mgr.add_const('IDM_CENTERALIGNPARA',0x000008CA)
		win_const_mgr.add_const('PHONELAMPMODE_STEADY',0x00000004)
		win_const_mgr.add_const('SM_TABLETPC',0x00000056)
		win_const_mgr.add_const('WM_COPY',0x00000301)
		win_const_mgr.add_const('MSV1_0_USE_DOMAIN_FOR_ROUTING_ONLY',0x00008000)
		win_const_mgr.add_const('IDS_CAP_ERRORPALOPEN',0x00000194)
		win_const_mgr.add_const('STI_GENCAP_NOTIFICATIONS',0x00000001)
		win_const_mgr.add_const('MKF_REPLACENUMBERS',0x00000080)
		win_const_mgr.add_const('TAPE_DRIVE_SET_BLOCK_SIZE',0x80000010)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_OVER',0x00010000)
		win_const_mgr.add_const('LANG_BOSNIAN_NEUTRAL',0x00000781)
		win_const_mgr.add_const('CSURL_SERVERPUBLISH',0x00000001)
		win_const_mgr.add_const('LINECALLFEATURE_PARK',0x00008000)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_TYPE_NAME_WIDE',0x00000004)
		win_const_mgr.add_const('MD_APP_POOL_RECYCLE_REQUESTS',0x00000002)
		win_const_mgr.add_const('ED_AUDIO_3',0x00000004)
		win_const_mgr.add_const('EMR_RESTOREDC',0x00000022)
		win_const_mgr.add_const('TBN_FIRST',0x00000000)
		win_const_mgr.add_const('WCB16_CDECL',0x00000001)
		win_const_mgr.add_const('D3DSP_DCL_USAGE_SHIFT',0x00000000)
		win_const_mgr.add_const('IDM_GETIPRINT',0x00000963)
		win_const_mgr.add_const('GL_ID_INPUTREADING',0x00000024)
		win_const_mgr.add_const('RR_VE',0x00000000)
		win_const_mgr.add_const('DEBUG_OUTCTL_ALL_CLIENTS',0x00000001)
		win_const_mgr.add_const('PROCESSOR_PPC_604',0x0000025C)
		win_const_mgr.add_const('MAPI_PASSWORD_UI',0x00020000)
		win_const_mgr.add_const('NDIS_INTERRUPT_MODERATION_CHANGE_NEEDS_REINITIALIZE',0x00000002)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_WINDOW_CLASS_REDIRECTION',0x00000003)
		win_const_mgr.add_const('ERROR_TRANSACTIONAL_CONFLICT',0x00001A90)
		win_const_mgr.add_const('DDFXCAPS_BLTROTATION90',0x00000200)
		win_const_mgr.add_const('ERROR_CTX_LICENSE_EXPIRED',0x00001B90)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_USERS',0x00000221)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_TRANSFERHELD',0x00001000)
		win_const_mgr.add_const('ISDB_DLT_TID',0x000000C1)
		win_const_mgr.add_const('TYPE_POINTER',0x00000001)
		win_const_mgr.add_const('NTDSCONN_OPT_DISABLE_INTERSITE_COMPRESSION',0x00000001)
		win_const_mgr.add_const('TMT_GLOWCOLOR',0x00000EE8)
		win_const_mgr.add_const('META_SAVEDC',0x0000001E)
		win_const_mgr.add_const('DXGI_MWA_VALID',0x00000007)
		win_const_mgr.add_const('MCI_INFO_MEDIA_IDENTITY',0x00000800)
		win_const_mgr.add_const('PAN_WEIGHT_BOOK',0x00000005)
		win_const_mgr.add_const('MD_HISTORY_LATEST',0x00000001)
		win_const_mgr.add_const('BG_E_FILE_NOT_AVAILABLE',0x80200004)
		win_const_mgr.add_const('SIOM_RESERVED_LINK',0x00000001)
		win_const_mgr.add_const('DS_BEHAVIOR_WIN2003',0x00000002)
		win_const_mgr.add_const('DS_BEHAVIOR_WIN2000',0x00000000)
		win_const_mgr.add_const('CERT_LDAP_STORE_SIGN_FLAG',0x00010000)
		win_const_mgr.add_const('PKCS_7_NDR_ENCODING',0x00020000)
		win_const_mgr.add_const('NRB_FUNCTION_ADD_LBAS_PINNED_SET',0x00000010)
		win_const_mgr.add_const('URLACTION_SHELL_EXTENSIONSECURITY',0x0000180C)
		win_const_mgr.add_const('CIF_USEICONEXE',0x00000010)
		win_const_mgr.add_const('UINT128_MAX',0x00000000)
		win_const_mgr.add_const('CI_STATE_INDEX_MIGRATION_MERGE',0x00000040)
		win_const_mgr.add_const('SQL_DIAG_UPDATE_WHERE',0x00000052)
		win_const_mgr.add_const('HTTP_QUERY_PASSPORT_URLS',0x0000004D)
		win_const_mgr.add_const('DB_MODE_WRITE',0x00000002)
		win_const_mgr.add_const('XEKL_KEYSIZE_MAX',0x00000002)
		win_const_mgr.add_const('OF_SHARE_DENY_NONE',0x00000040)
		win_const_mgr.add_const('SPI_SETHOTTRACKING',0x0000100F)
		win_const_mgr.add_const('BG_S_UNABLE_TO_DELETE_FILES',0x0020001A)
		win_const_mgr.add_const('DPAS_SORTED',0x00000001)
		win_const_mgr.add_const('WM_ENTERSIZEMOVE',0x00000231)
		win_const_mgr.add_const('TMT_SIZE',0x000000CF)
		win_const_mgr.add_const('FWP_FILTER_ENUM_FLAG_BOOTTIME_ONLY',0x00000004)
		win_const_mgr.add_const('URL_MK_LEGACY',0x00000000)
		win_const_mgr.add_const('RPC_S_INTERNAL_ERROR',0x000006E6)
		win_const_mgr.add_const('ERROR_TOO_MANY_LINKS',0x00000476)
		win_const_mgr.add_const('SQL_DESC_PARAMETER_TYPE',0x00000021)
		win_const_mgr.add_const('OID_FDDI_IF_OPER_STATUS',0x0303027F)
		win_const_mgr.add_const('XINPUT_GAMEPAD_DPAD_RIGHT',0x00000008)
		win_const_mgr.add_const('OID_802_11_RELOAD_DEFAULTS',0x0D01011C)
		win_const_mgr.add_const('D3D10_FLOAT16_FUSED_TOLERANCE_IN_ULP',0x00000000)
		win_const_mgr.add_const('GCL_CONVERSION',0x00000001)
		win_const_mgr.add_const('WIA_IPS_SUPPORTS_CHILD_ITEM_CREATION',0x00000C24)
		win_const_mgr.add_const('_DPNH_HRESULT_BASE',0x0000F000)
		win_const_mgr.add_const('OS_WIN2000DATACENTER',0x0000000B)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_ROAMING_ASSOCIATION_LOST',0x00000000)
		win_const_mgr.add_const('COMPONENT_TOP',0x00000003)
		win_const_mgr.add_const('TVS_HASLINES',0x00000002)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_BYTES_RCV',0x00000008)
		win_const_mgr.add_const('IDC_VP_CHANGEICON',0x000003E9)
		win_const_mgr.add_const('KS_TVAUDIO_PRESET_STEREO',0x00000200)
		win_const_mgr.add_const('D3DPRESENT_FLIPRESTART',0x00000008)
		win_const_mgr.add_const('TRUE',0x00000001)
		win_const_mgr.add_const('RSC_MBZ1_LEN',0x00000022)
		win_const_mgr.add_const('MD_ACCESS_REQUIRE_CERT',0x00000040)
		win_const_mgr.add_const('ENM_NONE',0x00000000)
		win_const_mgr.add_const('OCR_UP',0x00007F04)
		win_const_mgr.add_const('SCARD_T0_HEADER_LENGTH',0x00000007)
		win_const_mgr.add_const('TBIF_REPLACE',0x00000002)
		win_const_mgr.add_const('LMEM_ZEROINIT',0x00000040)
		win_const_mgr.add_const('KF_ALTDOWN',0x00002000)
		win_const_mgr.add_const('COPYFLG_NO_VERSION_DIALOG',0x00000020)
		win_const_mgr.add_const('WIA_INTENT_IMAGE_TYPE_COLOR',0x00000001)
		win_const_mgr.add_const('D3DDTCAPS_UBYTE4N',0x00000002)
		win_const_mgr.add_const('IDM_SCROLL_DOWN',0x00000952)
		win_const_mgr.add_const('WM_TABLET_DEFBASE',0x000002C0)
		win_const_mgr.add_const('WM_NCMBUTTONDOWN',0x000000A7)
		win_const_mgr.add_const('DDSD_PIXELFORMAT',0x00001000)
		win_const_mgr.add_const('FILE_DEVICE_PARALLEL_PORT',0x00000016)
		win_const_mgr.add_const('WIA_IPS_PAGE_WIDTH',0x00000C1A)
		win_const_mgr.add_const('CMSG_VERIFY_SIGNER_PUBKEY',0x00000001)
		win_const_mgr.add_const('DS_REPSYNC_FULL_REPLICA',0x01000000)
		win_const_mgr.add_const('OID_FDDI_MAC_RING_OP_CT',0x03030244)
		win_const_mgr.add_const('IPX_RECVHDR',0x00004005)
		win_const_mgr.add_const('DC_SIZE',0x00000008)
		win_const_mgr.add_const('CRYPT_DEFAULT_CONTEXT_CERT_SIGN_OID',0x00000001)
		win_const_mgr.add_const('OS_WIN2000ADVSERVER',0x0000000A)
		win_const_mgr.add_const('UINT64_MAX',0x00000000)
		win_const_mgr.add_const('FR_PROP_ISSUEDCERTIFICATE',0x0000000B)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_TOSTRING',0x0000048E)
		win_const_mgr.add_const('SQL_SNVF_CHARACTER_LENGTH',0x00000004)
		win_const_mgr.add_const('REGDF_NOTDETMEM',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_DUPLICATE_DLL_NAME',0x000036C5)
		win_const_mgr.add_const('IME_CHOTKEY_SHAPE_TOGGLE',0x00000011)
		win_const_mgr.add_const('BS_PATTERN',0x00000003)
		win_const_mgr.add_const('D3DDEVCAPS_TEXTUREVIDEOMEMORY',0x00000200)
		win_const_mgr.add_const('FILE_ACTION_REMOVED',0x00000002)
		win_const_mgr.add_const('SHCNE_RMDIR',0x00000010)
		win_const_mgr.add_const('MCI_DGV_STATUS_BRIGHTNESS',0x00004005)
		win_const_mgr.add_const('EM_EMPTYUNDOBUFFER',0x000000CD)
		win_const_mgr.add_const('MAXBYTE',0x00000000)
		win_const_mgr.add_const('TBSTATE_ENABLED',0x00000004)
		win_const_mgr.add_const('IDM_TRIED_FONTSIZE',0x00000025)
		win_const_mgr.add_const('FWPM_CONTEXT_IPSEC_INBOUND_RESERVED',0x00000000)
		win_const_mgr.add_const('STREAM_CONTAINS_SECURITY',0x00000002)
		win_const_mgr.add_const('LDAP_SSL_PORT',0x0000027C)
		win_const_mgr.add_const('KP_SCHANNEL_ALG',0x00000014)
		win_const_mgr.add_const('GDIREGISTERDDRAWPACKETVERSION',0x00000001)
		win_const_mgr.add_const('SUBLANG_YORUBA_NIGERIA',0x00000001)
		win_const_mgr.add_const('SB_VERT',0x00000001)
		win_const_mgr.add_const('MDM_PROTOCOLID_V128',0x00000002)
		win_const_mgr.add_const('TAPE_DRIVE_TAPE_CAPACITY',0x00000100)
		win_const_mgr.add_const('CSCONFIGFLAG_DO_NOT_START',0x00000004)
		win_const_mgr.add_const('PLATFORM_ID_OS2',0x00000190)
		win_const_mgr.add_const('FACILITY_TPM_SOFTWARE',0x00000029)
		win_const_mgr.add_const('MDM_PROTOCOLID_V120',0x00000005)
		win_const_mgr.add_const('HTTP_LOG_FIELD_STATUS',0x00000400)
		win_const_mgr.add_const('MEDIASINK_RATELESS',0x00000004)
		win_const_mgr.add_const('INTERNET_OPTION_END_BROWSER_SESSION',0x0000002A)
		win_const_mgr.add_const('FOREGROUND_RED',0x00000004)
		win_const_mgr.add_const('INTERNET_FLAG_UNUSED_4',0x00000004)
		win_const_mgr.add_const('RPC_S_PROTOCOL_ERROR',0x000006C0)
		win_const_mgr.add_const('FPO_ON',0x00000001)
		win_const_mgr.add_const('META_SETTEXTALIGN',0x0000012E)
		win_const_mgr.add_const('ICDECOMPRESS_NULLFRAME',0x10000000)
		win_const_mgr.add_const('VK_OEM_FINISH',0x000000F1)
		win_const_mgr.add_const('MDPROPVAL_MF_CREATE_CALCMEMBERS',0x00000004)
		win_const_mgr.add_const('GDIP_WMF_RECORD_BASE',0x00010000)
		win_const_mgr.add_const('CREDUI_FLAGS_REQUEST_ADMINISTRATOR',0x00000004)
		win_const_mgr.add_const('ERROR_SERVICE_NO_THREAD',0x0000041E)
		win_const_mgr.add_const('CRYPT_ANY',0x00000004)
		win_const_mgr.add_const('LOGON32_LOGON_NETWORK',0x00000003)
		win_const_mgr.add_const('AVRF_ENUM_RESOURCES_FLAGS_SUSPEND',0x00000001)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_CLOSED',0x00000017)
		win_const_mgr.add_const('C3_HIGHSURROGATE',0x00000800)
		win_const_mgr.add_const('FOF_CONFIRMMOUSE',0x00000002)
		win_const_mgr.add_const('POWER_ACTION_CRITICAL',0x80000000)
		win_const_mgr.add_const('CERT_SUBJECT_PUBLIC_KEY_MD5_HASH_PROP_ID',0x00000019)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_DISK_FILE_IO',0x00000200)
		win_const_mgr.add_const('LVTVIF_FIXEDSIZE',0x00000003)
		win_const_mgr.add_const('PHOTO_METERINGMODE_PATTERN',0x00000005)
		win_const_mgr.add_const('IS_TEXT_UNICODE_NOT_UNICODE_MASK',0x00000F00)
		win_const_mgr.add_const('ERROR_SYSTEM_POWERSTATE_TRANSITION',0x0000030E)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM7B_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('ERROR_DS_DRA_NOT_SUPPORTED',0x00002106)
		win_const_mgr.add_const('ICEE_CREATE_FILE_PE64',0x00000002)
		win_const_mgr.add_const('OBM_UPARROWD',0x00007FE7)
		win_const_mgr.add_const('TF_LBI_STYLE_SHOWNINTRAY',0x00000002)
		win_const_mgr.add_const('CM_GETIDLIST_FILTER_EJECTRELATIONS',0x00000004)
		win_const_mgr.add_const('LDAP_OPT_SCH_FLAGS',0x00000043)
		win_const_mgr.add_const('SQL_QUIET_MODE',0x0000006F)
		win_const_mgr.add_const('FNERR_BUFFERTOOSMALL',0x00003003)
		win_const_mgr.add_const('TVS_NOSCROLL',0x00002000)
		win_const_mgr.add_const('AF_IPX',0x00000006)
		win_const_mgr.add_const('OS_WELCOMELOGONUI',0x0000001B)
		win_const_mgr.add_const('OID_GEN_DIRECTED_FRAMES_RCV',0x00020208)
		win_const_mgr.add_const('CR_PROP_CAFORWARDCROSSCERT',0x00000023)
		win_const_mgr.add_const('MSG_MCAST',0x00000800)
		win_const_mgr.add_const('DIOCR_INSTALLER',0x00000001)
		win_const_mgr.add_const('BS_NULL',0x00000001)
		win_const_mgr.add_const('DBG_SEGLOAD',0x00000000)
		win_const_mgr.add_const('VK_NUMLOCK',0x00000090)
		win_const_mgr.add_const('INTERNET_STATUS_CLOSING_CONNECTION',0x00000032)
		win_const_mgr.add_const('D3DCAPS2_CANCALIBRATEGAMMA',0x00100000)
		win_const_mgr.add_const('DBPARAMTYPE_INPUTOUTPUT',0x00000002)
		win_const_mgr.add_const('OFFLINESTATUS_OFFLINE',0x00000001)
		win_const_mgr.add_const('TPM_RIGHTALIGN',0x00000008)
		win_const_mgr.add_const('SD_BOTH',0x00000002)
		win_const_mgr.add_const('DISPID_PROGRESSCHANGE',0x0000006C)
		win_const_mgr.add_const('ERROR_DRIVE_NOT_INSTALLED',0x00000008)
		win_const_mgr.add_const('CERT_INFO_NOT_BEFORE_FLAG',0x00000005)
		win_const_mgr.add_const('DSOP_FILTER_UNIVERSAL_GROUPS_SE',0x00000020)
		win_const_mgr.add_const('CREDUI_FLAGS_INCORRECT_PASSWORD',0x00000001)
		win_const_mgr.add_const('DISPID_SAX_XMLREADER__MAX',0x00010000)
		win_const_mgr.add_const('EVENT_SYSTEM_MOVESIZESTART',0x0000000A)
		win_const_mgr.add_const('USER_TIMER_MINIMUM',0x0000000A)
		win_const_mgr.add_const('SW_MINIMIZE',0x00000006)
		win_const_mgr.add_const('IPPORT_QOTD',0x00000011)
		win_const_mgr.add_const('OBJ_METAFILE',0x00000009)
		win_const_mgr.add_const('SUPPORTS_LOCAL',0x00000020)
		win_const_mgr.add_const('SQL_GD_ANY_COLUMN',0x00000001)
		win_const_mgr.add_const('CDO_E_INVALID_SEND_OPTION',0x80040220)
		win_const_mgr.add_const('SDP_ATTRIB_BROWSE_GROUP_LIST',0x00000005)
		win_const_mgr.add_const('EVENT_HEADER_EXT_TYPE_TS_ID',0x00000003)
		win_const_mgr.add_const('CM_GET_DEVICE_INTERFACE_LIST_BITS',0x00000001)
		win_const_mgr.add_const('ERROR_ACCOUNT_RESTRICTION',0x0000052F)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ',0x0000360C)
		win_const_mgr.add_const('SQL_NC_END',0x00000004)
		win_const_mgr.add_const('MIXERCONTROL_CT_CLASS_FADER',0x50000000)
		win_const_mgr.add_const('PD_PAGENUMS',0x00000002)
		win_const_mgr.add_const('TIME_TICKS',0x00000020)
		win_const_mgr.add_const('SMART_CMD',0x000000B0)
		win_const_mgr.add_const('LINECALLFEATURE_GATHERDIGITS',0x00000100)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INVALIDENCODING',0x000036F3)
		win_const_mgr.add_const('PFM_STARTINDENT',0x00000001)
		win_const_mgr.add_const('ERROR_DS_NO_CHECKPOINT_WITH_PDC',0x00002167)
		win_const_mgr.add_const('FTPWPP_ERROR_FIRST',0x40042300)
		win_const_mgr.add_const('WLAN_AVAILABLE_NETWORK_INCLUDE_ALL_MANUAL_HIDDEN_PROFILES',0x00000002)
		win_const_mgr.add_const('PRODUCT_ENTERPRISE',0x00000004)
		win_const_mgr.add_const('FLAGCOLOR_YELLOW',0x00000004)
		win_const_mgr.add_const('HH_HELP_CONTEXT',0x0000000F)
		win_const_mgr.add_const('MCI_DGV_RESERVE_IN',0x00010000)
		win_const_mgr.add_const('BTH_MFG_RTX_TELECOM',0x00000015)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_MINIPORT_INIT_PARAMETERS',0x00000081)
		win_const_mgr.add_const('MAX_PHYSADDR_SIZE',0x00000008)
		win_const_mgr.add_const('ERROR_DS_ENCODING_ERROR',0x0000203C)
		win_const_mgr.add_const('AE_ACLMODFAIL',0x00000013)
		win_const_mgr.add_const('DISPID_ACTIVEELMENTS_ITEM',0x00000000)
		win_const_mgr.add_const('MCI_OVLY_STATUS_STRETCH',0x00004002)
		win_const_mgr.add_const('NRC_SCLOSED',0x00000000)
		win_const_mgr.add_const('NCBSSTAT',0x00000034)
		win_const_mgr.add_const('DM_DISPLAYFREQUENCY',0x00400000)
		win_const_mgr.add_const('DDCREATE_HARDWAREONLY',0x00000001)
		win_const_mgr.add_const('REVEXT_CDPFTPURL_OLD',0x00000004)
		win_const_mgr.add_const('CSOUND_SYSTEM',0x00000010)
		win_const_mgr.add_const('BLACKONWHITE',0x00000001)
		win_const_mgr.add_const('DEBUG_CONNECT_SESSION_NO_ANNOUNCE',0x00000002)
		win_const_mgr.add_const('WLX_SAS_ACTION_UNLOCK_WKSTA',0x00000008)
		win_const_mgr.add_const('ERROR_TIMER_NOT_CANCELED',0x0000021D)
		win_const_mgr.add_const('MD_USER_ISOLATION_LAST',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_PPC_ADDR32NB',0x0000000A)
		win_const_mgr.add_const('CERT_STORE_REVOCATION_FLAG',0x00000004)
		win_const_mgr.add_const('WMSZ_BOTTOM',0x00000006)
		win_const_mgr.add_const('NDIS_CO_MAC_OPTION_DYNAMIC_LINK_SPEED',0x00000001)
		win_const_mgr.add_const('COMP_ELEM_NOSCROLL',0x00000008)
		win_const_mgr.add_const('WT_ADD_ACTION_ID_RET_RESULT_FLAG',0x00000001)
		win_const_mgr.add_const('CMSG_SIGNED_AND_ENVELOPED_FLAG',0x00000001)
		win_const_mgr.add_const('PERF_COUNTERSET_SINGLE_INSTANCE',0x00000000)
		win_const_mgr.add_const('INTERNET_RAS_INSTALLED',0x00000010)
		win_const_mgr.add_const('OQWF_PARAMISPROPERTYBAG',0x80000000)
		win_const_mgr.add_const('WARN_BASE',0x00000000)
		win_const_mgr.add_const('RASCCPCA_MPPC',0x00000006)
		win_const_mgr.add_const('RBHT_NOWHERE',0x00000001)
		win_const_mgr.add_const('IDM_SCROLL_LEFTEDGE',0x00000953)
		win_const_mgr.add_const('GESTURE_LEFT_ARROW_DOWN',0x00000000)
		win_const_mgr.add_const('ERROR_DS_AUX_CLS_TEST_FAIL',0x000020C5)
		win_const_mgr.add_const('CERT_RDN_VISIBLE_STRING',0x00000009)
		win_const_mgr.add_const('GCT_INVALID',0x00000000)
		win_const_mgr.add_const('DAOBINDING_CALLBACK',0x00000004)
		win_const_mgr.add_const('RTCEF_INTENSITY',0x00000040)
		win_const_mgr.add_const('NTDSDSA_OPT_DISABLE_OUTBOUND_REPL_OBJ',0x00000001)
		win_const_mgr.add_const('X3_BTYPE_QP_INST_WORD_POS_X',0x00000017)
		win_const_mgr.add_const('ADS_PRINTER_BUSY',0x00000200)
		win_const_mgr.add_const('DEBUG_EVENT_EXIT_THREAD',0x00000008)
		win_const_mgr.add_const('SM_CYDOUBLECLK',0x00000025)
		win_const_mgr.add_const('TPM_RETURNCMD',0x00000100)
		win_const_mgr.add_const('DFS_ADD_VOLUME',0x00000001)
		win_const_mgr.add_const('OLEUI_ERR_LPFNHOOKINVALID',0x0000006A)
		win_const_mgr.add_const('PBST_NORMAL',0x00000001)
		win_const_mgr.add_const('_WIN32_IE',0x00000501)
		win_const_mgr.add_const('MENU_EVENT',0x00000008)
		win_const_mgr.add_const('INTSERV_VERS_MASK',0x00000000)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_OPEN',0x0000000D)
		win_const_mgr.add_const('MAXIMUM_RID',0x0003FFFF)
		win_const_mgr.add_const('SI_EDIT_OWNER',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_XML_E_DUPLICATEATTRIBUTE',0x000036E5)
		win_const_mgr.add_const('IMAGE_REL_BASED_REL32',0x00000007)
		win_const_mgr.add_const('SESS_GUEST',0x00000001)
		win_const_mgr.add_const('DEBUG_EVENT_CHANGE_SYMBOL_STATE',0x00001000)
		win_const_mgr.add_const('WMDM_SCP_TRANSFER_OBJECTDATA',0x00000020)
		win_const_mgr.add_const('MAPI_SERVICE_UI_ALWAYS',0x00002000)
		win_const_mgr.add_const('WSAEPROTOTYPE',0x00002739)
		win_const_mgr.add_const('LSP_INSPECTOR',0x00000001)
		win_const_mgr.add_const('DEBUG_IOUTPUT_EVENT',0x10000000)
		win_const_mgr.add_const('DI_FLAGSEX_ALLOWEXCLUDEDDRVS',0x00000800)
		win_const_mgr.add_const('TVN_FIRST',0x00000000)
		win_const_mgr.add_const('SASL_OPTION_AUTHZ_PROCESSING',0x00000004)
		win_const_mgr.add_const('NANOSECONDS',0x00989680)
		win_const_mgr.add_const('PDH_MORE_DATA',0x800007D2)
		win_const_mgr.add_const('DS_CLOSEST_FLAG',0x00000080)
		win_const_mgr.add_const('LOCALE_SLONGDATE',0x00000020)
		win_const_mgr.add_const('AIF_NOLANGUAGECHECK',0x10000000)
		win_const_mgr.add_const('SPI_GETSPEECHRECOGNITION',0x0000104A)
		win_const_mgr.add_const('CONSOLE_CARET_SELECTION',0x00000001)
		win_const_mgr.add_const('GCT_WILD',0x00000004)
		win_const_mgr.add_const('KS_VBI_FLAG_MV_DETECTED',0x00000400)
		win_const_mgr.add_const('TMT_CONTENTALIGNMENT',0x00000FA6)
		win_const_mgr.add_const('BROADCAST_QUERY_DENY',0x424D5144)
		win_const_mgr.add_const('DS_FULL_SECRET_DOMAIN_6_FLAG',0x00001000)
		win_const_mgr.add_const('OBJ_BRUSH',0x00000002)
		win_const_mgr.add_const('MAPI_E_ATTACHMENT_OPEN_FAILURE',0x0000000C)
		win_const_mgr.add_const('KS_VBIDATARATE_CC',0x0007AEC5)
		win_const_mgr.add_const('IDM_COPYFORMAT',0x000008BD)
		win_const_mgr.add_const('DATA_SOURCE_LOGFILE',0x00000002)
		win_const_mgr.add_const('POLICY_QOS_DHCP_SERVER_ALLOWED',0x00000080)
		win_const_mgr.add_const('TIME_CALLBACK_FUNCTION',0x00000000)
		win_const_mgr.add_const('SECPKG_ATTR_PROTO_INFO',0x00000007)
		win_const_mgr.add_const('PHONESTATE_RINGVOLUME',0x00000100)
		win_const_mgr.add_const('DR_RW_LEN',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY',0x00003718)
		win_const_mgr.add_const('OFN_NOVALIDATE',0x00000100)
		win_const_mgr.add_const('HTNOWHERE',0x00000000)
		win_const_mgr.add_const('IME_RS_NOROOM',0x00000000)
		win_const_mgr.add_const('MAPI_ONE_OFF_UNICODE',0x00008000)
		win_const_mgr.add_const('EVENT_TRACE_NONSTOPPABLE_MODE',0x00000040)
		win_const_mgr.add_const('CERT_STORE_PROV_GET_CTL_PROPERTY_FUNC',0x00000016)
		win_const_mgr.add_const('PID_DICTIONARY',0x00000000)
		win_const_mgr.add_const('FRERR_FINDREPLACECODES',0x00004000)
		win_const_mgr.add_const('DAV_COLLECTION_STATUS',0x00004000)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_CREATOR_OWNER',0x80000100)
		win_const_mgr.add_const('TMT_CAPTIONMARGINS',0x00000E13)
		win_const_mgr.add_const('WNDT_NORMAL',0x00000000)
		win_const_mgr.add_const('CM_PROB_DISABLED_SERVICE',0x00000020)
		win_const_mgr.add_const('D3DSP_DSTMOD_MASK',0x00F00000)
		win_const_mgr.add_const('BLLI_L2_HDLC_ABM',0x0000000B)
		win_const_mgr.add_const('TF_SFT_LOWTRANSPARENCY',0x00000020)
		win_const_mgr.add_const('HTTP_QUERY_ECHO_HEADERS_CRLF',0x0000004A)
		win_const_mgr.add_const('DISPID_IADCCTL_PUBCAT',0x00000101)
		win_const_mgr.add_const('IPSEC_CIPHER_CONFIG_MAX',0x00000006)
		win_const_mgr.add_const('MCHT_TITLE',0x00010000)
		win_const_mgr.add_const('SQL_RD_ON',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_IA64_DIR64',0x00000005)
		win_const_mgr.add_const('GESTURE_DOWN_LEFT_LONG',0x00000000)
		win_const_mgr.add_const('OID_ATM_RCV_CELLS_OK',0x08020101)
		win_const_mgr.add_const('ATMPROTO_AAL2',0x00000002)
		win_const_mgr.add_const('SERVICE_IP_WAIT_TIME',0x0000FF00)
		win_const_mgr.add_const('CERT_COMPARE_MASK',0x0000FFFF)
		win_const_mgr.add_const('FAXDEVREPORTSTATUS_SIZE',0x00001000)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_ALLOW_TESTROOT_FLAG',0x00008000)
		win_const_mgr.add_const('D3DDEVCAPS2_ADAPTIVETESSNPATCH',0x00000008)
		win_const_mgr.add_const('POLICY_AUDIT_EVENT_UNCHANGED',0x00000000)
		win_const_mgr.add_const('DBT_APPYBEGIN',0x00000000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_ACCEPTTOALERT',0x00100000)
		win_const_mgr.add_const('CR_INVALID_ARBITRATOR',0x00000008)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_LOCATION',0x00000006)
		win_const_mgr.add_const('OID_CO_TAPI_DONT_REPORT_DIGITS',0xFE001009)
		win_const_mgr.add_const('PIR_STATUS_TABLE_SUCCESS',0x00000006)
		win_const_mgr.add_const('DEBUG_LOG_UNICODE',0x00000002)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_IS_INTER_SITE_AUTO_TOPOLOGY_DISABLED',0x00000001)
		win_const_mgr.add_const('PHONEERR_INVALHOOKSWITCHDEV',0x9000000F)
		win_const_mgr.add_const('CR_NO_MORE_RES_DES',0x0000000F)
		win_const_mgr.add_const('MH_KEEP',0x00000002)
		win_const_mgr.add_const('DEBUG_SYMENT_IS_CODE',0x00000001)
		win_const_mgr.add_const('SUBLANG_ARABIC_OMAN',0x00000008)
		win_const_mgr.add_const('DNS_TYPE_LOC',0x00000001)
		win_const_mgr.add_const('FILE_ACTION_RENAMED_NEW_NAME',0x00000005)
		win_const_mgr.add_const('DISPLAY_DEVICE_PRIMARY_DEVICE',0x00000004)
		win_const_mgr.add_const('DTBG_COMPUTINGREGION',0x00000010)
		win_const_mgr.add_const('OID_FDDI_PORT_CURRENT_PATH',0x03030260)
		win_const_mgr.add_const('ERROR_DS_CANT_RETRIEVE_SD',0x0000214E)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INVALID_HEXIDECIMAL',0x000036E0)
		win_const_mgr.add_const('SQL_PARAM_UNUSED',0x00000007)
		win_const_mgr.add_const('JOB_ACCESS_ADMINISTER',0x00000010)
		win_const_mgr.add_const('LINEERR_OPERATIONFAILED',0x80000048)
		win_const_mgr.add_const('ERROR_PAGE_FAULT_PAGING_FILE',0x000002EF)
		win_const_mgr.add_const('LINEERR_INVALDIGITMODE',0x80000027)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_VC1_D',0x000000A3)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_VC1_A',0x000000A0)
		win_const_mgr.add_const('PORT_RJE',0x00000005)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_VC1_C',0x000000A2)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_VC1_B',0x000000A1)
		win_const_mgr.add_const('BCPFILEFMT',0x0000000F)
		win_const_mgr.add_const('DBPROPVAL_HT_DIFFERENT_CATALOGS',0x00000001)
		win_const_mgr.add_const('KSAUDIO_STEREO_SPEAKER_GEOMETRY_WIDE',0x00000014)
		win_const_mgr.add_const('ERROR_DS_INVALID_LDAP_DISPLAY_NAME',0x0000211F)
		win_const_mgr.add_const('RPC_S_UNKNOWN_AUTHZ_SERVICE',0x000006D6)
		win_const_mgr.add_const('DISPID_IHTMLOPSPROFILE_ADDREQUEST',0x00000001)
		win_const_mgr.add_const('WINDOWS_BOOT',0x00000009)
		win_const_mgr.add_const('ICW_MAX_ACCTNAME',0x00000100)
		win_const_mgr.add_const('AUTHZ_ALLOW_MULTIPLE_SOURCE_INSTANCES',0x00000001)
		win_const_mgr.add_const('DNF_BASIC_DRIVER',0x00010000)
		win_const_mgr.add_const('BSF_MSGSRV32ISOK',0x80000000)
		win_const_mgr.add_const('ERROR_UNIDENTIFIED_ERROR',0x00000507)
		win_const_mgr.add_const('IS_TEXT_UNICODE_REVERSE_CONTROLS',0x00000040)
		win_const_mgr.add_const('OPPROGDLG_ALLOWUNDO',0x00000100)
		win_const_mgr.add_const('MAX_DEVICETYPE_NAME',0x00000010)
		win_const_mgr.add_const('SE_ERR_FNF',0x00000002)
		win_const_mgr.add_const('SD_SEND',0x00000001)
		win_const_mgr.add_const('V86FLAGS_PARITY',0x00000004)
		win_const_mgr.add_const('DNS_ERROR_DP_BASE',0x000026AC)
		win_const_mgr.add_const('SQL_DRIVER_HENV',0x00000004)
		win_const_mgr.add_const('VM_PAGE',0x00000009)
		win_const_mgr.add_const('MPEG_CAT_PID',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_GENERIC_S',0x00008015)
		win_const_mgr.add_const('ERROR_DS_ATT_IS_NOT_ON_OBJ',0x00002076)
		win_const_mgr.add_const('WHITEBALANCE_FLORESCENT',0x00000005)
		win_const_mgr.add_const('SM_MOUSEWHEELPRESENT',0x0000004B)
		win_const_mgr.add_const('IDC_EL_LINKTYPE',0x000000D9)
		win_const_mgr.add_const('MAX_BATTERY_STRING_SIZE',0x00000080)
		win_const_mgr.add_const('TOKEN_MANDATORY_POLICY_NO_WRITE_UP',0x00000001)
		win_const_mgr.add_const('STATE_SYSTEM_UNAVAILABLE',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_SECTION_MAX',0x0000FEFF)
		win_const_mgr.add_const('VARCMP_EQ',0x00000001)
		win_const_mgr.add_const('MCI_DGV_INFO_AUDIO_ALG',0x00004004)
		win_const_mgr.add_const('MCI_VCR_CUE_OUTPUT',0x00020000)
		win_const_mgr.add_const('RBBS_USECHEVRON',0x00000200)
		win_const_mgr.add_const('XA_OK',0x00000000)
		win_const_mgr.add_const('UINT_MAX',0x00000000)
		win_const_mgr.add_const('_FACDD',0x00000876)
		win_const_mgr.add_const('PHOTO_METERINGMODE_SPOT',0x00000003)
		win_const_mgr.add_const('LVA_ALIGNLEFT',0x00000001)
		win_const_mgr.add_const('HHWIN_BUTTON_HISTORY',0x00000001)
		win_const_mgr.add_const('STGM_CONVERT',0x00020000)
		win_const_mgr.add_const('UNISP_RPC_ID',0x0000000E)
		win_const_mgr.add_const('LINEERR_DISCONNECTED',0x00000000)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_HUNG',0x00000006)
		win_const_mgr.add_const('TSPI_MESSAGE_BASE',0x000001F4)
		win_const_mgr.add_const('WMS_STREAM_MAX_BITRATE',0x00000002)
		win_const_mgr.add_const('DDBLT_ALPHADESTCONSTOVERRIDE',0x00000002)
		win_const_mgr.add_const('WINHTTP_AUTOLOGON_SECURITY_LEVEL_HIGH',0x00000002)
		win_const_mgr.add_const('MCI_DGV_PUT_FRAME',0x00080000)
		win_const_mgr.add_const('ERROR_LOG_FULL_HANDLER_IN_PROGRESS',0x000019EE)
		win_const_mgr.add_const('ONE5STOPBITS',0x00000001)
		win_const_mgr.add_const('PORT_SNMPTRAP',0x000000A2)
		win_const_mgr.add_const('INTERNET_SERVICE_HTTP',0x00000003)
		win_const_mgr.add_const('OR_INVALID_SET',0x00000778)
		win_const_mgr.add_const('PARTITION_HUGE',0x00000006)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_500',0x801901F4)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_1BYTES',0x00100000)
		win_const_mgr.add_const('DEBUG_FILTER_EXIT_THREAD',0x00000001)
		win_const_mgr.add_const('TMT_FROMHUE4',0x0000070C)
		win_const_mgr.add_const('SECPKG_ATTR_CC_POLICY_RESULT',0x00000061)
		win_const_mgr.add_const('FILE_DEVICE_VDM',0x00000002)
		win_const_mgr.add_const('TBSTYLE_SEP',0x00000001)
		win_const_mgr.add_const('GETTECHNOLGY',0x00000014)
		win_const_mgr.add_const('MD_ERROR_SUB401_LOGON_CONFIG',0x00000002)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_503',0x801901F7)
		win_const_mgr.add_const('ERROR_INVALID_INDEX',0x00000585)
		win_const_mgr.add_const('QUERY_ACTCTX_FLAG_USE_ACTIVE_ACTCTX',0x00000004)
		win_const_mgr.add_const('SPI_GETCLEARTYPE',0x00001048)
		win_const_mgr.add_const('DFC_SCROLL',0x00000003)
		win_const_mgr.add_const('PS2',0x00000004)
		win_const_mgr.add_const('PS3',0x00000008)
		win_const_mgr.add_const('PS0',0x00000001)
		win_const_mgr.add_const('DSQPF_HASCREDENTIALS',0x00000020)
		win_const_mgr.add_const('PICTYPE_NONE',0x00000000)
		win_const_mgr.add_const('PS4',0x00000010)
		win_const_mgr.add_const('MCI_DGV_STATUS_WINDOW_MINIMIZED',0x00004022)
		win_const_mgr.add_const('DCI_STATUS_POINTERCHANGED',0x00000001)
		win_const_mgr.add_const('PD_ENABLESETUPTEMPLATEHANDLE',0x00020000)
		win_const_mgr.add_const('LCMAP_FULLWIDTH',0x00800000)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_MINI_PROCESS_1',0x0000000B)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_MINI_PROCESS_2',0x0000000C)
		win_const_mgr.add_const('LINECALLREASON_UNPARK',0x00000020)
		win_const_mgr.add_const('LVGMF_BORDERSIZE',0x00000001)
		win_const_mgr.add_const('DXVA_FILM_GRAIN_SYNTHESIS_FUNCTION',0x00000006)
		win_const_mgr.add_const('DI_PROPS_NOCHANGEUSAGE',0x20000000)
		win_const_mgr.add_const('MCI_OVLY_WHERE_VIDEO',0x00100000)
		win_const_mgr.add_const('SPI_SETACTIVEWNDTRKZORDER',0x0000100D)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_SECAM',0x00004004)
		win_const_mgr.add_const('LINECALLINFOSTATE_MONITORMODES',0x08000000)
		win_const_mgr.add_const('ERROR_SERVICE_MARKED_FOR_DELETE',0x00000430)
		win_const_mgr.add_const('VK_OEM_COMMA',0x000000BC)
		win_const_mgr.add_const('PRINTER_STATUS_OUTPUT_BIN_FULL',0x00000800)
		win_const_mgr.add_const('FC_PIPE_HAS_RANGE',0x00000020)
		win_const_mgr.add_const('DM_PAPERWIDTH',0x00000008)
		win_const_mgr.add_const('MQMSG_DEADLETTER',0x00000001)
		win_const_mgr.add_const('PCMCIA_OPT_NO_AUDIO',0x00000010)
		win_const_mgr.add_const('MS_DSR_ON',0x00000020)
		win_const_mgr.add_const('WININET_API_FLAG_ASYNC',0x00000001)
		win_const_mgr.add_const('SQL_ISV_SCHEMATA',0x00002000)
		win_const_mgr.add_const('RASLCPO_AES_256',0x00000040)
		win_const_mgr.add_const('WINEFS_SETUSERKEY_BLOCK_CACHE_FLUSH',0x00000002)
		win_const_mgr.add_const('MCIWNDF_NOPLAYBAR',0x00000002)
		win_const_mgr.add_const('IDM_UNLINK',0x0000084D)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_LOGICALDISK',0x0000000C)
		win_const_mgr.add_const('BTH_MFG_MICROSOFT',0x00000006)
		win_const_mgr.add_const('MCI_DGV_INFO_STILL_ALG',0x00004005)
		win_const_mgr.add_const('MPEG_TSDT_PID',0x00000002)
		win_const_mgr.add_const('FEI_FAXSVC_ENDED',0x00000014)
		win_const_mgr.add_const('PREDICTIVE_SERV',0x00000003)
		win_const_mgr.add_const('TMT_TOHUE1',0x0000070E)
		win_const_mgr.add_const('ACM_DRIVERPRIORITYF_BEGIN',0x00010000)
		win_const_mgr.add_const('LINEADDRFEATURE_MAKECALL',0x00000002)
		win_const_mgr.add_const('WMDM_STORAGECONTROL_INSERTINTO',0x00000800)
		win_const_mgr.add_const('SCRIPTINTERRUPT_DEBUG',0x00000001)
		win_const_mgr.add_const('SO_PAP_SET_SERVER_STATUS',0x0000A007)
		win_const_mgr.add_const('WIA_DATA_RAW_RGB',0x00000006)
		win_const_mgr.add_const('DISPID_SEARCHCOMMAND_ABORT',0x00000003)
		win_const_mgr.add_const('FILE_SUPPORTS_SPARSE_FILES',0x00000040)
		win_const_mgr.add_const('SFVM_UNMERGEMENU',0x0000001C)
		win_const_mgr.add_const('DM_PELSWIDTH',0x00080000)
		win_const_mgr.add_const('HCF_INDICATOR',0x00000020)
		win_const_mgr.add_const('OFS_MAXPATHNAME',0x00000080)
		win_const_mgr.add_const('MMIO_DELETE',0x00000200)
		win_const_mgr.add_const('SS_LEFTNOWORDWRAP',0x0000000C)
		win_const_mgr.add_const('WIA_PAGE_ISO_C4',0x00000020)
		win_const_mgr.add_const('WIA_PAGE_ISO_C5',0x00000021)
		win_const_mgr.add_const('WIA_PAGE_ISO_C6',0x00000022)
		win_const_mgr.add_const('WIA_PAGE_ISO_C7',0x00000023)
		win_const_mgr.add_const('MSIM_DISPID_ONINVITECONTACT',0x00000E10)
		win_const_mgr.add_const('WIA_PAGE_ISO_C1',0x0000001D)
		win_const_mgr.add_const('WIA_PAGE_ISO_C2',0x0000001E)
		win_const_mgr.add_const('WIA_PAGE_ISO_C3',0x0000001F)
		win_const_mgr.add_const('GESTURE_BRACKET_LEFT',0x00000000)
		win_const_mgr.add_const('FD_ROUTING_INTERFACE_CHANGE_BIT',0x00000008)
		win_const_mgr.add_const('WIA_PAGE_ISO_C8',0x00000024)
		win_const_mgr.add_const('WIA_PAGE_ISO_C9',0x00000025)
		win_const_mgr.add_const('NET_IF_OPER_STATUS_DORMANT_PAUSED',0x00000004)
		win_const_mgr.add_const('CF_PENDATA',0x0000000A)
		win_const_mgr.add_const('SYMFLAG_FUNCTION',0x00000800)
		win_const_mgr.add_const('DIF_PROPERTIES',0x00000004)
		win_const_mgr.add_const('DIIRFLAG_NOBACKUP',0x00000010)
		win_const_mgr.add_const('CBN_EDITUPDATE',0x00000006)
		win_const_mgr.add_const('CERT_OCSP_RESPONSE_PROP_ID',0x00000046)
		win_const_mgr.add_const('MCI_OVLY_WHERE_SOURCE',0x00020000)
		win_const_mgr.add_const('OID_FFP_CONTROL',0xFC010212)
		win_const_mgr.add_const('DEBUG_ENGOPT_DISABLE_MODULE_SYMBOL_LOAD',0x00008000)
		win_const_mgr.add_const('DBPROPVAL_STGM_FAILIFTHERE',0x00080000)
		win_const_mgr.add_const('IR_DBCSCHAR',0x00000160)
		win_const_mgr.add_const('DS_REPUPD_ADD_REFERENCE',0x00000004)
		win_const_mgr.add_const('ACCESS_AUDIT',0x00000001)
		win_const_mgr.add_const('SF_NOTIFY_PREPROC_HEADERS',0x00004000)
		win_const_mgr.add_const('SELECTPAPERSOURCE',0x00000012)
		win_const_mgr.add_const('MCI_SET_AUDIO_ALL',0x00000000)
		win_const_mgr.add_const('TBS_RIGHT',0x00000000)
		win_const_mgr.add_const('WSA_QOS_ESHAPERATEOBJ',0x00002B16)
		win_const_mgr.add_const('DXVA_NUM_TYPES_COMP_BUFFERS',0x00000012)
		win_const_mgr.add_const('WIA_IPS_BRIGHTNESS',0x0000180A)
		win_const_mgr.add_const('CI_STATE_HIGH_CPU',0x00020000)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_VALUE',0x01000000)
		win_const_mgr.add_const('IMAPI2_DEFAULT_COMMAND_TIMEOUT',0x0000000A)
		win_const_mgr.add_const('ERROR_STOPPED_ON_SYMLINK',0x000002A9)
		win_const_mgr.add_const('PSH_HASHELP',0x00000200)
		win_const_mgr.add_const('KSAC3_SERVICE_VOICE_OVER',0x00000007)
		win_const_mgr.add_const('REG_OPTION_OPEN_LINK',0x00000008)
		win_const_mgr.add_const('ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME',0x00003B04)
		win_const_mgr.add_const('PFD_TYPE_RGBA',0x00000000)
		win_const_mgr.add_const('INTERNET_OPTION_IDN',0x00000066)
		win_const_mgr.add_const('NDIS_ETH_TYPE_ARP',0x00000806)
		win_const_mgr.add_const('JOYERR_NOERROR',0x00000000)
		win_const_mgr.add_const('AW_HOR_NEGATIVE',0x00000002)
		win_const_mgr.add_const('ARCONTENT_BLURAY',0x00004000)
		win_const_mgr.add_const('MEM_PRIVATE',0x00020000)
		win_const_mgr.add_const('LOCKP_USER_MASK',0x00000003)
		win_const_mgr.add_const('FOCUSMETERING_CENTERSPOT',0x00000001)
		win_const_mgr.add_const('WTS_EVENT_LOGOFF',0x00000040)
		win_const_mgr.add_const('SCARD_T1_MAX_IFS',0x000000FE)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_ACKDUP',0x00000016)
		win_const_mgr.add_const('TVS_EX_DIMMEDCHECKBOXES',0x00000200)
		win_const_mgr.add_const('PRINTACTION_PROPERTIES',0x00000001)
		win_const_mgr.add_const('MIM_MAXHEIGHT',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_PPC_ADDR24',0x00000003)
		win_const_mgr.add_const('DDSCAPS2_NOTUSERLOCKABLE',0x00400000)
		win_const_mgr.add_const('LINEADDRFEATURE_SETTERMINAL',0x00000010)
		win_const_mgr.add_const('D3DLOCK_NO_DIRTY_UPDATE',0x00008000)
		win_const_mgr.add_const('LINEERR_RATEUNAVAIL',0x8000004A)
		win_const_mgr.add_const('ERROR_SXS_XML_E_MISSINGQUOTE',0x000036CE)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_409',0x80190199)
		win_const_mgr.add_const('INTERNET_CONNECTION_PROXY',0x00000004)
		win_const_mgr.add_const('EC_RIGHTMARGIN',0x00000002)
		win_const_mgr.add_const('WMI_GUIDTYPE_TRACE',0x00000001)
		win_const_mgr.add_const('SQL_SC_SQL92_FULL',0x00000008)
		win_const_mgr.add_const('SQL_CA_CONSTRAINT_DEFERRABLE',0x00000040)
		win_const_mgr.add_const('CLFS_FLAG_READ_IN_PROGRESS',0x00000080)
		win_const_mgr.add_const('DDSD_REFRESHRATE',0x00040000)
		win_const_mgr.add_const('WIA_DPC_CAPTURE_MODE',0x00000821)
		win_const_mgr.add_const('DISKQUOTA_USER_ACCOUNT_UNRESOLVED',0x00000005)
		win_const_mgr.add_const('DDF_SAME_HDC',0x00000004)
		win_const_mgr.add_const('ICM_REGISTERICMATCHER',0x00000005)
		win_const_mgr.add_const('PARTITION_LDM',0x00000042)
		win_const_mgr.add_const('PHONEFEATURE_GETGAINHANDSET',0x00000008)
		win_const_mgr.add_const('IDM_MENUEXT_LAST__',0x00000E94)
		win_const_mgr.add_const('MMIO_DEFAULTBUFFER',0x00002000)
		win_const_mgr.add_const('SERVICE_ACCEPT_HARDWAREPROFILECHANGE',0x00000020)
		win_const_mgr.add_const('DSBI_DONTSIGNSEAL',0x02000000)
		win_const_mgr.add_const('WIA_DPS_DOCUMENT_HANDLING_CAPACITY',0x00000C11)
		win_const_mgr.add_const('ERROR_DS_DUP_OID',0x000020BB)
		win_const_mgr.add_const('DDBLT_EXTENDED_FLAGS',0x40000000)
		win_const_mgr.add_const('SQL_ISV_CHARACTER_SETS',0x00000002)
		win_const_mgr.add_const('DRM_LICENSE_STATE_TYPES_DEFINED',0x00000001)
		win_const_mgr.add_const('FILE_PREFETCH_TYPE_FOR_DIRENUM',0x00000002)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_UNKNOWN',0x00000000)
		win_const_mgr.add_const('DXVA_EXECUTE_RETURN_DATA_ERROR_SIGNIF',0x00000002)
		win_const_mgr.add_const('IN_CLASSC_HOST',0x00000000)
		win_const_mgr.add_const('WSA_QOS_SENDERS',0x00002AFE)
		win_const_mgr.add_const('HCF_CONFIRMHOTKEY',0x00000008)
		win_const_mgr.add_const('CDO_E_AUTHENTICATION_FAILURE',0x80040215)
		win_const_mgr.add_const('D3DCONVOLUTIONMONO_MAXWIDTH',0x00000007)
		win_const_mgr.add_const('PIDDSI_HIDDENCOUNT',0x00000009)
		win_const_mgr.add_const('URLACTION_SCRIPT_SAFE_ACTIVEX',0x00001405)
		win_const_mgr.add_const('PARTITION_OS2BOOTMGR',0x0000000A)
		win_const_mgr.add_const('_RICHEDIT_VER',0x00000300)
		win_const_mgr.add_const('SQL_PARC_NO_BATCH',0x00000002)
		win_const_mgr.add_const('DRIVE_FIXED',0x00000003)
		win_const_mgr.add_const('HP_HASHVAL',0x00000002)
		win_const_mgr.add_const('OID_FFP_DATA',0xFC010214)
		win_const_mgr.add_const('DLCTL_DLIMAGES',0x00000010)
		win_const_mgr.add_const('LINETOLLLISTOPTION_ADD',0x00000001)
		win_const_mgr.add_const('BTH_ERROR_HARDWARE_FAILURE',0x00000003)
		win_const_mgr.add_const('RBBIM_SIZE',0x00000040)
		win_const_mgr.add_const('URLACTION_SHELL_EXECUTE_LOWRISK',0x00001808)
		win_const_mgr.add_const('SS_ENHMETAFILE',0x0000000F)
		win_const_mgr.add_const('DMPAPER_JENV_KAKU2',0x00000047)
		win_const_mgr.add_const('DBT_APPYEND',0x00000001)
		win_const_mgr.add_const('IT_STATUS_PROCESSING_DATA',0x00000002)
		win_const_mgr.add_const('WINHTTP_DISABLE_PASSPORT_KEYRING',0x20000000)
		win_const_mgr.add_const('OBM_RGARROWD',0x00007FE5)
		win_const_mgr.add_const('TCP_ATMARK',0x00000008)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_404',0x80190194)
		win_const_mgr.add_const('TMT_SIZINGBORDERWIDTH',0x000004B1)
		win_const_mgr.add_const('ASC_RET_SEQUENCE_DETECT',0x00000008)
		win_const_mgr.add_const('IF_TYPE_A12MPPSWITCH',0x00000082)
		win_const_mgr.add_const('WIA_DPS_FIRST',0x00000C02)
		win_const_mgr.add_const('SAVE_ATTRIBUTE_VALUES',0x000000D3)
		win_const_mgr.add_const('SCARD_PROVIDER_PRIMARY',0x00000001)
		win_const_mgr.add_const('NDIS_LINK_STATE_DUPLEX_AUTO_NEGOTIATED',0x00000004)
		win_const_mgr.add_const('WMDM_POWER_PERCENT_AVAILABLE',0x00000010)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_HIDDEN',0x00000020)
		win_const_mgr.add_const('DEBUG_VALUE_TYPES',0x0000000C)
		win_const_mgr.add_const('ERROR_UNKNOWN_REVISION',0x00000519)
		win_const_mgr.add_const('SCH_MACHINE_CERT_HASH',0x00000001)
		win_const_mgr.add_const('FLG_ADDREG_64BITKEY',0x00001000)
		win_const_mgr.add_const('RPC_S_SERVER_UNAVAILABLE',0x000006BA)
		win_const_mgr.add_const('DS_IS_DNS_NAME',0x00020000)
		win_const_mgr.add_const('MKF_HOTKEYSOUND',0x00000010)
		win_const_mgr.add_const('TMT_APPWORKSPACE',0x0000064D)
		win_const_mgr.add_const('SMTO_ABORTIFHUNG',0x00000002)
		win_const_mgr.add_const('ERROR_BAD_FUNCTION_TABLE',0x0000022F)
		win_const_mgr.add_const('IMGTRANS_MASK',0x20000000)
		win_const_mgr.add_const('DDF_NOTKEYFRAME',0x00000400)
		win_const_mgr.add_const('CTRY_KYRGYZSTAN',0x000003E4)
		win_const_mgr.add_const('KERB_CHECKSUM_HMAC_SHA1_96_AES256',0x00000010)
		win_const_mgr.add_const('UF_SERVER_TRUST_ACCOUNT',0x00002000)
		win_const_mgr.add_const('D3DTEXOPCAPS_MODULATEINVALPHA_ADDCOLOR',0x00080000)
		win_const_mgr.add_const('URLACTION_ALLOW_APEVALUATION',0x00002301)
		win_const_mgr.add_const('QDI_SETDIBITS',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_SQL_NONE',0x00000000)
		win_const_mgr.add_const('D3DUSAGE_NONSECURE',0x00800000)
		win_const_mgr.add_const('WMDRM_CERTIFICATE_TYPE_V1',0x00000001)
		win_const_mgr.add_const('PORT_XNSCOURIER',0x000000A5)
		win_const_mgr.add_const('MDPROPVAL_MNF_MEDIAN',0x00000001)
		win_const_mgr.add_const('KERB_ETYPE_DES_CBC_MD5',0x00000003)
		win_const_mgr.add_const('SQLAOPSTDEVP',0x00000031)
		win_const_mgr.add_const('LUP_RETURN_VERSION',0x00000040)
		win_const_mgr.add_const('TRANSPORT_QUALITYOFSERVICE_PARMNUM',0x000000C9)
		win_const_mgr.add_const('BTH_ERROR_HOST_REJECTED_SECURITY_REASONS',0x00000000)
		win_const_mgr.add_const('OID_IP4_OFFLOAD_STATS',0xFC010209)
		win_const_mgr.add_const('CM_DRP_UNUSED2',0x00000007)
		win_const_mgr.add_const('CM_DRP_UNUSED0',0x00000004)
		win_const_mgr.add_const('CM_DRP_UNUSED1',0x00000006)
		win_const_mgr.add_const('SECURITY_FLAG_IGNORE_CERT_WRONG_USAGE',0x00000200)
		win_const_mgr.add_const('OID_GEN_PORT_AUTHENTICATION_PARAMETERS',0x0001020F)
		win_const_mgr.add_const('RPC_C_OPT_MQ_PRIORITY',0x00000002)
		win_const_mgr.add_const('CRYPT_OID_INFO_OID_GROUP_BIT_LEN_SHIFT',0x00000010)
		win_const_mgr.add_const('PID_CONTROLPANEL_CATEGORY',0x00000002)
		win_const_mgr.add_const('SNMPAPI_MODE_INVALID',0x00000010)
		win_const_mgr.add_const('POLICY_ERRV_NO_PRIVILEGES',0x00000032)
		win_const_mgr.add_const('ERROR_DS_INVALID_SEARCH_FLAG_TUPLE',0x000021B3)
		win_const_mgr.add_const('D3DPMISCCAPS_MRTINDEPENDENTBITDEPTHS',0x00040000)
		win_const_mgr.add_const('ACMFILTERCHOOSE_STYLEF_ENABLETEMPLATE',0x00000010)
		win_const_mgr.add_const('WIA_DPC_FOCUS_METERING',0x00000818)
		win_const_mgr.add_const('BTH_MFG_TOSHIBA',0x00000004)
		win_const_mgr.add_const('SQL_SCROLL_CONCURRENCY',0x0000002B)
		win_const_mgr.add_const('META_SCALEWINDOWEXT',0x00000410)
		win_const_mgr.add_const('PID_LASTPRINTED',0x0000000B)
		win_const_mgr.add_const('PRINT_DONTBOTHERUSER',0x00000001)
		win_const_mgr.add_const('ERROR_DATABASE_FULL',0x000010DA)
		win_const_mgr.add_const('DDCAPS_BLT',0x00000040)
		win_const_mgr.add_const('IMAGE_COMDAT_SELECT_ANY',0x00000002)
		win_const_mgr.add_const('ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING',0x0000211A)
		win_const_mgr.add_const('LANG_GREENLANDIC',0x00000006)
		win_const_mgr.add_const('D3DPRESENTFLAG_NOAUTOROTATE',0x00000020)
		win_const_mgr.add_const('RASTERCAPS',0x00000026)
		win_const_mgr.add_const('SYNCH_DATA_STORE_CALENDAR',0x00000003)
		win_const_mgr.add_const('SP_STOPBITS',0x00000008)
		win_const_mgr.add_const('MDM_V110_SPEED_1DOT2K',0x00000001)
		win_const_mgr.add_const('SIZE_MAXSHOW',0x00000003)
		win_const_mgr.add_const('TBNF_TEXT',0x00000002)
		win_const_mgr.add_const('ODBC_ERROR_USER_CANCELED',0x00000010)
		win_const_mgr.add_const('D3DPRESENTFLAG_UNPRUNEDMODE',0x00000040)
		win_const_mgr.add_const('TRANSACTION_MANAGER_CORRUPT_FOR_PROGRESS',0x00000020)
		win_const_mgr.add_const('FLASHW_CAPTION',0x00000001)
		win_const_mgr.add_const('LINEFORWARDMODE_UNCONDINTERNAL',0x00000002)
		win_const_mgr.add_const('SQL_CONVERT_INTERVAL_YEAR_MONTH',0x0000007C)
		win_const_mgr.add_const('VK_OEM_RESET',0x000000E9)
		win_const_mgr.add_const('ERROR_PAGE_FAULT_COPY_ON_WRITE',0x000002ED)
		win_const_mgr.add_const('MDM_HDLCPPP_ML_NONE',0x00000001)
		win_const_mgr.add_const('BSF_REGISTERASDROPTARGET',0x00000001)
		win_const_mgr.add_const('OPER_STATE_SLEEPING',0x00000003)
		win_const_mgr.add_const('REVEXT_CDPFILEURL_OLD',0x00000008)
		win_const_mgr.add_const('ERROR_NO_QUOTAS_FOR_ACCOUNT',0x00000516)
		win_const_mgr.add_const('ERROR_QUORUM_OWNER_ALIVE',0x000013AA)
		win_const_mgr.add_const('ERROR_INVALID_DRIVE',0x0000000F)
		win_const_mgr.add_const('MDM_PROTOCOLID_GPRS',0x00000008)
		win_const_mgr.add_const('SERVICE_UIC_M_NULL',0x00000000)
		win_const_mgr.add_const('USER_ACCOUNT_AUTO_LOCKED',0x00000400)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_PRINT_PROCESSOR',0x00000009)
		win_const_mgr.add_const('TF_IPP_CAPS_UIELEMENTENABLED',0x00000004)
		win_const_mgr.add_const('SCARD_READER_TYPE_SERIAL',0x00000001)
		win_const_mgr.add_const('ISR_CODE',0x00000000)
		win_const_mgr.add_const('CSIDL_COMMON_STARTUP',0x00000018)
		win_const_mgr.add_const('MCI_OVLY_OPEN_WS',0x00010000)
		win_const_mgr.add_const('DCI_CANOVERLAY',0x00010000)
		win_const_mgr.add_const('CLCTL_INTERNAL_SHIFT',0x00000014)
		win_const_mgr.add_const('REG_APP_HIVE',0x00000010)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2_DISCRECORDER',0x00000100)
		win_const_mgr.add_const('URLACTION_NETWORK_MIN',0x00001A00)
		win_const_mgr.add_const('BCP_FMT_COLLATION',0x00000006)
		win_const_mgr.add_const('DRIVE_CDROM',0x00000005)
		win_const_mgr.add_const('DEBUG_CLASS_IMAGE_FILE',0x00000003)
		win_const_mgr.add_const('SQL_POSITIONED_STATEMENTS',0x00000050)
		win_const_mgr.add_const('LB_DST_MASK_LATE_FLAG',0x00000020)
		win_const_mgr.add_const('BM_SETDONTCLICK',0x000000F8)
		win_const_mgr.add_const('STACK_SIZE_PARAM_IS_A_RESERVATION',0x00010000)
		win_const_mgr.add_const('LINEMEDIACONTROL_START',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_I386_REL16',0x00000002)
		win_const_mgr.add_const('CMC_STATUS_PENDING',0x00000003)
		win_const_mgr.add_const('REQDISP_MASK',0x00000000)
		win_const_mgr.add_const('SEARCH_ALT_NO_SEQ',0x00000006)
		win_const_mgr.add_const('IPPORT_SMTP',0x00000019)
		win_const_mgr.add_const('CMSG_CMS_SIGNER_INFO_PARAM',0x00000027)
		win_const_mgr.add_const('PRINTER_CHANGE_PRINTER',0x000000FF)
		win_const_mgr.add_const('CALENDAR_SHOWTIMEAS_OOF',0x00000003)
		win_const_mgr.add_const('LINEAGENTFEATURE_GETAGENTACTIVITYLIST',0x00000010)
		win_const_mgr.add_const('PORT_UNIFY',0x000000B5)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST0',0x00000048)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST1',0x00000049)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST2',0x0000004A)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST3',0x0000004B)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST4',0x0000004C)
		win_const_mgr.add_const('ISCSI_SECURITY_FLAG_IKE_IPSEC_ENABLED',0x00000002)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST6',0x0000004E)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST7',0x0000004F)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST8',0x00000050)
		win_const_mgr.add_const('IDM_OBJECTVERBLIST9',0x00000051)
		win_const_mgr.add_const('CONNDLG_HIDE_BOX',0x00000008)
		win_const_mgr.add_const('ERROR_SXS_MANIFEST_TOO_BIG',0x00003719)
		win_const_mgr.add_const('LVHT_EX_GROUP_BACKGROUND',0x80000000)
		win_const_mgr.add_const('MSDRM_CLIENT_ZONE',0x0000CF00)
		win_const_mgr.add_const('SBT_RTLREADING',0x00000400)
		win_const_mgr.add_const('CS_ENABLE',0x00000001)
		win_const_mgr.add_const('WSA_QOS_RECEIVERS',0x00002AFD)
		win_const_mgr.add_const('DEVPROP_TYPE_BYTE',0x00000003)
		win_const_mgr.add_const('LINEADDRESSSTATE_CAPSCHANGE',0x00000100)
		win_const_mgr.add_const('URLPOLICY_AUTHENTICATE_MUTUAL_ONLY',0x00030000)
		win_const_mgr.add_const('RPC_S_INTERFACE_NOT_EXPORTED',0x00000784)
		win_const_mgr.add_const('EXP_SPECIAL_FOLDER_SIG',0xA0000005)
		win_const_mgr.add_const('DMPAPER_A4_TRANSVERSE',0x00000037)
		win_const_mgr.add_const('WST_TVTUNER_CHANGE_END_TUNE',0x00002000)
		win_const_mgr.add_const('WMDM_FILE_CREATE_OVERWRITE',0x00100000)
		win_const_mgr.add_const('LINECALLFEATURE2_TRANSFERCONF',0x00000080)
		win_const_mgr.add_const('FWPM_NET_EVENT_KEYWORD_INBOUND_BCAST',0x00000002)
		win_const_mgr.add_const('ENABLE_SMART',0x000000D8)
		win_const_mgr.add_const('AVIF_HASINDEX',0x00000010)
		win_const_mgr.add_const('DR_PLM1',0x00000039)
		win_const_mgr.add_const('DR_PLM0',0x00000038)
		win_const_mgr.add_const('DR_PLM3',0x0000003B)
		win_const_mgr.add_const('DR_PLM2',0x0000003A)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_POWER_USERS',0x00000223)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_LONG',0x00000005)
		win_const_mgr.add_const('CDO_E_NO_PICKUP_DIR',0x80040222)
		win_const_mgr.add_const('CLUS_ACCESS_WRITE',0x00000002)
		win_const_mgr.add_const('FACILITY_SXS_ERROR_CODE',0x00000015)
		win_const_mgr.add_const('SQL_BRC_PROCEDURES',0x00000001)
		win_const_mgr.add_const('CR_PROP_CAXCHGCERTCHAIN',0x00000010)
		win_const_mgr.add_const('D3DUSAGE_POINTS',0x00000040)
		win_const_mgr.add_const('SV_ENABLEFCBOPENS_PARMNUM',0x0000021A)
		win_const_mgr.add_const('SYMFLAG_EXPORT',0x00000200)
		win_const_mgr.add_const('DEBUG_OUTPUT_SYMBOLS_NO_OFFSETS',0x00000002)
		win_const_mgr.add_const('RPC_S_NO_PROTSEQS',0x000006B7)
		win_const_mgr.add_const('HDFT_ISSTRING',0x00000000)
		win_const_mgr.add_const('NDW_INSTALLFLAG_PCMCIAMODE',0x00010000)
		win_const_mgr.add_const('JOY_BUTTON6',0x00000020)
		win_const_mgr.add_const('POLLPRI',0x00000400)
		win_const_mgr.add_const('DISPID_PROPERTYCHANGE',0x00000070)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_EXISTS',0x000013B0)
		win_const_mgr.add_const('MCI_AVI_SETVIDEO_DRAW_PROCEDURE',0x00008000)
		win_const_mgr.add_const('XA_RETRY',0x00000004)
		win_const_mgr.add_const('CLUSTER_INSTALLED',0x00000001)
		win_const_mgr.add_const('OID_CO_SIGNALING_ENABLED',0xFE000008)
		win_const_mgr.add_const('LINECALLPRIVILEGE_NONE',0x00000001)
		win_const_mgr.add_const('WAVEOUT_MAPPER_STATUS_DEVICE',0x00000000)
		win_const_mgr.add_const('KF_FLAG_NOT_PARENT_RELATIVE',0x00000200)
		win_const_mgr.add_const('SETKERNTRACK',0x00000302)
		win_const_mgr.add_const('FACILITY_MAXIMUM_VALUE',0x00000037)
		win_const_mgr.add_const('TC_SCROLLBLT',0x00010000)
		win_const_mgr.add_const('DISPID_INITIALIZED',0x00000004)
		win_const_mgr.add_const('PSH_USEPAGELANG',0x00200000)
		win_const_mgr.add_const('DMPAPER_LETTER_EXTRA_TRANSVERSE',0x00000038)
		win_const_mgr.add_const('LINECALLFEATURE_GENERATEDIGITS',0x00000200)
		win_const_mgr.add_const('CR_PROP_DELTACRLPUBLISHSTATUS',0x0000001F)
		win_const_mgr.add_const('HTTP_QUERY_RAW_HEADERS_CRLF',0x00000016)
		win_const_mgr.add_const('BATTERY_FLAG_CHARGING',0x00000008)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_NO_IMPERSONATION_LUID_VERIFY',0x00000040)
		win_const_mgr.add_const('ERROR_XML_ENCODING_MISMATCH',0x00003714)
		win_const_mgr.add_const('CAUSE_OPTION_UNAVAILABLE',0x0000003F)
		win_const_mgr.add_const('KS_DVD_SECTOR_NOT_PROTECTED',0x00000000)
		win_const_mgr.add_const('OCR_SIZEWE',0x00007F84)
		win_const_mgr.add_const('SM_CXSMICON',0x00000031)
		win_const_mgr.add_const('EMR_POLYPOLYGON16',0x0000005B)
		win_const_mgr.add_const('LB_DELETESTRING',0x00000182)
		win_const_mgr.add_const('SQL_CORRELATION_NAME',0x0000004A)
		win_const_mgr.add_const('ACTION_LOCKOUT',0x00000000)
		win_const_mgr.add_const('QOS_OBJECT_DS_CLASS',0x00000001)
		win_const_mgr.add_const('TMT_HEADING2FONT',0x00000328)
		win_const_mgr.add_const('PC_RESERVED',0x00000001)
		win_const_mgr.add_const('SQL_ATTR_PARAMS_PROCESSED_PTR',0x00000015)
		win_const_mgr.add_const('SDP_ATTRIB_HID_VIRTUAL_CABLE',0x00000204)
		win_const_mgr.add_const('IMAGE_REL_AMD64_SECREL7',0x0000000C)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_KEY_COLUMN_USAGE',0x00000007)
		win_const_mgr.add_const('MDPROPVAL_AU_UNKNOWN',0x00000002)
		win_const_mgr.add_const('IDM_SCROLL_RIGHT',0x00000958)
		win_const_mgr.add_const('WM_SETTEXT',0x0000000C)
		win_const_mgr.add_const('CR_PROP_CAPROPIDMAX',0x00000015)
		win_const_mgr.add_const('IF_TYPE_DIGITAL_WRAPPER_OVERHEAD_CHANNEL',0x000000BA)
		win_const_mgr.add_const('ETW_COUNTED_STRING_TYPE_VALUE',0x00000068)
		win_const_mgr.add_const('GOPHER_TYPE_INDEX_SERVER',0x00000080)
		win_const_mgr.add_const('WM_WININICHANGE',0x0000001A)
		win_const_mgr.add_const('NDIS_OPER_STATE_REVISION_1',0x00000001)
		win_const_mgr.add_const('D3DTSS_TCI_CAMERASPACEREFLECTIONVECTOR',0x00030000)
		win_const_mgr.add_const('CERT_STORE_PROV_SET_CTL_PROPERTY_FUNC',0x0000000C)
		win_const_mgr.add_const('IMAGE_REL_I386_TOKEN',0x0000000C)
		win_const_mgr.add_const('OID_GEN_DRIVER_VERSION',0x00010110)
		win_const_mgr.add_const('CA_NEGATIVE',0x00000001)
		win_const_mgr.add_const('AUDIT_TYPE_WMI',0x00000002)
		win_const_mgr.add_const('LVIM_AFTER',0x00000001)
		win_const_mgr.add_const('SQLAOPSUM',0x00000004)
		win_const_mgr.add_const('OFN_SHARENOWARN',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_FAR_EXTERNAL',0x00000044)
		win_const_mgr.add_const('ACMFILTERCHOOSE_STYLEF_INITTOFILTERSTRUCT',0x00000040)
		win_const_mgr.add_const('CORDLESS_EXTERNAL_NETWORK_CDMA',0x00000004)
		win_const_mgr.add_const('SV_VERSION_MINOR_PARMNUM',0x00000068)
		win_const_mgr.add_const('BTH_ERROR_REPEATED_ATTEMPTS',0x00000017)
		win_const_mgr.add_const('SECPKG_CALL_RECURSIVE',0x00000008)
		win_const_mgr.add_const('AUDIT_ALLOW_NO_PRIVILEGE',0x00000001)
		win_const_mgr.add_const('SACL_SECURITY_INFORMATION',0x00000008)
		win_const_mgr.add_const('RPC_P_ADDR_FORMAT_TCP_IPV6',0x00000002)
		win_const_mgr.add_const('PDH_FMT_ANSI',0x00000020)
		win_const_mgr.add_const('ERROR_CANNOT_DETECT_DRIVER_FAILURE',0x00000438)
		win_const_mgr.add_const('LVTVIF_FIXEDWIDTH',0x00000001)
		win_const_mgr.add_const('CM_DEVCAP_EJECTSUPPORTED',0x00000002)
		win_const_mgr.add_const('RF_ADD_ALL_INTERFACES',0x00000010)
		win_const_mgr.add_const('SQL_ODBC_SAG_CLI_CONFORMANCE',0x0000000C)
		win_const_mgr.add_const('MDPROPVAL_MOQ_SCHEMA_CUBE',0x00000004)
		win_const_mgr.add_const('LINEERR_INVALMEDIAMODE',0x8000002F)
		win_const_mgr.add_const('GMR_VISIBLE',0x00000000)
		win_const_mgr.add_const('MDM_SHIFT_HDLCPPP_ML',0x00000006)
		win_const_mgr.add_const('LANG_ICELANDIC',0x00000000)
		win_const_mgr.add_const('DDCAPS_ZBLTS',0x00100000)
		win_const_mgr.add_const('DEBUG_FILTER_CREATE_PROCESS',0x00000002)
		win_const_mgr.add_const('RPC_S_NO_INTERFACES',0x00000719)
		win_const_mgr.add_const('SQL_DRIVER_HDESC',0x00000087)
		win_const_mgr.add_const('AVI_INDEX_SUB_DEFAULT',0x00000000)
		win_const_mgr.add_const('FOCUSMODE_MANUAL',0x00000001)
		win_const_mgr.add_const('RPC_S_STRING_TOO_LONG',0x000006CF)
		win_const_mgr.add_const('DDSCAPS_STANDARDVGAMODE',0x40000000)
		win_const_mgr.add_const('VFN_LEN',0x00000013)
		win_const_mgr.add_const('CREATE_EVENT_INITIAL_SET',0x00000002)
		win_const_mgr.add_const('SCARD_E_SYSTEM_CANCELLED',0x80100012)
		win_const_mgr.add_const('REG_NOTIFY_CHANGE_LAST_SET',0x00000004)
		win_const_mgr.add_const('TT_PRIM_LINE',0x00000001)
		win_const_mgr.add_const('DNOBJECT_CTERM',0x0000002A)
		win_const_mgr.add_const('DDCKEYCAPS_SRCBLTYUV',0x00001000)
		win_const_mgr.add_const('TR_P',0x00000000)
		win_const_mgr.add_const('CRSWPP_SERVER_BINDING_INCOMPLETE',0xC0042206)
		win_const_mgr.add_const('HTTP_QUERY_USER_AGENT',0x00000027)
		win_const_mgr.add_const('MF_USECHECKBITMAPS',0x00000200)
		win_const_mgr.add_const('WSA_QOS_EFLOWDESC',0x00002B12)
		win_const_mgr.add_const('MCI_VCR_SIGNAL_AT',0x00010000)
		win_const_mgr.add_const('MAX_DOMAIN_NAME_LEN',0x00000080)
		win_const_mgr.add_const('CDRF_NOTIFYPOSTPAINT',0x00000010)
		win_const_mgr.add_const('CRYPT_MAC',0x00000020)
		win_const_mgr.add_const('GPO_OPEN_LOAD_REGISTRY',0x00000001)
		win_const_mgr.add_const('ILC_PERITEMMIRROR',0x00008000)
		win_const_mgr.add_const('SQL_CODE_TIME',0x00000002)
		win_const_mgr.add_const('SPI_GETMOUSEHOVERWIDTH',0x00000062)
		win_const_mgr.add_const('WMIREG_FLAG_EVENT_ONLY_GUID',0x00000040)
		win_const_mgr.add_const('PDH_LOG_CREATE_ALWAYS',0x00000002)
		win_const_mgr.add_const('ACM_DRIVERADDF_NAME',0x00000001)
		win_const_mgr.add_const('DISPID_TABLEPARAMS_CAPTION',0x00000005)
		win_const_mgr.add_const('CHANNEL_RC_NULL_DATA',0x00000010)
		win_const_mgr.add_const('ERROR_QUOTA_LIST_INCONSISTENT',0x0000026D)
		win_const_mgr.add_const('EV_PERR',0x00000200)
		win_const_mgr.add_const('DBPROPVAL_AO_SEQUENTIALSTORAGEOBJECTS',0x00000001)
		win_const_mgr.add_const('TMT_COLOR',0x000000CC)
		win_const_mgr.add_const('WM_HANDHELDLAST',0x0000035F)
		win_const_mgr.add_const('DDPF_STENCILBUFFER',0x00004000)
		win_const_mgr.add_const('STD_PRINTPRE',0x00000009)
		win_const_mgr.add_const('MD_ROOT_MAX_HISTORY_FILES',0x0000270B)
		win_const_mgr.add_const('PID_INTROTEXT',0x00000001)
		win_const_mgr.add_const('DEBUG_BREAKPOINT_ONE_SHOT',0x00000010)
		win_const_mgr.add_const('POLICY_QOS_RAS_SERVER_ALLOWED',0x00000040)
		win_const_mgr.add_const('ASSEMBLYINFO_FLAG_INSTALLED',0x00000001)
		win_const_mgr.add_const('COLOR_LUMSCROLL',0x000002BE)
		win_const_mgr.add_const('IFS_MBZ0',0x00000026)
		win_const_mgr.add_const('LUP_FLUSHCACHE',0x00001000)
		win_const_mgr.add_const('OLEUI_ERR_STRUCTURENULL',0x00000065)
		win_const_mgr.add_const('CRYPT_FLAG_IPSEC',0x00000010)
		win_const_mgr.add_const('WM_TABLET_FIRST',0x00000002)
		win_const_mgr.add_const('MCIWNDF_SHOWNAME',0x00000010)
		win_const_mgr.add_const('PP_KEYEXCHANGE_ALG',0x0000000E)
		win_const_mgr.add_const('CERT_AUTO_ENROLL_RETRY_PROP_ID',0x00000042)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SOURCE',0x00004009)
		win_const_mgr.add_const('OEM_CHARSET',0x000000FF)
		win_const_mgr.add_const('TTN_FIRST',0x00000000)
		win_const_mgr.add_const('TIME_MS',0x00000001)
		win_const_mgr.add_const('PAPS_CLEANUP',0x00000002)
		win_const_mgr.add_const('USER_MARSHAL_FC_BYTE',0x00000001)
		win_const_mgr.add_const('VIF_SHARINGVIOLATION',0x00000400)
		win_const_mgr.add_const('RPC_C_STATS_PKTS_OUT',0x00000003)
		win_const_mgr.add_const('ERROR_CLUSTER_NETINTERFACE_EXISTS',0x000013B6)
		win_const_mgr.add_const('VER_MINORVERSION',0x00000001)
		win_const_mgr.add_const('BCRYPT_RNG_INTERFACE',0x00000006)
		win_const_mgr.add_const('LINEADDRFEATURE_SETUPCONF',0x00000020)
		win_const_mgr.add_const('IOCTL_WMP_METADATA_ROUND_TRIP',0x00031504)
		win_const_mgr.add_const('OPTION_END',0x000000FF)
		win_const_mgr.add_const('AM_VIDEO_FLAG_FIELD1FIRST',0x00000004)
		win_const_mgr.add_const('MCI_DGV_STATUS_HWND',0x00004001)
		win_const_mgr.add_const('FILE_ATTRIBUTE_REPARSE_POINT',0x00000400)
		win_const_mgr.add_const('SQL_AD_OFF',0x00000000)
		win_const_mgr.add_const('IMR_CONFIRMRECONVERTSTRING',0x00000005)
		win_const_mgr.add_const('IME_CAND_RADICAL',0x00000004)
		win_const_mgr.add_const('FPS_SENDING',0x20000002)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_MASK',0x00F00000)
		win_const_mgr.add_const('FILE_WRITE_ATTRIBUTES',0x00000100)
		win_const_mgr.add_const('SSWF_TITLE',0x00000001)
		win_const_mgr.add_const('CERT_CONTEXT_REVOCATION_TYPE',0x00000001)
		win_const_mgr.add_const('LVCFMT_JUSTIFYMASK',0x00000003)
		win_const_mgr.add_const('PRODUCT_STORAGE_EXPRESS_SERVER',0x00000014)
		win_const_mgr.add_const('LPM_RESULT_DEFER',0x00000001)
		win_const_mgr.add_const('LINEADDRESSSTATE_INUSEONE',0x00000008)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_STREAM',0x00004006)
		win_const_mgr.add_const('SYNC_HANDLERTYPE_WEBSERVICES',0x00000004)
		win_const_mgr.add_const('CONVERT10_E_FIRST',0x800401C0)
		win_const_mgr.add_const('TMT_BTNHIGHLIGHT',0x00000655)
		win_const_mgr.add_const('SPDRP_CLASS',0x00000007)
		win_const_mgr.add_const('SERVICE_UNINSTALLED',0x00000000)
		win_const_mgr.add_const('ERROR_RM_METADATA_CORRUPT',0x00001A92)
		win_const_mgr.add_const('SQL_SG_USAGE_ON_DOMAIN',0x00000001)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2_USESTREAMINGWRITE12',0x00000101)
		win_const_mgr.add_const('ERROR_DS_DRA_OUT_OF_MEM',0x000020FE)
		win_const_mgr.add_const('COMP_ELEM_DIRTY',0x00000004)
		win_const_mgr.add_const('DISPID_GETDETAILSSTATE',0x00000013)
		win_const_mgr.add_const('KS_VBI_FLAG_MV_HARDWARE',0x00000200)
		win_const_mgr.add_const('SPI_GETBORDER',0x00000005)
		win_const_mgr.add_const('NSTYPE_WORKGROUP',0x00000008)
		win_const_mgr.add_const('DEBUG_OUTCTL_AMBIENT',0x00000000)
		win_const_mgr.add_const('PD_CAN_DRAW_DIB',0x00000001)
		win_const_mgr.add_const('ERROR_CRM_PROTOCOL_NOT_FOUND',0x00001A38)
		win_const_mgr.add_const('CERT_LOGOTYPE_GRAY_SCALE_IMAGE_INFO_CHOICE',0x00000001)
		win_const_mgr.add_const('ERROR_I24_UNCERTAIN_MEDIA',0x00000010)
		win_const_mgr.add_const('CAUSE_COND_UNKNOWN',0x00000000)
		win_const_mgr.add_const('GM_ADVANCED',0x00000002)
		win_const_mgr.add_const('TREE_SEC_INFO_RESET_KEEP_EXPLICIT',0x00000003)
		win_const_mgr.add_const('PKR_KEY',0x00000008)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYSHRINKXN',0x00100000)
		win_const_mgr.add_const('DNS_RTYPE_MX',0x00000000)
		win_const_mgr.add_const('THREAD_IMPERSONATE',0x00000100)
		win_const_mgr.add_const('PIDSI_ARTIST',0x00000002)
		win_const_mgr.add_const('DNS_RTYPE_MR',0x00000900)
		win_const_mgr.add_const('DISPID_GETPERERRSTATE',0x00000015)
		win_const_mgr.add_const('IASSEMBLYCACHEITEM_COMMIT_FLAG_REFRESH',0x00000001)
		win_const_mgr.add_const('SCARD_F_COMM_ERROR',0x80100013)
		win_const_mgr.add_const('STAT_MISSING_PROP_IN_RELDOC',0x00000800)
		win_const_mgr.add_const('SW_MAXIMIZE',0x00000003)
		win_const_mgr.add_const('SUBSMGRENUM_MASK',0x00000001)
		win_const_mgr.add_const('DNS_RTYPE_MF',0x00000400)
		win_const_mgr.add_const('DNS_RTYPE_MG',0x00000800)
		win_const_mgr.add_const('DNS_RTYPE_MD',0x00000300)
		win_const_mgr.add_const('SV_MAXFREERFCBS_PARMNUM',0x00000243)
		win_const_mgr.add_const('PSD_ENABLEPAGESETUPHOOK',0x00002000)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MINFPYRAMIDALQUAD',0x00000800)
		win_const_mgr.add_const('FPSR_WRE0',0x00000007)
		win_const_mgr.add_const('FPSR_WRE3',0x0000002E)
		win_const_mgr.add_const('FPSR_WRE2',0x00000021)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_CONNECTION_OFFLOAD_DISABLED',0x00000001)
		win_const_mgr.add_const('ERROR_ENLISTMENT_NOT_SUPERIOR',0x00001AA4)
		win_const_mgr.add_const('DISKQUOTA_LOGFLAG_USER_THRESHOLD',0x00000001)
		win_const_mgr.add_const('DISPID_ONSTATUSBAR',0x00000101)
		win_const_mgr.add_const('TF_MOD_SHIFT',0x00000004)
		win_const_mgr.add_const('ERROR_DS_DRA_BAD_INSTANCE_TYPE',0x000020FD)
		win_const_mgr.add_const('GPO_BROWSE_NOUSERGPOS',0x00000020)
		win_const_mgr.add_const('DEBUG_MODULE_EXPLICIT',0x00000008)
		win_const_mgr.add_const('WEBPOST_ERROR_UNKNOWN',0xC0042101)
		win_const_mgr.add_const('WIA_DPS_TRANSPARENCY_CAPABILITIES',0x00000C22)
		win_const_mgr.add_const('VK_DBE_DBCSCHAR',0x00000000)
		win_const_mgr.add_const('DNS_RTYPE_AFSDB',0x00001200)
		win_const_mgr.add_const('LDAP_OPT_SECURITY_CONTEXT',0x00000099)
		win_const_mgr.add_const('FIND_OFFSET',0x00002000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAOEVENTARGS_CURRENTACTION',0x00000301)
		win_const_mgr.add_const('ISFB_STATE_NOSHOWTEXT',0x00000004)
		win_const_mgr.add_const('RPC_C_MGMT_INQ_PRINC_NAME',0x00000001)
		win_const_mgr.add_const('PP_KEYX_KEYSIZE_INC',0x00000023)
		win_const_mgr.add_const('INHERIT_ONLY',0x00000008)
		win_const_mgr.add_const('GUID_PRESENT',0x00000001)
		win_const_mgr.add_const('CERT_FILTER_KEY_EXISTS',0x00000020)
		win_const_mgr.add_const('PDH_FMT_DOUBLE',0x00000200)
		win_const_mgr.add_const('TMT_TRUESIZESCALINGTYPE',0x00000FAF)
		win_const_mgr.add_const('IPX_AUTO_STATIC_UPDATE',0x00000003)
		win_const_mgr.add_const('D3DPMISCCAPS_COLORWRITEENABLE',0x00000080)
		win_const_mgr.add_const('CM_DRP_CHARACTERISTICS',0x0000001C)
		win_const_mgr.add_const('META_SETVIEWPORTORG',0x0000020D)
		win_const_mgr.add_const('DEBUG_FILTER_DEBUGGEE_OUTPUT',0x00000009)
		win_const_mgr.add_const('UDS_HOTTRACK',0x00000100)
		win_const_mgr.add_const('HTTP_LOG_FIELD_BYTES_RECV',0x00002000)
		win_const_mgr.add_const('IGP_CONVERSION',0x00000008)
		win_const_mgr.add_const('SHDID_NET_SERVER',0x0000000E)
		win_const_mgr.add_const('GUID_STRING_SIZE',0x00000028)
		win_const_mgr.add_const('WLX_SAS_ACTION_SHUTDOWN_HIBERNATE',0x0000000E)
		win_const_mgr.add_const('IP_PKTINFO',0x00000013)
		win_const_mgr.add_const('ET_CREATOR',0x00008000)
		win_const_mgr.add_const('REG_NOTIFY_CHANGE_SECURITY',0x00000008)
		win_const_mgr.add_const('CERT_VALIDITY_NAME_CONSTRAINTS_FAILURE',0x00000040)
		win_const_mgr.add_const('LR_COLOR',0x00000002)
		win_const_mgr.add_const('DDSCAPS_PRIMARYSURFACE',0x00000200)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_REMOTE_JOB_ID',0x00000018)
		win_const_mgr.add_const('IME_CHOTKEY_IME_NONIME_TOGGLE',0x00000010)
		win_const_mgr.add_const('OID_ATM_ASSIGNED_VPI',0x08010202)
		win_const_mgr.add_const('LBN_SELCANCEL',0x00000003)
		win_const_mgr.add_const('LINEMEDIAMODE_INTERACTIVEVOICE',0x00000004)
		win_const_mgr.add_const('WMS_CONTAINER_DURATION_LO',0x00000004)
		win_const_mgr.add_const('WM_INITDIALOG',0x00000110)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_WRITECLIPBOARD',0x00000004)
		win_const_mgr.add_const('_A_NAME_IS_UTF',0x00000080)
		win_const_mgr.add_const('D3D10_SHADER_ENABLE_BACKWARDS_COMPATIBILITY',0x00000001)
		win_const_mgr.add_const('VIDCF_FASTTEMPORALC',0x00000020)
		win_const_mgr.add_const('VIDCF_FASTTEMPORALD',0x00000080)
		win_const_mgr.add_const('STDOLE_MAJORVERNUM',0x00000001)
		win_const_mgr.add_const('QITIPF_SINGLELINE',0x00000010)
		win_const_mgr.add_const('PORT_SQLNET',0x00000096)
		win_const_mgr.add_const('DNS_TYPE_PTR',0x00000000)
		win_const_mgr.add_const('BTH_MFG_INTERNAL_USE',0x0000FFFF)
		win_const_mgr.add_const('SF_NOTIFY_SEND_RESPONSE',0x00000040)
		win_const_mgr.add_const('PHYSICALOFFSETY',0x00000071)
		win_const_mgr.add_const('IMAGE_REL_IA64_PCREL21F',0x00000008)
		win_const_mgr.add_const('SECURITY_NATIVE_DREP',0x00000010)
		win_const_mgr.add_const('SDP_ATTRIB_SDP_DATABASE_STATE',0x00000201)
		win_const_mgr.add_const('DMPAPER_PENV_9',0x00000068)
		win_const_mgr.add_const('DDL_SYSTEM',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_IA64_PCREL21M',0x00000007)
		win_const_mgr.add_const('FILEOPENORDMOTIF',0x00002713)
		win_const_mgr.add_const('DMPAPER_PENV_6',0x00000065)
		win_const_mgr.add_const('TCP_NOURG',0x00000007)
		win_const_mgr.add_const('ILR_VERTICAL_CENTER',0x00000010)
		win_const_mgr.add_const('TMT_SATURATION',0x0000096D)
		win_const_mgr.add_const('OFN_SHAREWARN',0x00000000)
		win_const_mgr.add_const('EXTENSION_POLICY_MASK',0x00000000)
		win_const_mgr.add_const('RSC_PL',0x00000002)
		win_const_mgr.add_const('ENDPOINT_SYSFX_DISABLED',0x00000001)
		win_const_mgr.add_const('SHCNE_CREATE',0x00000002)
		win_const_mgr.add_const('DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION',0x0000255B)
		win_const_mgr.add_const('OID_TAPI_SEND_USER_USER_INFO',0x0703011C)
		win_const_mgr.add_const('WAVE_FILTER_ECHO',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_SHM_PAIR',0x00000018)
		win_const_mgr.add_const('SNMP_LOG_FATAL',0x00000001)
		win_const_mgr.add_const('WIA_ITEM_CAN_BE_DELETED',0x00000080)
		win_const_mgr.add_const('KERB_RETRIEVE_TICKET_USE_CREDHANDLE',0x00000004)
		win_const_mgr.add_const('LOGON_ZERO_PASSWORD_BUFFER',0x80000000)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_PLAYBACK',0x00000001)
		win_const_mgr.add_const('MCI_DEVTYPE_WAVEFORM_AUDIO',0x0000020A)
		win_const_mgr.add_const('CMC_FAIL_UNSUPORTED_EXT',0x00000005)
		win_const_mgr.add_const('DEBUG_SYSVERSTR_BUILD',0x00000001)
		win_const_mgr.add_const('PID_INTSITE_TRACKING',0x00000013)
		win_const_mgr.add_const('DMPAPER_PENV_3',0x00000062)
		win_const_mgr.add_const('PDH_MAX_COUNTER_PATH',0x00000800)
		win_const_mgr.add_const('RF_ARBITRARY_ANGLE',0x00000400)
		win_const_mgr.add_const('DISPID_SETSECURELOCKICON',0x0000010D)
		win_const_mgr.add_const('SCARD_E_UNEXPECTED',0x8010001F)
		win_const_mgr.add_const('MCI_VCR_SEEK_REVERSE',0x00010000)
		win_const_mgr.add_const('HIST_FAVORITES',0x00000002)
		win_const_mgr.add_const('KSWAVE_BUFFER_ATTRIBUTEF_STATIC',0x00000002)
		win_const_mgr.add_const('PORT_ANYRJE',0x0000004D)
		win_const_mgr.add_const('EMR_POLYBEZIERTO16',0x00000058)
		win_const_mgr.add_const('SUOI_INTERNAL1',0x00000002)
		win_const_mgr.add_const('NETLOGON_CONTROL_PDC_REPLICATE',0x00000004)
		win_const_mgr.add_const('WIA_PAGE_USLEDGER',0x00000004)
		win_const_mgr.add_const('PROTO_IPV6_DHCP',0x000003E7)
		win_const_mgr.add_const('ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND',0x000013B3)
		win_const_mgr.add_const('SBSP_INITIATEDBYHLINKFRAME',0x80000000)
		win_const_mgr.add_const('MQMSG_AUTH_LEVEL_MSMQ20',0x00000004)
		win_const_mgr.add_const('OFN_ALLOWMULTISELECT',0x00000200)
		win_const_mgr.add_const('DMPAPER_PENV_4_ROTATED',0x00000070)
		win_const_mgr.add_const('POWER_SYSTEM_MAXIMUM',0x00000007)
		win_const_mgr.add_const('COM_RIGHTS_EXECUTE_LOCAL',0x00000002)
		win_const_mgr.add_const('SQL_FETCH_DIRECTION',0x00000008)
		win_const_mgr.add_const('ACCESS_READ',0x00000001)
		win_const_mgr.add_const('LOCALE_SINTLSYMBOL',0x00000015)
		win_const_mgr.add_const('SMART_LOG_SECTOR_SIZE',0x00000200)
		win_const_mgr.add_const('TCS_SINGLELINE',0x00000000)
		win_const_mgr.add_const('SCOPE_FLAG_DEEP',0x00000002)
		win_const_mgr.add_const('SV_NUMADMIN_PARMNUM',0x00000196)
		win_const_mgr.add_const('DBPROP_MSREMOTE_CURRENT_DFMODE',0x00000002)
		win_const_mgr.add_const('EV_ERR',0x00000080)
		win_const_mgr.add_const('KS_DVD_NOT_COPYRIGHTED',0x00000000)
		win_const_mgr.add_const('SHGVSPB_ROAM',0x00000020)
		win_const_mgr.add_const('IDM_TABLESELECT',0x000008A1)
		win_const_mgr.add_const('CFM_LINK',0x00000020)
		win_const_mgr.add_const('WINEVENT_LEVEL_VERBOSE',0x00000005)
		win_const_mgr.add_const('SQL_CO_FFO',0x00000001)
		win_const_mgr.add_const('PSD_NONETWORKBUTTON',0x00200000)
		win_const_mgr.add_const('LDAP_RES_MODIFY',0x00000067)
		win_const_mgr.add_const('EAP_E_SERVER_ROOT_CERT_FIRST',0x80420400)
		win_const_mgr.add_const('PLA_CAPABILITY_LEGACY_SESSION',0x00000008)
		win_const_mgr.add_const('D3DTEXOPCAPS_BUMPENVMAPLUMINANCE',0x00400000)
		win_const_mgr.add_const('RPC_S_INVALID_NETWORK_OPTIONS',0x000006BC)
		win_const_mgr.add_const('FILE_VER_GET_LOCALISED',0x00000001)
		win_const_mgr.add_const('STATE_SYSTEM_ALERT_MEDIUM',0x08000000)
		win_const_mgr.add_const('TAPE_DRIVE_REVERSE_POSITION',0x80400000)
		win_const_mgr.add_const('ERROR_SXS_RELEASE_ACTIVATION_CONTEXT',0x00003708)
		win_const_mgr.add_const('TSF_ALLOW_DECRYPTION',0x00000004)
		win_const_mgr.add_const('SORT_CHINESE_BIG5',0x00000000)
		win_const_mgr.add_const('SPSVCINST_NOCLOBBER_ERRORCONTROL',0x00000020)
		win_const_mgr.add_const('MB_COMPOSITE',0x00000002)
		win_const_mgr.add_const('FWPM_AUTO_WEIGHT_BITS',0x0000003C)
		win_const_mgr.add_const('IO_REPARSE_TAG_SIS',0x80000007)
		win_const_mgr.add_const('D3DPBLENDCAPS_SRCALPHASAT',0x00000400)
		win_const_mgr.add_const('MCI_VCR_SETVIDEO_SOURCE',0x00020000)
		win_const_mgr.add_const('BCRYPTBUFFER_VERSION',0x00000000)
		win_const_mgr.add_const('SDP_ATTRIB_FAX_CLASS_2_SUPPORT',0x00000304)
		win_const_mgr.add_const('DOMAIN_LENGTH',0x00000011)
		win_const_mgr.add_const('RPC_C_BIND_TO_ALL_NICS',0x00000001)
		win_const_mgr.add_const('ALG_SID_RSA_PGP',0x00000004)
		win_const_mgr.add_const('VERTRES',0x0000000A)
		win_const_mgr.add_const('PRINTER_STATUS_PENDING_DELETION',0x00000004)
		win_const_mgr.add_const('WKSTA_DORMANTFILELIMIT_PARMNUM',0x0000002E)
		win_const_mgr.add_const('ERROR_PNP_RESTART_ENUMERATION',0x0000027C)
		win_const_mgr.add_const('TUISPIDLL_OBJECT_DIALOGINSTANCE',0x00000004)
		win_const_mgr.add_const('CHANGER_SERIAL_NUMBER_VALID',0x04000000)
		win_const_mgr.add_const('DEBUG_CDS_ALL',0x00000000)
		win_const_mgr.add_const('COOKIE_OP_SESSION',0x00000008)
		win_const_mgr.add_const('MCMV_MONTH',0x00000000)
		win_const_mgr.add_const('COMPRESSION_ENGINE_STANDARD',0x00000000)
		win_const_mgr.add_const('VK_NONCONVERT',0x0000001D)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_LOCAL_SERVICE',0x80040000)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_RESIZETO',0x00000009)
		win_const_mgr.add_const('MF_FLAGS_EVEN_IF_NO_RESOURCE',0x00000001)
		win_const_mgr.add_const('USN_SOURCE_DATA_MANAGEMENT',0x00000001)
		win_const_mgr.add_const('CB_MAX_DISK',0x00000007)
		win_const_mgr.add_const('EDITF_REQUESTEXTENSIONLIST',0x00000002)
		win_const_mgr.add_const('RTL_RUN_ONCE_INIT_FAILED',0x00000004)
		win_const_mgr.add_const('MIN_PRIORITY',0x00000001)
		win_const_mgr.add_const('CACHE_E_LAST',0x8004017F)
		win_const_mgr.add_const('CERT_PE_IMAGE_DIGEST_NON_PE_INFO',0x00000008)
		win_const_mgr.add_const('KERB_CHECKSUM_CRC32',0x00000001)
		win_const_mgr.add_const('IMC_SETCOMPOSITIONFONT',0x0000000A)
		win_const_mgr.add_const('TVC_UNKNOWN',0x00000000)
		win_const_mgr.add_const('SERVICE_RUNNING',0x00000004)
		win_const_mgr.add_const('PORT_HMMP_INDICATION',0x00000264)
		win_const_mgr.add_const('PARTID_MASK',0x00000000)
		win_const_mgr.add_const('SSRVOPT_PARAMTYPE',0x00000100)
		win_const_mgr.add_const('URLPOLICY_NOTIFY_ON_DISALLOW',0x00000020)
		win_const_mgr.add_const('CTRY_MOROCCO',0x000000D4)
		win_const_mgr.add_const('PDCAP_WAKE_FROM_S0_SUPPORTED',0x00100000)
		win_const_mgr.add_const('WMDM_STORAGECAP_FOLDERSINFOLDERS',0x00000004)
		win_const_mgr.add_const('WM_MENUSELECT',0x0000011F)
		win_const_mgr.add_const('DFCS_BUTTONRADIOMASK',0x00000002)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_LSOV1_DISABLED',0x00000001)
		win_const_mgr.add_const('DISPID_SEARCHCOMMAND_COMPLETE',0x00000002)
		win_const_mgr.add_const('MIXERCONTROL_CT_UNITS_MASK',0x00FF0000)
		win_const_mgr.add_const('AW_HOR_POSITIVE',0x00000001)
		win_const_mgr.add_const('DS_GFTI_VALID_FLAGS',0x00000001)
		win_const_mgr.add_const('PAN_FAMILY_PICTORIAL',0x00000005)
		win_const_mgr.add_const('OBM_DNARROW',0x00007FF0)
		win_const_mgr.add_const('GUI_POPUPMENUMODE',0x00000010)
		win_const_mgr.add_const('DBDTF_RETURNINBOUND',0x00000008)
		win_const_mgr.add_const('KEY_ENUMERATE_SUB_KEYS',0x00000008)
		win_const_mgr.add_const('D3D10_FTOU_INSTRUCTION_MIN_INPUT',0x00000000)
		win_const_mgr.add_const('TXTBIT_READONLY',0x00000004)
		win_const_mgr.add_const('ERROR_DS_INCORRECT_ROLE_OWNER',0x00002012)
		win_const_mgr.add_const('VER_PRERELEASE',0x00000000)
		win_const_mgr.add_const('HTTB_SIZINGTEMPLATE',0x00000100)
		win_const_mgr.add_const('ENLISTMENT_MAXIMUM_OPTION',0x00000001)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_XBOX',0x0000000E)
		win_const_mgr.add_const('TTS_CLOSE',0x00000080)
		win_const_mgr.add_const('IME_SMODE_CONVERSATION',0x00000010)
		win_const_mgr.add_const('PKR_WD',0x00000001)
		win_const_mgr.add_const('MIDICAPS_VOLUME',0x00000001)
		win_const_mgr.add_const('SQL_DIAG_DROP_TRANSLATION',0x00000021)
		win_const_mgr.add_const('CM_DEVICE_ICM',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_NEED_SECONDARY_ADDRESSES',0x0000258E)
		win_const_mgr.add_const('SERVICE_CONTROL_NETBINDREMOVE',0x00000008)
		win_const_mgr.add_const('OPTION_ROOT_DISK',0x00000011)
		win_const_mgr.add_const('PERF_TYPE_COUNTER',0x00000400)
		win_const_mgr.add_const('SHCNF_IDLIST',0x00000000)
		win_const_mgr.add_const('FACILITY_SECURITY',0x00000009)
		win_const_mgr.add_const('PROCESS_VM_READ',0x00000010)
		win_const_mgr.add_const('PF_RDTSC_INSTRUCTION_AVAILABLE',0x00000008)
		win_const_mgr.add_const('SECPKG_FLAG_INTEGRITY',0x00000001)
		win_const_mgr.add_const('IO_ALIAS_POSITIVE_DECODE',0x000000FF)
		win_const_mgr.add_const('ISCSI_LOGIN_FLAG_RESERVED1',0x00000004)
		win_const_mgr.add_const('SQL_EXPRESSIONS_IN_ORDERBY',0x0000001B)
		win_const_mgr.add_const('BSF_HTMLNAVCANCELED',0x00002000)
		win_const_mgr.add_const('COR_VTABLE_FROM_UNMANAGED_RETAIN_APPDOMAIN',0x00000008)
		win_const_mgr.add_const('LPV_MIN_PRIORITY',0x00000001)
		win_const_mgr.add_const('CAPTUREMODE_BURST',0x00000002)
		win_const_mgr.add_const('EVENT_OBJECT_LOCATIONCHANGE',0x0000800B)
		win_const_mgr.add_const('HSR_DOWNLOAD',0x00000010)
		win_const_mgr.add_const('EMR_TRANSPARENTBLT',0x00000074)
		win_const_mgr.add_const('DEBUG_TBINFO_TIMES',0x00000008)
		win_const_mgr.add_const('LINEMEDIACONTROL_RATEUP',0x00000020)
		win_const_mgr.add_const('VIF_CANNOTLOADLZ32',0x00080000)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_UNSTABLE',0x00000007)
		win_const_mgr.add_const('AUTO_PROXY_FLAG_DETECTION_RUN',0x00000004)
		win_const_mgr.add_const('ERROR_RESOURCE_DISABLED',0x000010D5)
		win_const_mgr.add_const('LINECALLINFOSTATE_DEVSPECIFIC',0x00000002)
		win_const_mgr.add_const('IP_OPT_EOL',0x00000000)
		win_const_mgr.add_const('HKL_PREV',0x00000000)
		win_const_mgr.add_const('HEAP_TAG_SHIFT',0x00000012)
		win_const_mgr.add_const('CERT_RDN_GRAPHIC_STRING',0x00000008)
		win_const_mgr.add_const('PDH_INVALID_DATA',0xC0000BC6)
		win_const_mgr.add_const('XP1_PSEUDO_STREAM',0x00000010)
		win_const_mgr.add_const('ERROR_DS_SCHEMA_ALLOC_FAILED',0x000020DF)
		win_const_mgr.add_const('CMSG_KEY_AGREE_ENCRYPT_FREE_MATERIAL_FLAG',0x00000002)
		win_const_mgr.add_const('IF_TYPE_AFLANE_8025',0x0000003C)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_OUTPUT',0x04000000)
		win_const_mgr.add_const('RPC_S_ENTRY_NOT_FOUND',0x000006E1)
		win_const_mgr.add_const('JOB_OBJECT_MSG_ACTIVE_PROCESS_LIMIT',0x00000003)
		win_const_mgr.add_const('SSRVACTION_EVENT',0x00000003)
		win_const_mgr.add_const('MEM_RELEASE',0x00008000)
		win_const_mgr.add_const('FILEOPENORD',0x00000600)
		win_const_mgr.add_const('IR_STRING',0x00000140)
		win_const_mgr.add_const('RASCCPCA_STAC',0x00000005)
		win_const_mgr.add_const('IDM_SHOWHIDE_CODE',0x000008BB)
		win_const_mgr.add_const('SECURITY_MAX_ALWAYS_FILTERED',0x000003E7)
		win_const_mgr.add_const('KSPRIORITY_EXCLUSIVE',0xFFFFFFFF)
		win_const_mgr.add_const('MDPROPVAL_MNF_RANK',0x00000008)
		win_const_mgr.add_const('IMPLINK_LOWEXPER',0x0000009C)
		win_const_mgr.add_const('DDBLT_ZBUFFER',0x00080000)
		win_const_mgr.add_const('METADATA_VOLATILE',0x00000010)
		win_const_mgr.add_const('SF_DENIED_APPLICATION',0x00000008)
		win_const_mgr.add_const('LVIR_SELECTBOUNDS',0x00000003)
		win_const_mgr.add_const('UISF_ACTIVE',0x00000004)
		win_const_mgr.add_const('CHANGER_DRIVE_CLEANING_REQUIRED',0x00010000)
		win_const_mgr.add_const('TXTBIT_EXTENTCHANGE',0x00080000)
		win_const_mgr.add_const('EMR_SETWINDOWORGEX',0x0000000A)
		win_const_mgr.add_const('SQL_ATTR_ASYNC_ENABLE',0x00000004)
		win_const_mgr.add_const('CFU_UNDERLINETHICKDASHDOTDOT',0x00000010)
		win_const_mgr.add_const('LANG_DIVEHI',0x00000065)
		win_const_mgr.add_const('IME_SMODE_PLAURALCLAUSE',0x00000001)
		win_const_mgr.add_const('TF_DICTATION_ON',0x00000001)
		win_const_mgr.add_const('CERT_EXTENDED_ERROR_INFO_PROP_ID',0x0000001E)
		win_const_mgr.add_const('PDH_FMT_UNICODE',0x00000040)
		win_const_mgr.add_const('MCIWNDF_NOOPEN',0x00008000)
		win_const_mgr.add_const('CMM_DESCRIPTION',0x00000005)
		win_const_mgr.add_const('ISC_REQ_CONNECTION',0x00000800)
		win_const_mgr.add_const('IDM_CREATELINK',0x000008F2)
		win_const_mgr.add_const('SCARD_W_UNPOWERED_CARD',0x80100067)
		win_const_mgr.add_const('LINE_GROUPSTATUS',0x0000001E)
		win_const_mgr.add_const('IMPORTANCE_LOW_MIN',0x00000000)
		win_const_mgr.add_const('CM_PROB_FAILED_START',0x0000000A)
		win_const_mgr.add_const('PIFNAMESIZE',0x0000001E)
		win_const_mgr.add_const('SI_ACCESS_PROPERTY',0x00080000)
		win_const_mgr.add_const('COD_SERVICE_MAX_COUNT',0x00000009)
		win_const_mgr.add_const('IME_CAND_CODE',0x00000002)
		win_const_mgr.add_const('DMPAPER_CSHEET',0x00000018)
		win_const_mgr.add_const('NS_NETDES',0x0000003C)
		win_const_mgr.add_const('MD_EXTLOG_HTTP_SUB_STATUS',0x00200000)
		win_const_mgr.add_const('DS_PDC_REQUIRED',0x00000080)
		win_const_mgr.add_const('OT_LINK',0x00000001)
		win_const_mgr.add_const('RTM_ROUTE_CHANGE_FIRST',0x00000001)
		win_const_mgr.add_const('ACCESS_FAIL_ACL',0x00000800)
		win_const_mgr.add_const('HCBT_MINMAX',0x00000001)
		win_const_mgr.add_const('STAT_SHARING_VIOLATION',0x00000200)
		win_const_mgr.add_const('CHANGER_PREDISMOUNT_EJECT_REQUIRED',0x00020000)
		win_const_mgr.add_const('SPI_GETSHOWIMEUI',0x0000006E)
		win_const_mgr.add_const('QUERY_VIRTUAL_PATH',0x00000002)
		win_const_mgr.add_const('SM_CYMINSPACING',0x00000030)
		win_const_mgr.add_const('PSH_USEPSTARTPAGE',0x00000040)
		win_const_mgr.add_const('TBTS_BOTTOM',0x00000002)
		win_const_mgr.add_const('TRANSACTION_DO_NOT_PROMOTE',0x00000001)
		win_const_mgr.add_const('IDS_CAP_NO_AUDIO_CAP_ERROR',0x000001B6)
		win_const_mgr.add_const('D3DPSHADECAPS_FOGGOURAUD',0x00080000)
		win_const_mgr.add_const('MDM_MASK_V110_SPEED',0x00000000)
		win_const_mgr.add_const('PHONEERR_INVALHOOKSWITCHMODE',0x90000010)
		win_const_mgr.add_const('TF_CLUIE_PAGEINDEX',0x00000010)
		win_const_mgr.add_const('CRSWPP_SERVER_NOT_RESPONDING',0xC0042207)
		win_const_mgr.add_const('NETWORK_ALIVE_LAN',0x00000001)
		win_const_mgr.add_const('FILE_DEVICE_SMARTCARD',0x00000031)
		win_const_mgr.add_const('FILE_CREATE_PIPE_INSTANCE',0x00000004)
		win_const_mgr.add_const('LSP_FIREWALL',0x00000008)
		win_const_mgr.add_const('SQL_CA2_SIMULATE_TRY_UNIQUE',0x00008000)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_EFI_ROM',0x0000000D)
		win_const_mgr.add_const('TT_PRIM_CSPLINE',0x00000003)
		win_const_mgr.add_const('MDMSPKR_DIAL',0x00000001)
		win_const_mgr.add_const('PORT_SQLSRV',0x0000009C)
		win_const_mgr.add_const('SFGAO_STORAGE',0x00000008)
		win_const_mgr.add_const('ERROR_NODE_NOT_AVAILABLE',0x000013AC)
		win_const_mgr.add_const('BF_MIDDLE',0x00000800)
		win_const_mgr.add_const('TPM_VCENTERALIGN',0x00000010)
		win_const_mgr.add_const('NSPROTO_IPX',0x000003E8)
		win_const_mgr.add_const('DDPF_YUV',0x00000200)
		win_const_mgr.add_const('MINIDUMP_MISC1_PROCESS_TIMES',0x00000002)
		win_const_mgr.add_const('DB_DISP_KRA_CERT',0x00000011)
		win_const_mgr.add_const('GD_ICON',0x0000000E)
		win_const_mgr.add_const('WHITEBALANCE_FLASH',0x00000007)
		win_const_mgr.add_const('PAN_CONTRAST_VERY_LOW',0x00000003)
		win_const_mgr.add_const('DISPID_ABORT',0x0000000A)
		win_const_mgr.add_const('DEBUG_ENGOPT_NETWORK_PATHS',0x00000004)
		win_const_mgr.add_const('KERB_ETYPE_RSA_ES_OEAP_ENV',0x0000000E)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_MINI_THREAD_1',0x00000006)
		win_const_mgr.add_const('SUBLANG_CHINESE_TRADITIONAL',0x00000001)
		win_const_mgr.add_const('CAL_SSHORTESTDAYNAME2',0x00000032)
		win_const_mgr.add_const('WMDM_FILE_ATTR_CANDELETE',0x00008000)
		win_const_mgr.add_const('SQL_COLUMN_TABLE_NAME',0x0000000F)
		win_const_mgr.add_const('F_EOF',0x00000005)
		win_const_mgr.add_const('JOY_CAL_READALWAYS',0x00010000)
		win_const_mgr.add_const('RPC_C_MQ_JOURNAL_NONE',0x00000000)
		win_const_mgr.add_const('TAPE_PSEUDO_LOGICAL_POSITION',0x00000002)
		win_const_mgr.add_const('FRERR_BUFFERLENGTHZERO',0x00004001)
		win_const_mgr.add_const('BOE_PLAINTEXT',0x00000002)
		win_const_mgr.add_const('IMN_SETSENTENCEMODE',0x00000007)
		win_const_mgr.add_const('MCI_FORMAT_TMSF',0x0000000A)
		win_const_mgr.add_const('SQL_CA2_MAX_ROWS_DELETE',0x00000200)
		win_const_mgr.add_const('RASEDFLAG_NAT',0x00000200)
		win_const_mgr.add_const('RPC_S_PROXY_ACCESS_DENIED',0x000006C1)
		win_const_mgr.add_const('CBS_HASSTRINGS',0x00000200)
		win_const_mgr.add_const('RS_MAYBOTHERUSER',0x00020000)
		win_const_mgr.add_const('SHGFI_LARGEICON',0x00000000)
		win_const_mgr.add_const('FILE_DEVICE_CD_ROM_FILE_SYSTEM',0x00000003)
		win_const_mgr.add_const('WIA_DATA_COLOR',0x00000003)
		win_const_mgr.add_const('IDD_EDITLINKS4',0x00000451)
		win_const_mgr.add_const('LTGRAY_BRUSH',0x00000001)
		win_const_mgr.add_const('BCRYPT_PAD_PSS',0x00000008)
		win_const_mgr.add_const('ITWW_OPEN_CONNECT',0x00000000)
		win_const_mgr.add_const('TR_PPN',0x0000000D)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME2',0x00000023)
		win_const_mgr.add_const('ERROR_LOG_TAIL_INVALID',0x000019E3)
		win_const_mgr.add_const('MM_JOY1ZMOVE',0x000003A2)
		win_const_mgr.add_const('DEBUG_CLASS_USER_WINDOWS',0x00000002)
		win_const_mgr.add_const('NCRYPTBUFFER_VERSION',0x00000000)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME4',0x00000025)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME5',0x00000026)
		win_const_mgr.add_const('MOD_WIN',0x00000008)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME8',0x00000029)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME9',0x00000002)
		win_const_mgr.add_const('DEBUG_ENGOPT_IGNORE_EXTENSION_VERSIONS',0x00000002)
		win_const_mgr.add_const('VER_ERR_EXCEP_NUM_1',0x00000010)
		win_const_mgr.add_const('UIA_E_TIMEOUT',0x80131505)
		win_const_mgr.add_const('MEM_256K',0x00040000)
		win_const_mgr.add_const('AMVA_TYPEINDEX_OUTPUTFRAME',0xFFFFFFFF)
		win_const_mgr.add_const('PAN_MIDLINE_CONSTANT_TRIMMED',0x00000008)
		win_const_mgr.add_const('KAGPROP_SPECIALCHARACTERS',0x0000000B)
		win_const_mgr.add_const('MEM_256M',0x10000000)
		win_const_mgr.add_const('F_MEMORY',0x00000004)
		win_const_mgr.add_const('LINEAGENTSTATEEX_READY',0x00000002)
		win_const_mgr.add_const('CTRY_PERU',0x00000033)
		win_const_mgr.add_const('SV_MAXCOPYWRITELEN_PARMNUM',0x00000209)
		win_const_mgr.add_const('PFL_MATCHES_PROTOCOL_ZERO',0x00000008)
		win_const_mgr.add_const('SECPKG_OPTIONS_PERMANENT',0x00000001)
		win_const_mgr.add_const('ACM_DRIVERPRIORITYF_END',0x00020000)
		win_const_mgr.add_const('LDAP_FILTER_AND',0x00000000)
		win_const_mgr.add_const('CDO_E_NNTP_SERVER_REQUIRED',0x8004020B)
		win_const_mgr.add_const('DBPROPVAL_NC_LOW',0x00000004)
		win_const_mgr.add_const('CSIDL_COMMON_APPDATA',0x00000023)
		win_const_mgr.add_const('DST_BITMAP',0x00000004)
		win_const_mgr.add_const('IN_CLASSB_NSHIFT',0x00000010)
		win_const_mgr.add_const('MINIDUMP_MISC1_PROCESSOR_POWER_INFO',0x00000004)
		win_const_mgr.add_const('PANE_PRINTER',0x00000003)
		win_const_mgr.add_const('BTH_MFG_INFINEON',0x00000009)
		win_const_mgr.add_const('PDH_ACCESS_DENIED',0xC0000BDB)
		win_const_mgr.add_const('TVS_CHECKBOXES',0x00000100)
		win_const_mgr.add_const('MCI_DGV_STATUS_LEFT',0x00080000)
		win_const_mgr.add_const('DNS_TYPE_CERT',0x00000025)
		win_const_mgr.add_const('CMS_TARGETOVERFLOW',0x20000000)
		win_const_mgr.add_const('CLUSCTL_ACCESS_SHIFT',0x00000000)
		win_const_mgr.add_const('SHGFI_PIDL',0x00000008)
		win_const_mgr.add_const('MCA_POISON_MEMORY',0x00000002)
		win_const_mgr.add_const('MD_CERT_CACHE_RETRIEVAL_ONLY',0x00000002)
		win_const_mgr.add_const('DNS_WINS_FLAG_LOCAL',0x00010000)
		win_const_mgr.add_const('MD_NOTIFY_PREPROC_HEADERS',0x00004000)
		win_const_mgr.add_const('CBEN_FIRST',0x00000000)
		win_const_mgr.add_const('WSAENETDOWN',0x00002742)
		win_const_mgr.add_const('TRANSPORT_TYPE_DG',0x00000002)
		win_const_mgr.add_const('SCARD_W_CACHE_ITEM_STALE',0x80100071)
		win_const_mgr.add_const('SPECIFIC_RIGHTS_ALL',0x0000FFFF)
		win_const_mgr.add_const('USE_CONN',0x00000004)
		win_const_mgr.add_const('XEPR_DATE',0x00000005)
		win_const_mgr.add_const('EC_NEED_RESTART',0x00000014)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_COOKIE',0x00003616)
		win_const_mgr.add_const('CERT_SET_PROPERTY_INHIBIT_PERSIST_FLAG',0x40000000)
		win_const_mgr.add_const('PAN_CONTRAST_NONE',0x00000002)
		win_const_mgr.add_const('CRL_REASON_AFFILIATION_CHANGED_FLAG',0x00000010)
		win_const_mgr.add_const('FCW_TREE',0x00000003)
		win_const_mgr.add_const('IN6ADDR_MULTICASTPREFIX_LENGTH',0x00000008)
		win_const_mgr.add_const('DDOVER_ALPHADESTSURFACEOVERRIDE',0x00000008)
		win_const_mgr.add_const('IPPROTO_ICMP',0x00000001)
		win_const_mgr.add_const('PSP_USEHEADERSUBTITLE',0x00002000)
		win_const_mgr.add_const('DEBUG_OUTPUT_NORMAL',0x00000001)
		win_const_mgr.add_const('VER_ERR_FIELD_SIG',0x03000000)
		win_const_mgr.add_const('DE_E_FILTER_MULTIPLETAGS',0x80100004)
		win_const_mgr.add_const('WSA_WAIT_EVENT_0',0x00000000)
		win_const_mgr.add_const('SV_ULIST_MTIME_PARMNUM',0x00000191)
		win_const_mgr.add_const('EC_SAMPLE_LATENCY',0x00000022)
		win_const_mgr.add_const('NT51_MAJOR_VERSION',0x00000004)
		win_const_mgr.add_const('SECURITYMSG_ERROR',0x00000003)
		win_const_mgr.add_const('ERROR_NOT_EMPTY',0x000010D3)
		win_const_mgr.add_const('TMT_FROMCOLOR3',0x000007D3)
		win_const_mgr.add_const('FLASHW_TIMER',0x00000004)
		win_const_mgr.add_const('PROCESSOR_OPTIL',0x00000494)
		win_const_mgr.add_const('BIF_BROWSEINCLUDEFILES',0x00004000)
		win_const_mgr.add_const('PHYSICAL_MONITOR_DESCRIPTION_SIZE',0x00000080)
		win_const_mgr.add_const('SM_DEBUG',0x00000016)
		win_const_mgr.add_const('STYPE_TEMPORARY',0x40000000)
		win_const_mgr.add_const('CERT_STORE_NO_CRL_FLAG',0x00010000)
		win_const_mgr.add_const('DNS_RTYPE_CNAME',0x00000500)
		win_const_mgr.add_const('MIN_DEV_VER_FOR_QI',0x00000100)
		win_const_mgr.add_const('MANAGED_APPS_USERAPPLICATIONS',0x00000001)
		win_const_mgr.add_const('LVBKIF_FLAG_TILEOFFSET',0x00000100)
		win_const_mgr.add_const('ERROR_PROCESS_ABORTED',0x0000042B)
		win_const_mgr.add_const('PRJOB_QS_PAUSED',0x00000001)
		win_const_mgr.add_const('DDPF_PALETTEINDEXED4',0x00000008)
		win_const_mgr.add_const('CRYPT_FASTSGC',0x00000002)
		win_const_mgr.add_const('IDM_TRIED_UNLINK',0x0000003B)
		win_const_mgr.add_const('CMSG_CMS_RECIPIENT_COUNT_PARAM',0x00000021)
		win_const_mgr.add_const('TAPE_SPACE_END_OF_DATA',0x00000004)
		win_const_mgr.add_const('MCIWNDF_SHOWALL',0x00000070)
		win_const_mgr.add_const('SQL_COLUMN_ALIAS',0x00000057)
		win_const_mgr.add_const('DEV_PORT_DIAQ',0x00000006)
		win_const_mgr.add_const('CR_INVALID_LOG_CONF',0x00000007)
		win_const_mgr.add_const('DISKQUOTA_STATE_MASK',0x00000003)
		win_const_mgr.add_const('ATTR_INPUT_ERROR',0x00000004)
		win_const_mgr.add_const('WMDM_FILE_ATTR_AUDIOBOOK',0x00200000)
		win_const_mgr.add_const('IMAGE_FILE_REMOVABLE_RUN_FROM_SWAP',0x00000400)
		win_const_mgr.add_const('SHOW_OPENNOACTIVATE',0x00000004)
		win_const_mgr.add_const('TXFS_RM_STATE_NOT_STARTED',0x00000000)
		win_const_mgr.add_const('KSPROBE_PROBEANDLOCK',0x00000020)
		win_const_mgr.add_const('SQL_AT_DROP_COLUMN_CASCADE',0x00000400)
		win_const_mgr.add_const('TAPE_DRIVE_SET_COMPRESSION',0x80000200)
		win_const_mgr.add_const('SQL_FN_STR_CHARACTER_LENGTH',0x00200000)
		win_const_mgr.add_const('ERROR_UNHANDLED_EXCEPTION',0x0000023E)
		win_const_mgr.add_const('PDH_FMT_NOSCALE',0x00001000)
		win_const_mgr.add_const('COD_COMPUTER_MINOR_PALM',0x00000005)
		win_const_mgr.add_const('PBT_APMBATTERYLOW',0x00000009)
		win_const_mgr.add_const('ADS_PRINTER_USER_INTERVENTION',0x00100000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGOPEN',0x0000000B)
		win_const_mgr.add_const('CM_CREATE_DEVNODE_GENERATE_ID',0x00000004)
		win_const_mgr.add_const('SQL_SNVF_EXTRACT',0x00000008)
		win_const_mgr.add_const('MUI_SXS_FALLBACK',0x00010000)
		win_const_mgr.add_const('OID_FDDI_LCT_FAILURES',0x03020107)
		win_const_mgr.add_const('PORT_BOOTPS',0x00000043)
		win_const_mgr.add_const('MIXER_GETLINEINFOF_DESTINATION',0x00000000)
		win_const_mgr.add_const('MIXERLINE_TARGETTYPE_MIDIIN',0x00000004)
		win_const_mgr.add_const('MIM_STYLE',0x00000010)
		win_const_mgr.add_const('DNS_ERROR_SECURE_BASE',0x00002648)
		win_const_mgr.add_const('DI_APPBANDING',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_CLOCKTIME',0x00020000)
		win_const_mgr.add_const('PRINTER_STATUS_DRIVER_UPDATE_NEEDED',0x04000000)
		win_const_mgr.add_const('ERROR_NETWORK_ACCESS_DENIED',0x00000041)
		win_const_mgr.add_const('PORT_BOOTPC',0x00000044)
		win_const_mgr.add_const('CF_REJECT',0x00000001)
		win_const_mgr.add_const('ERR_TSTOVFL',0x0000005B)
		win_const_mgr.add_const('LVFF_ITEMCOUNT',0x00000001)
		win_const_mgr.add_const('MMIOM_SEEK',0x00000002)
		win_const_mgr.add_const('D3DPTEXTURECAPS_TEXREPEATNOTSCALEDBYSIZE',0x00000040)
		win_const_mgr.add_const('SQL_CN_OFF',0x00000000)
		win_const_mgr.add_const('ERROR_SYSTEM_HIVE_TOO_LARGE',0x0000028D)
		win_const_mgr.add_const('LINE_GATHERDIGITS',0x00000006)
		win_const_mgr.add_const('TMT_BGTYPE',0x00000FA1)
		win_const_mgr.add_const('CTRY_ECUADOR',0x00000251)
		win_const_mgr.add_const('BLLI_L3_X223',0x00000008)
		win_const_mgr.add_const('DDOSD_SCAPS',0x00000004)
		win_const_mgr.add_const('CRYPT_OFFLINE_CHECK_RETRIEVAL',0x00004000)
		win_const_mgr.add_const('TC_GP_TRAP',0x00000002)
		win_const_mgr.add_const('SORTED_CTL_EXT_HASHED_SUBJECT_IDENTIFIER_FLAG',0x00000001)
		win_const_mgr.add_const('MDM_MASK_PROTOCOLID',0x00000000)
		win_const_mgr.add_const('IDM_SUBSCRIPT',0x000008C7)
		win_const_mgr.add_const('ACPI_PPM_SOFTWARE_ALL',0x000000FC)
		win_const_mgr.add_const('GESTURE_CHECK',0x00000000)
		win_const_mgr.add_const('SQL_PARAM_ARRAY_ROW_COUNTS',0x00000099)
		win_const_mgr.add_const('DISPID_ONMOUSEMOVE',0x00000006)
		win_const_mgr.add_const('LINEERR_NODRIVER',0x80000043)
		win_const_mgr.add_const('WMSZ_TOP',0x00000003)
		win_const_mgr.add_const('CTFMODEBIAS_HALFWIDTHKATAKANA',0x0000000A)
		win_const_mgr.add_const('IDM_HORIZSPACECONCATENATE',0x00000015)
		win_const_mgr.add_const('LINECALLREASON_PICKUP',0x00000010)
		win_const_mgr.add_const('SQLAOPSTDEV',0x00000030)
		win_const_mgr.add_const('GR_USEROBJECTS',0x00000001)
		win_const_mgr.add_const('RESOURCEMANAGER_SET_INFORMATION',0x00000002)
		win_const_mgr.add_const('PORT_MPMSND',0x0000002E)
		win_const_mgr.add_const('IDSI_FLAG_KEEP_ALIVE',0x00000001)
		win_const_mgr.add_const('XP_MESSAGE_ORIENTED',0x00000008)
		win_const_mgr.add_const('EMR_FRAMERGN',0x00000048)
		win_const_mgr.add_const('HSE_URL_FLAGS_EXECUTE',0x00000004)
		win_const_mgr.add_const('SCE_LOG_LEVEL_DEBUG',0x00000003)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_OMAP_TO_SRC',0x00000007)
		win_const_mgr.add_const('IR_PROMISCUOUS_MULTICAST',0x00000001)
		win_const_mgr.add_const('DNS_CONFIG_FLAG_ALLOC',0x00000001)
		win_const_mgr.add_const('EVT_ALL_ACCESS',0x00000007)
		win_const_mgr.add_const('SEE_MASK_DOENVSUBST',0x00000200)
		win_const_mgr.add_const('ACS_TIMER',0x00000008)
		win_const_mgr.add_const('DLCTL_OFFLINEIFNOTCONNECTED',0x80000000)
		win_const_mgr.add_const('DEBUG_CMDEX_ADD_EVENT_STRING',0x00000001)
		win_const_mgr.add_const('CB_MAX_FILENAME',0x00000100)
		win_const_mgr.add_const('MCI_VCR_SET_TRACKING',0x00400000)
		win_const_mgr.add_const('LANG_SINDHI',0x00000059)
		win_const_mgr.add_const('SERVICE_ADAPTER',0x00000004)
		win_const_mgr.add_const('PCMCIA_DEF_MEMEND',0x00FFFFFF)
		win_const_mgr.add_const('D3DPTEXTURECAPS_MIPCUBEMAP',0x00010000)
		win_const_mgr.add_const('C2_NOTAPPLICABLE',0x00000000)
		win_const_mgr.add_const('MOUSEEVENTF_ABSOLUTE',0x00008000)
		win_const_mgr.add_const('ERROR_DS_EXISTING_AD_CHILD_NC',0x000021A5)
		win_const_mgr.add_const('CBS_DISABLENOSCROLL',0x00000800)
		win_const_mgr.add_const('EXCHIVERB_RESERVED_OPEN',0x00000065)
		win_const_mgr.add_const('LDAP_SUBSTRING_ANY',0x00000081)
		win_const_mgr.add_const('SCHEDULE_PRIORITY',0x00000002)
		win_const_mgr.add_const('BF_LEFT',0x00000001)
		win_const_mgr.add_const('SSPROP_CURRENTCOLLATION',0x00000007)
		win_const_mgr.add_const('TAPE_SPACE_FILEMARKS',0x00000006)
		win_const_mgr.add_const('JOB_OBJECT_UILIMIT_DISPLAYSETTINGS',0x00000010)
		win_const_mgr.add_const('IRLMP_TINYTP_MODE',0x00000017)
		win_const_mgr.add_const('MAX_DEVPROP_TYPE',0x00000019)
		win_const_mgr.add_const('MCA_CONTEXT_BAD',0x00000001)
		win_const_mgr.add_const('AUDIO_CHANNELCOUNT_STEREO',0x00000002)
		win_const_mgr.add_const('D3DTA_TEXTURE',0x00000002)
		win_const_mgr.add_const('MCI_DGV_STATUS_AUDIO_INPUT',0x00004000)
		win_const_mgr.add_const('DC_PRINTRATEUNIT',0x0000001B)
		win_const_mgr.add_const('IPV6_ADD_MEMBERSHIP',0x0000000C)
		win_const_mgr.add_const('SV_ENABLEW9XSECURITYSIGNATURE_PARMNUM',0x00000256)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_CURRENT_SERVICE_ID',0x00000004)
		win_const_mgr.add_const('ADS_SERVICE_STOPPED',0x00000001)
		win_const_mgr.add_const('VFT2_DRV_INSTALLABLE',0x00000008)
		win_const_mgr.add_const('IMAGE_REL_IA64_SREL14',0x00000011)
		win_const_mgr.add_const('IDM_SHOWPICTURE',0x000008DD)
		win_const_mgr.add_const('UOI_NAME',0x00000002)
		win_const_mgr.add_const('MAXSHORT',0x00000007)
		win_const_mgr.add_const('SAP_FIELD_ANY',0xFFFFFFFF)
		win_const_mgr.add_const('PROXIMITY_UNIT_CHAPTER',0x00000003)
		win_const_mgr.add_const('DDF_HURRYUP',0x00000800)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_TYPECHANGED',0x00000008)
		win_const_mgr.add_const('TRACE_LEVEL_FATAL',0x00000001)
		win_const_mgr.add_const('FOREGROUND_BLUE',0x00000001)
		win_const_mgr.add_const('SAC_PROTOCOL_WMDM',0x00000001)
		win_const_mgr.add_const('MCS_DAYSTATE',0x00000001)
		win_const_mgr.add_const('IF_TYPE_DVB_ASI_OUT',0x000000AD)
		win_const_mgr.add_const('SPINST_LOGCONFIG',0x00000001)
		win_const_mgr.add_const('ERROR_NULL_LM_PASSWORD',0x00000518)
		win_const_mgr.add_const('CRYPT_IMPL_MIXED',0x00000003)
		win_const_mgr.add_const('FILEOP_BACKUP',0x00000003)
		win_const_mgr.add_const('SNMP_ERROR_NOERROR',0x00000000)
		win_const_mgr.add_const('MSGFLT_REMOVE',0x00000002)
		win_const_mgr.add_const('NDW_INSTALLFLAG_DIDFACTDEFS',0x00000001)
		win_const_mgr.add_const('HHN_LAST',0x00000000)
		win_const_mgr.add_const('TR_RV0',0x00000001)
		win_const_mgr.add_const('NI_CHANGECANDIDATELIST',0x00000013)
		win_const_mgr.add_const('AVIFILECAPS_CANWRITE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED',0x00002158)
		win_const_mgr.add_const('ODA_SELECT',0x00000002)
		win_const_mgr.add_const('IPPORT_MSP',0x00000012)
		win_const_mgr.add_const('RS_SUSPENDONIDLE',0x00010000)
		win_const_mgr.add_const('DNS_CLASS_HESIOD',0x00000004)
		win_const_mgr.add_const('PORT_ISOTP0',0x00000092)
		win_const_mgr.add_const('WIA_COMPRESSION_G3',0x00000003)
		win_const_mgr.add_const('ERROR_DEVICE_ALREADY_ATTACHED',0x00000224)
		win_const_mgr.add_const('LVA_SNAPTOGRID',0x00000005)
		win_const_mgr.add_const('SCARD_E_CERTIFICATE_UNAVAILABLE',0x8010002D)
		win_const_mgr.add_const('SBT_NOTABPARSING',0x00000800)
		win_const_mgr.add_const('ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED',0x000036BF)
		win_const_mgr.add_const('MD_ERROR_NO_SESSION_KEY',0x800CC81D)
		win_const_mgr.add_const('MEM_PHYSICAL',0x00400000)
		win_const_mgr.add_const('LOGON32_PROVIDER_WINNT50',0x00000003)
		win_const_mgr.add_const('DC_TEXT',0x00000008)
		win_const_mgr.add_const('ALG_SID_DESX',0x00000004)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2_MEDIASUPPORTED',0x00000801)
		win_const_mgr.add_const('LOCALE_SNAN',0x00000069)
		win_const_mgr.add_const('SE_GROUP_OWNER',0x00000008)
		win_const_mgr.add_const('UOI_TYPE',0x00000003)
		win_const_mgr.add_const('IMAGE_DLLCHARACTERISTICS_NX_COMPAT',0x00000100)
		win_const_mgr.add_const('MD_ERROR_SUB403_PWD_CHANGE',0x0000000B)
		win_const_mgr.add_const('NSTYPE_HIERARCHICAL',0x00000001)
		win_const_mgr.add_const('DISKQUOTA_USER_ACCOUNT_DELETED',0x00000002)
		win_const_mgr.add_const('DDOVER_ALPHADEST',0x00000001)
		win_const_mgr.add_const('CERT_UNICODE_VALUE_ERR_INDEX_SHIFT',0x00000000)
		win_const_mgr.add_const('ISC_RET_RESERVED1',0x00100000)
		win_const_mgr.add_const('SQL_CA1_BULK_DELETE_BY_BOOKMARK',0x00040000)
		win_const_mgr.add_const('OID_QOS_RESERVED20',0xFB010113)
		win_const_mgr.add_const('PROGDLG_AUTOTIME',0x00000002)
		win_const_mgr.add_const('CDS_SET_PRIMARY',0x00000010)
		win_const_mgr.add_const('DLGC_WANTMESSAGE',0x00000004)
		win_const_mgr.add_const('IPPORT_MTP',0x00000039)
		win_const_mgr.add_const('MUI_MERGE_USER_FALLBACK',0x00000020)
		win_const_mgr.add_const('MDPROPVAL_MNF_DRILLDOWNMEMBERBOTTOM',0x00002000)
		win_const_mgr.add_const('SAFER_POLICY_HASH_DUPLICATE',0x00040000)
		win_const_mgr.add_const('SQL_ORDER_BY_COLUMNS_IN_SELECT',0x0000005A)
		win_const_mgr.add_const('MIN_UCSCHAR',0x00000000)
		win_const_mgr.add_const('WMDM_STATUS_STORAGE_BROKEN',0x00000400)
		win_const_mgr.add_const('SQL_XL_OFF',0x00000000)
		win_const_mgr.add_const('TRANSPORT_NAME_PARMNUM',0x000000CA)
		win_const_mgr.add_const('DMTT_SUBDEV',0x00000003)
		win_const_mgr.add_const('ABE_LEFT',0x00000000)
		win_const_mgr.add_const('UNLEN',0x00000100)
		win_const_mgr.add_const('LSP_INBOUND_MODIFY',0x00000010)
		win_const_mgr.add_const('WM_QUEUESYNC',0x00000023)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_WORKINGSET',0x00000001)
		win_const_mgr.add_const('ILSIF_LEAVE_LARGE_ICON',0x40000000)
		win_const_mgr.add_const('NETERR_RING_STATUS_COUNTER_OVERFLOW',0x00000100)
		win_const_mgr.add_const('GT_RAWTEXT',0x00000004)
		win_const_mgr.add_const('SUBLANG_SAMI_SOUTHERN_NORWAY',0x00000006)
		win_const_mgr.add_const('SM_CXBORDER',0x00000005)
		win_const_mgr.add_const('HS_FDIAGONAL',0x00000002)
		win_const_mgr.add_const('COD_SERVICE_INFORMATION',0x00000400)
		win_const_mgr.add_const('RC_DIBTODEV',0x00000200)
		win_const_mgr.add_const('STATE_SYSTEM_TRAVERSED',0x00800000)
		win_const_mgr.add_const('CHANGER_MEDIUM_FLIP',0x00000200)
		win_const_mgr.add_const('PID_DISPLAY_PROPERTIES',0x00000000)
		win_const_mgr.add_const('SUBLANG_FRENCH_CANADIAN',0x00000003)
		win_const_mgr.add_const('SHARE_MAX_USES_PARMNUM',0x00000006)
		win_const_mgr.add_const('DEBUG_CSS_TYPE_OPTIONS',0x00000020)
		win_const_mgr.add_const('COD_IMAGING_MINOR_CAMERA_MASK',0x00000008)
		win_const_mgr.add_const('HELP_TCARD_DATA',0x00000010)
		win_const_mgr.add_const('KSALLOCATOR_OPTIONF_COMPATIBLE',0x00000001)
		win_const_mgr.add_const('AM_DVD_CGMS_COPY_PROTECT_MASK',0x00000018)
		win_const_mgr.add_const('SEE_MASK_IDLIST',0x00000004)
		win_const_mgr.add_const('ERROR_COLORSPACE_MISMATCH',0x000007E5)
		win_const_mgr.add_const('AF_NS',0x00000006)
		win_const_mgr.add_const('OS_FASTUSERSWITCHING',0x0000001A)
		win_const_mgr.add_const('DTPB_WINDOWDC',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY',0x00003709)
		win_const_mgr.add_const('VCAPS_OVERLAY',0x00000001)
		win_const_mgr.add_const('RPC_C_OPT_MQ_TIME_TO_REACH_QUEUE',0x00000007)
		win_const_mgr.add_const('SQL_SP_COMPARISON',0x00001000)
		win_const_mgr.add_const('SQL_HANDLE_STMT',0x00000003)
		win_const_mgr.add_const('CACHE_HEADER_DATA_SSL_STATE_COUNT',0x0000000E)
		win_const_mgr.add_const('LINETERMMODE_RINGER',0x00000008)
		win_const_mgr.add_const('IR_FULLCONVERT',0x00000123)
		win_const_mgr.add_const('NTDSCONN_KCC_SITE_FAILOVER_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('UNIQUE_NAME',0x00000000)
		win_const_mgr.add_const('CTRY_PAKISTAN',0x0000005C)
		win_const_mgr.add_const('MAPI_SHORTTERM',0x00000080)
		win_const_mgr.add_const('PFNS_NEWNUMBER',0x00008000)
		win_const_mgr.add_const('WMI_GUIDTYPE_DATA',0x00000002)
		win_const_mgr.add_const('ALG_SID_RC4',0x00000001)
		win_const_mgr.add_const('SQL_SR_USAGE_ON_TRANSLATION',0x00000008)
		win_const_mgr.add_const('ALG_SID_RC2',0x00000002)
		win_const_mgr.add_const('MM_MAX_NUMAXES',0x00000010)
		win_const_mgr.add_const('SQL_QI_ON',0x00000001)
		win_const_mgr.add_const('EV_RXCHAR',0x00000001)
		win_const_mgr.add_const('V86FLAGS_V86',0x00020000)
		win_const_mgr.add_const('SCHEME_CREATE',0x00000080)
		win_const_mgr.add_const('SN_CMP_IDENTICAL',0x00000001)
		win_const_mgr.add_const('CREDP_FLAGS_CLEAR_PASSWORD',0x00000008)
		win_const_mgr.add_const('SYSFXUI_DONOTSHOW_CHANNELPHANTOMING',0x00000080)
		win_const_mgr.add_const('IPSEC_AUTH_CONFIG_MAX',0x00000002)
		win_const_mgr.add_const('SQLNUMERIC',0x00000006)
		win_const_mgr.add_const('HDF_CENTER',0x00000002)
		win_const_mgr.add_const('MD_ERROR_SUB502_FORWARDER_CONN_ERROR',0x00000003)
		win_const_mgr.add_const('FAULT_INVALID_ACTION',0x00000191)
		win_const_mgr.add_const('INTERNET_OPTION_CONTEXT_VALUE',0x0000002D)
		win_const_mgr.add_const('KS_TVTUNER_CHANGE_END_TUNE',0x00000002)
		win_const_mgr.add_const('IN4ADDR_LOOPBACK',0x00100007)
		win_const_mgr.add_const('CRYPT_ENCRYPT',0x00000001)
		win_const_mgr.add_const('MAX_ADAPTER_NAME_LENGTH',0x00000100)
		win_const_mgr.add_const('NRC_GOODRET',0x00000000)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_CHAR',0x00000002)
		win_const_mgr.add_const('PRODUCT_DATACENTER_SERVER_CORE',0x0000000C)
		win_const_mgr.add_const('MAPI_E_INVALID_RECIPS',0x00000019)
		win_const_mgr.add_const('LINEDEVSTATE_CONFIGCHANGE',0x00200000)
		win_const_mgr.add_const('HKCOMB_SCA',0x00000080)
		win_const_mgr.add_const('PAN_MIDLINE_CONSTANT_SERIFED',0x0000000A)
		win_const_mgr.add_const('CAL_SMONTHNAME11',0x00000001)
		win_const_mgr.add_const('CM_ADD_CERT_STORES',0x00000200)
		win_const_mgr.add_const('D3DDTCAPS_FLOAT16_2',0x00000100)
		win_const_mgr.add_const('RBS_BANDBORDERS',0x00000400)
		win_const_mgr.add_const('LVGF_ALIGN',0x00000008)
		win_const_mgr.add_const('D3DDTCAPS_FLOAT16_4',0x00000200)
		win_const_mgr.add_const('HTSYSMENU',0x00000003)
		win_const_mgr.add_const('DISPID_IHTMLDLGSAFEHELPER_FONTS',0x00000003)
		win_const_mgr.add_const('ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED',0x00001A43)
		win_const_mgr.add_const('SMC_SFEXEC_MIDDLE',0x00000031)
		win_const_mgr.add_const('RPC_S_INVALID_OBJECT',0x0000076C)
		win_const_mgr.add_const('SELCERT_SERIAL_NUM',0x0000006A)
		win_const_mgr.add_const('SQL_ISV_COLUMN_DOMAIN_USAGE',0x00000010)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_MPEG2_B',0x0000000B)
		win_const_mgr.add_const('IDTB_SEARCH',0x000000D7)
		win_const_mgr.add_const('ERROR_CHILD_MUST_BE_VOLATILE',0x000003FD)
		win_const_mgr.add_const('MSV1_0_VALIDATION_SESSION_KEY',0x00000010)
		win_const_mgr.add_const('DOMAIN_PASSWORD_STORE_CLEARTEXT',0x00000010)
		win_const_mgr.add_const('LANG_SERBIAN',0x00000001)
		win_const_mgr.add_const('SV_XACTMEMSIZE_PARMNUM',0x00000213)
		win_const_mgr.add_const('DDCAPS_VBI',0x00080000)
		win_const_mgr.add_const('PROTECTED_DACL_SECURITY_INFORMATION',0x80000000)
		win_const_mgr.add_const('ILP_NORMAL',0x00000000)
		win_const_mgr.add_const('RESUTIL_PROPITEM_SIGNED',0x00000004)
		win_const_mgr.add_const('SNMP_ERROR_NOCREATION',0x0000000B)
		win_const_mgr.add_const('KDF_USE_SECRET_AS_HMAC_KEY_FLAG',0x00000001)
		win_const_mgr.add_const('WPF_NO_DIRECT_LOOKUP',0x00000010)
		win_const_mgr.add_const('DEBUG_CONNECT_SESSION_NO_VERSION',0x00000001)
		win_const_mgr.add_const('WS_EX_LEFTSCROLLBAR',0x00004000)
		win_const_mgr.add_const('RFCOMM_CMD_RPN_REQUEST',0x00000004)
		win_const_mgr.add_const('CRYPTDLG_REVOCATION_CACHE',0x40000000)
		win_const_mgr.add_const('PCS_PATHTOOLONG',0x00000008)
		win_const_mgr.add_const('IDS_CAP_VIDEO_OPEN_ERROR',0x000001A8)
		win_const_mgr.add_const('LOCALE_SISO3166CTRYNAME',0x0000005A)
		win_const_mgr.add_const('WINEVENT_SKIPOWNPROCESS',0x00000002)
		win_const_mgr.add_const('CMF_DEFAULTONLY',0x00000001)
		win_const_mgr.add_const('MDM_SHIFT_AUTO_ML',0x00000006)
		win_const_mgr.add_const('C2_EUROPENUMBER',0x00000003)
		win_const_mgr.add_const('VP_TV_STANDARD_PAL_60',0x00040000)
		win_const_mgr.add_const('SQL_API_SQLBINDPARAMETER',0x00000048)
		win_const_mgr.add_const('ERROR_ACPI_ERROR',0x0000029D)
		win_const_mgr.add_const('FOCUS_EVENT',0x00000010)
		win_const_mgr.add_const('ISC_REQ_NO_INTEGRITY',0x00800000)
		win_const_mgr.add_const('DS_ROLE_DOMAIN_OWNER',0x00000001)
		win_const_mgr.add_const('TT_PRIM_QSPLINE',0x00000002)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_LOCAL_MACHINE_ID',0x00000002)
		win_const_mgr.add_const('CACHE_HEADER_DATA_NOTIFICATION_MESG',0x00000004)
		win_const_mgr.add_const('WTPF_OFFLINEOKNBU_IND',0x00001000)
		win_const_mgr.add_const('BCPFILECP_OEMCP',0x00000001)
		win_const_mgr.add_const('DEBUG_MODNAME_SYMBOL_FILE',0x00000003)
		win_const_mgr.add_const('PORT_WPAGES',0x00000308)
		win_const_mgr.add_const('CTF_REF_COUNTED',0x00000020)
		win_const_mgr.add_const('MCI_DEVTYPE_CD_AUDIO',0x00000204)
		win_const_mgr.add_const('D3DDEVCAPS_TLVERTEXSYSTEMMEMORY',0x00000040)
		win_const_mgr.add_const('GENERIC_WRITE',0x40000000)
		win_const_mgr.add_const('SE_GROUP_ENABLED',0x00000004)
		win_const_mgr.add_const('PDH_REFRESHCOUNTERS',0x00000004)
		win_const_mgr.add_const('ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED',0x000013D4)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_PRE_FETCH_AUTOROOT_CAB',0x00000005)
		win_const_mgr.add_const('TRANSACTIONMANAGER_CREATE_RM',0x00000010)
		win_const_mgr.add_const('MCI_OVLY_WHERE_DESTINATION',0x00040000)
		win_const_mgr.add_const('ENHMETA_STOCK_OBJECT',0x80000000)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_VALUE',0x01000000)
		win_const_mgr.add_const('TXTBIT_RICHTEXT',0x00000001)
		win_const_mgr.add_const('POLICY_ERRV_EXPIRED_CREDENTIALS',0x00000004)
		win_const_mgr.add_const('DDCOLOR_BRIGHTNESS',0x00000001)
		win_const_mgr.add_const('DLLVER_MINOR_MASK',0xFFFF00000000)
		win_const_mgr.add_const('ERROR_HOOK_NEEDS_HMOD',0x00000594)
		win_const_mgr.add_const('GOPHER_TYPE_DOS_ARCHIVE',0x00000020)
		win_const_mgr.add_const('CACHE_ENTRY_EXEMPT_DELTA_FC',0x00000800)
		win_const_mgr.add_const('COOKIE_OP_PERSISTENT',0x00000010)
		win_const_mgr.add_const('FORMAT_MESSAGE_IGNORE_INSERTS',0x00000200)
		win_const_mgr.add_const('PHONESTATE_HANDSETHOOKSWITCH',0x00000200)
		win_const_mgr.add_const('MAX_COMPUTERNAME_LENGTH',0x0000001F)
		win_const_mgr.add_const('TRANSACTION_SET_INFORMATION',0x00000002)
		win_const_mgr.add_const('RFCOMM_MIN_MTU',0x00000017)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_CACHEABLE_PRINCIPALS_GROUP',0x0000023B)
		win_const_mgr.add_const('LB_MSGMAX',0x000001A8)
		win_const_mgr.add_const('PERF_ENUM_INSTANCES',0x00000003)
		win_const_mgr.add_const('USER_PRIV_USER',0x00000001)
		win_const_mgr.add_const('USER_LAST_LOGOFF_PARMNUM',0x00000010)
		win_const_mgr.add_const('CDO_E_INVALID_CHARSET',0x8004022B)
		win_const_mgr.add_const('OUT_SCREEN_OUTLINE_PRECIS',0x00000009)
		win_const_mgr.add_const('ADAM_REPL_AUTHENTICATION_MODE_NEGOTIATE',0x00000001)
		win_const_mgr.add_const('CRYPT_VERIFY_CERT_SIGN_SUBJECT_BLOB',0x00000001)
		win_const_mgr.add_const('ICM_NOTOPEN',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_PPC_PAIR',0x00000012)
		win_const_mgr.add_const('D3D10_FLOAT32_MAX',0x00000003)
		win_const_mgr.add_const('VFW_FIRST_CODE',0x00000200)
		win_const_mgr.add_const('HEAP_NO_SERIALIZE',0x00000001)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_ND_SECURE',0x00000001)
		win_const_mgr.add_const('IPX_OUT_TRAFFIC_FILTER_GLOBAL_INFO_TYPE',0x0000000D)
		win_const_mgr.add_const('CM_REENUMERATE_ASYNCHRONOUS',0x00000004)
		win_const_mgr.add_const('ACM_FORMATTAGDETAILSF_FORMATTAG',0x00000001)
		win_const_mgr.add_const('LBS_HASSTRINGS',0x00000040)
		win_const_mgr.add_const('URLACTION_SHELL_CURR_MAX',0x0000180D)
		win_const_mgr.add_const('POWER_LEVEL_USER_NOTIFY_EXEC',0x00000004)
		win_const_mgr.add_const('FILE_FLAG_WRITE_THROUGH',0x80000000)
		win_const_mgr.add_const('DB_COLLATION_DESC',0x00000002)
		win_const_mgr.add_const('RESOURCEUSAGE_SIBLING',0x00000008)
		win_const_mgr.add_const('MUI_RESET_FILTERS',0x00000001)
		win_const_mgr.add_const('AM_DVD_SECTOR_PROTECT_MASK',0x00000020)
		win_const_mgr.add_const('CALG_OID_INFO_CNG_ONLY',0xFFFFFFFF)
		win_const_mgr.add_const('NET_VALIDATE_PASSWORD_HISTORY',0x00000020)
		win_const_mgr.add_const('SI_MAY_WRITE',0x10000000)
		win_const_mgr.add_const('PDH_CANNOT_READ_NAME_STRINGS',0xC0000BC8)
		win_const_mgr.add_const('SFVM_INITMENUPOPUP',0x00000007)
		win_const_mgr.add_const('SW_MAX',0x0000000B)
		win_const_mgr.add_const('IF_TYPE_VIRTUALIPADDRESS',0x00000070)
		win_const_mgr.add_const('DDOSDCAPS_OPTCOMPRESSED',0x00000001)
		win_const_mgr.add_const('PERF_COUNTER_HISTOGRAM',0x00060000)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_COMMENT',0x00000005)
		win_const_mgr.add_const('SET_ARC_DIRECTION',0x00001006)
		win_const_mgr.add_const('DXVA_RESIDUAL_DIFFERENCE_BUFFER',0x00000003)
		win_const_mgr.add_const('MSV1_0_CRED_NT_PRESENT',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_GB_COLLATE',0x00000010)
		win_const_mgr.add_const('ERROR_IPSEC_INTEGRITY_CHECK_FAILED',0x0000365B)
		win_const_mgr.add_const('EXITEVENT_CERTRETRIEVEPENDING',0x00000010)
		win_const_mgr.add_const('DXVA_CONFIG_DATA_TYPE_AI44',0x00000001)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MINFANISOTROPIC',0x00000400)
		win_const_mgr.add_const('SQL_CODE_DATE',0x00000001)
		win_const_mgr.add_const('UIA_E_ELEMENTNOTAVAILABLE',0x80040201)
		win_const_mgr.add_const('TF_IPP_CAPS_SECUREMODESUPPORT',0x00000002)
		win_const_mgr.add_const('EC_SND_DEVICE_ERROR_BASE',0x00000200)
		win_const_mgr.add_const('MF_MINCRYPT_FAILURE',0x10000000)
		win_const_mgr.add_const('ACMERR_BASE',0x00000200)
		win_const_mgr.add_const('MP_STATUS_ABORT_DELIVERY',0x00000002)
		win_const_mgr.add_const('DDBLTFAST_DONOTWAIT',0x00000020)
		win_const_mgr.add_const('KSAUDIO_CPU_RESOURCES_HOST_CPU',0x7FFFFFFF)
		win_const_mgr.add_const('WSAENETRESET',0x00002744)
		win_const_mgr.add_const('DIREG_DRV',0x00000002)
		win_const_mgr.add_const('FWP_FILTER_ENUM_FLAG_SORTED',0x00000002)
		win_const_mgr.add_const('MSG_PEEK',0x00000002)
		win_const_mgr.add_const('WINHTTP_QUERY_ACCEPT',0x00000018)
		win_const_mgr.add_const('KSNODEPIN_SUM_MUX_OUT',0x00000000)
		win_const_mgr.add_const('KERB_ETYPE_RSA_ENV',0x0000000D)
		win_const_mgr.add_const('MPEG2_PROGRAM_SYSTEM_HEADER',0x00000005)
		win_const_mgr.add_const('DSQPF_NOSAVE',0x00000001)
		win_const_mgr.add_const('DISPID_DOCUMENTHTML',0x00000011)
		win_const_mgr.add_const('EMR_BEGINPATH',0x0000003B)
		win_const_mgr.add_const('SNMP_LOG_VERBOSE',0x00000005)
		win_const_mgr.add_const('DN_DEFAULTPRN',0x00000001)
		win_const_mgr.add_const('IDM_LOCALIZEEDITOR',0x00000936)
		win_const_mgr.add_const('SQL_ISV_CONSTRAINT_TABLE_USAGE',0x00000100)
		win_const_mgr.add_const('SESI2_NUM_ELEMENTS',0x00000009)
		win_const_mgr.add_const('BTH_MFG_WAVEPLUS_TECHNOLOGY_CO',0x00000023)
		win_const_mgr.add_const('DL_COPYCURSOR',0x00000002)
		win_const_mgr.add_const('COLOR_MENU',0x00000004)
		win_const_mgr.add_const('EVENT_OBJECT_STATECHANGE',0x0000800A)
		win_const_mgr.add_const('CERT_STORE_PROV_SET_CERT_PROPERTY_FUNC',0x00000004)
		win_const_mgr.add_const('GOPHER_TYPE_BINARY',0x00000200)
		win_const_mgr.add_const('CERT_PHYSICAL_STORE_OPEN_DISABLE_FLAG',0x00000002)
		win_const_mgr.add_const('PFA_CENTER',0x00000003)
		win_const_mgr.add_const('MCI_OVLY_PUT_FRAME',0x00080000)
		win_const_mgr.add_const('MD_SCRIPTMAPFLAG_CHECK_PATH_INFO',0x00000004)
		win_const_mgr.add_const('ERROR_NO_SUCH_PACKAGE',0x00000554)
		win_const_mgr.add_const('DT_EXPANDTABS',0x00000040)
		win_const_mgr.add_const('CRYPT_POLICY_OID_GROUP_ID',0x00000008)
		win_const_mgr.add_const('WM_INITMENUPOPUP',0x00000117)
		win_const_mgr.add_const('KF_FLAG_CREATE',0x00008000)
		win_const_mgr.add_const('DEACTIVATE_ACTCTX_FLAG_FORCE_EARLY_DEACTIVATION',0x00000001)
		win_const_mgr.add_const('MD_EXTLOG_COMPUTER_NAME',0x00000020)
		win_const_mgr.add_const('CERT_CHAIN_DISABLE_AUTH_ROOT_AUTO_UPDATE',0x00000100)
		win_const_mgr.add_const('VFT_UNKNOWN',0x00000000)
		win_const_mgr.add_const('BG_E_PROTOCOL_NOT_AVAILABLE',0x80200005)
		win_const_mgr.add_const('D3DDEVCAPS_SEPARATETEXTUREMEMORIES',0x00004000)
		win_const_mgr.add_const('TF_RIUIE_STRING',0x00000002)
		win_const_mgr.add_const('CSIDL_COMPUTERSNEARME',0x00000003)
		win_const_mgr.add_const('MOUSE_MOVED',0x00000001)
		win_const_mgr.add_const('X3_BTYPE_QP_INST_WORD_X',0x00000002)
		win_const_mgr.add_const('AA_S_ACL',0x00000080)
		win_const_mgr.add_const('MS_PROFILE_USER',0x00000002)
		win_const_mgr.add_const('BCRYPT_RSAFULLPRIVATE_MAGIC',0x33415352)
		win_const_mgr.add_const('E_XML_NODTD',0xC00CE224)
		win_const_mgr.add_const('ERROR_MEDIA_INCOMPATIBLE',0x000010DB)
		win_const_mgr.add_const('SQL_INTERVAL_SECOND',0x00000064)
		win_const_mgr.add_const('SQL_CODE_YEAR',0x00000001)
		win_const_mgr.add_const('NDIS_INTERRUPT_MODERATION_CHANGE_NEEDS_RESET',0x00000001)
		win_const_mgr.add_const('CRED_TI_SERVER_FORMAT_UNKNOWN',0x00000001)
		win_const_mgr.add_const('ERROR_DS_NO_CHAINING',0x00002087)
		win_const_mgr.add_const('PROXIMITY_UNIT_WORD',0x00000000)
		win_const_mgr.add_const('VER_SUITE_COMMUNICATIONS',0x00000008)
		win_const_mgr.add_const('ERROR_ROLLBACK_TIMER_EXPIRED',0x00001AAD)
		win_const_mgr.add_const('AIF_NOVERSIONCHECK',0x00000004)
		win_const_mgr.add_const('FD_GROUP_QOS_BIT',0x00000007)
		win_const_mgr.add_const('MODE_WINDOW',0x00000001)
		win_const_mgr.add_const('EDITF_ADDOLDCERTTYPE',0x00000010)
		win_const_mgr.add_const('SUBLANG_INUKTITUT_CANADA_LATIN',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_MM_AUTH_NOT_FOUND',0x000032D3)
		win_const_mgr.add_const('VK_RSHIFT',0x000000A1)
		win_const_mgr.add_const('RTM_ENUM_START',0x00000000)
		win_const_mgr.add_const('DMPAPER_FANFOLD_US',0x00000027)
		win_const_mgr.add_const('SERVICE_CONTROL_CONTINUE',0x00000003)
		win_const_mgr.add_const('DBPROP_APPLICATION_NAME',0x0000000B)
		win_const_mgr.add_const('DBPROPVAL_SS_ILOCKBYTES',0x00000008)
		win_const_mgr.add_const('MINIMUM_RESERVED_MANIFEST_RESOURCE_ID',0x00000001)
		win_const_mgr.add_const('DONT_USE_EMBEDDED_WCS_PROFILES',0x00000001)
		win_const_mgr.add_const('ERROR_RESOURCE_NAME_NOT_FOUND',0x00000716)
		win_const_mgr.add_const('PAN_LETT_NORMAL_CONTACT',0x00000002)
		win_const_mgr.add_const('BL_48M',0x03000000)
		win_const_mgr.add_const('MAX_ENTITY',0x00000020)
		win_const_mgr.add_const('IACE_IGNORENOCONTEXT',0x00000020)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYSTRETCHXN',0x01000000)
		win_const_mgr.add_const('BTH_MFG_INVENTEL',0x0000001E)
		win_const_mgr.add_const('GAA_FLAG_INCLUDE_TUNNEL_BINDINGORDER',0x00000400)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_SAVEREPEAT',0x0000002C)
		win_const_mgr.add_const('PICTYPE_ICON',0x00000003)
		win_const_mgr.add_const('CPF_HTTP_ERROR',0x00000800)
		win_const_mgr.add_const('MW_FILTERMODE_EXCLUDE',0x00000000)
		win_const_mgr.add_const('WM_MOUSEACTIVATE',0x00000021)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_JOB_MEMORY',0x00000200)
		win_const_mgr.add_const('CRED_FLAGS_OWF_CRED_BLOB',0x00000008)
		win_const_mgr.add_const('IDM_UNORDERLIST',0x00000889)
		win_const_mgr.add_const('IF_TYPE_VOICE_ENCAP',0x00000067)
		win_const_mgr.add_const('WM_RENDERALLFORMATS',0x00000306)
		win_const_mgr.add_const('LINEMEDIAMODE_VIDEOTEX',0x00000400)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_SECAM_S',0x00008014)
		win_const_mgr.add_const('TASK_JUNE',0x00000020)
		win_const_mgr.add_const('DBPROP_CI_QUERY_TYPE',0x00000007)
		win_const_mgr.add_const('KERB_TRANSFER_CRED_WITH_TICKETS',0x00000001)
		win_const_mgr.add_const('PORT_BFTP',0x00000098)
		win_const_mgr.add_const('NDIS_PNP_WAKE_UP_MAGIC_PACKET',0x00000001)
		win_const_mgr.add_const('WINEVENT_LEVEL_LOG_ALWAYS',0x00000000)
		win_const_mgr.add_const('MM_MIM_OPEN',0x000003C1)
		win_const_mgr.add_const('DSBS_HIDDEN',0x00000002)
		win_const_mgr.add_const('KS_DVD_CGMS_COPY_ONCE',0x00000010)
		win_const_mgr.add_const('TSF_RENAME_EXIST',0x00000001)
		win_const_mgr.add_const('CONVERT10_S_FIRST',0x000401C0)
		win_const_mgr.add_const('TIME_ZONE_ID_UNKNOWN',0x00000000)
		win_const_mgr.add_const('WINHTTP_FLAG_ASYNC',0x10000000)
		win_const_mgr.add_const('COD_PHONE_MINOR_SMART',0x00000003)
		win_const_mgr.add_const('DEBUG_MODULE_SYNTHETIC',0x00000020)
		win_const_mgr.add_const('HSE_APP_FLAG_ISOLATED_OOP',0x00000001)
		win_const_mgr.add_const('OLEUI_ERR_STANDARDMIN',0x00000064)
		win_const_mgr.add_const('DEBUG_DISASM_SOURCE_FILE_NAME',0x00000008)
		win_const_mgr.add_const('MD_ASP_SERVICE_ENABLE_TRACKER',0x00000001)
		win_const_mgr.add_const('DEBUG_BREAKPOINT_DEFERRED',0x00000002)
		win_const_mgr.add_const('SQL_INTERVAL_YEAR_TO_MONTH',0x00000064)
		win_const_mgr.add_const('NET_STRING_IPV4_NETWORK',0x00000004)
		win_const_mgr.add_const('IDM_TRIED_BLOCKFMT',0x0000001B)
		win_const_mgr.add_const('ERROR_DS_DRA_OBJ_IS_REP_SOURCE',0x00002102)
		win_const_mgr.add_const('MC_SUPPORTED_COLOR_TEMPERATURE_11500K',0x00000080)
		win_const_mgr.add_const('ERROR_PATCH_PACKAGE_REJECTED',0x0000066B)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_HARDWARE',0x00020000)
		win_const_mgr.add_const('PROCESS_HEAP_ENTRY_MOVEABLE',0x00000010)
		win_const_mgr.add_const('WKSTA_USERAWREAD_PARMNUM',0x00000036)
		win_const_mgr.add_const('WINHTTP_QUERY_USER_AGENT',0x00000027)
		win_const_mgr.add_const('SCRIPTPROC_IMPLICIT_PARENTS',0x00000200)
		win_const_mgr.add_const('HELP_MULTIKEY',0x00000201)
		win_const_mgr.add_const('D3DSP_DSTSHIFT_SHIFT',0x00000018)
		win_const_mgr.add_const('MIXER_SETCONTROLDETAILSF_QUERYMASK',0x0000000F)
		win_const_mgr.add_const('HH_ENUM_INFO_TYPE',0x00000007)
		win_const_mgr.add_const('SQL_HANDLE_SENV',0x00000005)
		win_const_mgr.add_const('MAPI_INIT_VERSION',0x00000000)
		win_const_mgr.add_const('CERT_VALIDITY_NO_CRL_FOUND',0x20000000)
		win_const_mgr.add_const('URLACTION_SHELL_WEBVIEW_VERB',0x00001805)
		win_const_mgr.add_const('DNS_TYPE_TKEY',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_ASYNCH_PREPOPULATE',0x00000010)
		win_const_mgr.add_const('CR_INVALID_STRUCTURE_SIZE',0x0000003B)
		win_const_mgr.add_const('USER_ACCOUNT_DISABLED',0x00000001)
		win_const_mgr.add_const('MDTREEOP_ANCESTORS',0x00000020)
		win_const_mgr.add_const('ETW_REVERSED_COUNTED_ANSISTRING_TYPE_VALUE',0x0000006F)
		win_const_mgr.add_const('IDM_TRIED_BACKCOLOR',0x0000001A)
		win_const_mgr.add_const('SN_V86',0x00000002)
		win_const_mgr.add_const('ACCESS_SUCCESS_DELETE',0x00000040)
		win_const_mgr.add_const('SPQ_DELAYED_COPY',0x00000001)
		win_const_mgr.add_const('DDCAPS2_CANRENDERWINDOWED',0x00080000)
		win_const_mgr.add_const('TRUST_DIRECTION_OUTBOUND',0x00000002)
		win_const_mgr.add_const('MDPROP_CELL',0x00000002)
		win_const_mgr.add_const('DEBUG_EINDEX_FROM_END',0x00000001)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_PARAM_SEQUENCE',0x0000000E)
		win_const_mgr.add_const('CLCTL_USER_SHIFT',0x00000015)
		win_const_mgr.add_const('BG_E_USERNAME_TOO_LARGE',0x80200025)
		win_const_mgr.add_const('EAP_E_EAPHOST_IDENTITY_UNKNOWN',0x80420014)
		win_const_mgr.add_const('DNS_ERROR_RECORD_TIMED_OUT',0x000025E9)
		win_const_mgr.add_const('ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER',0x00002182)
		win_const_mgr.add_const('ILLUMINANT_D55',0x00000005)
		win_const_mgr.add_const('PHONEERR_NODRIVER',0x90000019)
		win_const_mgr.add_const('CAL_GREGORIAN_ARABIC',0x0000000A)
		win_const_mgr.add_const('EDITF_ENABLEDEFAULTSMIME',0x00010000)
		win_const_mgr.add_const('KSAC3_SERVICE_NO_DIALOG',0x00000001)
		win_const_mgr.add_const('URLACTION_ACTIVEX_CURR_MAX',0x0000120A)
		win_const_mgr.add_const('BSM_NETDRIVER',0x00000002)
		win_const_mgr.add_const('KSDEVICE_DESCRIPTOR_VERSION',0x00000100)
		win_const_mgr.add_const('SELCERT_ALGORITHM',0x00000069)
		win_const_mgr.add_const('SQL_CA2_MAX_ROWS_CATALOG',0x00000800)
		win_const_mgr.add_const('VAR_CALENDAR_HIJRI',0x00000008)
		win_const_mgr.add_const('CLFS_FLAG_REENTRANT_FILE_SYSTEM',0x00000008)
		win_const_mgr.add_const('D3DLOCK_DONOTWAIT',0x00004000)
		win_const_mgr.add_const('BG_COPY_FILE_DACL',0x00000004)
		win_const_mgr.add_const('ERROR_INVALID_LDT_DESCRIPTOR',0x00000234)
		win_const_mgr.add_const('RPC_S_ALREADY_REGISTERED',0x000006AF)
		win_const_mgr.add_const('ERROR_INSTALL_PACKAGE_OPEN_FAILED',0x00000653)
		win_const_mgr.add_const('IF_TYPE_MYRINET',0x00000063)
		win_const_mgr.add_const('D3DTEXOPCAPS_MODULATEALPHA_ADDCOLOR',0x00020000)
		win_const_mgr.add_const('DC_GRADIENT',0x00000020)
		win_const_mgr.add_const('SB_PAGEDOWN',0x00000003)
		win_const_mgr.add_const('EVENT_SYSTEM_SOUND',0x00000001)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_TUNGSTEN',0x00000003)
		win_const_mgr.add_const('WMPCOREEVENT_NETWORK_BASE',0x00001518)
		win_const_mgr.add_const('TRACE_MESSAGE_PERFORMANCE_TIMESTAMP',0x00000010)
		win_const_mgr.add_const('LINECALLORIGIN_OUTBOUND',0x00000001)
		win_const_mgr.add_const('SERIAL_IOC_FCR_DMA_MODE',0x00000008)
		win_const_mgr.add_const('CONTEXT_MENU_CONTROL',0x00000002)
		win_const_mgr.add_const('KERB_ETYPE_DES3_CBC_SHA1_KD',0x00000010)
		win_const_mgr.add_const('IDD_ACMFILTERCHOOSE_CMB_FILTER',0x00000066)
		win_const_mgr.add_const('CRED_MAX_GENERIC_TARGET_NAME_LENGTH',0x00007FFF)
		win_const_mgr.add_const('EVCF_ENABLEBYDEFAULT_AUTO',0x00000008)
		win_const_mgr.add_const('EMSIS_COMPOSITIONSTRING',0x00000001)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_READONLY_CONTROLLERS',0x00000209)
		win_const_mgr.add_const('UNPROTECTED_DACL_SECURITY_INFORMATION',0x20000000)
		win_const_mgr.add_const('IMAGE_FILE_DEBUG_STRIPPED',0x00000200)
		win_const_mgr.add_const('DISPID_ADDCHANNEL',0x00000005)
		win_const_mgr.add_const('IDM_HELP_ABOUT',0x000008AD)
		win_const_mgr.add_const('SCARD_STATE_INUSE',0x00000100)
		win_const_mgr.add_const('FWPS_INCOMING_FLAG_ENFORCE_QUERY',0x00000002)
		win_const_mgr.add_const('IDM_INSINPUTBUTTON',0x00000843)
		win_const_mgr.add_const('HHWIN_BUTTON_OPTIONS',0x00000001)
		win_const_mgr.add_const('JIFMK_TEM',0x0000FF01)
		win_const_mgr.add_const('DDL_DRIVES',0x00004000)
		win_const_mgr.add_const('GL_FILE_CHANGE',0x00000080)
		win_const_mgr.add_const('OID_ATM_ILMI_VPIVCI',0x08010205)
		win_const_mgr.add_const('ISC_REQ_USE_SUPPLIED_CREDS',0x00000080)
		win_const_mgr.add_const('RF_LEFT_AND_DOWN',0x00000080)
		win_const_mgr.add_const('MF_MENUBARBREAK',0x00000020)
		win_const_mgr.add_const('D3DSP_REGTYPE_SHIFT',0x0000001C)
		win_const_mgr.add_const('ERROR_I24_OUT_OF_PAPER',0x00000009)
		win_const_mgr.add_const('DMNUP_ONEUP',0x00000002)
		win_const_mgr.add_const('TMONEPHASE',0x40000000)
		win_const_mgr.add_const('PROPID_M_XACTID_SIZE',0x00000014)
		win_const_mgr.add_const('LANG_UPPER_SORBIAN',0x00000002)
		win_const_mgr.add_const('SM_SERVERR2',0x00000059)
		win_const_mgr.add_const('WIA_IPA_SUPPRESS_PROPERTY_PAGE',0x0000101C)
		win_const_mgr.add_const('WM_KEYUP',0x00000101)
		win_const_mgr.add_const('BTH_MFG_ATMEL',0x00000013)
		win_const_mgr.add_const('ALINF_CHECKBKDATA',0x00000080)
		win_const_mgr.add_const('ICU_USERNAME',0x40000000)
		win_const_mgr.add_const('SPI_SETTOOLTIPFADE',0x00001019)
		win_const_mgr.add_const('CERT_RENEWAL_PROP_ID',0x00000040)
		win_const_mgr.add_const('CR_DEVICE_NOT_THERE',0x00000024)
		win_const_mgr.add_const('DMPAPER_LETTER',0x00000001)
		win_const_mgr.add_const('IF_TYPE_ASYNC',0x00000054)
		win_const_mgr.add_const('MDM_BEARERMODE_ISDN',0x00000001)
		win_const_mgr.add_const('WMDM_APP_REVOKED',0x00000002)
		win_const_mgr.add_const('XP_EXPEDITED_DATA',0x00000040)
		win_const_mgr.add_const('VAR_VALIDDATE',0x00000004)
		win_const_mgr.add_const('ELEMENT_STATUS_EXENAB',0x00000010)
		win_const_mgr.add_const('BACKUP_REPARSE_DATA',0x00000008)
		win_const_mgr.add_const('WMS_TOTAL_MIN_BITRATE',0x00000000)
		win_const_mgr.add_const('IF_TYPE_SMDS_ICIP',0x00000034)
		win_const_mgr.add_const('DMPAPER_ENV_DL',0x0000001B)
		win_const_mgr.add_const('MD_AUTH_SINGLEREQUESTIFPROXY',0x00000080)
		win_const_mgr.add_const('LDAP_OPT_SSL',0x00000000)
		win_const_mgr.add_const('SUBLANG_ARMENIAN_ARMENIA',0x00000001)
		win_const_mgr.add_const('INTERNET_STATE_CONNECTED',0x00000001)
		win_const_mgr.add_const('SERVICE_SID_TYPE_NONE',0x00000000)
		win_const_mgr.add_const('SV_MAXRAWBUFLEN_PARMNUM',0x000001FD)
		win_const_mgr.add_const('CFM_OFFSET',0x10000000)
		win_const_mgr.add_const('OFN_FILEMUSTEXIST',0x00001000)
		win_const_mgr.add_const('RP_DSN_NOTIFY_FAILURE',0x02000000)
		win_const_mgr.add_const('POLICY_ERRV_UNKNOWN',0x00000000)
		win_const_mgr.add_const('ERROR_FAIL_REBOOT_INITIATED',0x00000BCA)
		win_const_mgr.add_const('VENDOR_ID_LENGTH',0x00000008)
		win_const_mgr.add_const('ACCESS_NONE',0x00000000)
		win_const_mgr.add_const('D3DDEVCAPS_PUREDEVICE',0x00100000)
		win_const_mgr.add_const('RPC_S_INVALID_BINDING',0x000006A6)
		win_const_mgr.add_const('ENCRYPTION_FORMAT_DEFAULT',0x00000001)
		win_const_mgr.add_const('MM_ADLIB',0x00000009)
		win_const_mgr.add_const('WKSTA_BUFFERNAMEDPIPES_PARMNUM',0x00000033)
		win_const_mgr.add_const('SCARD_READER_EJECTS',0x00000002)
		win_const_mgr.add_const('RPC_C_MGMT_INQ_STATS',0x00000002)
		win_const_mgr.add_const('ISC_REQ_FRAGMENT_SUPPLIED',0x00002000)
		win_const_mgr.add_const('CSIDL_TEMPLATES',0x00000015)
		win_const_mgr.add_const('NUM_CM_PROB',0x00000025)
		win_const_mgr.add_const('ERROR_DOMAIN_LIMIT_EXCEEDED',0x0000054D)
		win_const_mgr.add_const('MXDCOP_PRINTTICKET_FIXED_DOC_SEQ',0x00000016)
		win_const_mgr.add_const('DLL_THREAD_DETACH',0x00000003)
		win_const_mgr.add_const('MCI_DGV_LIST_AUDIO_STREAM',0x00004002)
		win_const_mgr.add_const('LINEMEDIACONTROL_VOLUMENORMAL',0x00000400)
		win_const_mgr.add_const('MULTICLASSINFO_GETNUMRESERVEDDISPIDS',0x00000002)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_DEF_FLOW_COUNT',0x00000001)
		win_const_mgr.add_const('DNS_TYPE_NULL',0x00000000)
		win_const_mgr.add_const('CRYPT_ARCHIVABLE',0x00004000)
		win_const_mgr.add_const('DEBUG_SRCFILE_SYMBOL_TOKEN',0x00000000)
		win_const_mgr.add_const('VK_F13',0x0000007C)
		win_const_mgr.add_const('ET_MEDIATYPE',0x00000002)
		win_const_mgr.add_const('FR_PROP_STATUS',0x00000004)
		win_const_mgr.add_const('IMN_SETCOMPOSITIONFONT',0x0000000A)
		win_const_mgr.add_const('VK_F12',0x0000007B)
		win_const_mgr.add_const('F_NULL',0x0000000B)
		win_const_mgr.add_const('LVGGR_GROUP',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_NOT_ALLOWED_UNDER_DNAME',0x00002562)
		win_const_mgr.add_const('INTERIM_WINDOW',0x00000000)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_PRESERVE_CHANGES',0x00000800)
		win_const_mgr.add_const('CERT_CHAIN_RETURN_LOWER_QUALITY_CONTEXTS',0x00000080)
		win_const_mgr.add_const('PTE_WRITE',0x0000000A)
		win_const_mgr.add_const('PIR_STATUS_MINIPORT_NOKEY',0x00000005)
		win_const_mgr.add_const('IME_CMODE_FIXED',0x00000800)
		win_const_mgr.add_const('WRITE_COMPRESSION_INFO_VALID',0x00000010)
		win_const_mgr.add_const('ERROR_USER_APC',0x000002E1)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_PATH_MTU',0x00002000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR',0x00003605)
		win_const_mgr.add_const('DBPROPVAL_CU_INDEX_DEFINITION',0x00000004)
		win_const_mgr.add_const('VK_F16',0x0000007F)
		win_const_mgr.add_const('WINHTTP_DISABLE_PASSPORT_AUTH',0x00000000)
		win_const_mgr.add_const('BTH_MFG_SILICONWAVE',0x0000000B)
		win_const_mgr.add_const('IKEEXT_POLICY_FLAG_NO_IMPERSONATION_LUID_VERIFY',0x00000004)
		win_const_mgr.add_const('DNS_ERROR_ALIAS_LOOP',0x000025FA)
		win_const_mgr.add_const('ERROR_VIRUS_DELETED',0x000000E2)
		win_const_mgr.add_const('LINECALLREASON_TRANSFER',0x00000100)
		win_const_mgr.add_const('DDSCAPS2_DISCARDBACKBUFFER',0x10000000)
		win_const_mgr.add_const('DWORDLONG_ERROR',0x00000000)
		win_const_mgr.add_const('JOB_CONTROL_RESUME',0x00000002)
		win_const_mgr.add_const('IDANI_CAPTION',0x00000003)
		win_const_mgr.add_const('BLLI_L2_ELAPB',0x00000008)
		win_const_mgr.add_const('EMBDHLP_CREATENOW',0x00000000)
		win_const_mgr.add_const('DICLASSPROP_INSTALLER',0x00000001)
		win_const_mgr.add_const('D3DSTENCILCAPS_INCR',0x00000040)
		win_const_mgr.add_const('SQL_CB_NULL',0x00000000)
		win_const_mgr.add_const('VIEW_PRIORITY_DESPERATE',0x00000010)
		win_const_mgr.add_const('MAX_PHONE_NUMBER_LEN',0x00000080)
		win_const_mgr.add_const('LDAP_OPT_HOST_NAME',0x00000030)
		win_const_mgr.add_const('S_QUEUEEMPTY',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_FILE_MODE_NONE',0x00000000)
		win_const_mgr.add_const('MCI_ANIM_REALIZE_BKGD',0x00020000)
		win_const_mgr.add_const('WC_NO_BEST_FIT_CHARS',0x00000400)
		win_const_mgr.add_const('OPTION_PARAMETER_REQUEST_LIST',0x00000037)
		win_const_mgr.add_const('OS_TERMINALCLIENT',0x0000000E)
		win_const_mgr.add_const('GESTURE_DOWN_RIGHT_LONG',0x00000000)
		win_const_mgr.add_const('ERROR_DEVICE_NOT_AVAILABLE',0x000010DF)
		win_const_mgr.add_const('ERROR_RING2_STACK_IN_USE',0x000000CF)
		win_const_mgr.add_const('WMPOCXEVENT_BASE',0x00001964)
		win_const_mgr.add_const('EVENT_CONSOLE_START_APPLICATION',0x00004006)
		win_const_mgr.add_const('SM_CYMENUSIZE',0x00000037)
		win_const_mgr.add_const('PORT_LPD722',0x000002D2)
		win_const_mgr.add_const('PORT_LPD723',0x000002D3)
		win_const_mgr.add_const('MD_ERROR_SUB500_URLAUTH_STORE_ERROR',0x00000012)
		win_const_mgr.add_const('PORT_LPD721',0x000002D1)
		win_const_mgr.add_const('PORT_LPD726',0x000002D6)
		win_const_mgr.add_const('PORT_LPD727',0x000002D7)
		win_const_mgr.add_const('SERVICE_NTIP_WAITTIME_SHIFT',0x0000000C)
		win_const_mgr.add_const('DRV_OPEN',0x00000003)
		win_const_mgr.add_const('URLPOLICY_CREDENTIALS_ANONYMOUS_ONLY',0x00030000)
		win_const_mgr.add_const('PORT_LPD728',0x000002D8)
		win_const_mgr.add_const('PORT_LPD729',0x000002D9)
		win_const_mgr.add_const('EXPOSUREMODE_AUTO',0x00000002)
		win_const_mgr.add_const('ETW_REFRENCE_TYPE_VALUE',0x00000078)
		win_const_mgr.add_const('SOFTKEYBOARD_TYPE_T1',0x00000001)
		win_const_mgr.add_const('PAGESETUPDLGORDMOTIF',0x0000060E)
		win_const_mgr.add_const('IDM_TRIED_IS_1D_ELEMENT',0x00000000)
		win_const_mgr.add_const('NUMBER_OF_DEBUG_REGISTER_PAIRS',0x00000004)
		win_const_mgr.add_const('SSL_SESSION_DISABLE_RECONNECTS',0x00000002)
		win_const_mgr.add_const('ERROR_MUI_INVALID_LOCALE_NAME',0x00003AFF)
		win_const_mgr.add_const('PS_JOIN_MITER',0x00002000)
		win_const_mgr.add_const('RPC_C_AUTHN_MSN',0x00000012)
		win_const_mgr.add_const('PHOTO_CONTRAST_SOFT',0x00000001)
		win_const_mgr.add_const('SB_SIMPLEID',0x00000000)
		win_const_mgr.add_const('ERROR_INVALID_PARAMETER',0x00000057)
		win_const_mgr.add_const('DSS_RIGHT',0x00008000)
		win_const_mgr.add_const('MSV1_0_AV_FLAG_FORCE_GUEST',0x00000001)
		win_const_mgr.add_const('RBBS_FIXEDSIZE',0x00000002)
		win_const_mgr.add_const('INTERNET_AUTOPROXY_INIT_QUERYSTATE',0x00000004)
		win_const_mgr.add_const('MCIWNDF_NOTIFYANSI',0x00000080)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_DOMAIN',0x00000001)
		win_const_mgr.add_const('MDM_TONE_DIAL',0x00000100)
		win_const_mgr.add_const('ILSIF_LEAVE_SMALL_ICON',0x20000000)
		win_const_mgr.add_const('INTERNET_STATUS_COOKIE_SENT',0x00000140)
		win_const_mgr.add_const('PLAL_ALERT_CMD_LINE_A_NAME',0x00000200)
		win_const_mgr.add_const('TTFCFP_FLAGS_SUBSET',0x00000001)
		win_const_mgr.add_const('DICD_GENERATE_ID',0x00000001)
		win_const_mgr.add_const('COLOR_SOLID_RIGHT',0x000002DB)
		win_const_mgr.add_const('PAN_SERIFSTYLE_INDEX',0x00000001)
		win_const_mgr.add_const('OID_FDDI_MAC_NOT_COPIED_FLAG',0x0303024D)
		win_const_mgr.add_const('ERROR_UNHANDLED_ERROR',0xFFFFFFFF)
		win_const_mgr.add_const('ERROR_CLUSTER_SHUTTING_DOWN',0x0000139E)
		win_const_mgr.add_const('CAUSE_AAL_PARAMETERS_UNSUPPORTED',0x0000005D)
		win_const_mgr.add_const('BCSIF_SIZE',0x00000008)
		win_const_mgr.add_const('PS_OPENTYPE_FONTTYPE',0x00010000)
		win_const_mgr.add_const('LANG_GREEK',0x00000008)
		win_const_mgr.add_const('ERROR_DS_NAMING_VIOLATION',0x00002037)
		win_const_mgr.add_const('GS_8BIT_INDICES',0x00000001)
		win_const_mgr.add_const('PRIVILEGE_SET_ALL_NECESSARY',0x00000001)
		win_const_mgr.add_const('START_SESSION_RID',0x00000003)
		win_const_mgr.add_const('BAUD_4800',0x00000200)
		win_const_mgr.add_const('SUBLANG_KHMER_CAMBODIA',0x00000001)
		win_const_mgr.add_const('EDITF_ENABLEOCSPREVNOCHECK',0x02000000)
		win_const_mgr.add_const('MC_RESTORE_FACTORY_DEFAULTS_ENABLES_MONITOR_SETTINGS',0x00001000)
		win_const_mgr.add_const('HSE_TERM_ADVISORY_UNLOAD',0x00000001)
		win_const_mgr.add_const('VER_ERR_STACK_SLOT',0x00000040)
		win_const_mgr.add_const('ERROR_DS_PROTOCOL_ERROR',0x00002021)
		win_const_mgr.add_const('SS_ETCHEDHORZ',0x00000010)
		win_const_mgr.add_const('EMR_SETPALETTEENTRIES',0x00000032)
		win_const_mgr.add_const('PS_JOIN_ROUND',0x00000000)
		win_const_mgr.add_const('BTH_MFG_DIGIANSWER',0x0000000C)
		win_const_mgr.add_const('SAFER_CRITERIA_IMAGEPATH_NT',0x00001000)
		win_const_mgr.add_const('DRV_QUERYCONFIGURE',0x00000008)
		win_const_mgr.add_const('WIA_PAGE_ISO_B4',0x00000015)
		win_const_mgr.add_const('D3DCOLORWRITEENABLE_BLUE',0x00000001)
		win_const_mgr.add_const('DEBUG_REQUEST_EXT_TYPED_DATA_ANSI',0x0000000C)
		win_const_mgr.add_const('ERROR_SXS_XML_E_XMLDECLSYNTAX',0x000036D3)
		win_const_mgr.add_const('SETUP_SECURITY_CHANGED',0x00001000)
		win_const_mgr.add_const('CCM_FIRST',0x00002000)
		win_const_mgr.add_const('CLOCK_NETWORK_DERIVED',0x00000002)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_FINISHMEDIA',0x00000203)
		win_const_mgr.add_const('MCI_DGV_PASTE_AUDIO_STREAM',0x00020000)
		win_const_mgr.add_const('URLACTION_FEATURE_BLOCK_INPUT_PROMPTS',0x00002105)
		win_const_mgr.add_const('TMT_DRAWBORDERS',0x000008A6)
		win_const_mgr.add_const('CERT_UNICODE_ATTR_ERR_INDEX_SHIFT',0x00000010)
		win_const_mgr.add_const('TF_DICTATION_ENABLED',0x00000002)
		win_const_mgr.add_const('PP_VERSION',0x00000005)
		win_const_mgr.add_const('FILE_DEVICE_SERENUM',0x00000037)
		win_const_mgr.add_const('DN_NOT_FIRST_TIME',0x00000040)
		win_const_mgr.add_const('SUBLANG_SINHALESE_SRI_LANKA',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_SH3_DIRECT4_WORD',0x00000007)
		win_const_mgr.add_const('ERROR_NO_GUID_TRANSLATION',0x00000230)
		win_const_mgr.add_const('DEBUG_SYMBOL_EXPANDED',0x00000010)
		win_const_mgr.add_const('KSPROPERTY_SUPPORT_SET',0x00000002)
		win_const_mgr.add_const('RBHT_CAPTION',0x00000002)
		win_const_mgr.add_const('SPI_SETBORDER',0x00000006)
		win_const_mgr.add_const('PRINTER_STATUS_TONER_LOW',0x00020000)
		win_const_mgr.add_const('DOT11_WME_PACKET',0x00000100)
		win_const_mgr.add_const('PSINJECT_PAGES',0x00000004)
		win_const_mgr.add_const('BDIF_COD',0x00000002)
		win_const_mgr.add_const('CM_REGISTER_DEVICE_DRIVER_DISABLEABLE',0x00000001)
		win_const_mgr.add_const('SERVICE_DISABLED',0x00000004)
		win_const_mgr.add_const('NRC_NORESOURCES',0x00000038)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INVALID_DECIMAL',0x000036DF)
		win_const_mgr.add_const('ERROR_INVALID_SEPARATOR_FILE',0x00000707)
		win_const_mgr.add_const('OID_ARCNET_RECONFIGURATIONS',0x06020201)
		win_const_mgr.add_const('EM_SETIMESTATUS',0x000000D8)
		win_const_mgr.add_const('WMS_TOTAL_MAX_BITRATE',0x00000001)
		win_const_mgr.add_const('DVB_BAT_TID',0x0000004A)
		win_const_mgr.add_const('IME_MODE_NOROMAN',0x00000040)
		win_const_mgr.add_const('HTTP_STATUS_PRECOND_FAILED',0x0000019C)
		win_const_mgr.add_const('GIL_NOTFILENAME',0x00000008)
		win_const_mgr.add_const('DXVA_CHROMA_FORMAT_422',0x00000002)
		win_const_mgr.add_const('DXVA_CHROMA_FORMAT_420',0x00000001)
		win_const_mgr.add_const('CM_DETECT_HWPROF_FIRST_BOOT',0x00000004)
		win_const_mgr.add_const('SUBLANG_SYS_DEFAULT',0x00000002)
		win_const_mgr.add_const('CAL_GREGORIAN_ME_FRENCH',0x00000009)
		win_const_mgr.add_const('MCIWNDF_NOTIFYPOS',0x00000200)
		win_const_mgr.add_const('REG_OPTION_CREATE_LINK',0x00000002)
		win_const_mgr.add_const('LBN_SETFOCUS',0x00000004)
		win_const_mgr.add_const('HTTB_RESIZINGBORDER_RIGHT',0x00000040)
		win_const_mgr.add_const('EMR_EXTTEXTOUTW',0x00000054)
		win_const_mgr.add_const('MCI_SYSINFO_NAME',0x00000400)
		win_const_mgr.add_const('CR_NO_DEPENDENT',0x0000002C)
		win_const_mgr.add_const('SSTF_BORDER',0x00000002)
		win_const_mgr.add_const('DBT_NO_DISK_SPACE',0x00000047)
		win_const_mgr.add_const('LINEFORWARDMODE_UNCONDEXTERNAL',0x00000004)
		win_const_mgr.add_const('PRINTER_STATUS_PRINTING',0x00000400)
		win_const_mgr.add_const('DSROLE_PRIMARY_DS_READONLY',0x00000008)
		win_const_mgr.add_const('OCSP_INTERNAL_ERROR_RESPONSE',0x00000002)
		win_const_mgr.add_const('CM_GET_DEVICE_INTERFACE_LIST_ALL_DEVICES',0x00000001)
		win_const_mgr.add_const('RGN_DIFF',0x00000004)
		win_const_mgr.add_const('MDM_HDLCPPP_AUTH_NONE',0x00000001)
		win_const_mgr.add_const('LANG_SAMI',0x00000003)
		win_const_mgr.add_const('WM_KILLFOCUS',0x00000008)
		win_const_mgr.add_const('DBPROP_MSREMOTE_DFMODE',0x00000005)
		win_const_mgr.add_const('EMR_EXTTEXTOUTA',0x00000053)
		win_const_mgr.add_const('PORT_ISAKMP',0x000001F4)
		win_const_mgr.add_const('IAS_ATTRIB_NO_ATTRIB',0x00000000)
		win_const_mgr.add_const('TF_IPPMF_DONTCARECURRENTINPUTLANGUAGE',0x00000004)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_RINGAGAIN',0x0000000E)
		win_const_mgr.add_const('TLS1_ALERT_CLOSE_NOTIFY',0x00000000)
		win_const_mgr.add_const('CRLF_LOG_FULL_RESPONSE',0x00002000)
		win_const_mgr.add_const('FILE_WRITE_ACCESS',0x00000002)
		win_const_mgr.add_const('DISPID_DWEBBRIDGEEVENTS_ONSCRIPTLETEVENT',0x00000001)
		win_const_mgr.add_const('XEPR_V1TEMPLATENAME',0x00000009)
		win_const_mgr.add_const('DISPID_TITLEICONCHANGE',0x00000072)
		win_const_mgr.add_const('CERT_STORE_PROV_DELETED_FLAG',0x00000002)
		win_const_mgr.add_const('UAS_ROLE_MEMBER',0x00000001)
		win_const_mgr.add_const('LUP_RETURN_ALL',0x00000FF0)
		win_const_mgr.add_const('DISPID_IWBSCRIPTCONTROL_BUBBLEEVENT',0x00000002)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_NTSC_S',0x00008010)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_UNAUTH_USER_SUM_PEAK_RATE',0x0000002C)
		win_const_mgr.add_const('CREDP_FLAGS_TRUSTED_CALLER',0x00000020)
		win_const_mgr.add_const('SPMODE_MSGTRACE',0x00000400)
		win_const_mgr.add_const('DN_REBAL_CANDIDATE',0x00200000)
		win_const_mgr.add_const('OID_CO_GET_CALL_INFORMATION',0xFE000003)
		win_const_mgr.add_const('MNC_SELECT',0x00000003)
		win_const_mgr.add_const('DEBUG_SYMBOL_EXPANSION_LEVEL_MASK',0x00000000)
		win_const_mgr.add_const('KP_ROUNDS',0x00000023)
		win_const_mgr.add_const('PAN_CONTRAST_HIGH',0x00000008)
		win_const_mgr.add_const('SC_MONITORPOWER',0x0000F170)
		win_const_mgr.add_const('NRB_FUNCTION_QUERY_PINNED_SET',0x00000012)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_MSIL',0x00000008)
		win_const_mgr.add_const('ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND',0x000013D6)
		win_const_mgr.add_const('INHERITED_ACCESS_ENTRY',0x00000010)
		win_const_mgr.add_const('SCS_64BIT_BINARY',0x00000006)
		win_const_mgr.add_const('MAX_ISCSI_ALIAS_LEN',0x000000FF)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGQUERYMULTIPLEVALUE',0x00000013)
		win_const_mgr.add_const('IMAGE_REL_ARM_ADDR32NB',0x00000002)
		win_const_mgr.add_const('SQL_DIAG_UNKNOWN_STATEMENT',0x00000000)
		win_const_mgr.add_const('LVIR_BOUNDS',0x00000000)
		win_const_mgr.add_const('LINEAGENTSESSIONSTATE_BUSYONCALL',0x00000004)
		win_const_mgr.add_const('SECURITY_IUSER_RID',0x00000011)
		win_const_mgr.add_const('NUM_CR_RESULTS',0x0000003C)
		win_const_mgr.add_const('SECPKG_FLAG_DATAGRAM',0x00000008)
		win_const_mgr.add_const('IF_TYPE_SONET',0x00000027)
		win_const_mgr.add_const('ERROR_CLUSTER_INCOMPATIBLE_VERSIONS',0x000013D3)
		win_const_mgr.add_const('DRIVE_REMOTE',0x00000004)
		win_const_mgr.add_const('TITLEBARNAMELEN',0x00000028)
		win_const_mgr.add_const('IDH_MISSING_CONTEXT',0x00006F19)
		win_const_mgr.add_const('ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION',0x00003B62)
		win_const_mgr.add_const('DDSCAPS_OWNDC',0x00040000)
		win_const_mgr.add_const('DNS_RTYPE_A6',0x00002600)
		win_const_mgr.add_const('WINHTTP_ENABLE_PASSPORT_AUTH',0x10000000)
		win_const_mgr.add_const('EVENT_ACTIVITY_CTRL_SET_ID',0x00000002)
		win_const_mgr.add_const('LSA_MODE_LOG_FULL',0x00000008)
		win_const_mgr.add_const('STM_ONLY_THIS_TYPE',0x00000004)
		win_const_mgr.add_const('D3DLINECAPS_ANTIALIAS',0x00000020)
		win_const_mgr.add_const('HDF_FIXEDWIDTH',0x00000100)
		win_const_mgr.add_const('CMSG_CTRL_KEY_AGREE_DECRYPT',0x00000011)
		win_const_mgr.add_const('CONSOLE_SELECTION_NOT_EMPTY',0x00000002)
		win_const_mgr.add_const('DISPID_FRAMENEWWINDOW',0x000000CC)
		win_const_mgr.add_const('PSCB_BUTTONPRESSED',0x00000003)
		win_const_mgr.add_const('CFE_STRIKEOUT',0x00000008)
		win_const_mgr.add_const('CURSOR_SHOWING',0x00000001)
		win_const_mgr.add_const('DEBUG_FIND_SOURCE_TOKEN_LOOKUP',0x00000008)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_GOPHER_FIND',0x00000009)
		win_const_mgr.add_const('CERT_VERIFY_INHIBIT_CTL_UPDATE_FLAG',0x00000001)
		win_const_mgr.add_const('CERT_DISPWELL_SELECT',0x00000001)
		win_const_mgr.add_const('HHWIN_PARAM_RECT',0x00000001)
		win_const_mgr.add_const('IT_CUSTOM',0x00000003)
		win_const_mgr.add_const('SBT_POPOUT',0x00000200)
		win_const_mgr.add_const('ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK',0x000036E2)
		win_const_mgr.add_const('MSGF_DIALOGBOX',0x00000000)
		win_const_mgr.add_const('MC_CAPS_RED_GREEN_BLUE_GAIN',0x00000010)
		win_const_mgr.add_const('RASLCPO_SSHF',0x00000004)
		win_const_mgr.add_const('MIXERCONTROL_CONTROLF_MULTIPLE',0x00000002)
		win_const_mgr.add_const('CPLPAGE_DISPLAY_BACKGROUND',0x00000001)
		win_const_mgr.add_const('RESOURCETYPE_UNKNOWN',0xFFFFFFFF)
		win_const_mgr.add_const('DIOD_INHERIT_CLASSDRVS',0x00000002)
		win_const_mgr.add_const('MDTREEOP_CHILDREN',0x00000001)
		win_const_mgr.add_const('CERT_ID_KEY_IDENTIFIER',0x00000002)
		win_const_mgr.add_const('OCSP_MALFORMED_REQUEST_RESPONSE',0x00000001)
		win_const_mgr.add_const('IMF_VERTICAL',0x00000020)
		win_const_mgr.add_const('IMAGE_COMPRESSION_PACKBITS',0x00008005)
		win_const_mgr.add_const('EMR_ABORTPATH',0x00000044)
		win_const_mgr.add_const('WM_EXITMENULOOP',0x00000212)
		win_const_mgr.add_const('DDENUMOVERLAYZ_FRONTTOBACK',0x00000001)
		win_const_mgr.add_const('MIDIPROP_SET',0x80000000)
		win_const_mgr.add_const('ACTRL_DS_CONTROL_ACCESS',0x00000100)
		win_const_mgr.add_const('VK_OEM_NEC_EQUAL',0x00000092)
		win_const_mgr.add_const('F_DELETE',0x00000010)
		win_const_mgr.add_const('BG_E_OVERLAPPING_RANGES',0x8020002C)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_WEAK_EXTERNAL',0x00000069)
		win_const_mgr.add_const('FACILITY_METADIRECTORY',0x00000023)
		win_const_mgr.add_const('DWM_BB_TRANSITIONONMAXIMIZED',0x00000004)
		win_const_mgr.add_const('ACM_METRIC_COUNT_LOCAL_DISABLED',0x00000018)
		win_const_mgr.add_const('USE_NOFORCE',0x00000000)
		win_const_mgr.add_const('KS_INTERLACE_UNUSED',0x00000008)
		win_const_mgr.add_const('ALG_SID_DH_EPHEM',0x00000002)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MAGFPYRAMIDALQUAD',0x08000000)
		win_const_mgr.add_const('RPC_C_QOS_IDENTITY_STATIC',0x00000000)
		win_const_mgr.add_const('DM_DITHERTYPE',0x04000000)
		win_const_mgr.add_const('D3DPBLENDCAPS_INVDESTCOLOR',0x00000200)
		win_const_mgr.add_const('CHANGER_DEVICE_REINITIALIZE_CAPABLE',0x08000000)
		win_const_mgr.add_const('D3D10_SHADER_PARTIAL_PRECISION',0x00000001)
		win_const_mgr.add_const('MCI_OVLY_PUT_VIDEO',0x00100000)
		win_const_mgr.add_const('SQL_AUTOCOMMIT',0x00000066)
		win_const_mgr.add_const('IF_TYPE_RSRB',0x0000004F)
		win_const_mgr.add_const('DT_CALCRECT',0x00000400)
		win_const_mgr.add_const('SI_OBJECT_GUID',0x00010000)
		win_const_mgr.add_const('PRJOB_QS_QUEUED',0x00000000)
		win_const_mgr.add_const('C3_IDEOGRAPH',0x00000100)
		win_const_mgr.add_const('XP1_GUARANTEED_ORDER',0x00000004)
		win_const_mgr.add_const('RTM_ENUM_ALL_DESTS',0x00000000)
		win_const_mgr.add_const('MDPROPVAL_FS_GENERATED_DIMENSION',0x00000003)
		win_const_mgr.add_const('KSPROBE_MODIFY',0x00000200)
		win_const_mgr.add_const('D3DSTENCILCAPS_ZERO',0x00000002)
		win_const_mgr.add_const('WS_MAXIMIZEBOX',0x00010000)
		win_const_mgr.add_const('OID_FDDI_SMT_MAC_INDEXES',0x03030213)
		win_const_mgr.add_const('IMAGE_REL_AM_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('LINEADDRESSSTATE_FORWARD',0x00000040)
		win_const_mgr.add_const('EM_GETTHUMB',0x000000BE)
		win_const_mgr.add_const('FORMAT_MESSAGE_ARGUMENT_ARRAY',0x00002000)
		win_const_mgr.add_const('VER_SUITE_COMPUTE_SERVER',0x00004000)
		win_const_mgr.add_const('D3DCLIPPLANE0',0x00000001)
		win_const_mgr.add_const('D3DCLIPPLANE1',0x00000001)
		win_const_mgr.add_const('D3DCLIPPLANE2',0x00000001)
		win_const_mgr.add_const('D3DCLIPPLANE3',0x00000001)
		win_const_mgr.add_const('D3DCLIPPLANE4',0x00000001)
		win_const_mgr.add_const('D3DCLIPPLANE5',0x00000001)
		win_const_mgr.add_const('OPTION_PERFORM_MASK_DISCOVERY',0x0000001D)
		win_const_mgr.add_const('IDH_GENERIC_HELP_BUTTON',0x00006F1A)
		win_const_mgr.add_const('DS_REPSYNC_ASYNCHRONOUS_OPERATION',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_DROP_NO_RESPONSE',0x000035F5)
		win_const_mgr.add_const('BS_AUTORADIOBUTTON',0x00000009)
		win_const_mgr.add_const('DISPID_SETROOT',0x0000000D)
		win_const_mgr.add_const('BTH_MAX_NAME_SIZE',0x000000F8)
		win_const_mgr.add_const('CTRY_MONACO',0x00000021)
		win_const_mgr.add_const('TC_NONCONF_DISCARD',0x00000002)
		win_const_mgr.add_const('PORT_SUMITTG',0x00000059)
		win_const_mgr.add_const('WTPF_TESTCANBEVALID',0x00000080)
		win_const_mgr.add_const('SQL_SR_RESTRICT',0x00000040)
		win_const_mgr.add_const('ACMSTREAMHEADER_STATUSF_INQUEUE',0x00100000)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_INSIST_ON_FRAMESIZE_RATIO',0x00000080)
		win_const_mgr.add_const('HTTP_QUERY_RANGE',0x0000003E)
		win_const_mgr.add_const('WINHTTP_OPTION_URL',0x00000022)
		win_const_mgr.add_const('EVENT_TRACE_DELAY_OPEN_FILE_MODE',0x00000200)
		win_const_mgr.add_const('ERROR_LOG_POLICY_CONFLICT',0x000019DE)
		win_const_mgr.add_const('HORZRES',0x00000008)
		win_const_mgr.add_const('DISPID_IWEBBRIDGE_URL',0x00000001)
		win_const_mgr.add_const('FOF_WANTNUKEWARNING',0x00004000)
		win_const_mgr.add_const('TDHCACHE_LINE',0x00000008)
		win_const_mgr.add_const('LINK_STATUS_RESOLVED',0x00000001)
		win_const_mgr.add_const('DNF_INBOX_DRIVER',0x00100000)
		win_const_mgr.add_const('DBPROPVAL_TC_NONE',0x00000000)
		win_const_mgr.add_const('PORT_SUNRPC',0x0000006F)
		win_const_mgr.add_const('CRYPT_REGISTER_FIRST_INDEX',0x00000000)
		win_const_mgr.add_const('CERT_CHAIN_FIND_BY_ISSUER_COMPARE_KEY_FLAG',0x00000001)
		win_const_mgr.add_const('GT_TASK',0x00000004)
		win_const_mgr.add_const('SFGAO_GHOSTED',0x00008000)
		win_const_mgr.add_const('CONFIGFLAG_FINISH_INSTALL',0x00000400)
		win_const_mgr.add_const('WCE_AF_IRDA',0x00000016)
		win_const_mgr.add_const('RBS_FIXEDORDER',0x00000800)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_SERVICEPACK',0x00000010)
		win_const_mgr.add_const('SPFILENOTIFY_STARTREGISTRATION',0x00000019)
		win_const_mgr.add_const('DIRID_COMMON_PROGRAMS',0x00004017)
		win_const_mgr.add_const('DFM_WM_MEASUREITEM',0x00000006)
		win_const_mgr.add_const('CAUSE_UNSUPPORTED_TRAFFIC_PARAMETERS',0x00000049)
		win_const_mgr.add_const('ERROR_MEMBER_NOT_IN_ALIAS',0x00000561)
		win_const_mgr.add_const('MCI_CDA_STATUS_TYPE_TRACK',0x00004001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_ATTRIB_FAIL',0x000035EA)
		win_const_mgr.add_const('DEBUG_FILTER_OUTPUT',0x00000002)
		win_const_mgr.add_const('PBT_POWERSETTINGCHANGE',0x00008013)
		win_const_mgr.add_const('AMDDS_RGBFLP',0x00000040)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_CAN_ALLOCATE',0x00000040)
		win_const_mgr.add_const('MSV1_0_SUBAUTHENTICATION_DLL_EX',0x00100000)
		win_const_mgr.add_const('TMT_BOOL',0x000000CB)
		win_const_mgr.add_const('VIF_CANNOTCREATE',0x00000800)
		win_const_mgr.add_const('TAPE_DRIVE_CLEAN_REQUESTS',0x02000000)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_ATTENTION_STEPPING',0x00002000)
		win_const_mgr.add_const('KAGPROP_LIKEESCAPECLAUSE',0x0000000A)
		win_const_mgr.add_const('ERROR_DS_EXISTS_IN_MAY_HAVE',0x000020C2)
		win_const_mgr.add_const('SDP_ATTRIB_HID_BATTERY_POWER',0x00000209)
		win_const_mgr.add_const('RPC_X_PIPE_EMPTY',0x0000077E)
		win_const_mgr.add_const('CAUSE_INVALID_CALL_REFERENCE',0x00000051)
		win_const_mgr.add_const('TRACELOG_CREATE_REALTIME',0x00000020)
		win_const_mgr.add_const('COPYFLG_NOVERSIONCHECK',0x00000004)
		win_const_mgr.add_const('TF_LBI_STYLE_BTN_BUTTON',0x00010000)
		win_const_mgr.add_const('PR_JOBSTATUS',0x00000000)
		win_const_mgr.add_const('SCARD_E_ICC_INSTALLATION',0x80100020)
		win_const_mgr.add_const('OID_FDDI_MAC_INDEX',0x0303022C)
		win_const_mgr.add_const('HTHSCROLL',0x00000006)
		win_const_mgr.add_const('CERT_RDN_FLAGS_MASK',0xFF000000)
		win_const_mgr.add_const('WINHTTP_OPTION_DISABLE_FEATURE',0x0000003F)
		win_const_mgr.add_const('ERROR_UNABLE_TO_MOVE_REPLACEMENT',0x00000498)
		win_const_mgr.add_const('RPC_C_HTTP_AUTHN_SCHEME_CERT',0x00010000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGDELETE',0x0000000C)
		win_const_mgr.add_const('MD_APPPOOL_IDENTITY_TYPE_LOCALSYSTEM',0x00000000)
		win_const_mgr.add_const('SC_NEXTWINDOW',0x0000F040)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_COM_PROGID_REDIRECTION',0x00000007)
		win_const_mgr.add_const('TXTLOG_SYSTEM_STATE_CHANGE',0x00000003)
		win_const_mgr.add_const('ODS_CHECKED',0x00000008)
		win_const_mgr.add_const('OLEUI_ERR_OLEMEMALLOC',0x00000064)
		win_const_mgr.add_const('SQL_API_SQLFETCHSCROLL',0x000003FD)
		win_const_mgr.add_const('SQL_DESC_DATETIME_INTERVAL_CODE',0x000003EF)
		win_const_mgr.add_const('ACTRL_CHANGE_ACCESS',0x20000000)
		win_const_mgr.add_const('IDS_CAP_WAVE_OPEN_ERROR',0x000001A3)
		win_const_mgr.add_const('PID_IPV6',0x00000057)
		win_const_mgr.add_const('DNS_TYPE_UID',0x00000065)
		win_const_mgr.add_const('ERROR_CONNECTION_ABORTED',0x000004D4)
		win_const_mgr.add_const('DNS_RCLASS_CHAOS',0x00000300)
		win_const_mgr.add_const('LEFT_CTRL_PRESSED',0x00000008)
		win_const_mgr.add_const('SHCIDS_ALLFIELDS',0x80000000)
		win_const_mgr.add_const('CMSG_HASHED_FLAG',0x00000001)
		win_const_mgr.add_const('BTH_MFG_RF_MICRO_DEVICES',0x00000028)
		win_const_mgr.add_const('EVENT_HEADER_FLAG_STRING_ONLY',0x00000004)
		win_const_mgr.add_const('IMN_GUIDELINE',0x0000000D)
		win_const_mgr.add_const('SHDID_COMPUTER_DRIVE525',0x00000006)
		win_const_mgr.add_const('JIFMK_DAC',0x0000FFCC)
		win_const_mgr.add_const('SQL_SG_USAGE_ON_TRANSLATION',0x00000008)
		win_const_mgr.add_const('SQLBINARY',0x00000002)
		win_const_mgr.add_const('BS_TYPEMASK',0x0000000F)
		win_const_mgr.add_const('ALG_SID_TLS1_MASTER',0x00000006)
		win_const_mgr.add_const('WKSTA_LOCKINCREMENT_PARMNUM',0x0000002A)
		win_const_mgr.add_const('D3D10_MAX_BORDER_COLOR_COMPONENT',0x00000001)
		win_const_mgr.add_const('MCI_VCR_SET_POWER',0x00020000)
		win_const_mgr.add_const('INTERNET_OPTION_USER_AGENT',0x00000029)
		win_const_mgr.add_const('IDS_CAP_AVI_INIT_ERROR',0x000001B1)
		win_const_mgr.add_const('EM_POSFROMCHAR',0x000000D6)
		win_const_mgr.add_const('ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST',0x000013DA)
		win_const_mgr.add_const('SCARD_E_PROTO_MISMATCH',0x8010000F)
		win_const_mgr.add_const('JIFMK_SOI',0x0000FFD8)
		win_const_mgr.add_const('GESTURE_RIGHT_LEFT',0x00000000)
		win_const_mgr.add_const('CM_CREATE_DEVNODE_NORMAL',0x00000000)
		win_const_mgr.add_const('NCRYPT_ALLOW_KEY_AGREEMENT_FLAG',0x00000004)
		win_const_mgr.add_const('CR_INVALID_RESOURCEID',0x0000000B)
		win_const_mgr.add_const('SUBLANG_ENGLISH_ZIMBABWE',0x00000000)
		win_const_mgr.add_const('INTERNET_FLAG_ASYNC',0x10000000)
		win_const_mgr.add_const('GL_ID_NODICTIONARY',0x00000010)
		win_const_mgr.add_const('MDPROPVAL_MOQ_DATASOURCE_CUBE',0x00000001)
		win_const_mgr.add_const('VRN_SHIFT',0x0000003D)
		win_const_mgr.add_const('PROP_COMMENT',0x00000001)
		win_const_mgr.add_const('EXPOSUREMODE_SHUTTER_PRIORITY',0x00000004)
		win_const_mgr.add_const('COD_MAJOR_PHONE',0x00000002)
		win_const_mgr.add_const('WCB16_PASCAL',0x00000000)
		win_const_mgr.add_const('ACL_REVISION4',0x00000004)
		win_const_mgr.add_const('AVISTDINDEX_DELTAFRAME',0x80000000)
		win_const_mgr.add_const('AVIF_WASCAPTUREFILE',0x00010000)
		win_const_mgr.add_const('_WIN32_IE_IE401',0x00000401)
		win_const_mgr.add_const('LINEERR_CONFERENCEFULL',0x80000007)
		win_const_mgr.add_const('WINHTTP_OPTION_CONFIGURE_PASSPORT_AUTH',0x00000053)
		win_const_mgr.add_const('ERROR_EVT_MALFORMED_XML_TEXT',0x00003AA0)
		win_const_mgr.add_const('SF_MAX_FILTER_DESC_LEN',0x00000100)
		win_const_mgr.add_const('LCPRI_IMPOSSIBLE',0x0000F000)
		win_const_mgr.add_const('BG_E_ERROR_CONTEXT_GENERAL_QUEUE_MANAGER',0x80200008)
		win_const_mgr.add_const('LVGF_HEADER',0x00000001)
		win_const_mgr.add_const('DDLOCK_SURFACEMEMORYPTR',0x00000000)
		win_const_mgr.add_const('MDPROPVAL_MSC_GREATERTHAN',0x00000002)
		win_const_mgr.add_const('SECTION_MAP_WRITE',0x00000002)
		win_const_mgr.add_const('SHGFI_TYPENAME',0x00000400)
		win_const_mgr.add_const('TXFS_ROLLFORWARD_REDO_FLAG_USE_LAST_VIRTUAL_CLOCK',0x00000002)
		win_const_mgr.add_const('VOS_OS232_PM32',0x00030003)
		win_const_mgr.add_const('URLACTION_HTML_SUBMIT_FORMS_TO',0x00001603)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_NETINFO',0x00000011)
		win_const_mgr.add_const('LVCF_SUBITEM',0x00000008)
		win_const_mgr.add_const('WSAESTALE',0x00002756)
		win_const_mgr.add_const('STREAM_CONTAINS_PROPERTIES',0x00000004)
		win_const_mgr.add_const('PROCESSOR_AMD_X8664',0x000021D8)
		win_const_mgr.add_const('IPV6_RECVDSTADDR',0x00000019)
		win_const_mgr.add_const('DEBUG_MODULE_LOADED',0x00000000)
		win_const_mgr.add_const('WM_APP',0x00008000)
		win_const_mgr.add_const('SQL_CDO_CONSTRAINT',0x00000004)
		win_const_mgr.add_const('MIXER_OBJECTF_MIDIOUT',0x30000000)
		win_const_mgr.add_const('ERROR_UNWIND',0x0000021E)
		win_const_mgr.add_const('X3_D_WH_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('SPI_SETSPEECHRECOGNITION',0x0000104B)
		win_const_mgr.add_const('DSA_NEWOBJ_CTX_CLEANUP',0x00000004)
		win_const_mgr.add_const('AMDDS_NONE',0x00000000)
		win_const_mgr.add_const('LINEAGENTSESSIONSTATE_READY',0x00000002)
		win_const_mgr.add_const('MSV1_0_S4U_LOGON_FLAG_CHECK_LOGONHOURS',0x00000002)
		win_const_mgr.add_const('IDI_HAND',0x00007F01)
		win_const_mgr.add_const('EVENT_HEADER_FLAG_64_BIT_HEADER',0x00000040)
		win_const_mgr.add_const('ISIOI_ICONINDEX',0x00000002)
		win_const_mgr.add_const('IDS_ON_BEHALF_OF',0x0001100A)
		win_const_mgr.add_const('SQL_SP_LIKE',0x00000200)
		win_const_mgr.add_const('SQL_ROW_IGNORE',0x00000001)
		win_const_mgr.add_const('MM_MOM_DONE',0x000003C9)
		win_const_mgr.add_const('PFD_SWAP_COPY',0x00000400)
		win_const_mgr.add_const('XECT_EXTENSION_V2',0x00000002)
		win_const_mgr.add_const('SYMFLAG_REGISTER',0x00000008)
		win_const_mgr.add_const('XECT_EXTENSION_V1',0x00000001)
		win_const_mgr.add_const('EVENTLOG_START_PAIRED_EVENT',0x00000001)
		win_const_mgr.add_const('PIPE_TYPE_BYTE',0x00000000)
		win_const_mgr.add_const('CERT_FILTER_OP_EXISTS',0x00000001)
		win_const_mgr.add_const('IF_TYPE_WAN_WORKSTATION',0x00000004)
		win_const_mgr.add_const('LINECALLSTATE_ONHOLD',0x00000400)
		win_const_mgr.add_const('ERROR_MUI_FILE_NOT_FOUND',0x00003AFC)
		win_const_mgr.add_const('SQL_AT_ADD_COLUMN_SINGLE',0x00000020)
		win_const_mgr.add_const('STI_HW_CONFIG_SERIAL',0x00000008)
		win_const_mgr.add_const('CERT_VERIFY_UPDATED_CTL_FLAG',0x00000001)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_DEFAULT',0x00000004)
		win_const_mgr.add_const('ERROR_VERSION_PARSE_ERROR',0x00000309)
		win_const_mgr.add_const('STI_ONLINESTATE_IO_ACTIVE',0x00000080)
		win_const_mgr.add_const('WMDM_STATUS_STORAGECONTROL_INSERTING',0x00002000)
		win_const_mgr.add_const('BZ_DISABLERETRYBUTTON',0x00000004)
		win_const_mgr.add_const('NRC_BRIDGE',0x00000023)
		win_const_mgr.add_const('SCRIPTPROP_CONVERSIONLCID',0x00001002)
		win_const_mgr.add_const('SPDRP_UI_NUMBER',0x00000010)
		win_const_mgr.add_const('TYPE_ENUMFONTFAMILIESEX',0x00000003)
		win_const_mgr.add_const('SES_BIDI',0x00001000)
		win_const_mgr.add_const('ELF_DISABLECHANGESOURCE',0x00000008)
		win_const_mgr.add_const('CMSG_KEY_TRANS_ENCRYPT_FREE_PARA_FLAG',0x00000001)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_FLIP',0x00000012)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_GPRELLO',0x00000016)
		win_const_mgr.add_const('DNS_RTYPE_LOC',0x00000001)
		win_const_mgr.add_const('WLX_VERSION_1_0',0x00000000)
		win_const_mgr.add_const('WLX_VERSION_1_1',0x00000000)
		win_const_mgr.add_const('WLX_VERSION_1_2',0x00000000)
		win_const_mgr.add_const('WLX_VERSION_1_3',0x00000000)
		win_const_mgr.add_const('EVENT_MODIFY_STATE',0x00000002)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_NO_ADDING_SUBSCRIPTIONS',0x00001D03)
		win_const_mgr.add_const('BTHPROTO_L2CAP',0x00000100)
		win_const_mgr.add_const('SPI_GETFONTSMOOTHINGORIENTATION',0x00002012)
		win_const_mgr.add_const('SPI_GETSCREENREADER',0x00000046)
		win_const_mgr.add_const('DMO_E_NOTACCEPTING',0x80040204)
		win_const_mgr.add_const('DBPROPVAL_ASYNCH_RANDOMPOPULATION',0x00000004)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_LIMITED_BC',0x00000400)
		win_const_mgr.add_const('LVCFMT_FIXED_RATIO',0x00080000)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H261_B',0x00000002)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_H261_A',0x00000001)
		win_const_mgr.add_const('ERROR_INVALID_MINALLOCSIZE',0x000000C3)
		win_const_mgr.add_const('CRYPTLIMIT_USING_SGC',0x00000002)
		win_const_mgr.add_const('SQL_SNVF_CHAR_LENGTH',0x00000002)
		win_const_mgr.add_const('WM_INPUTLANGCHANGE',0x00000051)
		win_const_mgr.add_const('ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS',0x000019E8)
		win_const_mgr.add_const('ERROR_SECTOR_NOT_FOUND',0x0000001B)
		win_const_mgr.add_const('PURGE_TXCLEAR',0x00000004)
		win_const_mgr.add_const('WNTYPE_FILE',0x00000002)
		win_const_mgr.add_const('OID_FDDI_MAC_MA_UNITDATA_AVAILABLE',0x0303024E)
		win_const_mgr.add_const('CRYPT_MESSAGE_ENCAPSULATED_CONTENT_OUT_FLAG',0x00000002)
		win_const_mgr.add_const('PD_SHOWHELP',0x00000800)
		win_const_mgr.add_const('DC_PEN',0x00000013)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_DAY_TO_HOUR',0x00000400)
		win_const_mgr.add_const('INDEX_GUID_OBJECT',0x00000004)
		win_const_mgr.add_const('MM_MSFT_ACM_MSAUDIO1',0x00000027)
		win_const_mgr.add_const('SECPKG_STATE_STRONG_ENCRYPTION_PERMITTED',0x00000002)
		win_const_mgr.add_const('SND_ALIAS_ID',0x00110000)
		win_const_mgr.add_const('D3DPBLENDCAPS_SRCCOLOR2',0x00004000)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_CONSTRAINT_TABLE_USAGE',0x00000003)
		win_const_mgr.add_const('CERT_NAME_ATTR_TYPE',0x00000003)
		win_const_mgr.add_const('PHONE_REMOVE',0x0000001A)
		win_const_mgr.add_const('WCS_ICCONLY',0x00010000)
		win_const_mgr.add_const('CM_PROB_HARDWARE_DISABLED',0x0000001D)
		win_const_mgr.add_const('HTHELP',0x00000015)
		win_const_mgr.add_const('LVGF_TITLEIMAGE',0x00001000)
		win_const_mgr.add_const('MAX_ELAPSED_TIME_LENGTH',0x0000000F)
		win_const_mgr.add_const('SB_LINERIGHT',0x00000001)
		win_const_mgr.add_const('ERROR_DS_DUP_RDN',0x000020BA)
		win_const_mgr.add_const('KS_DVD_SECTOR_PROTECTED',0x00000020)
		win_const_mgr.add_const('SWP_HIDEWINDOW',0x00000080)
		win_const_mgr.add_const('OPTION_EXTENSIONS_PATH',0x00000012)
		win_const_mgr.add_const('ERROR_CTX_SHADOW_NOT_RUNNING',0x00001B91)
		win_const_mgr.add_const('ERROR_RESMON_INVALID_STATE',0x000013DC)
		win_const_mgr.add_const('MWT_RIGHTMULTIPLY',0x00000003)
		win_const_mgr.add_const('DMPAPER_A2',0x00000042)
		win_const_mgr.add_const('CM_SETUP_PROP_CHANGE',0x00000003)
		win_const_mgr.add_const('COMMON_LVB_GRID_HORIZONTAL',0x00000400)
		win_const_mgr.add_const('CTRY_UNITED_STATES',0x00000001)
		win_const_mgr.add_const('PDH_CANNOT_CONNECT_WMI_SERVER',0xC0000BE8)
		win_const_mgr.add_const('SQL_API_SQLGETDIAGREC',0x000003F3)
		win_const_mgr.add_const('D3D10_DEFAULT_BLEND_FACTOR_BLUE',0x00000001)
		win_const_mgr.add_const('IDM_ROWINSERT',0x000008A4)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_RESTART_GENERAL_ATTRIBUTES',0x000000A2)
		win_const_mgr.add_const('BI_PNG',0x00000005)
		win_const_mgr.add_const('BG_E_NOT_FOUND',0x80200001)
		win_const_mgr.add_const('KSMETHOD_TYPE_SOURCE',0x00000004)
		win_const_mgr.add_const('JOB_OBJECT_POST_AT_END_OF_JOB',0x00000001)
		win_const_mgr.add_const('IDM_IMGARTPLAY',0x000008E2)
		win_const_mgr.add_const('CDO_E_INVALID_ENCODING_FOR_MULTIPART',0x8004021C)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_CLOCK_INCREMENT_RATE',0x0000401C)
		win_const_mgr.add_const('GCP_ERROR',0x00008000)
		win_const_mgr.add_const('AVICOMPRESSF_DATARATE',0x00000002)
		win_const_mgr.add_const('MAX_UUIDS_IN_QUERY',0x0000000C)
		win_const_mgr.add_const('SHFMT_NOFORMAT',0xFFFFFFFD)
		win_const_mgr.add_const('SSPROP_INIT_FILENAME',0x0000000C)
		win_const_mgr.add_const('PS_USERSTYLE',0x00000007)
		win_const_mgr.add_const('WSA_FLAG_MULTIPOINT_D_LEAF',0x00000010)
		win_const_mgr.add_const('ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION',0x00001AC2)
		win_const_mgr.add_const('SHCIDS_BITMASK',0xFFFF0000)
		win_const_mgr.add_const('REVEXT_CDPLDAPURL_OLD',0x00000001)
		win_const_mgr.add_const('SPI_GETFONTSMOOTHINGCONTRAST',0x0000200C)
		win_const_mgr.add_const('DISPID_IWEBBRIDGE_EMBED',0x00000003)
		win_const_mgr.add_const('SV_INITSEARCHTABLE_PARMNUM',0x00000222)
		win_const_mgr.add_const('PORT_PUMP',0x000002EF)
		win_const_mgr.add_const('LVBKIF_SOURCE_NONE',0x00000000)
		win_const_mgr.add_const('LINEQUEUESTATUS_UPDATEINFO',0x00000001)
		win_const_mgr.add_const('PXE_ADDR_USE_ADDR',0x00000004)
		win_const_mgr.add_const('WLX_SAS_TYPE_SCRNSVR_ACTIVITY',0x00000003)
		win_const_mgr.add_const('LR_COPYDELETEORG',0x00000008)
		win_const_mgr.add_const('DNS_ERROR_SECONDARY_DATA',0x000025F0)
		win_const_mgr.add_const('DNS_ATMA_FORMAT_E164',0x00000001)
		win_const_mgr.add_const('CGD_DATE_PROPERTY',0x00000002)
		win_const_mgr.add_const('EC_FILE_CLOSED',0x00000044)
		win_const_mgr.add_const('UPPER_GET_HINT_MASK',0x0FF00000)
		win_const_mgr.add_const('DDBLT_ALPHADESTSURFACEOVERRIDE',0x00000008)
		win_const_mgr.add_const('MCI_RESTORE',0x00000087)
		win_const_mgr.add_const('TIMEELEMENT_OFFSET',0x00000100)
		win_const_mgr.add_const('CMSG_CTRL_VERIFY_HASH',0x00000005)
		win_const_mgr.add_const('VIDEO_IN',0x00000004)
		win_const_mgr.add_const('ERROR_CLUSCFG_ALREADY_COMMITTED',0x0000170D)
		win_const_mgr.add_const('LINECALLINFOSTATE_NUMOWNERDECR',0x00001000)
		win_const_mgr.add_const('MCI_SET_AUDIO',0x00000800)
		win_const_mgr.add_const('AVIGETFRAMEF_BESTDISPLAYFMT',0x00000001)
		win_const_mgr.add_const('SMAE_EXPANDED',0x00000001)
		win_const_mgr.add_const('PSP_RTLREADING',0x00000010)
		win_const_mgr.add_const('EC_VMR_RENDERDEVICE_SET',0x00000053)
		win_const_mgr.add_const('SUBLANG_PERSIAN_IRAN',0x00000001)
		win_const_mgr.add_const('MPR_INTERFACE_NO_DEVICE',0x00000040)
		win_const_mgr.add_const('TVE_COLLAPSE',0x00000001)
		win_const_mgr.add_const('MB_ICONMASK',0x000000F0)
		win_const_mgr.add_const('FMMENU_FIRST',0x00000001)
		win_const_mgr.add_const('DNS_TYPE_GPOS',0x00000001)
		win_const_mgr.add_const('MDPROPVAL_MF_WITH_CALCMEMBERS',0x00000001)
		win_const_mgr.add_const('SQL_DIAG_CREATE_TABLE',0x0000004D)
		win_const_mgr.add_const('E_XML_BUFFERTOOSMALL',0xC00CE226)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_DISPOSITION',0x0000002F)
		win_const_mgr.add_const('OFN_OVERWRITEPROMPT',0x00000002)
		win_const_mgr.add_const('FTPWPP_ERROR_INETOPEN_FAILED',0xC0042301)
		win_const_mgr.add_const('DEV_PORT_COM1',0x00000002)
		win_const_mgr.add_const('DISPID_TITLECHANGE',0x00000071)
		win_const_mgr.add_const('DEV_PORT_COM3',0x00000004)
		win_const_mgr.add_const('READ_THRESHOLDS',0x000000D1)
		win_const_mgr.add_const('DXGI_CPU_ACCESS_DYNAMIC',0x00000001)
		win_const_mgr.add_const('IDM_COPY',0x0000000F)
		win_const_mgr.add_const('ERROR_POTENTIAL_FILE_FOUND',0x0000049C)
		win_const_mgr.add_const('URLPOLICY_AUTHENTICATE_CHALLENGE_RESPONSE',0x00010000)
		win_const_mgr.add_const('CERT_STORE_SAVE_TO_MEMORY',0x00000002)
		win_const_mgr.add_const('LINEBEARERMODE_VOICE',0x00000001)
		win_const_mgr.add_const('TF_IPP_FLAG_ACTIVE',0x00000001)
		win_const_mgr.add_const('LINECALLINFOSTATE_TREATMENT',0x10000000)
		win_const_mgr.add_const('XEPR_CANAME',0x00000002)
		win_const_mgr.add_const('DEBUG_BREAKPOINT_GO_ONLY',0x00000001)
		win_const_mgr.add_const('DBFLAGS_READONLY',0x00000001)
		win_const_mgr.add_const('FLG_DELPROPERTY_MULTI_SZ_DELSTRING',0x00000001)
		win_const_mgr.add_const('IDM_SNAPTOGRID',0x00000028)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_HANDLE_COUNT',0x00000003)
		win_const_mgr.add_const('ERROR_BAD_CURRENT_DIRECTORY',0x000002BF)
		win_const_mgr.add_const('GAA_FLAG_INCLUDE_PREFIX',0x00000010)
		win_const_mgr.add_const('LOCALE_SISO3166CTRYNAME2',0x00000068)
		win_const_mgr.add_const('MDM_AUTO_ML_NONE',0x00000001)
		win_const_mgr.add_const('DDSCAPS2_ADDITIONALPRIMARY',0x80000000)
		win_const_mgr.add_const('SERVICE_CONFIG_PRESHUTDOWN_INFO',0x00000007)
		win_const_mgr.add_const('FAX_ERR_START',0x00001B59)
		win_const_mgr.add_const('LDAP_OPT_AUTO_RECONNECT',0x00000091)
		win_const_mgr.add_const('D3DPRASTERCAPS_SCISSORTEST',0x01000000)
		win_const_mgr.add_const('SPI_SETSTICKYKEYS',0x0000003B)
		win_const_mgr.add_const('WNODE_FLAG_SINGLE_INSTANCE',0x00000002)
		win_const_mgr.add_const('EXITEVENT_CRLISSUED',0x00000020)
		win_const_mgr.add_const('CRYPT_OID_INFO_OID_KEY',0x00000001)
		win_const_mgr.add_const('PORT_VIAFTP',0x0000003F)
		win_const_mgr.add_const('DSPRINT_PUBLISH',0x00000001)
		win_const_mgr.add_const('CERT_STORE_PROV_DELETE_CTL_FUNC',0x0000000B)
		win_const_mgr.add_const('SHERB_NOCONFIRMATION',0x00000001)
		win_const_mgr.add_const('DEBUG_REQUEST_TARGET_EXCEPTION_RECORD',0x00000003)
		win_const_mgr.add_const('CERT_TRUST_INVALID_BASIC_CONSTRAINTS',0x00000400)
		win_const_mgr.add_const('SERVICE_CONTINUE_PENDING',0x00000005)
		win_const_mgr.add_const('URLACTION_ACTIVEX_RUN',0x00001200)
		win_const_mgr.add_const('EMR_BITBLT',0x0000004C)
		win_const_mgr.add_const('DEBUG_ASMOPT_DEFAULT',0x00000000)
		win_const_mgr.add_const('RPC_C_PROTSEQ_MAX_REQS_DEFAULT',0x0000000A)
		win_const_mgr.add_const('HTTP_TRACE_EVENT_FLAG_STATIC_DESCRIPTIVE_FIELDS',0x00000001)
		win_const_mgr.add_const('MB_OK',0x00000000)
		win_const_mgr.add_const('DN_MF_PARENT',0x00010000)
		win_const_mgr.add_const('BCRYPT_SUPPORTED_PAD_PSS',0x00000010)
		win_const_mgr.add_const('MDM_HDLCPPP_AUTH_CHAP',0x00000003)
		win_const_mgr.add_const('AUDCLNT_STREAMFLAGS_EVENTCALLBACK',0x00040000)
		win_const_mgr.add_const('SQL_FN_TD_CURRENT_DATE',0x00020000)
		win_const_mgr.add_const('BCN_FIRST',0x00000000)
		win_const_mgr.add_const('KERB_ETYPE_AES256_CTS_HMAC_SHA1_96',0x00000012)
		win_const_mgr.add_const('OBJECT_PUSH_FORMAT_VMESSAGE',0x00000006)
		win_const_mgr.add_const('MOVEFILE_COPY_ALLOWED',0x00000002)
		win_const_mgr.add_const('IP_DROP_MEMBERSHIP',0x0000000D)
		win_const_mgr.add_const('SOUND_SYSTEM_INFORMATION',0x00000007)
		win_const_mgr.add_const('EXECUTE_FLAG_BUFFER_RESPONSE',0x00000020)
		win_const_mgr.add_const('DBIMF_FIXEDBMP',0x00000004)
		win_const_mgr.add_const('CONNECT_UPDATE_PROFILE',0x00000001)
		win_const_mgr.add_const('SSM_UPDATE',0x00000004)
		win_const_mgr.add_const('CMSG_SIGNER_HASH_ALGORITHM_PARAM',0x00000008)
		win_const_mgr.add_const('ETW_GUID_TYPE_VALUE',0x00000065)
		win_const_mgr.add_const('CRYPT_STRING_BASE64HEADER',0x00000000)
		win_const_mgr.add_const('ERROR_SERVICE_NOTIFICATION',0x000002CC)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_CURRENTMEDIATYPE',0x0000010F)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_MM_ACQUIRE_DROP',0x000035F1)
		win_const_mgr.add_const('NETERR_RING_STATUS_SIGNAL_STATION',0x00000080)
		win_const_mgr.add_const('PDH_NOT_IMPLEMENTED',0xC0000BD3)
		win_const_mgr.add_const('RPC_BUFFER_EXTRA',0x00004000)
		win_const_mgr.add_const('OPEN_ALWAYS',0x00000004)
		win_const_mgr.add_const('WIA_DPC_TIMER_VALUE',0x0000080F)
		win_const_mgr.add_const('ERROR_ERRORS_ENCOUNTERED',0x00000306)
		win_const_mgr.add_const('WIA_IPA_BYTES_PER_LINE',0x00001011)
		win_const_mgr.add_const('SF_DENIED_RESOURCE',0x00000002)
		win_const_mgr.add_const('LVSIL_SMALL',0x00000001)
		win_const_mgr.add_const('BIGENDIAN',0x00000000)
		win_const_mgr.add_const('GESTURE_UP_RIGHT_LONG',0x00000000)
		win_const_mgr.add_const('IDI_WINLOGO',0x00007F05)
		win_const_mgr.add_const('EAP_I_EAPHOST_FIRST',0x80420000)
		win_const_mgr.add_const('DDBLTFAST_SRCCOLORKEY',0x00000001)
		win_const_mgr.add_const('OID_QOS_RESERVED6',0xFB010105)
		win_const_mgr.add_const('LINECALLFEATURE_SETTREATMENT',0x20000000)
		win_const_mgr.add_const('NETLOGON_DNS_UPDATE_FAILURE',0x00000040)
		win_const_mgr.add_const('CERT_NAME_SIMPLE_DISPLAY_TYPE',0x00000004)
		win_const_mgr.add_const('VOLUME_NAME_GUID',0x00000001)
		win_const_mgr.add_const('CACHE_NOTIFY_DELETE_ALL',0x00000008)
		win_const_mgr.add_const('LINEMEDIAMODE_G3FAX',0x00000020)
		win_const_mgr.add_const('MD_NOTIFY_AUTH_COMPLETE',0x04000000)
		win_const_mgr.add_const('FPST_ENUM_PROP',0x00000001)
		win_const_mgr.add_const('BG_E_ERROR_CONTEXT_UNKNOWN',0x80200007)
		win_const_mgr.add_const('SPI_SETFLATMENU',0x00001023)
		win_const_mgr.add_const('SNMPLISTEN_ALL_ADDR',0x00000001)
		win_const_mgr.add_const('CLFS_SCAN_BACKWARD',0x00000004)
		win_const_mgr.add_const('MSV1_0_SUBAUTHENTICATION_FLAGS',0xFF000000)
		win_const_mgr.add_const('DDBLTFAST_WAIT',0x00000010)
		win_const_mgr.add_const('_WIN32_IE_IE40',0x00000400)
		win_const_mgr.add_const('WTS_SESSION_LOGOFF',0x00000006)
		win_const_mgr.add_const('IDM_TEXTBOX',0x00000871)
		win_const_mgr.add_const('CRED_ALLOW_NAME_RESOLUTION',0x00000001)
		win_const_mgr.add_const('EFFECTMODE_SEPIA',0x00000003)
		win_const_mgr.add_const('FILE_SHARE_WRITE',0x00000002)
		win_const_mgr.add_const('PROGDLG_NORMAL',0x00000000)
		win_const_mgr.add_const('ERROR_DS_BAD_HIERARCHY_FILE',0x000020E9)
		win_const_mgr.add_const('JOY_BUTTON3CHG',0x00000400)
		win_const_mgr.add_const('APPLICATION_RUN',0x00000005)
		win_const_mgr.add_const('LINEDISCONNECTMODE_INCOMPATIBLE',0x00000400)
		win_const_mgr.add_const('CONNECT_CRED_RESET',0x00002000)
		win_const_mgr.add_const('JOB_CONTROL_LAST_PAGE_EJECTED',0x00000007)
		win_const_mgr.add_const('CDO_E_NO_SUPPORT_FOR_OBJECTS',0x80040207)
		win_const_mgr.add_const('ERROR_INVALID_CALLGATE',0x000000B5)
		win_const_mgr.add_const('SQL_COLUMN_MONEY',0x00000009)
		win_const_mgr.add_const('DBPROPVAL_OA_ATEXECUTE',0x00000002)
		win_const_mgr.add_const('D3DUSAGE_QUERY_SRGBREAD',0x00010000)
		win_const_mgr.add_const('MDM_SPEED_ADJUST',0x00000080)
		win_const_mgr.add_const('COLOR_SATSCROLL',0x000002BD)
		win_const_mgr.add_const('CAL_GREGORIAN',0x00000001)
		win_const_mgr.add_const('CLFS_FLAG_NO_FLAGS',0x00000000)
		win_const_mgr.add_const('IPX_STOPFILTERPTYPE',0x00004003)
		win_const_mgr.add_const('SNMP_ACCESS_READ_ONLY',0x00000002)
		win_const_mgr.add_const('IF_TYPE_MPLS',0x000000A6)
		win_const_mgr.add_const('MQ_ADMIN_ACCESS',0x00000080)
		win_const_mgr.add_const('UNDNAME_NO_ARGUMENTS',0x00002000)
		win_const_mgr.add_const('GPO_LIST_FLAG_SITEONLY',0x00000002)
		win_const_mgr.add_const('INTERNET_RFC1123_BUFSIZE',0x0000001E)
		win_const_mgr.add_const('CM_DEVCAP_SILENTINSTALL',0x00000020)
		win_const_mgr.add_const('D3D10_MAX_POSITION_VALUE',0x00000003)
		win_const_mgr.add_const('EPR_180',0x00000002)
		win_const_mgr.add_const('PID_QUERY_RANK',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_POLICY_MATCH',0x0000362C)
		win_const_mgr.add_const('DSBID_CONTAINERLIST',0x00000101)
		win_const_mgr.add_const('IMAGE_SCN_MEM_EXECUTE',0x20000000)
		win_const_mgr.add_const('ICM_SETDEFAULTPROFILE',0x00000004)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY2',0x00000004)
		win_const_mgr.add_const('MAX_DHCPV6_DUID_LENGTH',0x00000082)
		win_const_mgr.add_const('SQL_SNVF_POSITION',0x00000020)
		win_const_mgr.add_const('DEBUG_ATTACH_LOCAL_KERNEL',0x00000001)
		win_const_mgr.add_const('LVNI_ALL',0x00000000)
		win_const_mgr.add_const('ERROR_LOG_POLICY_NOT_INSTALLED',0x000019DC)
		win_const_mgr.add_const('MAX_PRIORITY',0x00000063)
		win_const_mgr.add_const('SEM_FAILCRITICALERRORS',0x00000001)
		win_const_mgr.add_const('CMM_VERSION',0x00000004)
		win_const_mgr.add_const('MFASFINDEXER_READ_FOR_REVERSEPLAYBACK_OUTOFDATASEGMENT',0x00000000)
		win_const_mgr.add_const('CRYPT_OVERRIDE',0x00010000)
		win_const_mgr.add_const('MAX_SID_SIZE',0x00000100)
		win_const_mgr.add_const('WINHTTP_QUERY_CUSTOM',0x0000FFFF)
		win_const_mgr.add_const('ISCSI_SECURITY_FLAG_VALID',0x00000001)
		win_const_mgr.add_const('DIGCF_PROFILE',0x00000008)
		win_const_mgr.add_const('KF_DLGMODE',0x00000800)
		win_const_mgr.add_const('DBHHEADER_DEBUGDIRS',0x00000001)
		win_const_mgr.add_const('SI_NO_TREE_APPLY',0x00000400)
		win_const_mgr.add_const('WM_AFXFIRST',0x00000360)
		win_const_mgr.add_const('DISPID_ACTIVATEACTIVEXCONTROLS',0x00000008)
		win_const_mgr.add_const('NDIS_802_11_LENGTH_SSID',0x00000020)
		win_const_mgr.add_const('DNS_RTYPE_SIG',0x00001800)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_14',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_FU_NOT_SUPPORTED',0x00000001)
		win_const_mgr.add_const('COMP_TYPE_PICTURE',0x00000001)
		win_const_mgr.add_const('VIEW_S_LAST',0x0004014F)
		win_const_mgr.add_const('DISPID_SAX_XMLREADER__MIN',0x00000501)
		win_const_mgr.add_const('IMAGE_SYM_DTYPE_NULL',0x00000000)
		win_const_mgr.add_const('AGP_FLAG_NO_1X_RATE',0x00000001)
		win_const_mgr.add_const('EN_ALIGNRTL',0x00000711)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_INVALID_POLICY_FLAG',0x00000080)
		win_const_mgr.add_const('TMT_NORMALSIZE',0x00000D51)
		win_const_mgr.add_const('PAN_STROKE_GRADUAL_DIAG',0x00000002)
		win_const_mgr.add_const('EC_WMT_EVENT_BASE',0x00000251)
		win_const_mgr.add_const('INF_STYLE_CACHE_IGNORE',0x00000040)
		win_const_mgr.add_const('EMO_PROMOTE',0x00000002)
		win_const_mgr.add_const('SPI_GETTOOLTIPANIMATION',0x00001016)
		win_const_mgr.add_const('C2_LEFTTORIGHT',0x00000001)
		win_const_mgr.add_const('HELP_PARTIALKEY',0x00000105)
		win_const_mgr.add_const('SPI_GETFOREGROUNDFLASHCOUNT',0x00002004)
		win_const_mgr.add_const('IPX_OUT_TRAFFIC_FILTER_INFO_TYPE',0x0000000C)
		win_const_mgr.add_const('DEVICEPOWER_FILTER_WAKEPROGRAMMABLE',0x04000000)
		win_const_mgr.add_const('SERVICE_NOTIFY_STATUS_CHANGE_1',0x00000001)
		win_const_mgr.add_const('PRINTER_STATUS_OUT_OF_MEMORY',0x00200000)
		win_const_mgr.add_const('TTDT_AUTOMATIC',0x00000000)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY9',0x00000200)
		win_const_mgr.add_const('LDAP_DELETE_CMD',0x00000004)
		win_const_mgr.add_const('VERTSIZE',0x00000006)
		win_const_mgr.add_const('DCX_INTERSECTRGN',0x00000080)
		win_const_mgr.add_const('SQL_OJ_INNER',0x00000020)
		win_const_mgr.add_const('LINEQUEUESTATUS_NEWQUEUE',0x00000002)
		win_const_mgr.add_const('GOPHER_TYPE_ERROR',0x00000008)
		win_const_mgr.add_const('VR_INSTANT_OK',0x00000001)
		win_const_mgr.add_const('SBSP_NAVIGATEFORWARD',0x00008000)
		win_const_mgr.add_const('SCRIPTPROP_HACK_TRIDENTEVENTSINK',0x70000001)
		win_const_mgr.add_const('URLPOLICY_CHANNEL_SOFTDIST_AUTOINSTALL',0x00030000)
		win_const_mgr.add_const('LVGF_FOOTER',0x00000002)
		win_const_mgr.add_const('DOT11_STATUS_PS_LIFETIME_EXPIRED',0x00040000)
		win_const_mgr.add_const('FIND_INDEX',0x00004000)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_8BYTES',0x00400000)
		win_const_mgr.add_const('SV_MAXFREEPAGEDPOOLCHUNKS_PARMNUM',0x00000246)
		win_const_mgr.add_const('PTE_LP_CACHE_SHIFT',0x00000035)
		win_const_mgr.add_const('PRINTER_STATUS_PAPER_JAM',0x00000008)
		win_const_mgr.add_const('CFM_SIZE',0x80000000)
		win_const_mgr.add_const('TAPE_DRIVE_FIXED_BLOCK',0x00000400)
		win_const_mgr.add_const('ERROR_CONVERT_TO_LARGE',0x00000258)
		win_const_mgr.add_const('ERROR_NET_WRITE_FAULT',0x00000058)
		win_const_mgr.add_const('RESOURCEUSAGE_CONTAINER',0x00000002)
		win_const_mgr.add_const('SUBLANG_BRETON_FRANCE',0x00000001)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_NOT_SUPPORTED_CRITICAL_EXT_FLAG',0x00002000)
		win_const_mgr.add_const('OID_802_11_DESIRED_RATES',0x0D010210)
		win_const_mgr.add_const('DN_NT_ENUMERATOR',0x00800000)
		win_const_mgr.add_const('RFCOMM_CMD_RPN',0x00000003)
		win_const_mgr.add_const('DO_DROPFILE',0x454C4946)
		win_const_mgr.add_const('ERROR_SXS_ASSEMBLY_NOT_LOCKED',0x00003711)
		win_const_mgr.add_const('CERT_CHAIN_MAX_AIA_URL_RETRIEVAL_COUNT_PER_CHAIN_DEFAULT',0x0000000A)
		win_const_mgr.add_const('MM_SNDBLST_MIDIIN',0x00000004)
		win_const_mgr.add_const('DNS_COMPRESSED_QUESTION_NAME',0x0000C00C)
		win_const_mgr.add_const('WMSZ_RIGHT',0x00000002)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_NOT_TIME_NESTED_FLAG',0x00000004)
		win_const_mgr.add_const('IDM_CSSEDITING_LEVEL',0x00000966)
		win_const_mgr.add_const('PSF_STAYONCLIPBOARDCHANGE',0x00000040)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_SUPPORTEDMODEPAGES',0x0000020C)
		win_const_mgr.add_const('LOCALSTATE_UNINSTALL_UNMANAGED',0x00000004)
		win_const_mgr.add_const('RPC_CONTEXT_HANDLE_DONT_SERIALIZE',0x20000000)
		win_const_mgr.add_const('LVS_NOSORTHEADER',0x00008000)
		win_const_mgr.add_const('SELCERT_ISSUED_TO',0x00000067)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_HTTP_REQUEST',0x0000000D)
		win_const_mgr.add_const('CONTEXT_EXCEPTION_REPORTING',0x80000000)
		win_const_mgr.add_const('CREATE_DEFAULT_ERROR_MODE',0x04000000)
		win_const_mgr.add_const('TMT_HIGHLIGHTTEXT',0x0000064F)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_ENABLEMCN',0x00000105)
		win_const_mgr.add_const('FILTER_SERVER_TRUST_ACCOUNT',0x00000020)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_PRIORITY',0x0000000E)
		win_const_mgr.add_const('SQL_CREATE_VIEW',0x00000086)
		win_const_mgr.add_const('MF_OWNERDRAW',0x00000100)
		win_const_mgr.add_const('INTERNET_OPTION_SEND_THROUGHPUT',0x00000038)
		win_const_mgr.add_const('ALG_SID_DSS_ANY',0x00000000)
		win_const_mgr.add_const('CERT_NCRYPT_KEY_HANDLE_PROP_ID',0x0000004E)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_RGB_S',0x00008011)
		win_const_mgr.add_const('EXCHIVERB_RESERVED_COMPOSE',0x00000064)
		win_const_mgr.add_const('DISABLE_L1_BYPASS',0x00000009)
		win_const_mgr.add_const('ERROR_BEYOND_VDL',0x00000509)
		win_const_mgr.add_const('LVGF_DESCRIPTIONBOTTOM',0x00000800)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_PRIVATE_READ_WRITE_MEMORY',0x00000100)
		win_const_mgr.add_const('EVENT_SYSTEM_MENUPOPUPEND',0x00000007)
		win_const_mgr.add_const('DMPAPER_LETTER_EXTRA',0x00000032)
		win_const_mgr.add_const('DN_REMOVABLE',0x00004000)
		win_const_mgr.add_const('SUBLANG_GEORGIAN_GEORGIA',0x00000001)
		win_const_mgr.add_const('SECURITY_OTHER_ORGANIZATION_RID',0x000003E8)
		win_const_mgr.add_const('CERT_DISPWELL_DISTRUST_CA_CERT',0x00000006)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_DSN',0x00000009)
		win_const_mgr.add_const('PROPID_QUERY_VIRTUALPATH',0x00000009)
		win_const_mgr.add_const('KF_FLAG_INIT',0x00000800)
		win_const_mgr.add_const('FLG_ADDREG_TYPE_MULTI_SZ',0x00010000)
		win_const_mgr.add_const('XECP_STRING_PROPERTY',0x00000001)
		win_const_mgr.add_const('AUTO_PROXY_FLAG_USER_SET',0x00000001)
		win_const_mgr.add_const('PRF_FIRSTDIRDEF',0x00000004)
		win_const_mgr.add_const('DIRID_COMMON_DOCUMENTS',0x0000402E)
		win_const_mgr.add_const('ERROR_DS_ATTRIBUTE_OWNED_BY_SAM',0x0000209A)
		win_const_mgr.add_const('ASYNC_RECO_SETTEXTCONTEXT_FAILED',0x00000100)
		win_const_mgr.add_const('NTMS_USERNAME_LENGTH',0x00000040)
		win_const_mgr.add_const('DISPID_TIME_MAX',0x0000270F)
		win_const_mgr.add_const('SQL_AUTOCOMMIT_ON',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_MM_POLICY_NOT_FOUND',0x000032CC)
		win_const_mgr.add_const('SUBLANG_UI_CUSTOM_DEFAULT',0x00000005)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_NIGHTSRV',0x00000024)
		win_const_mgr.add_const('PROCESSOR_ARM920',0x00000920)
		win_const_mgr.add_const('RIDEV_EXMODEMASK',0x000000F0)
		win_const_mgr.add_const('ERROR_NT_CROSS_ENCRYPTION_REQUIRED',0x0000056A)
		win_const_mgr.add_const('SSTF_DISPLAY',0x00000003)
		win_const_mgr.add_const('TXFS_RM_FLAG_LOG_GROWTH_INCREMENT_NUM_CONTAINERS',0x00000010)
		win_const_mgr.add_const('HTTP_REQUEST_FLAG_IP_ROUTED',0x00000002)
		win_const_mgr.add_const('LB_GETSELITEMS',0x00000191)
		win_const_mgr.add_const('MKF_CONFIRMHOTKEY',0x00000008)
		win_const_mgr.add_const('MSV1_0_CHALLENGE_LENGTH',0x00000008)
		win_const_mgr.add_const('HH_ALINK_LOOKUP',0x00000013)
		win_const_mgr.add_const('PP_USER_CERTSTORE',0x0000002A)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_CONFIRM',0x00000456)
		win_const_mgr.add_const('MD_ACCESS_SSL128',0x00000100)
		win_const_mgr.add_const('DIRID_PROGRAM_FILES_COMMON',0x0000402B)
		win_const_mgr.add_const('ERROR_NOT_SUPPORTED_ON_SBS',0x000004E6)
		win_const_mgr.add_const('TAPE_DRIVE_LOCK_UNLOCK',0x80000004)
		win_const_mgr.add_const('CRYPT_FIRST',0x00000001)
		win_const_mgr.add_const('SHOW_OPENWINDOW',0x00000001)
		win_const_mgr.add_const('PRODUCT_ULTIMATE',0x00000001)
		win_const_mgr.add_const('INVALID_FILE_SIZE',0xFFFFFFFF)
		win_const_mgr.add_const('RPC_S_FP_DIV_ZERO',0x000006E9)
		win_const_mgr.add_const('WINHTTP_OPTION_ENABLETRACING',0x00000055)
		win_const_mgr.add_const('ACM_FORMATTAGDETAILSF_LARGESTSIZE',0x00000002)
		win_const_mgr.add_const('DISPID_SNAPTOGRID',0x00000015)
		win_const_mgr.add_const('IFF_BROADCAST',0x00000002)
		win_const_mgr.add_const('DDSCL_NOWINDOWCHANGES',0x00000004)
		win_const_mgr.add_const('CRM_PROTOCOL_MAXIMUM_OPTION',0x00000003)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_STATUS_STRING',0x00000013)
		win_const_mgr.add_const('CRYPT_STRING_HEX_ANY',0x00000008)
		win_const_mgr.add_const('IDD_ACMFORMATCHOOSE_BTN_DELNAME',0x00000068)
		win_const_mgr.add_const('IS_SPLIT',0x00000004)
		win_const_mgr.add_const('SYMOPT_LOAD_ANYTHING',0x00000040)
		win_const_mgr.add_const('LINEADDRFEATURE_UNPARK',0x00000080)
		win_const_mgr.add_const('EIMES_COMPLETECOMPSTRKILLFOCUS',0x00000004)
		win_const_mgr.add_const('IDM_TEXTONLY',0x00000855)
		win_const_mgr.add_const('PORT_TCPMUX',0x00000001)
		win_const_mgr.add_const('KSMPEGVIDMODE_SCALE',0x00000004)
		win_const_mgr.add_const('PAN_SERIF_TRIANGLE',0x0000000A)
		win_const_mgr.add_const('LINECALLPARTYID_UNKNOWN',0x00000020)
		win_const_mgr.add_const('DC_HASDEFID',0x0000534B)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_305',0x80190131)
		win_const_mgr.add_const('BG_E_TOO_MANY_FILES',0x8020001C)
		win_const_mgr.add_const('SORT_KOREAN_UNICODE',0x00000001)
		win_const_mgr.add_const('WPSTYLE_STRETCH',0x00000002)
		win_const_mgr.add_const('TMT_POSITION',0x000000D0)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_PRE_FETCH_NONE',0x00000000)
		win_const_mgr.add_const('WIA_DPS_DITHER_SELECT',0x00000C0C)
		win_const_mgr.add_const('SCESTATUS_EXCEPTION_IN_SERVER',0x00000010)
		win_const_mgr.add_const('CURVECAPS',0x0000001C)
		win_const_mgr.add_const('BEGIN_NESTED_SYSTEM_CHANGE',0x00000066)
		win_const_mgr.add_const('SM_MOUSEHORIZONTALWHEELPRESENT',0x0000005B)
		win_const_mgr.add_const('INTERENT_GOONLINE_REFRESH',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_PPC_REFLO',0x00000011)
		win_const_mgr.add_const('TF_REUSE_SOCKET',0x00000002)
		win_const_mgr.add_const('STOCK_LAST',0x00000010)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME10',0x0000004D)
		win_const_mgr.add_const('ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED',0x000013D5)
		win_const_mgr.add_const('LOCALE_SPARENT',0x00000006)
		win_const_mgr.add_const('PFM_TEXTWRAPPINGBREAK',0x20000000)
		win_const_mgr.add_const('FWPM_CONTEXT_IPSEC_INBOUND_PASSTHRU',0x00000001)
		win_const_mgr.add_const('EVENT_HEADER_PROPERTY_FORWARDED_XML',0x00000002)
		win_const_mgr.add_const('DDFXALPHACAPS_OVERLAYALPHAPIXELSNEG',0x00000080)
		win_const_mgr.add_const('FIND_ACTCTX_SECTION_KEY_RETURN_HACTCTX',0x00000001)
		win_const_mgr.add_const('HTMLDLG_ALLOW_UNKNOWN_THREAD',0x00000200)
		win_const_mgr.add_const('INPUTLANGCHANGE_BACKWARD',0x00000004)
		win_const_mgr.add_const('FEI_BAD_ADDRESS',0x00000007)
		win_const_mgr.add_const('SQL_TC_DDL_COMMIT',0x00000003)
		win_const_mgr.add_const('FIND_TYPE',0x000000F0)
		win_const_mgr.add_const('D3D10_DEFAULT_DEPTH_BIAS_CLAMP',0x00000000)
		win_const_mgr.add_const('UDS_WRAP',0x00000001)
		win_const_mgr.add_const('MAX_DESC',0x00000040)
		win_const_mgr.add_const('MAP_PRECOMPOSED',0x00000020)
		win_const_mgr.add_const('MMIO_READ',0x00000000)
		win_const_mgr.add_const('DBFLAGS_LAZYFLUSH',0x00000008)
		win_const_mgr.add_const('REGISTERED',0x00000004)
		win_const_mgr.add_const('GCS_VALIDATEA',0x00000002)
		win_const_mgr.add_const('SNMP_TRAP_WARMSTART',0x00000001)
		win_const_mgr.add_const('ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT',0x00000673)
		win_const_mgr.add_const('REG_OPTION_RESERVED',0x00000000)
		win_const_mgr.add_const('SHGFI_ATTR_SPECIFIED',0x00020000)
		win_const_mgr.add_const('AE_SRVSTATUS',0x00000000)
		win_const_mgr.add_const('IDM_SAVEPICTURE',0x000008DE)
		win_const_mgr.add_const('GCS_VALIDATEW',0x00000006)
		win_const_mgr.add_const('PSM_SDP',0x00000001)
		win_const_mgr.add_const('CFU_UNDERLINENONE',0x00000000)
		win_const_mgr.add_const('PORT_STATUS_TYPE_INFO',0x00000003)
		win_const_mgr.add_const('CONTEXT_MENU_TABLE',0x00000003)
		win_const_mgr.add_const('MCI_WAVE_SET_AVGBYTESPERSEC',0x00080000)
		win_const_mgr.add_const('COD_FORMAT_MASK',0x00000003)
		win_const_mgr.add_const('PORT_ISIGL',0x00000037)
		win_const_mgr.add_const('SQL_FN_TD_NOW',0x00000001)
		win_const_mgr.add_const('VK_EREOF',0x000000F9)
		win_const_mgr.add_const('ENABLE_GAMUT_CHECKING',0x00010000)
		win_const_mgr.add_const('SHGFI_ATTRIBUTES',0x00000800)
		win_const_mgr.add_const('TIME_ONESHOT',0x00000000)
		win_const_mgr.add_const('SC_RESTORE',0x0000F120)
		win_const_mgr.add_const('ISCSI_LOGIN_OPTIONS_DEFAULT_TIME_2_RETAIN',0x00000010)
		win_const_mgr.add_const('SQL_DIAG_CREATE_ASSERTION',0x00000006)
		win_const_mgr.add_const('SM_CXDRAG',0x00000044)
		win_const_mgr.add_const('CFU_UNDERLINEWORD',0x00000002)
		win_const_mgr.add_const('SMART_READ_LOG',0x000000D5)
		win_const_mgr.add_const('SQL_SG_INSERT_COLUMN',0x00000080)
		win_const_mgr.add_const('SQL_SCOPE_TRANSACTION',0x00000001)
		win_const_mgr.add_const('DISPLAY_DEVICE_REMOTE',0x04000000)
		win_const_mgr.add_const('ERROR_DS_DRA_SCHEMA_MISMATCH',0x000020E2)
		win_const_mgr.add_const('SRCINFO_TAGFILE',0x00000002)
		win_const_mgr.add_const('OID_802_11_CAPABILITY',0x0D010122)
		win_const_mgr.add_const('BG_E_EMPTY',0x80200003)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_PCODE',0x00008000)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_EXTENSION',0x80000000)
		win_const_mgr.add_const('MPEGLAYER3_ID_UNKNOWN',0x00000000)
		win_const_mgr.add_const('MFOUTPUTATTRIBUTE_COMPRESSED',0x00000008)
		win_const_mgr.add_const('D3DVS_Y_W',0x00000003)
		win_const_mgr.add_const('MCI_GETDEVCAPS_CAN_RECORD',0x00000001)
		win_const_mgr.add_const('ICM_QUERYMATCH',0x00000007)
		win_const_mgr.add_const('LOCALSTATE_ORPHANED',0x00000020)
		win_const_mgr.add_const('D3DVS_Y_X',0x00000000)
		win_const_mgr.add_const('D3DVS_Y_Y',0x00000001)
		win_const_mgr.add_const('D3DVS_Y_Z',0x00000002)
		win_const_mgr.add_const('IDM_TRIED_BRING_FORWARD',0x00000009)
		win_const_mgr.add_const('MCI_DGV_LIST_STILL_QUALITY',0x00004004)
		win_const_mgr.add_const('DMPAPER_ESHEET',0x0000001A)
		win_const_mgr.add_const('MD_CPU_ENABLE_ALL_PROC_LOGGING',0x00000001)
		win_const_mgr.add_const('DBPROP_FREETEXTUSESTEMMING',0x0000000D)
		win_const_mgr.add_const('RSOP_TEMPNAMESPACE_EXISTS',0x00000004)
		win_const_mgr.add_const('SQL_BOOKMARK_PERSISTENCE',0x00000052)
		win_const_mgr.add_const('DEBUG_ENGOPT_INITIAL_MODULE_BREAK',0x00000040)
		win_const_mgr.add_const('IDM_HYPERLINK',0x0000084C)
		win_const_mgr.add_const('EVENTLOG_FORWARDS_READ',0x00000004)
		win_const_mgr.add_const('PERF_SIZE_ZERO',0x00000200)
		win_const_mgr.add_const('STDPROP_INDEX_VFLD',0x000000C9)
		win_const_mgr.add_const('__RPCPROXY_H_VERSION__',0x000001DB)
		win_const_mgr.add_const('EVENT_OBJECT_DEFACTIONCHANGE',0x00008011)
		win_const_mgr.add_const('HTTP_QUERY_FLAG_NUMBER',0x20000000)
		win_const_mgr.add_const('LINEERR_TARGETNOTFOUND',0x8000004E)
		win_const_mgr.add_const('PHONELAMPMODE_OFF',0x00000002)
		win_const_mgr.add_const('IDM_INSERTOBJECT',0x00000019)
		win_const_mgr.add_const('DNS_ERROR_OPERATION_BASE',0x00002616)
		win_const_mgr.add_const('BSF_IGNORECURRENTTASK',0x00000002)
		win_const_mgr.add_const('DEBUG_SYSOBJINFO_THREAD_BASIC_INFORMATION',0x00000000)
		win_const_mgr.add_const('CS_BYTEALIGNWINDOW',0x00002000)
		win_const_mgr.add_const('EDITF_ENABLEAKIISSUERSERIAL',0x00001000)
		win_const_mgr.add_const('NETLOGON_VERIFY_STATUS_RETURNED',0x00000080)
		win_const_mgr.add_const('DIRID_SYSTEM16',0x00000032)
		win_const_mgr.add_const('WM_CT_TOP_FIELD_FIRST',0x00000040)
		win_const_mgr.add_const('SPI_SETPOWEROFFTIMEOUT',0x00000052)
		win_const_mgr.add_const('PDERR_PRINTERCODES',0x00001000)
		win_const_mgr.add_const('DXVA_BIDIRECTIONAL_AVERAGING_H263_TRUNC',0x00000001)
		win_const_mgr.add_const('RPC_P_ADDR_FORMAT_TCP_IPV4',0x00000001)
		win_const_mgr.add_const('MSGNAME_FORWARDED_TO',0x00000004)
		win_const_mgr.add_const('DLCTL_VIDEOS',0x00000020)
		win_const_mgr.add_const('CF_DISABLEACTIVATEAS',0x00000040)
		win_const_mgr.add_const('COM_RIGHTS_ACTIVATE_REMOTE',0x00000010)
		win_const_mgr.add_const('SHCNE_UPDATEITEM',0x00002000)
		win_const_mgr.add_const('SQL_NULL_HENV',0x00000000)
		win_const_mgr.add_const('LANG_PUNJABI',0x00000046)
		win_const_mgr.add_const('SP_COPY_NOPRUNE',0x00100000)
		win_const_mgr.add_const('NDIS_MAC_OPTION_SUPPORTS_MAC_ADDRESS_OVERWRITE',0x00000080)
		win_const_mgr.add_const('DSSSF_SIMPLEAUTHENTICATE',0x00000001)
		win_const_mgr.add_const('PID_WORDCOUNT',0x0000000F)
		win_const_mgr.add_const('DEVICEPOWER_AND_OPERATION',0x40000000)
		win_const_mgr.add_const('SQL_SR_REFERENCES_TABLE',0x00000400)
		win_const_mgr.add_const('COPYFILE_SIS_FLAGS',0x00000003)
		win_const_mgr.add_const('SQL_FALSE',0x00000000)
		win_const_mgr.add_const('WS_HSCROLL',0x00100000)
		win_const_mgr.add_const('VS_FFI_SIGNATURE',0xBD04EFFE)
		win_const_mgr.add_const('ERROR_CONTROL_C_EXIT',0x0000023C)
		win_const_mgr.add_const('PERF_TIMER_TICK',0x00000000)
		win_const_mgr.add_const('RQ_AUTHORIZE_REQUEST',0x00000004)
		win_const_mgr.add_const('EAP_PEER_FLAG_GUEST_ACCESS',0x00000040)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_DIALBILLING',0x00000040)
		win_const_mgr.add_const('RP_ERROR_CONTEXT_MTA',0x00400000)
		win_const_mgr.add_const('MAX_NABTS_VBI_LINES_PER_FIELD',0x0000000B)
		win_const_mgr.add_const('MAPIFORM_SELECT_NON_FOLDER_REGISTRY_ONLY',0x00000002)
		win_const_mgr.add_const('DMPAPER_PENV_8',0x00000067)
		win_const_mgr.add_const('LVGGR_SUBSETLINK',0x00000003)
		win_const_mgr.add_const('LVS_EX_UNDERLINECOLD',0x00001000)
		win_const_mgr.add_const('DMPAPER_PENV_7',0x00000066)
		win_const_mgr.add_const('DMPAPER_PENV_4',0x00000063)
		win_const_mgr.add_const('DMPAPER_PENV_5',0x00000064)
		win_const_mgr.add_const('DMPAPER_PENV_2',0x00000061)
		win_const_mgr.add_const('SV_LOGONALERT_PARMNUM',0x00000027)
		win_const_mgr.add_const('DMPAPER_PENV_1',0x00000060)
		win_const_mgr.add_const('PORT_CON',0x000002F7)
		win_const_mgr.add_const('RC_BITBLT',0x00000001)
		win_const_mgr.add_const('BCRYPT_PAD_NONE',0x00000001)
		win_const_mgr.add_const('WM_SYSKEYUP',0x00000105)
		win_const_mgr.add_const('FILE_ATTRIBUTE_SPARSE_FILE',0x00000200)
		win_const_mgr.add_const('FR_ENABLEHOOK',0x00000100)
		win_const_mgr.add_const('ERROR_NO_ASSOCIATION',0x00000483)
		win_const_mgr.add_const('OCR_SIZENWSE',0x00007F82)
		win_const_mgr.add_const('CERT_REQUEST_V1',0x00000000)
		win_const_mgr.add_const('REG_OPTION_VOLATILE',0x00000001)
		win_const_mgr.add_const('DCR_DEFER_ALL',0x00000007)
		win_const_mgr.add_const('PHOTO_EXPOSUREPROGRAM_PORTRAIT',0x00000007)
		win_const_mgr.add_const('STDOLE2_LCID',0x00000000)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_UPGRADE',0x00000003)
		win_const_mgr.add_const('MPR_INTERFACE_DIALOUT_HOURS_RESTRICTION',0x00000010)
		win_const_mgr.add_const('FILE_APPEND_DATA',0x00000004)
		win_const_mgr.add_const('DDPF_ZPIXELS',0x00002000)
		win_const_mgr.add_const('ERROR_INVALID_CMM',0x000007DA)
		win_const_mgr.add_const('MAX_LABEL_LEN',0x0000001E)
		win_const_mgr.add_const('WMIREG_FLAG_INSTANCE_PDO',0x00000020)
		win_const_mgr.add_const('PROPTYPE_DATE',0x00000002)
		win_const_mgr.add_const('DEBUG_SESSION_FAILURE',0x00000007)
		win_const_mgr.add_const('CTRY_BRAZIL',0x00000037)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_USER_SUM_FLOW_RATE',0x00000023)
		win_const_mgr.add_const('OPTION_BE_A_MASK_SUPPLIER',0x0000001E)
		win_const_mgr.add_const('PORT_TELNET',0x00000017)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_WRONGTYPE',0x00000007)
		win_const_mgr.add_const('PORT_HTTP',0x00000050)
		win_const_mgr.add_const('WINHTTP_OPTION_SEND_TIMEOUT',0x00000005)
		win_const_mgr.add_const('D3DSP_SRCMOD_MASK',0x0F000000)
		win_const_mgr.add_const('COMPRESSION_ENGINE_HIBER',0x00000200)
		win_const_mgr.add_const('TVN_LAST',0x00000000)
		win_const_mgr.add_const('L_MAX_URL_LENGTH',0x00000800)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_EXCLUSIVEACCESSOWNER',0x0000020D)
		win_const_mgr.add_const('OID_FDDI_MAC_MA_UNITDATA_ENABLE',0x03030250)
		win_const_mgr.add_const('MCI_INFO_FILE',0x00000200)
		win_const_mgr.add_const('DEBUG_OFFSINFO_VIRTUAL_SOURCE',0x00000001)
		win_const_mgr.add_const('CRYPT_NO_SALT',0x00000010)
		win_const_mgr.add_const('SWP_NOOWNERZORDER',0x00000200)
		win_const_mgr.add_const('WM_MAX_VIDEO_STREAMS',0x00000003)
		win_const_mgr.add_const('NTDSDSA_OPT_IS_GC',0x00000001)
		win_const_mgr.add_const('CFU_INVERT',0x000000FE)
		win_const_mgr.add_const('TBS_COMMAND_LOCALITY_ZERO',0x00000000)
		win_const_mgr.add_const('CR_INVALID_API',0x00000020)
		win_const_mgr.add_const('VK_ATTN',0x000000F6)
		win_const_mgr.add_const('VIEW_SORTNAME',0x00000004)
		win_const_mgr.add_const('RESOURCES_MODIFIED',0x00000002)
		win_const_mgr.add_const('SEF_DACL_AUTO_INHERIT',0x00000001)
		win_const_mgr.add_const('WM_APPCOMMAND',0x00000319)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_INTEL',0x00000000)
		win_const_mgr.add_const('CAUSE_RECOVERY_ON_TIMEOUT',0x00000066)
		win_const_mgr.add_const('GAI_STRERROR_BUFFER_SIZE',0x00000400)
		win_const_mgr.add_const('LVS_EX_COLUMNOVERFLOW',0x80000000)
		win_const_mgr.add_const('SLMFLAG_ALT_INDEX',0x00000002)
		win_const_mgr.add_const('SCWMI_CLOBBER_SECURITY',0x00000001)
		win_const_mgr.add_const('CERT_LAST_USER_PROP_ID',0x0000FFFF)
		win_const_mgr.add_const('ISR_PRIV_OP',0x00000001)
		win_const_mgr.add_const('DMPAPER_LETTER_ROTATED',0x0000004B)
		win_const_mgr.add_const('LWS_USEVISUALSTYLE',0x00000008)
		win_const_mgr.add_const('MCIWNDF_NOERRORDLG',0x00004000)
		win_const_mgr.add_const('RIM_INPUTSINK',0x00000001)
		win_const_mgr.add_const('NETSCAPE_SSL_CLIENT_AUTH_CERT_TYPE',0x00000080)
		win_const_mgr.add_const('FILE_SUPPORTS_REMOTE_STORAGE',0x00000100)
		win_const_mgr.add_const('IDC_IO_FILETYPE',0x00000841)
		win_const_mgr.add_const('URL_PLUGGABLE_PROTOCOL',0x40000000)
		win_const_mgr.add_const('SYMBOL_CHARSET',0x00000002)
		win_const_mgr.add_const('IF_TYPE_MIO_X25',0x00000026)
		win_const_mgr.add_const('TMT_DIBDATA',0x00000002)
		win_const_mgr.add_const('TMT_EDGELIGHTCOLOR',0x00000EDC)
		win_const_mgr.add_const('DISPID_FRAMENAVIGATECOMPLETE',0x000000C9)
		win_const_mgr.add_const('DISPID_IHTMLOPSPROFILE_ADDREADREQUEST',0x00000007)
		win_const_mgr.add_const('CDO_E_BAD_SENDER',0x80040233)
		win_const_mgr.add_const('HH_TP_HELP_WM_HELP',0x00000011)
		win_const_mgr.add_const('DCI_CAN_STRETCHY',0x00002000)
		win_const_mgr.add_const('DCI_CAN_STRETCHX',0x00001000)
		win_const_mgr.add_const('SECBUFFER_MISSING',0x00000004)
		win_const_mgr.add_const('TBS_CONTEXT_VERSION_ONE',0x00000001)
		win_const_mgr.add_const('GQOS_NO_ERRORCODE',0x00000000)
		win_const_mgr.add_const('PORT_RSVD',0x000000A8)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM9D_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('SQL_ISV_TRANSLATIONS',0x00040000)
		win_const_mgr.add_const('ERROR_ILLEGAL_DLL_RELOCATION',0x0000026F)
		win_const_mgr.add_const('ERROR_WMI_ALREADY_ENABLED',0x0000106E)
		win_const_mgr.add_const('OT_EMBEDDED',0x00000002)
		win_const_mgr.add_const('_WIN32_WINNT_WS03',0x00000502)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_UP',0x000013C0)
		win_const_mgr.add_const('REPL_ROLE_IMPORT',0x00000002)
		win_const_mgr.add_const('BATTERY_CRITICAL',0x00000008)
		win_const_mgr.add_const('PHONESTATE_OTHER',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND',0x000032D7)
		win_const_mgr.add_const('SECURITY_FLAG_IGNORE_WRONG_USAGE',0x00000200)
		win_const_mgr.add_const('PFM_SHADING',0x00001000)
		win_const_mgr.add_const('IMGCHG_VIEW',0x00000002)
		win_const_mgr.add_const('FLAG_PLANNING_MODE',0x01000000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_CURRENTROTATIONTYPEISPURECAV',0x0000010E)
		win_const_mgr.add_const('IDTR_MBZ2',0x0000003F)
		win_const_mgr.add_const('IDTR_MBZ0',0x00000000)
		win_const_mgr.add_const('IDTR_MBZ1',0x00000020)
		win_const_mgr.add_const('ERROR_LOG_NOT_ENOUGH_CONTAINERS',0x000019EB)
		win_const_mgr.add_const('INTERNET_FLAG_CACHE_IF_NET_FAIL',0x00010000)
		win_const_mgr.add_const('PARM_ERROR_NONE',0x00000000)
		win_const_mgr.add_const('CAL_SMONTHNAME12',0x00000020)
		win_const_mgr.add_const('CAL_SMONTHNAME13',0x00000021)
		win_const_mgr.add_const('CAL_SMONTHNAME10',0x00000001)
		win_const_mgr.add_const('ERROR_PATCH_REMOVAL_DISALLOWED',0x00000671)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_MPEG2_D',0x0000000D)
		win_const_mgr.add_const('RPCFLG_MESSAGE',0x01000000)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_MPEG2_C',0x0000000C)
		win_const_mgr.add_const('SCARD_ABSENT',0x00000001)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_MPEG2_A',0x0000000A)
		win_const_mgr.add_const('ERROR_SEVERITY_INFORMATIONAL',0x40000000)
		win_const_mgr.add_const('EN_OBJECTPOSITIONS',0x00000070)
		win_const_mgr.add_const('IME_SENDVKEY',0x00000013)
		win_const_mgr.add_const('AM_AC3_ALTERNATE_AUDIO_BOTH',0x00000003)
		win_const_mgr.add_const('CHECKPNGFORMAT',0x00001018)
		win_const_mgr.add_const('SV_SHARES_PARMNUM',0x0000019D)
		win_const_mgr.add_const('SET_FEATURE_ON_THREAD_INTRANET',0x00000010)
		win_const_mgr.add_const('XECR_PKCS10_V2_0',0x00000001)
		win_const_mgr.add_const('ERROR_FLOPPY_ID_MARK_NOT_FOUND',0x00000462)
		win_const_mgr.add_const('WIA_IPA_FIRST',0x00001002)
		win_const_mgr.add_const('LOCALE_ILZERO',0x00000012)
		win_const_mgr.add_const('SQL_CREATE_COLLATION',0x00000081)
		win_const_mgr.add_const('SOUND_SYSTEM_ERROR',0x00000004)
		win_const_mgr.add_const('SETMITERLIMIT',0x00000017)
		win_const_mgr.add_const('KS_VIDEO_FLAG_P_FRAME',0x00000010)
		win_const_mgr.add_const('SPEAKER_BACK_RIGHT',0x00000020)
		win_const_mgr.add_const('MDPROPVAL_RR_NORANGEROWSET',0x00000001)
		win_const_mgr.add_const('REPL_UNLOCK_NOFORCE',0x00000000)
		win_const_mgr.add_const('SUBSCRIPTION_CAP_DEVICEAVAILABLE',0x00000010)
		win_const_mgr.add_const('PORT_SUPDUP',0x0000005F)
		win_const_mgr.add_const('GTL_DEFAULT',0x00000000)
		win_const_mgr.add_const('DEBUG_BREAKPOINT_TIME',0x00000002)
		win_const_mgr.add_const('CERT_INFO_SUBJECT_FLAG',0x00000007)
		win_const_mgr.add_const('KERB_CHECKSUM_HMAC_SHA1_96_AES128',0x0000000F)
		win_const_mgr.add_const('IDM_TRIED_MAKE_ABSOLUTE',0x00000004)
		win_const_mgr.add_const('SHDID_ROOT_REGITEM',0x00000001)
		win_const_mgr.add_const('SIGNERSCORE_W9X_SUSPECT',0xC0000000)
		win_const_mgr.add_const('DBPROP_INIT_GENERALTIMEOUT',0x00000011)
		win_const_mgr.add_const('DICUSTOMDEVPROP_MERGE_MULTISZ',0x00000001)
		win_const_mgr.add_const('ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL',0x00003AA1)
		win_const_mgr.add_const('DB_DISP_PENDING',0x00000009)
		win_const_mgr.add_const('SQL_API_SQLGETINFO',0x0000002D)
		win_const_mgr.add_const('LINECALLINFOSTATE_APPSPECIFIC',0x00000020)
		win_const_mgr.add_const('IF_TYPE_IDSL',0x0000009A)
		win_const_mgr.add_const('SDP_ATTRIB_LANG_BASE_ATTRIB_ID_LIST',0x00000006)
		win_const_mgr.add_const('MD_ACR_RESTRICTED_WRITE',0x00000020)
		win_const_mgr.add_const('JOB_NOTIFY_TYPE',0x00000001)
		win_const_mgr.add_const('ERROR_DS_DRA_BAD_DN',0x000020F7)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_DESCRIPTION',0x00000004)
		win_const_mgr.add_const('RPC_C_USE_INTERNET_PORT',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_REQUESTEDDATASECTORTYPE',0x00000109)
		win_const_mgr.add_const('NTDSCONN_KCC_INTERSITE_GC_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('DMO_E_NO_MORE_ITEMS',0x80040206)
		win_const_mgr.add_const('ILLUMINANT_D50',0x00000004)
		win_const_mgr.add_const('TMT_SOURCEGROW',0x000008A4)
		win_const_mgr.add_const('ASSEMBLYINFO_FLAG_PAYLOADRESIDENT',0x00000002)
		win_const_mgr.add_const('ERROR_SHARING_VIOLATION',0x00000020)
		win_const_mgr.add_const('VPDF_SHOWMULTIBATT',0x00000020)
		win_const_mgr.add_const('E_SURFACE_NOSURFACE',0x8000C000)
		win_const_mgr.add_const('SNMP_ERROR_WRONGVALUE',0x0000000A)
		win_const_mgr.add_const('PIDDRSI_DESCRIPTION',0x00000003)
		win_const_mgr.add_const('D3DPRESENTFLAG_DEVICECLIP',0x00000004)
		win_const_mgr.add_const('SPI_GETANIMATION',0x00000048)
		win_const_mgr.add_const('ERROR_REQUEST_OUT_OF_SEQUENCE',0x00000308)
		win_const_mgr.add_const('VK_F19',0x00000082)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG',0x00003631)
		win_const_mgr.add_const('ADOMD_MAJOR',0x00000006)
		win_const_mgr.add_const('NCBLISTEN',0x00000011)
		win_const_mgr.add_const('DESKTOP_JOURNALRECORD',0x00000010)
		win_const_mgr.add_const('ADS_SERVICE_SHARE_PROCESS',0x00000020)
		win_const_mgr.add_const('SESSION_ESTABLISHED',0x00000003)
		win_const_mgr.add_const('DDSD_ALL',0x00000000)
		win_const_mgr.add_const('VK_F11',0x0000007A)
		win_const_mgr.add_const('VK_F10',0x00000079)
		win_const_mgr.add_const('CI_STATE_READ_ONLY',0x00000400)
		win_const_mgr.add_const('RPC_S_INVALID_NET_ADDR',0x000006AB)
		win_const_mgr.add_const('VK_F15',0x0000007E)
		win_const_mgr.add_const('VK_F14',0x0000007D)
		win_const_mgr.add_const('IMAGE_VXD_SIGNATURE',0x0000454C)
		win_const_mgr.add_const('ERROR_CTX_CONSOLE_CONNECT',0x00001B82)
		win_const_mgr.add_const('BATTERY_CHARGING',0x00000004)
		win_const_mgr.add_const('DMICM_COLORIMETRIC',0x00000003)
		win_const_mgr.add_const('FC_ALLOCED_ON_STACK',0x00000004)
		win_const_mgr.add_const('ARCONTENT_BLANKCD',0x00000010)
		win_const_mgr.add_const('SCHEME_GLOBAL',0x00000008)
		win_const_mgr.add_const('MIM_BACKGROUND',0x00000002)
		win_const_mgr.add_const('AM_VIDEO_FLAG_WEAVE',0x00000008)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY12',0x00001000)
		win_const_mgr.add_const('LBS_EXTENDEDSEL',0x00000800)
		win_const_mgr.add_const('WTPF_IGNOREEXPIRATION',0x00000100)
		win_const_mgr.add_const('EVENT_OBJECT_INVOKED',0x00008013)
		win_const_mgr.add_const('VIEW_SORTDATE',0x00000006)
		win_const_mgr.add_const('ERROR_NO_UNICODE_TRANSLATION',0x00000459)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY14',0x00004000)
		win_const_mgr.add_const('WMS_CONTAINER_PART_OF_WRAPPER_PLAYLIST',0x00000080)
		win_const_mgr.add_const('PD_RETURNDEFAULT',0x00000400)
		win_const_mgr.add_const('DIF_INSTALLDEVICEFILES',0x00000015)
		win_const_mgr.add_const('SQL_MAX_COLUMN_NAME_LEN',0x0000001E)
		win_const_mgr.add_const('AUDIT_SET_MISC_POLICY',0x00000020)
		win_const_mgr.add_const('EVENTLOG_ERROR_TYPE',0x00000001)
		win_const_mgr.add_const('EDITF_SERVERUPGRADED',0x00004000)
		win_const_mgr.add_const('WM_IME_REPORT',0x00000280)
		win_const_mgr.add_const('EPT_S_INVALID_ENTRY',0x000006D7)
		win_const_mgr.add_const('DEBUG_STATUS_GO',0x00000001)
		win_const_mgr.add_const('PDH_LOG_CREATE_MASK',0x0000000F)
		win_const_mgr.add_const('CDO_E_BAD_ATTENDEE_DATA',0x80040235)
		win_const_mgr.add_const('RTL_CRITICAL_SECTION_ALL_FLAG_BITS',0xFF000000)
		win_const_mgr.add_const('QCMINFO_PLACE_AFTER',0x00000001)
		win_const_mgr.add_const('SHTDN_REASON_FLAG_PLANNED',0x80000000)
		win_const_mgr.add_const('WNODE_FLAG_ALL_DATA',0x00000001)
		win_const_mgr.add_const('ERROR_LOG_HARD_ERROR',0x000002CE)
		win_const_mgr.add_const('LANG_FINNISH',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_SH_NOMODE',0x00008000)
		win_const_mgr.add_const('PORT_FTP',0x00000015)
		win_const_mgr.add_const('TF_LBI_ICON',0x00000001)
		win_const_mgr.add_const('LOGON_NETCREDENTIALS_ONLY',0x00000002)
		win_const_mgr.add_const('DEBUG_ATTACH_INVASIVE_NO_INITIAL_BREAK',0x00000008)
		win_const_mgr.add_const('GESTURE_TRIPLE_UP',0x00000000)
		win_const_mgr.add_const('STD_PRINT',0x0000000E)
		win_const_mgr.add_const('D3DUSAGE_WRITEONLY',0x00000008)
		win_const_mgr.add_const('LINEADDRESSSHARING_BRIDGEDSHARED',0x00000008)
		win_const_mgr.add_const('SORT_JAPANESE_UNICODE',0x00000001)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_VIRTUAL',0x00000020)
		win_const_mgr.add_const('DEBUG_EINDEX_NAME',0x00000000)
		win_const_mgr.add_const('DEBUG_TYPEOPTS_MATCH_MAXSIZE',0x00000008)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_ENCODING',0x0000001D)
		win_const_mgr.add_const('LINE_CALLHUBCLOSE',0x00000021)
		win_const_mgr.add_const('QOS_TRAFFIC_GENERAL_ID_BASE',0x00000FA0)
		win_const_mgr.add_const('BLUETOOTH_SERVICE_ENABLE',0x00000001)
		win_const_mgr.add_const('LDAP_CHASE_EXTERNAL_REFERRALS',0x00000040)
		win_const_mgr.add_const('DEBUG_SYMTYPE_SYM',0x00000006)
		win_const_mgr.add_const('INTERNET_PER_CONN_AUTOCONFIG_LAST_DETECT_URL',0x00000009)
		win_const_mgr.add_const('_DRVRESERVED',0x0000000A)
		win_const_mgr.add_const('HDI_BITMAP',0x00000010)
		win_const_mgr.add_const('ERROR_RESOURCE_NOT_FOUND',0x0000138F)
		win_const_mgr.add_const('ERROR_DS_CONFIDENTIALITY_REQUIRED',0x0000202D)
		win_const_mgr.add_const('TRANSACTION_MAXIMUM_OPTION',0x00000001)
		win_const_mgr.add_const('ERROR_HOTKEY_NOT_REGISTERED',0x0000058B)
		win_const_mgr.add_const('OCSP_REQUEST_V1',0x00000000)
		win_const_mgr.add_const('CM_PROB_INVALID_DATA',0x00000009)
		win_const_mgr.add_const('ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL',0x00003AAE)
		win_const_mgr.add_const('FILE_DEVICE_SOUND',0x00000001)
		win_const_mgr.add_const('ERROR_DS_CANT_MIX_MASTER_AND_REPS',0x0000208B)
		win_const_mgr.add_const('DM_COPIES',0x00000100)
		win_const_mgr.add_const('IP_MARGIN',0x00000004)
		win_const_mgr.add_const('CBEN_LAST',0x00000000)
		win_const_mgr.add_const('WIA_IPS_YEXTENT',0x00001808)
		win_const_mgr.add_const('ERROR_PATCH_PACKAGE_INVALID',0x00000664)
		win_const_mgr.add_const('ERROR_NOT_ENOUGH_MEMORY',0x00000008)
		win_const_mgr.add_const('BCSIF_GLYPH',0x00000001)
		win_const_mgr.add_const('FCIDM_SHVIEWFIRST',0x00000000)
		win_const_mgr.add_const('SYSTEM_ALARM_OBJECT_ACE_TYPE',0x00000008)
		win_const_mgr.add_const('DDBLT_LAST_PRESENTATION',0x20000000)
		win_const_mgr.add_const('ERROR_SXS_WRONG_SECTION_TYPE',0x000036B9)
		win_const_mgr.add_const('WMDM_POWER_IS_BATTERY',0x00000004)
		win_const_mgr.add_const('TTFCFP_SYMBOL_CHAR_SET',0x00000000)
		win_const_mgr.add_const('SECPKG_ATTR_TARGET',0x00000013)
		win_const_mgr.add_const('AE_UAS_GROUP',0x00000001)
		win_const_mgr.add_const('ERROR_DS_DRA_INVALID_PARAMETER',0x000020F5)
		win_const_mgr.add_const('IDM_TRIED_ACTIVATEAPPLETS',0x00000018)
		win_const_mgr.add_const('IS_TEXT_UNICODE_ASCII16',0x00000001)
		win_const_mgr.add_const('STATUS_SEVERITY_COERROR',0x00000002)
		win_const_mgr.add_const('MAPI_PW_PROVIDER_UI_ONLY',0x00000008)
		win_const_mgr.add_const('SPI_GETACTIVEWNDTRKTIMEOUT',0x00002002)
		win_const_mgr.add_const('NRC_NAMCONF',0x00000019)
		win_const_mgr.add_const('PIDDRSI_PLAYEXPIRES',0x00000006)
		win_const_mgr.add_const('SV_TYPE_SERVER_NT',0x00008000)
		win_const_mgr.add_const('IDM_NEWPAGE',0x00000057)
		win_const_mgr.add_const('ASC_RET_MUTUAL_AUTH',0x00000002)
		win_const_mgr.add_const('WINHTTP_FLAG_BYPASS_PROXY_CACHE',0x00000100)
		win_const_mgr.add_const('ITIR_RV1',0x00000020)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_REQUESTEDWRITESPEED',0x0000010F)
		win_const_mgr.add_const('PSD_DISABLEPAGEPAINTING',0x00080000)
		win_const_mgr.add_const('DDCAPS2_CANDROPZ16BIT',0x00000100)
		win_const_mgr.add_const('ODT_HEADER',0x00000064)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETQUEUEINFO',0x00000012)
		win_const_mgr.add_const('WMDM_STATUS_DEVICECONTROL_PAUSED',0x00000020)
		win_const_mgr.add_const('SMART_NO_ERROR',0x00000000)
		win_const_mgr.add_const('SO_MAXPATHDG',0x0000700A)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_IS_RAND_BH_SELECTION_DISABLED',0x00000001)
		win_const_mgr.add_const('LSA_NB_DISABLED_CONFLICT',0x00000008)
		win_const_mgr.add_const('ERROR_PATCH_IMAGEHLP_FAILURE',0xC00E3106)
		win_const_mgr.add_const('TF_SENTENCEMODE_SINGLECONVERT',0x00000002)
		win_const_mgr.add_const('CRYPT_STRING_HEXRAW',0x00000000)
		win_const_mgr.add_const('DOT11_ENCAP_802_1H',0x00000002)
		win_const_mgr.add_const('PAN_LETT_OBLIQUE_SQUARE',0x0000000F)
		win_const_mgr.add_const('MFE_NOT_FORWARDING',0x00000002)
		win_const_mgr.add_const('MAX_IO_PORTS',0x00000014)
		win_const_mgr.add_const('WABOBJECT_ME_NOCREATE',0x00000002)
		win_const_mgr.add_const('PSM_HID_CONTROL',0x00000011)
		win_const_mgr.add_const('IDM_DIRLTR',0x0000092E)
		win_const_mgr.add_const('SC_DEFAULT',0x0000F160)
		win_const_mgr.add_const('MAX_IPX_MIB_TABLES',0x00000006)
		win_const_mgr.add_const('CACHE_HEADER_DATA_LAST',0x0000001F)
		win_const_mgr.add_const('RPC_BHO_NONCAUSAL',0x00000001)
		win_const_mgr.add_const('WPF_SHOWPAGE_SRCFILE',0x00020000)
		win_const_mgr.add_const('D3DDEVCAPS2_VERTEXELEMENTSCANSHARESTREAMOFFSET',0x00000040)
		win_const_mgr.add_const('IMAGE_REL_SH3_GPREL4_LONG',0x00000011)
		win_const_mgr.add_const('PHONEBUTTONSTATE_UNAVAIL',0x00000008)
		win_const_mgr.add_const('CALLBACK_CHUNK_FINISHED',0x00000000)
		win_const_mgr.add_const('SYMOPT_NO_CPP',0x00000008)
		win_const_mgr.add_const('TCHT_NOWHERE',0x00000001)
		win_const_mgr.add_const('SV_NODISC',0x0000FFFF)
		win_const_mgr.add_const('DEV_PORT_1394',0x00000008)
		win_const_mgr.add_const('LGRPID_CYRILLIC',0x00000005)
		win_const_mgr.add_const('METADATA_PARTIAL_PATH',0x00000002)
		win_const_mgr.add_const('IDM_SCROLL_PAGEDOWN',0x00000950)
		win_const_mgr.add_const('RBBIM_IDEALSIZE',0x00000200)
		win_const_mgr.add_const('KEYBOARD_OVERRUN_MAKE_CODE',0x000000FF)
		win_const_mgr.add_const('OID_GEN_DIRECTED_FRAMES_XMIT',0x00020202)
		win_const_mgr.add_const('CORDLESS_EXTERNAL_NETWORK_PSTN',0x00000001)
		win_const_mgr.add_const('JOB_OBJECT_TERMINATE',0x00000008)
		win_const_mgr.add_const('PO_THROTTLE_ADAPTIVE',0x00000003)
		win_const_mgr.add_const('CPF_POSTPONED_BASE_FILE_ERROR',0x00002000)
		win_const_mgr.add_const('WNNC_NET_NONE',0x00000000)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_FLAG_CERT_REVOKED',0x00000004)
		win_const_mgr.add_const('RTM_NEXTHOP_STATE_CREATED',0x00000000)
		win_const_mgr.add_const('STGFMT_DOCFILE',0x00000005)
		win_const_mgr.add_const('MCI_DGV_COPY_AT',0x00010000)
		win_const_mgr.add_const('CRYPT_STRING_BASE64_ANY',0x00000006)
		win_const_mgr.add_const('MD_CPU_ENABLE_USER_TIME',0x00000004)
		win_const_mgr.add_const('SUBLANG_GERMAN',0x00000001)
		win_const_mgr.add_const('DMPAPER_PENV_7_ROTATED',0x00000073)
		win_const_mgr.add_const('SQL_SQ_CORRELATED_SUBQUERIES',0x00000010)
		win_const_mgr.add_const('VK_LAUNCH_MEDIA_SELECT',0x000000B5)
		win_const_mgr.add_const('CRLF_DISABLE_RDN_REORDER',0x00000800)
		win_const_mgr.add_const('XA_FMTID_DTC_VER1',0x01445443)
		win_const_mgr.add_const('FLG_ADDREG_KEYONLY',0x00000010)
		win_const_mgr.add_const('SWP_ASYNCWINDOWPOS',0x00004000)
		win_const_mgr.add_const('ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET',0x000036BB)
		win_const_mgr.add_const('COMP_ELEM_CHECKED',0x00000002)
		win_const_mgr.add_const('STRM_INITIAL',0x00000000)
		win_const_mgr.add_const('SETUP_CLIENT_FLAG',0x00000002)
		win_const_mgr.add_const('SCF_DEFAULT',0x00000000)
		win_const_mgr.add_const('TMPF_DEVICE',0x00000008)
		win_const_mgr.add_const('OID_FDDI_MAC_TOKEN_CT',0x0303023E)
		win_const_mgr.add_const('TRACE_HEADER_FLAG_USE_GUID_PTR',0x00080000)
		win_const_mgr.add_const('MCI_VD_PLAY_SCAN',0x00080000)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_EXCEPTION',0x00000003)
		win_const_mgr.add_const('IDM_CONVERTOBJECT',0x00000052)
		win_const_mgr.add_const('DDFXALPHACAPS_OVERLAYALPHASURFACES',0x00000100)
		win_const_mgr.add_const('BCSS_STRETCH',0x00000002)
		win_const_mgr.add_const('RBHT_CLIENT',0x00000003)
		win_const_mgr.add_const('SECPKG_FLAG_GSS_COMPATIBLE',0x00001000)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_MMC',0x00000019)
		win_const_mgr.add_const('KLF_NOTELLSHELL',0x00000080)
		win_const_mgr.add_const('D3DPRESENT_VIDEO_RESTRICT_TO_MONITOR',0x00000010)
		win_const_mgr.add_const('CDDS_POSTERASE',0x00000004)
		win_const_mgr.add_const('LDAP_GC_PORT',0x00000CC4)
		win_const_mgr.add_const('DMMEDIA_TRANSPARENCY',0x00000002)
		win_const_mgr.add_const('LANG_WELSH',0x00000052)
		win_const_mgr.add_const('SSA_DONTGLYPH',0x40000000)
		win_const_mgr.add_const('CB_SETEDITSEL',0x00000142)
		win_const_mgr.add_const('RPCFLG_HAS_MULTI_SYNTAXES',0x02000000)
		win_const_mgr.add_const('PAN_WEIGHT_LIGHT',0x00000003)
		win_const_mgr.add_const('ALG_TYPE_RSA',0x00000002)
		win_const_mgr.add_const('LOGPIXELSX',0x00000058)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_QM_DELAY_DROP',0x000035F7)
		win_const_mgr.add_const('TBTS_TOP',0x00000000)
		win_const_mgr.add_const('PORT_MUMPS',0x000000BC)
		win_const_mgr.add_const('MOVEFILE_DELAY_UNTIL_REBOOT',0x00000004)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_PROCESS_ID',0x00000020)
		win_const_mgr.add_const('ALG_SID_RIPEMD',0x00000006)
		win_const_mgr.add_const('IDF_NODETAILS',0x00000004)
		win_const_mgr.add_const('SCRIPTITEM_ISSOURCE',0x00000004)
		win_const_mgr.add_const('RSC_MODE_EA',0x00000003)
		win_const_mgr.add_const('DT_PLOTTER',0x00000000)
		win_const_mgr.add_const('EVENT_E_LAST',0x8004021F)
		win_const_mgr.add_const('TF_RIP_FLAG_FREEUNUSEDLIBRARIES',0x00000001)
		win_const_mgr.add_const('ADDRESS_TAG_BIT',0x80000000)
		win_const_mgr.add_const('ERROR_PARTIAL_COPY',0x0000012B)
		win_const_mgr.add_const('LINEFORWARDMODE_BUSYNASPECIFIC',0x00008000)
		win_const_mgr.add_const('CRYPT_ACQUIRE_NCRYPT_KEY_FLAGS_MASK',0x00070000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_FWDBUSYNAADDR',0x00080000)
		win_const_mgr.add_const('SQL_OIC_LEVEL1',0x00000002)
		win_const_mgr.add_const('SQL_OIC_LEVEL2',0x00000003)
		win_const_mgr.add_const('DEBUG_LOG_DEFAULT',0x00000000)
		win_const_mgr.add_const('IF_TYPE_FRAMERELAY',0x00000020)
		win_const_mgr.add_const('SS_ELLIPSISMASK',0x0000C000)
		win_const_mgr.add_const('NUMLOCK_ON',0x00000020)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_ALL_HANDLE_OPERATIONS',0x0000000A)
		win_const_mgr.add_const('LPD_TRANSPARENT',0x00001000)
		win_const_mgr.add_const('PSF_DISABLEDISPLAYASICON',0x00000010)
		win_const_mgr.add_const('TMT_ANIMATIONDURATION',0x0000138E)
		win_const_mgr.add_const('ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER',0x0000216F)
		win_const_mgr.add_const('EWX_RESTARTAPPS',0x00000040)
		win_const_mgr.add_const('CREATE_SUSPENDED',0x00000004)
		win_const_mgr.add_const('PDH_MAX_DATASOURCE_PATH',0x00000400)
		win_const_mgr.add_const('CMS_ENABLEPROOFING',0x00000002)
		win_const_mgr.add_const('LVN_FIRST',0x00000000)
		win_const_mgr.add_const('DNSSEC_PROTOCOL_EMAIL',0x00000002)
		win_const_mgr.add_const('USN_DELETE_VALID_FLAGS',0x00000003)
		win_const_mgr.add_const('SV_TYPE_SQLSERVER',0x00000004)
		win_const_mgr.add_const('CORHLPR_TURNED_FPO_ON',0x00000001)
		win_const_mgr.add_const('PAN_LETT_NORMAL_SQUARE',0x00000008)
		win_const_mgr.add_const('AMDDS_PS',0x00000002)
		win_const_mgr.add_const('CR_OUT_OF_MEMORY',0x00000002)
		win_const_mgr.add_const('INDEX_GUID_WORDMODE',0x00000002)
		win_const_mgr.add_const('WMPCOREEVENT_ERROR_BASE',0x0000157C)
		win_const_mgr.add_const('MD_SERVER_CONFIG_SSL_40',0x00000001)
		win_const_mgr.add_const('NRB_INPUT_DATA_UNDERRUN',0x00000004)
		win_const_mgr.add_const('LINECALLREASON_INTRUDE',0x00001000)
		win_const_mgr.add_const('OID_IRDA_UNICAST_LIST',0x0A010202)
		win_const_mgr.add_const('SERVICE_NOTIFY_PAUSED',0x00000040)
		win_const_mgr.add_const('HP_TLS1PRF_SEED',0x00000007)
		win_const_mgr.add_const('DDSCAPS_BACKBUFFER',0x00000004)
		win_const_mgr.add_const('SETUP_SERVER_FLAG',0x00000001)
		win_const_mgr.add_const('DEBUG_TBINFO_EXIT_STATUS',0x00000001)
		win_const_mgr.add_const('RPC_C_MGMT_IS_SERVER_LISTEN',0x00000003)
		win_const_mgr.add_const('SSRVOPT_MAX',0x00040000)
		win_const_mgr.add_const('CSA_DEFG',0x00000004)
		win_const_mgr.add_const('SQL_FN_STR_CONCAT',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_JOIN_ABORTED',0x000013D2)
		win_const_mgr.add_const('WSATRY_AGAIN',0x00002AFA)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_ALPHA64',0x00000284)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_CALLHUBTRACKING',0x00000800)
		win_const_mgr.add_const('FORMPROPSET_UNION',0x00000000)
		win_const_mgr.add_const('CR_PROP_DELTACRL',0x00000012)
		win_const_mgr.add_const('D3DSP_REGTYPE_MASK',0x70000000)
		win_const_mgr.add_const('KRAF_ENABLEARCHIVEALL',0x00000004)
		win_const_mgr.add_const('IDC_CV_ACTIVATELIST',0x0000009A)
		win_const_mgr.add_const('SPMODE_EVENTTRACE',0x00008000)
		win_const_mgr.add_const('RFCOMM_PROTOCOL_UUID16',0x00000003)
		win_const_mgr.add_const('LB_CTLCODE',0x00000000)
		win_const_mgr.add_const('HELP_TCARD_OTHER_CALLER',0x00000011)
		win_const_mgr.add_const('DBPROPVAL_CB_DELETE',0x00000001)
		win_const_mgr.add_const('LOAD_DLL_DEBUG_EVENT',0x00000006)
		win_const_mgr.add_const('SV_ENABLESOFTCOMPAT_PARMNUM',0x00000202)
		win_const_mgr.add_const('PO_THROTTLE_MAXIMUM',0x00000004)
		win_const_mgr.add_const('SCHANNEL_CRED_VERSION',0x00000004)
		win_const_mgr.add_const('EAP_E_CERT_STORE_INACCESSIBLE',0x80420010)
		win_const_mgr.add_const('PHONEERR_OPERATIONFAILED',0x9000001C)
		win_const_mgr.add_const('RPC_S_OBJECT_NOT_FOUND',0x000006AE)
		win_const_mgr.add_const('GDTR_MIN',0x00000001)
		win_const_mgr.add_const('CALENDAR_SHOWTIMEAS_TENTATIVE',0x00000001)
		win_const_mgr.add_const('USHORT_MAX',0x00000000)
		win_const_mgr.add_const('EC_QUERYWAITING',0x00000002)
		win_const_mgr.add_const('DNS_RCODE_BADVERS',0x00000010)
		win_const_mgr.add_const('KP_EFFECTIVE_KEYLEN',0x00000013)
		win_const_mgr.add_const('ERROR_SERVICE_NOT_FOUND',0x000004DB)
		win_const_mgr.add_const('ERROR_PATCH_REMOVAL_UNSUPPORTED',0x0000066E)
		win_const_mgr.add_const('MD_ERROR_SUB404_URL_DOUBLE_ESCAPED',0x0000000B)
		win_const_mgr.add_const('ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION',0x00002155)
		win_const_mgr.add_const('ERROR_PAGE_FAULT_DEMAND_ZERO',0x000002EC)
		win_const_mgr.add_const('PRINTER_CHANGE_ADD_PORT',0x00100000)
		win_const_mgr.add_const('PAN_BENT_ARMS_WEDGE',0x00000008)
		win_const_mgr.add_const('D3D9_RESOURCE_PRIORITY_HIGH',0x00000000)
		win_const_mgr.add_const('EXTENSION_ORIGIN_CMC',0x00080000)
		win_const_mgr.add_const('DISPID_SOURCECODEPRESERVATION',0x00000010)
		win_const_mgr.add_const('DT_VCENTER',0x00000004)
		win_const_mgr.add_const('FACILITY_WIA',0x00000021)
		win_const_mgr.add_const('IDM_INSINPUTUPLOAD',0x00000846)
		win_const_mgr.add_const('EAP_GROUP_MASK',0x0000FF00)
		win_const_mgr.add_const('SHGFI_SYSICONINDEX',0x00004000)
		win_const_mgr.add_const('PDH_CSTATUS_NO_COUNTERNAME',0xC0000BBF)
		win_const_mgr.add_const('SPI_SETSCREENSAVERRUNNING',0x00000061)
		win_const_mgr.add_const('IT_MSG_DATA',0x00000002)
		win_const_mgr.add_const('IDM_NOFIXUPURLSONPASTE',0x0000091F)
		win_const_mgr.add_const('SQL_KEYSET_SIZE_DEFAULT',0x00000000)
		win_const_mgr.add_const('ERROR_INVALID_SCROLLBAR_RANGE',0x000005A8)
		win_const_mgr.add_const('__RPCSAL_H_VERSION__',0x00000064)
		win_const_mgr.add_const('NNLEN',0x00000050)
		win_const_mgr.add_const('ERROR_MCA_INVALID_VCP_VERSION',0x00003B61)
		win_const_mgr.add_const('ID_PSRESTARTWINDOWS',0x00000002)
		win_const_mgr.add_const('MMIO_EXIST',0x00004000)
		win_const_mgr.add_const('ODBC_ERROR_OUTPUT_STRING_TRUNCATED',0x00000016)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_OBJECT_GUID',0x0000001A)
		win_const_mgr.add_const('MCI_DGV_SET_SEEK_EXACTLY',0x00010000)
		win_const_mgr.add_const('DPAM_SORTED',0x00000001)
		win_const_mgr.add_const('DISPID_DDISCMASTER2EVENTS_DEVICEADDED',0x00000100)
		win_const_mgr.add_const('COLOR_PALETTE',0x000002CE)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_MAX',0x0000001D)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_IUSERS',0x00000238)
		win_const_mgr.add_const('D3DPS20CAPS_GRADIENTINSTRUCTIONS',0x00000001)
		win_const_mgr.add_const('MAXDWORD',0x00000000)
		win_const_mgr.add_const('PROV_STT_ROOT',0x0000000A)
		win_const_mgr.add_const('ERROR_DS_ROLE_NOT_VERIFIED',0x000021A2)
		win_const_mgr.add_const('LBS_NOINTEGRALHEIGHT',0x00000100)
		win_const_mgr.add_const('SQL_BP_UPDATE',0x00000010)
		win_const_mgr.add_const('CRYPTPROTECT_CRED_REGENERATE',0x00000080)
		win_const_mgr.add_const('TCP_TIMESTAMPS',0x0000000A)
		win_const_mgr.add_const('SAFER_LEVELID_DISALLOWED',0x00000000)
		win_const_mgr.add_const('NET_VALIDATE_PASSWORD_LAST_SET',0x00000001)
		win_const_mgr.add_const('WIA_IPC_NUM_PICT_PER_ROW',0x00001408)
		win_const_mgr.add_const('CERT_TRUST_IS_NOT_VALID_FOR_USAGE',0x00000010)
		win_const_mgr.add_const('DCI_ASYNC',0x00000400)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_SAVEPOINT_COMPLETE',0x00100000)
		win_const_mgr.add_const('TAPE_DRIVE_HIGH_FEATURES',0x80000000)
		win_const_mgr.add_const('DT_RIGHT',0x00000002)
		win_const_mgr.add_const('XINPUT_GAMEPAD_LEFT_SHOULDER',0x00000100)
		win_const_mgr.add_const('IDTB_HOME',0x000000CD)
		win_const_mgr.add_const('PID_IPX',0x0000002B)
		win_const_mgr.add_const('DO_PRINTFILE',0x544E5250)
		win_const_mgr.add_const('ACTRL_CHANGE_OWNER',0x40000000)
		win_const_mgr.add_const('SPFILENOTIFY_ENDCOPY',0x00000000)
		win_const_mgr.add_const('D3DTSS_TCI_CAMERASPACEPOSITION',0x00020000)
		win_const_mgr.add_const('WINHTTP_QUERY_FLAG_NUMBER',0x20000000)
		win_const_mgr.add_const('TB_THUMBTRACK',0x00000005)
		win_const_mgr.add_const('FIEF_FLAG_SKIP_INSTALLED_VERSION_CHECK',0x00000004)
		win_const_mgr.add_const('WSA_QOS_EPOLICYOBJ',0x00002B11)
		win_const_mgr.add_const('FILE_ATTRIBUTE_VIRTUAL',0x00010000)
		win_const_mgr.add_const('MAPIFORM_CPU_X86',0x00000001)
		win_const_mgr.add_const('DXVA_QUERYORREPLYFUNCFLAG_ACCEL_PROBE_OK_COPY',0x00FFFFF8)
		win_const_mgr.add_const('STI_ONLINESTATE_PENDING',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_CS_COMMUNICATIONFAILURE',0x00000002)
		win_const_mgr.add_const('SHUTDOWN_FORCE_SELF',0x00000002)
		win_const_mgr.add_const('CONNDLG_RO_PATH',0x00000001)
		win_const_mgr.add_const('CTRY_MEXICO',0x00000034)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_ALERT',0x00000451)
		win_const_mgr.add_const('WINHTTP_QUERY_LOCATION',0x00000021)
		win_const_mgr.add_const('INTERNET_OPTION_CLIENT_CERT_CONTEXT',0x00000054)
		win_const_mgr.add_const('SCH_CRED_VERSION',0x00000002)
		win_const_mgr.add_const('LINEDEVSTATE_CONNECTED',0x00000004)
		win_const_mgr.add_const('SNMPAPI_NOOP',0x00000008)
		win_const_mgr.add_const('WMDRM_CLEAN_LICENSE_STORE_ASYNC',0x00000002)
		win_const_mgr.add_const('QS_PAINT',0x00000020)
		win_const_mgr.add_const('IMAGE_COLORSPACE_UNCALIBRATED',0x0000FFFF)
		win_const_mgr.add_const('SETLINEJOIN',0x00000016)
		win_const_mgr.add_const('WM_RASDIALEVENT',0x0000CCCD)
		win_const_mgr.add_const('IF_NOREMOTEICERTADMINBACKUP',0x00000040)
		win_const_mgr.add_const('IPX_EXTENDED_ADDRESS',0x00004004)
		win_const_mgr.add_const('D3DTEXOPCAPS_ADD',0x00000040)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_64BYTES',0x00700000)
		win_const_mgr.add_const('IAS_MAX_ATTRIBNAME',0x00000100)
		win_const_mgr.add_const('WINEVT_KEYWORD_ANY',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGQUERYVALUE',0x00000010)
		win_const_mgr.add_const('WM_CTLCOLOREDIT',0x00000133)
		win_const_mgr.add_const('ERROR_BAD_IMPERSONATION_LEVEL',0x00000542)
		win_const_mgr.add_const('KSCREATE_ITEM_SECURITYCHANGED',0x00000001)
		win_const_mgr.add_const('USE_RELATIVE_COLORIMETRIC',0x00020000)
		win_const_mgr.add_const('MDPROPVAL_MMF_CLOSINGPERIOD',0x00000008)
		win_const_mgr.add_const('DVB_TOT_PID',0x00000014)
		win_const_mgr.add_const('DC_MANUFACTURER',0x00000017)
		win_const_mgr.add_const('SNMPAPI_OUTPUT_TRUNCATED',0x0000000B)
		win_const_mgr.add_const('AVICOMPRESSF_KEYFRAMES',0x00000004)
		win_const_mgr.add_const('SQL_OWNER_TERM',0x00000027)
		win_const_mgr.add_const('CM_ENABLETEMPLATE',0x00000008)
		win_const_mgr.add_const('WTPF_TRUSTTEST',0x00000020)
		win_const_mgr.add_const('SV_CHDEVQ_PARMNUM',0x0000019A)
		win_const_mgr.add_const('ACM_MPEG_DUALCHANNEL',0x00000004)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_307',0x80190133)
		win_const_mgr.add_const('IMAGE_NT_OPTIONAL_HDR64_MAGIC',0x00000020)
		win_const_mgr.add_const('IDM_SETPAGEACTIONALLOWEDFLAGS',0x00003AFC)
		win_const_mgr.add_const('LINEERR_NOREQUEST',0x80000045)
		win_const_mgr.add_const('ERROR_NO_SUCH_PRIVILEGE',0x00000521)
		win_const_mgr.add_const('LINEMEDIAMODE_VIDEO',0x00008000)
		win_const_mgr.add_const('ODBC_ERROR_CREATE_DSN_FAILED',0x00000012)
		win_const_mgr.add_const('SECURITY_NULL_RID',0x00000000)
		win_const_mgr.add_const('SQL_MAX_ASYNC_CONCURRENT_STATEMENTS',0x00002726)
		win_const_mgr.add_const('D3DPMISCCAPS_FOGANDSPECULARALPHA',0x00010000)
		win_const_mgr.add_const('SYMFLAG_FRAMEREL',0x00000020)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_PLAY',0x0000002E)
		win_const_mgr.add_const('FS_INITIALIZING',0x20000000)
		win_const_mgr.add_const('COD_LAN_ACCESS_MASK',0x000000E0)
		win_const_mgr.add_const('OID_FDDI_PATH_CONFIGURATION',0x03030256)
		win_const_mgr.add_const('IMR_RECONVERTSTRING',0x00000004)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_IO_READ',0x0000000A)
		win_const_mgr.add_const('DRIVER_UNTRUSTED_COMPATID_RANK',0x0000BFFF)
		win_const_mgr.add_const('LVS_EX_FULLROWSELECT',0x00000020)
		win_const_mgr.add_const('OFFLINE_STATUS_LOCAL',0x00000001)
		win_const_mgr.add_const('WT_CURRENT_VERSION',0x00000200)
		win_const_mgr.add_const('DMPAPER_ENV_B4',0x00000021)
		win_const_mgr.add_const('SCHED_E_SERVICE_NOT_LOCALSYSTEM',0x00001838)
		win_const_mgr.add_const('ERROR_DS_CROSS_REF_EXISTS',0x000020B6)
		win_const_mgr.add_const('NCBACTION',0x00000077)
		win_const_mgr.add_const('SPI_SETFONTSMOOTHINGORIENTATION',0x00002013)
		win_const_mgr.add_const('SQL_CT_LOCAL_TEMPORARY',0x00000010)
		win_const_mgr.add_const('ERROR_SMI_PRIMITIVE_INSTALLER_FAILED',0x0000371C)
		win_const_mgr.add_const('DS_REPSYNC_NEVER_COMPLETED',0x00000400)
		win_const_mgr.add_const('ODBC_ERROR_COMPONENT_NOT_FOUND',0x00000006)
		win_const_mgr.add_const('COD_COMPUTER_MINOR_SERVER',0x00000002)
		win_const_mgr.add_const('MD_ERROR_SUB403_TOO_MANY_USERS',0x00000009)
		win_const_mgr.add_const('NIF_GUID',0x00000020)
		win_const_mgr.add_const('MCSC_TITLETEXT',0x00000003)
		win_const_mgr.add_const('DEBUG_CES_BREAKPOINTS',0x00000004)
		win_const_mgr.add_const('SQL_FETCH_FIRST_SYSTEM',0x00000020)
		win_const_mgr.add_const('WINHTTP_QUERY_IF_NONE_MATCH',0x00000039)
		win_const_mgr.add_const('SND_ALIAS',0x00010000)
		win_const_mgr.add_const('INDEX_GUID_CUSTOMRECOGNIZER',0x0000000C)
		win_const_mgr.add_const('IP_OPT_SECURITY',0x00000082)
		win_const_mgr.add_const('SPI_GETICONTITLEWRAP',0x00000019)
		win_const_mgr.add_const('AUTODIAL_MODE_NEVER',0x00000001)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_TRANSFER_ENCODING',0x00000002)
		win_const_mgr.add_const('MM_JOY1MOVE',0x000003A0)
		win_const_mgr.add_const('LINETRANSLATERESULT_CANONICAL',0x00000001)
		win_const_mgr.add_const('FO_DELETE',0x00000003)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_CURRENTMEDIASTATUS',0x00000106)
		win_const_mgr.add_const('SQL_ISV_COLUMN_PRIVILEGES',0x00000020)
		win_const_mgr.add_const('INTERNET_STATUS_CONNECTION_CLOSED',0x00000033)
		win_const_mgr.add_const('ISFB_STATE_NONAMESORT',0x00000080)
		win_const_mgr.add_const('FPSR_TD2',0x00000026)
		win_const_mgr.add_const('PFD_DEPTH_DONTCARE',0x20000000)
		win_const_mgr.add_const('DISPID_ENUMOPTIONS',0x0000000E)
		win_const_mgr.add_const('ICVERSION',0x00000104)
		win_const_mgr.add_const('PROCESS_VM_OPERATION',0x00000008)
		win_const_mgr.add_const('CLOSECHANNEL',0x00001010)
		win_const_mgr.add_const('CTRY_QATAR',0x000003CE)
		win_const_mgr.add_const('VCSTATUS_MODAL',0x00000004)
		win_const_mgr.add_const('EXPOSUREMODE_PROGRAM_CREATIVE',0x00000005)
		win_const_mgr.add_const('CM_RESDES_WIDTH_DEFAULT',0x00000000)
		win_const_mgr.add_const('NO_PROPAGATE_INHERIT_ACE',0x00000004)
		win_const_mgr.add_const('PIDSI_THUMBNAIL',0x00000011)
		win_const_mgr.add_const('PDH_PLA_ERROR_SCHEDULE_ELAPSED',0xC0000BEC)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_NUMERIC_NAME',0x00002559)
		win_const_mgr.add_const('IDM_SAVECOPYAS',0x000007D2)
		win_const_mgr.add_const('INVALID_AUDIO_FORMAT',0x00000000)
		win_const_mgr.add_const('ENM_LINK',0x04000000)
		win_const_mgr.add_const('TOKEN_SOURCE_LENGTH',0x00000008)
		win_const_mgr.add_const('CLIP_NOT',0x00000000)
		win_const_mgr.add_const('CRED_MARSHALED_TI_SIZE_SIZE',0x0000000C)
		win_const_mgr.add_const('DISPID_BASEURL',0x00000018)
		win_const_mgr.add_const('MOD_CONTROL',0x00000002)
		win_const_mgr.add_const('EC_ERRORABORTEX',0x00000045)
		win_const_mgr.add_const('SS_ETCHEDFRAME',0x00000012)
		win_const_mgr.add_const('ALTERNATE',0x00000001)
		win_const_mgr.add_const('PAN_LETT_OBLIQUE_CONTACT',0x00000009)
		win_const_mgr.add_const('WMDRM_ACQUIRE_LICENSE_LEGACY_NONSILENT',0x00000004)
		win_const_mgr.add_const('USE_LOCAL_PARMNUM',0x00000001)
		win_const_mgr.add_const('ASC_REQ_FRAGMENT_TO_FIT',0x00800000)
		win_const_mgr.add_const('ERROR_NO_SITE_SETTINGS_OBJECT',0x000021AB)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_DEFAULT',0x00000080)
		win_const_mgr.add_const('PDH_FLAGS_FILE_BROWSER_ONLY',0x00000001)
		win_const_mgr.add_const('TVIF_DI_SETITEM',0x00001000)
		win_const_mgr.add_const('DI_FLAGSEX_DEVICECHANGE',0x00000100)
		win_const_mgr.add_const('LINEERR_INVALCALLSTATELIST',0x8000001D)
		win_const_mgr.add_const('DVD_AUDIO_CAPS_AC3',0x00000001)
		win_const_mgr.add_const('VHDR_PREPARED',0x00000002)
		win_const_mgr.add_const('ENABLE_FULL_DISPERSAL',0x00000004)
		win_const_mgr.add_const('MAX_VOLUME_ID_SIZE',0x00000024)
		win_const_mgr.add_const('DCOMSCM_PING_USE_MID_AUTHNSERVICE',0x00000010)
		win_const_mgr.add_const('WINHTTP_ENABLE_SPN_SERVER_PORT',0x00000001)
		win_const_mgr.add_const('LASTGOOD_OPERATION',0x000000FF)
		win_const_mgr.add_const('CR_REGISTRY_ERROR',0x0000001D)
		win_const_mgr.add_const('LDAP_OPT_DNSDOMAIN_NAME',0x0000003B)
		win_const_mgr.add_const('SQL_AGGREGATE_FUNCTIONS',0x000000A9)
		win_const_mgr.add_const('DEBUG_IOUTPUT_REMOTING',0x40000000)
		win_const_mgr.add_const('HTTB_SYSTEMSIZINGMARGINS',0x00000200)
		win_const_mgr.add_const('COD_AUDIO_MINOR_HEADPHONES',0x00000006)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_LITUSE',0x00000005)
		win_const_mgr.add_const('MCI_RECORD',0x0000080F)
		win_const_mgr.add_const('NETLOGON_FULL_SYNC_REPLICATION',0x00000004)
		win_const_mgr.add_const('OID_GEN_MEDIA_SUPPORTED',0x00010103)
		win_const_mgr.add_const('KSNODEPIN_AEC_RENDER_IN',0x00000001)
		win_const_mgr.add_const('REPL_EXTENT_TREE',0x00000002)
		win_const_mgr.add_const('LVCFMT_NO_TITLE',0x00800000)
		win_const_mgr.add_const('OID_TAPI_CLOSE',0x07030103)
		win_const_mgr.add_const('SPFILENOTIFY_TARGETEXISTS',0x00020000)
		win_const_mgr.add_const('ERROR_LICENSE_QUOTA_EXCEEDED',0x00000573)
		win_const_mgr.add_const('CPL_INIT',0x00000001)
		win_const_mgr.add_const('LINECALLINFOSTATE_OTHER',0x00000001)
		win_const_mgr.add_const('MCIWNDF_SHOWMODE',0x00000040)
		win_const_mgr.add_const('HLNF_ALLOW_AUTONAVIGATE',0x20000000)
		win_const_mgr.add_const('SEF_AVOID_OWNER_CHECK',0x00000010)
		win_const_mgr.add_const('IMAGE_REL_CEF_ADDR32',0x00000001)
		win_const_mgr.add_const('DEVICE_STATE_NOTPRESENT',0x00000004)
		win_const_mgr.add_const('WINHTTP_AUTOPROXY_RUN_OUTPROCESS_ONLY',0x00020000)
		win_const_mgr.add_const('SHACF_URLMRU',0x00000004)
		win_const_mgr.add_const('LANG_XHOSA',0x00000034)
		win_const_mgr.add_const('CRYPT_FIND_MACHINE_KEYSET_FLAG',0x00000002)
		win_const_mgr.add_const('NTMS_I1_MESSAGE_LENGTH',0x0000007F)
		win_const_mgr.add_const('RSC_FLAG_SKIPDISKSPACECHECK',0x00000002)
		win_const_mgr.add_const('OF_READ',0x00000000)
		win_const_mgr.add_const('MD_NOTIFY_AUTHENTICATION',0x00002000)
		win_const_mgr.add_const('SECPKG_NEGOTIATION_DIRECT',0x00000003)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_OWNER_RIGHTS',0x80400000)
		win_const_mgr.add_const('SPINST_LOGCONFIG_IS_FORCED',0x00020000)
		win_const_mgr.add_const('SV_ENABLECOMPRESSION_PARMNUM',0x0000024E)
		win_const_mgr.add_const('PS_RATE_PHASE_BITS',0x00000004)
		win_const_mgr.add_const('ERROR_TOO_MANY_LUIDS_REQUESTED',0x00000535)
		win_const_mgr.add_const('OPTION_ROUTER_SOLICITATION_ADDR',0x00000020)
		win_const_mgr.add_const('PXE_MAX_ADDRESS',0x00000010)
		win_const_mgr.add_const('SECURITY_MANDATORY_UNTRUSTED_RID',0x00000000)
		win_const_mgr.add_const('ERROR_DS_ALIAS_POINTS_TO_ALIAS',0x00002090)
		win_const_mgr.add_const('D3DFVF_TEXCOUNT_MASK',0x00000000)
		win_const_mgr.add_const('AT_SIGNATURE',0x00000002)
		win_const_mgr.add_const('ENABLECLASS_QUERY',0x00000000)
		win_const_mgr.add_const('WSAPROTOCOL_LEN',0x000000FF)
		win_const_mgr.add_const('SAFER_TOKEN_MAKE_INERT',0x00000004)
		win_const_mgr.add_const('SQL_DIAG_DYNAMIC_FUNCTION_CODE',0x0000000C)
		win_const_mgr.add_const('MCI_DGV_STATUS_VIDEO',0x00004018)
		win_const_mgr.add_const('DNS_RTYPE_NS',0x00000200)
		win_const_mgr.add_const('DEBUG_STATUS_GO_HANDLED',0x00000002)
		win_const_mgr.add_const('URLACTION_ACTIVEX_CONFIRM_NOOBJECTSAFETY',0x00001204)
		win_const_mgr.add_const('RIGHTMOST_BUTTON_PRESSED',0x00000002)
		win_const_mgr.add_const('CRYPT_INITIATOR',0x00000040)
		win_const_mgr.add_const('IDS_POSTED_TO',0x00011006)
		win_const_mgr.add_const('ERROR_LOGON_TYPE_NOT_GRANTED',0x00000569)
		win_const_mgr.add_const('ERROR_IS_SUBSTED',0x00000087)
		win_const_mgr.add_const('SI_OWNER_ELEVATION_REQUIRED',0x04000000)
		win_const_mgr.add_const('HTTP_QUERY_ETAG',0x00000036)
		win_const_mgr.add_const('LVHT_EX_GROUP_COLLAPSE',0x40000000)
		win_const_mgr.add_const('TAPE_LOGICAL_POSITION',0x00000001)
		win_const_mgr.add_const('OID_GEN_RECEIVE_HASH',0x0001021F)
		win_const_mgr.add_const('CFE_PROTECTED',0x00000010)
		win_const_mgr.add_const('MQSEC_PEEK_MESSAGE',0x00000002)
		win_const_mgr.add_const('FACILITY_EAP',0x00000042)
		win_const_mgr.add_const('RP_DSN_SENT_DELIVERED',0x00020040)
		win_const_mgr.add_const('ERROR_TLW_WITH_WSCHILD',0x0000057E)
		win_const_mgr.add_const('CAUSE_INVALID_ENDPOINT_REFERENCE',0x00000059)
		win_const_mgr.add_const('ERROR_VC_DISCONNECTED',0x000000F0)
		win_const_mgr.add_const('RATING_UNRATED_SET',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_AM_ADDR32',0x00000001)
		win_const_mgr.add_const('DDBLT_DDFX',0x00000800)
		win_const_mgr.add_const('TCS_FOCUSNEVER',0x00008000)
		win_const_mgr.add_const('PRINTER_ENUM_ICON3',0x00040000)
		win_const_mgr.add_const('CRYPTUI_ENABLE_REVOCATION_CHECK_CHAIN',0x00008000)
		win_const_mgr.add_const('SUBLANG_DIVEHI_MALDIVES',0x00000001)
		win_const_mgr.add_const('SQL_LCK_UNLOCK',0x00000004)
		win_const_mgr.add_const('EN_CHANGE',0x00000300)
		win_const_mgr.add_const('INDEX_GUID_ENABLEDUNICODECHARACTERRANGES',0x0000000A)
		win_const_mgr.add_const('MP_MSGCLASS_REPLICATION',0x00000002)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_STAR',0x0000001E)
		win_const_mgr.add_const('IF_TYPE_PROP_BWA_P2MP',0x000000B8)
		win_const_mgr.add_const('DISPID_FONT_UNDER',0x00000005)
		win_const_mgr.add_const('LWS_NOPREFIX',0x00000004)
		win_const_mgr.add_const('MD_ASP_SERVICE_ENABLE_SXS',0x00000002)
		win_const_mgr.add_const('LANG_TIBETAN',0x00000051)
		win_const_mgr.add_const('ERROR_DS_MODIFYDN_WRONG_GRANDPARENT',0x00002186)
		win_const_mgr.add_const('VOS_OS216',0x00020000)
		win_const_mgr.add_const('ERROR_DS_CANT_MOD_OBJ_CLASS',0x00002017)
		win_const_mgr.add_const('MQMSG_AUTH_LEVEL_SIG20',0x00000004)
		win_const_mgr.add_const('WS_EX_DLGMODALFRAME',0x00000001)
		win_const_mgr.add_const('BATTERY_UNKNOWN_CAPACITY',0xFFFFFFFF)
		win_const_mgr.add_const('WIA_IPS_MIN_VERTICAL_SIZE',0x00001818)
		win_const_mgr.add_const('LPM_API_VERSION_1',0x00000001)
		win_const_mgr.add_const('IDS_CAP_SAVEASPERCENT',0x000001A1)
		win_const_mgr.add_const('WSB_PROP_MASK',0x00000FFF)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_RECOVER',0x00000100)
		win_const_mgr.add_const('SECPKG_PACKAGE_CHANGE_SELECT',0x00000002)
		win_const_mgr.add_const('COLOR_HUESCROLL',0x000002BC)
		win_const_mgr.add_const('SQL_CT_CREATE_TABLE',0x00000001)
		win_const_mgr.add_const('EVENT_SYSTEM_MENUEND',0x00000005)
		win_const_mgr.add_const('STREAM_FLAGS_RESERVED',0x00000000)
		win_const_mgr.add_const('FWPM_ACTRL_READ_STATS',0x00000100)
		win_const_mgr.add_const('TMT_GLYPHTYPE',0x00000FAC)
		win_const_mgr.add_const('DMICM_SATURATE',0x00000001)
		win_const_mgr.add_const('PID_INTSITE_ICONFILE',0x00000015)
		win_const_mgr.add_const('RPC_PROXY_CONNECTION_TYPE_OUT_PROXY',0x00000001)
		win_const_mgr.add_const('SVAUD_GOODUSE',0x00000600)
		win_const_mgr.add_const('ERROR_INVALID_PRIORITY',0x00000708)
		win_const_mgr.add_const('MCI_DGV_WINDOW_STATE',0x00040000)
		win_const_mgr.add_const('SV_INITCONNTABLE_PARMNUM',0x00000220)
		win_const_mgr.add_const('ERROR_NOT_QUORUM_CLASS',0x000013A1)
		win_const_mgr.add_const('WIA_DPS_MAX_SCAN_TIME',0x00000C17)
		win_const_mgr.add_const('CERT_VALIDITY_UNKNOWN_CRITICAL_EXTENSION',0x00000080)
		win_const_mgr.add_const('WIA_DPS_PAGES',0x00000C18)
		win_const_mgr.add_const('SVAUD_BADSESSLOGON',0x00000018)
		win_const_mgr.add_const('DSSI_IS_ROOT',0x00000010)
		win_const_mgr.add_const('PHONEERR_INVALPRIVILEGE',0x90000016)
		win_const_mgr.add_const('INITIAL_FPCSR',0x00000027)
		win_const_mgr.add_const('LINEFEATURE_FORWARDFWD',0x00000080)
		win_const_mgr.add_const('WM_CTLCOLORLISTBOX',0x00000134)
		win_const_mgr.add_const('WPWIZ_ERROR_COCREATE_WEBPOST',0xC0042004)
		win_const_mgr.add_const('CRYPT_LDAP_AREC_EXCLUSIVE_RETRIEVAL',0x00040000)
		win_const_mgr.add_const('KSAC3_SERVICE_MAIN_AUDIO',0x00000000)
		win_const_mgr.add_const('SBS_SIZEBOXBOTTOMRIGHTALIGN',0x00000004)
		win_const_mgr.add_const('IMF_FORCENONE',0x00000001)
		win_const_mgr.add_const('RPC_IF_OLE',0x00000002)
		win_const_mgr.add_const('SUBLANG_SWAHILI_KENYA',0x00000001)
		win_const_mgr.add_const('SNMP_MGMTAPI_NOTRAPS',0x0000002C)
		win_const_mgr.add_const('OPTION_TIME_OFFSET',0x00000002)
		win_const_mgr.add_const('WIA_IPS_YSCALING',0x00000C26)
		win_const_mgr.add_const('EVT_READ_ACCESS',0x00000001)
		win_const_mgr.add_const('LINEADDRFEATURE_FORWARD',0x00000001)
		win_const_mgr.add_const('IPPROTO_UDP',0x00000011)
		win_const_mgr.add_const('TMT_DESCRIPTION',0x00000260)
		win_const_mgr.add_const('PRF_REQUIREABSOLUTE',0x00000010)
		win_const_mgr.add_const('VK_F3',0x00000072)
		win_const_mgr.add_const('PIPE_ACCEPT_REMOTE_CLIENTS',0x00000000)
		win_const_mgr.add_const('SQL_FN_TD_DAYOFMONTH',0x00000004)
		win_const_mgr.add_const('ET_MODEL',0x00001000)
		win_const_mgr.add_const('SFGAO_CAPABILITYMASK',0x00000177)
		win_const_mgr.add_const('IN6ADDR_SOLICITEDNODEMULTICASTPREFIX_LENGTH',0x00000068)
		win_const_mgr.add_const('EVENT_SYSTEM_FOREGROUND',0x00000003)
		win_const_mgr.add_const('LSP_CRYPTO_COMPRESS',0x00000040)
		win_const_mgr.add_const('D3DCOLORWRITEENABLE_GREEN',0x00000001)
		win_const_mgr.add_const('ABORTDOC',0x00000002)
		win_const_mgr.add_const('SQL_ACCESSIBLE_TABLES',0x00000013)
		win_const_mgr.add_const('MCI_SET_DOOR_OPEN',0x00000100)
		win_const_mgr.add_const('MAX_PIN_NAME',0x00000080)
		win_const_mgr.add_const('WS_CLIPSIBLINGS',0x04000000)
		win_const_mgr.add_const('WIA_DPS_PLATEN_COLOR',0x00000C09)
		win_const_mgr.add_const('PROV_RNG',0x00000015)
		win_const_mgr.add_const('CSIDL_FLAG_NO_ALIAS',0x00001000)
		win_const_mgr.add_const('TMT_ATLASIMAGE',0x00001F40)
		win_const_mgr.add_const('CR_FLG_FORCEUTF8',0x00000004)
		win_const_mgr.add_const('OID_802_11_NETWORK_TYPE_IN_USE',0x0D010204)
		win_const_mgr.add_const('SQL_FC_ON',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLDESCRIBECOL',0x00000008)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_DEVICE_SPECIFIC',0x00000020)
		win_const_mgr.add_const('LANG_DARI',0x00000008)
		win_const_mgr.add_const('INTERNET_OPTION_ALTER_IDENTITY',0x00000050)
		win_const_mgr.add_const('TOKEN_QUERY_SOURCE',0x00000010)
		win_const_mgr.add_const('CERT_TRUST_HAS_PREFERRED_ISSUER',0x00000100)
		win_const_mgr.add_const('WMDRM_BACKUP_OVERWRITE',0x00000001)
		win_const_mgr.add_const('IKEEXT_CERT_FLAG_USE_NAP_CERTIFICATE',0x00000004)
		win_const_mgr.add_const('DESKTOP_READOBJECTS',0x00000001)
		win_const_mgr.add_const('SCARD_T1_EPILOGUE_LENGTH',0x00000002)
		win_const_mgr.add_const('TBS_TRANSPARENTBKGND',0x00001000)
		win_const_mgr.add_const('IPPORT_LDAP',0x00000185)
		win_const_mgr.add_const('DNS_TYPE_NXT',0x00000001)
		win_const_mgr.add_const('ACM_FORMATDETAILSF_INDEX',0x00000000)
		win_const_mgr.add_const('WSAECONNREFUSED',0x0000274D)
		win_const_mgr.add_const('LINE_MONITORTONE',0x0000000B)
		win_const_mgr.add_const('HTTP_LOG_FIELD_TIME_TAKEN',0x00004000)
		win_const_mgr.add_const('WM_MDIREFRESHMENU',0x00000234)
		win_const_mgr.add_const('ERROR_CLUSTER_PARTIAL_READ',0x00001721)
		win_const_mgr.add_const('ISR_TAK',0x00000003)
		win_const_mgr.add_const('WINHTTP_QUERY_RETRY_AFTER',0x00000024)
		win_const_mgr.add_const('SOFTKEYBOARD_TYPE_C1',0x00000002)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_GUESTS',0x00000202)
		win_const_mgr.add_const('DBPROP_CI_SECURITY_ID',0x00000006)
		win_const_mgr.add_const('BS_3STATE',0x00000005)
		win_const_mgr.add_const('DOSOPTF_SUPPORTED',0x00000002)
		win_const_mgr.add_const('WIA_IPS_FILM_NODE_NAME',0x00001021)
		win_const_mgr.add_const('WIA_IPA_APP_COLOR_MAPPING',0x00001019)
		win_const_mgr.add_const('JPEG_RGB',0x00000003)
		win_const_mgr.add_const('TMT_TRANSITIONDURATIONS',0x00001770)
		win_const_mgr.add_const('SUBLANG_KYRGYZ_KYRGYZSTAN',0x00000001)
		win_const_mgr.add_const('NCRYPT_IMPL_HARDWARE_RNG_FLAG',0x00000010)
		win_const_mgr.add_const('DBPROPVAL_ASYNCH_BACKGROUNDPOPULATION',0x00000008)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_TYPE',0x00000001)
		win_const_mgr.add_const('ACTRL_PERM_18',0x00020000)
		win_const_mgr.add_const('ACTRL_PERM_19',0x00040000)
		win_const_mgr.add_const('SES_LBSCROLLNOTIFY',0x00100000)
		win_const_mgr.add_const('CBA_DEFERRED_SYMBOL_LOAD_START',0x00000001)
		win_const_mgr.add_const('ACTRL_PERM_14',0x00002000)
		win_const_mgr.add_const('ACTRL_PERM_15',0x00004000)
		win_const_mgr.add_const('ACTRL_PERM_16',0x00008000)
		win_const_mgr.add_const('ACTRL_PERM_17',0x00010000)
		win_const_mgr.add_const('ACTRL_PERM_10',0x00000200)
		win_const_mgr.add_const('PDH_NOEXPANDCOUNTERS',0x00000001)
		win_const_mgr.add_const('ACTRL_PERM_12',0x00000800)
		win_const_mgr.add_const('ACTRL_PERM_13',0x00001000)
		win_const_mgr.add_const('POP3_MD_ID_BEGIN_RESERVED',0x00000000)
		win_const_mgr.add_const('WM_VSCROLL',0x00000115)
		win_const_mgr.add_const('KSDISPATCH_FASTIO',0x80000000)
		win_const_mgr.add_const('PHOTO_PROGRAMMODE_NORMAL',0x00000002)
		win_const_mgr.add_const('TTF_PARSELINKS',0x00001000)
		win_const_mgr.add_const('PSINJECT_TRAILER',0x00000012)
		win_const_mgr.add_const('AW_SLIDE',0x00040000)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_CLIENT_CHIMNEY_OFFLOAD_GENERIC_CHARACTERISTICS',0x0000008E)
		win_const_mgr.add_const('PFD_SWAP_LAYER_BUFFERS',0x00000800)
		win_const_mgr.add_const('CERT_STORE_PROV_FREE_FIND_CTL_FUNC',0x00000015)
		win_const_mgr.add_const('SP_PROT_SSL3_SERVER',0x00000010)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_DISABLEMCN',0x00000104)
		win_const_mgr.add_const('WMDM_POWER_IS_EXTERNAL',0x00000008)
		win_const_mgr.add_const('CSIDL_PROFILE',0x00000028)
		win_const_mgr.add_const('NTMS_DESCRIPTION_LENGTH',0x0000007F)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_LOGGING_MODE',0x00000400)
		win_const_mgr.add_const('TRACE_MESSAGE_MAXIMUM_SIZE',0x00000008)
		win_const_mgr.add_const('DEBUG_CES_ASSEMBLY_OPTIONS',0x00001000)
		win_const_mgr.add_const('SEC_RESERVE',0x04000000)
		win_const_mgr.add_const('APPCOMMAND_BROWSER_SEARCH',0x00000005)
		win_const_mgr.add_const('SHCNE_FREESPACE',0x00040000)
		win_const_mgr.add_const('CDO_E_INVALID_PROPERTYNAME',0x80040204)
		win_const_mgr.add_const('DEBUG_EVENT_BREAKPOINT',0x00000001)
		win_const_mgr.add_const('LINECALLSTATE_RINGBACK',0x00000020)
		win_const_mgr.add_const('SHCNE_DRIVEREMOVED',0x00000080)
		win_const_mgr.add_const('DMCOLOR_MONOCHROME',0x00000001)
		win_const_mgr.add_const('ERROR_RETRY',0x000004D5)
		win_const_mgr.add_const('CR_DEVICE_INTERFACE_ACTIVE',0x00000036)
		win_const_mgr.add_const('IMGDECODE_EVENT_USEDDRAW',0x00000010)
		win_const_mgr.add_const('WINHTTP_QUERY_IF_UNMODIFIED_SINCE',0x0000003B)
		win_const_mgr.add_const('SECPKG_NEGOTIATION_COMPLETE',0x00000000)
		win_const_mgr.add_const('IF_TYPE_QLLC',0x00000044)
		win_const_mgr.add_const('DEBUG_INTERRUPT_PASSIVE',0x00000001)
		win_const_mgr.add_const('PKCS5_PADDING',0x00000001)
		win_const_mgr.add_const('ADS_JOB_SPOOLING',0x00000008)
		win_const_mgr.add_const('HC_SYSMODALOFF',0x00000005)
		win_const_mgr.add_const('OCR_ICON',0x00007F81)
		win_const_mgr.add_const('ERROR_DS_BAD_INSTANCE_TYPE',0x00002079)
		win_const_mgr.add_const('BSF_MSGSRV32ISOK_BIT',0x0000001F)
		win_const_mgr.add_const('GCL_REVERSECONVERSION',0x00000002)
		win_const_mgr.add_const('COLOR_SAT',0x000002C0)
		win_const_mgr.add_const('DISPID_IWBSCRIPTCONTROL_SCROLLBAR',0x00000007)
		win_const_mgr.add_const('F_READ',0x00000002)
		win_const_mgr.add_const('WEBPOST_ERROR_PROVCLSID_UNKNOWN',0xC0042102)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_INCLUDE_PAGE_HASHES',0x00000004)
		win_const_mgr.add_const('PO_DELETE',0x00000013)
		win_const_mgr.add_const('SRCLIST_TEMPORARY',0x00000001)
		win_const_mgr.add_const('FPS_OFFLINE',0x20010000)
		win_const_mgr.add_const('IF_TYPE_DOCSCABLE_DOWNSTREAM',0x00000080)
		win_const_mgr.add_const('IMAGE_REL_IA64_UREL32',0x00000014)
		win_const_mgr.add_const('NS_ALL',0x00000000)
		win_const_mgr.add_const('WPWIZ_ERROR_WEBPOST_PTR',0xC0042007)
		win_const_mgr.add_const('MAX_MOF_FIELDS',0x00000010)
		win_const_mgr.add_const('ERROR_WMI_ITEMID_NOT_FOUND',0x0000106A)
		win_const_mgr.add_const('TXFS_TRANSACTION_STATE_NOTACTIVE',0x00000003)
		win_const_mgr.add_const('PIDDI_THUMBNAIL',0x00000002)
		win_const_mgr.add_const('SUBLANG_CUSTOM_DEFAULT',0x00000003)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_FLAG_CERT_REV_FAILED',0x00000001)
		win_const_mgr.add_const('WIA_IPS_FIRST',0x00001802)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_DEFAULT_PRIORITY',0x0000000F)
		win_const_mgr.add_const('SECURITY_FLAG_IGNORE_CERT_CN_INVALID',0x00001000)
		win_const_mgr.add_const('TA_CENTER',0x00000006)
		win_const_mgr.add_const('DV_ERR_OK',0x00000000)
		win_const_mgr.add_const('SQL_UB_ON',0x00000001)
		win_const_mgr.add_const('URLPOLICY_JAVA_PROHIBIT',0x00000000)
		win_const_mgr.add_const('ALG_TYPE_SECURECHANNEL',0x00000006)
		win_const_mgr.add_const('AMDDS_ALL',0x000000FF)
		win_const_mgr.add_const('SV_SECURITY_SHARE',0x00000000)
		win_const_mgr.add_const('PAGE_EXECUTE',0x00000010)
		win_const_mgr.add_const('AM_VIDEO_FLAG_IPB_MASK',0x00000030)
		win_const_mgr.add_const('TVIS_OVERLAYMASK',0x00000F00)
		win_const_mgr.add_const('FS_NO_ANSWER',0x20000080)
		win_const_mgr.add_const('ISC_RET_STREAM',0x00008000)
		win_const_mgr.add_const('VK_MEDIA_PLAY_PAUSE',0x000000B3)
		win_const_mgr.add_const('MSG_PARTIAL',0x00008000)
		win_const_mgr.add_const('INPLACE_E_LAST',0x800401AF)
		win_const_mgr.add_const('SUBLANG_ARABIC_LEBANON',0x00000000)
		win_const_mgr.add_const('RIGHT_ALT_PRESSED',0x00000001)
		win_const_mgr.add_const('ERROR_PKINIT_FAILURE',0x000004EF)
		win_const_mgr.add_const('EMR_SCALEVIEWPORTEXTEX',0x0000001F)
		win_const_mgr.add_const('KSDEVICE_FLAG_LOWPOWER_PASSTHROUGH',0x00000002)
		win_const_mgr.add_const('DRIVER_HARDWAREID_RANK',0x00000FFF)
		win_const_mgr.add_const('RQ_BEGIN_REQUEST',0x00000001)
		win_const_mgr.add_const('SQL_CASCADE',0x00000000)
		win_const_mgr.add_const('LINECALLINFOSTATE_ORIGIN',0x00000100)
		win_const_mgr.add_const('PARTITION_EXTENDED',0x00000005)
		win_const_mgr.add_const('OFFLINEAVAILABILITY_AVAILABLE',0x00000001)
		win_const_mgr.add_const('FS_SYMBOL',0x80000000)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2_STARTINGSECTORSPERSECOND',0x00000102)
		win_const_mgr.add_const('MAPI_FORCE_DOWNLOAD',0x00001000)
		win_const_mgr.add_const('MF_DISABLED',0x00000002)
		win_const_mgr.add_const('REALTIME_PRIORITY_CLASS',0x00000100)
		win_const_mgr.add_const('CREDUI_FLAGS_REQUIRE_CERTIFICATE',0x00000010)
		win_const_mgr.add_const('QS_MOUSEMOVE',0x00000002)
		win_const_mgr.add_const('PGF_SCROLLDOWN',0x00000002)
		win_const_mgr.add_const('CRYPTPROTECT_PROMPT_ON_UNPROTECT',0x00000001)
		win_const_mgr.add_const('WMDM_STATUS_DEVICE_NOTPRESENT',0x00000004)
		win_const_mgr.add_const('FCSM_ICONFILE',0x00000010)
		win_const_mgr.add_const('KS_NABTS_GROUPID_NETWORK_WIDE_ADVERTISER_BASE',0x00000870)
		win_const_mgr.add_const('TXTLOG_INSTALLER',0x40000000)
		win_const_mgr.add_const('LIFF_IMPLEMENT_TEXT_FILTER_FALLBACK_POLICY',0x00000002)
		win_const_mgr.add_const('ILD_BLEND50',0x00000004)
		win_const_mgr.add_const('ERROR_INVALID_MSGBOX_STYLE',0x0000059E)
		win_const_mgr.add_const('MD_NOTIFY_ORDER_LOW',0x00020000)
		win_const_mgr.add_const('INDEX_GUID_CUSTOMRECOGNIZERID',0x00000001)
		win_const_mgr.add_const('IGIMII_INPUTTOOLS',0x00000040)
		win_const_mgr.add_const('DOSOPTF_PROVIDESUMB',0x00000010)
		win_const_mgr.add_const('RTCSI_IM',0x00000008)
		win_const_mgr.add_const('DNF_NODRIVER',0x00000008)
		win_const_mgr.add_const('BM_GETSTATE',0x000000F2)
		win_const_mgr.add_const('LDAP_OPT_HOST_REACHABLE',0x0000003E)
		win_const_mgr.add_const('ERROR_REGISTRY_QUOTA_LIMIT',0x00000265)
		win_const_mgr.add_const('MCI_ANIM_PUT_DESTINATION',0x00040000)
		win_const_mgr.add_const('ERROR_SEM_NOT_FOUND',0x000000BB)
		win_const_mgr.add_const('ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE',0x000013A6)
		win_const_mgr.add_const('FILE_DEVICE_TERMSRV',0x00000038)
		win_const_mgr.add_const('REGDF_CONFLICTMEM',0x00020000)
		win_const_mgr.add_const('PAGE_EXECUTE_WRITECOPY',0x00000080)
		win_const_mgr.add_const('KP_G',0x0000000C)
		win_const_mgr.add_const('MAPI_UNREAD_ONLY',0x00000020)
		win_const_mgr.add_const('IASSEMBLYCACHE_UNINSTALL_DISPOSITION_STILL_IN_USE',0x00000002)
		win_const_mgr.add_const('ERROR_ADVANCED_INSTALLER_FAILED',0x00003713)
		win_const_mgr.add_const('DRIVER_USERMODE',0x00000002)
		win_const_mgr.add_const('SV_LOCKVIOLATIONDELAY_PARMNUM',0x00000239)
		win_const_mgr.add_const('KP_P',0x0000000B)
		win_const_mgr.add_const('KP_Q',0x0000000D)
		win_const_mgr.add_const('MQ_LOOKUP_PEEK_PREV',0x40000012)
		win_const_mgr.add_const('SQL_SS_QI_DEFAULT',0x00007530)
		win_const_mgr.add_const('MCI_VCR_STATUS_AUDIO_MONITOR_NUMBER',0x0000400B)
		win_const_mgr.add_const('INTERNET_INVALID_PORT_NUMBER',0x00000000)
		win_const_mgr.add_const('KP_X',0x0000000E)
		win_const_mgr.add_const('KP_Y',0x0000000F)
		win_const_mgr.add_const('GC_WCH_FONLYBEFORE',0x20000000)
		win_const_mgr.add_const('DISPID_TIMEPLAYLIST_LENGTH',0x00000005)
		win_const_mgr.add_const('CRYPTPROTECT_UI_FORBIDDEN',0x00000001)
		win_const_mgr.add_const('DFS_VOLUME_STATES',0x0000000F)
		win_const_mgr.add_const('ERROR_DS_LOW_DSA_VERSION',0x00002178)
		win_const_mgr.add_const('MCI_DGV_STATUS_SPEED',0x00004003)
		win_const_mgr.add_const('RPC_S_NOT_CANCELLED',0x00000722)
		win_const_mgr.add_const('SQL_SUBQUERIES',0x0000005F)
		win_const_mgr.add_const('IRLMP_IRLPT_MODE',0x00000015)
		win_const_mgr.add_const('SYMOPT_CASE_INSENSITIVE',0x00000001)
		win_const_mgr.add_const('LINETONEMODE_RINGBACK',0x00000002)
		win_const_mgr.add_const('SQL_POS_POSITION',0x00000001)
		win_const_mgr.add_const('ICM_SET_COLOR_MODE',0x00000003)
		win_const_mgr.add_const('HLNF_DISABLEWINDOWRESTRICTIONS',0x00800000)
		win_const_mgr.add_const('WINHTTP_OPTION_CONNECT_TIMEOUT',0x00000003)
		win_const_mgr.add_const('DS_NOIDLEMSG',0x00000100)
		win_const_mgr.add_const('SC_MANAGER_CONNECT',0x00000001)
		win_const_mgr.add_const('CRYPT_ACQUIRE_PREFER_NCRYPT_KEY_FLAG',0x00020000)
		win_const_mgr.add_const('ERROR_LOG_CLIENT_NOT_REGISTERED',0x000019ED)
		win_const_mgr.add_const('CERT_NAME_STR_REVERSE_FLAG',0x02000000)
		win_const_mgr.add_const('ERROR_SXS_PROTECTION_RECOVERY_FAILED',0x000036FA)
		win_const_mgr.add_const('STD_UNDO',0x00000003)
		win_const_mgr.add_const('IDM_STOPDOWNLOAD',0x000008FD)
		win_const_mgr.add_const('WMDRM_OPL_PLAY',0x00000001)
		win_const_mgr.add_const('SYMOPT_SECURE',0x00040000)
		win_const_mgr.add_const('CHANGER_POSITION_TO_ELEMENT',0x00000400)
		win_const_mgr.add_const('MCI_BREAK_HWND',0x00000200)
		win_const_mgr.add_const('DISPID_MOVESELECTIONUP',0x00000001)
		win_const_mgr.add_const('BCRYPT_SECRET_AGREEMENT_INTERFACE',0x00000004)
		win_const_mgr.add_const('ERROR_CTX_SHADOW_DENIED',0x00001B84)
		win_const_mgr.add_const('JOB_ADD_CURRENT_DATE',0x00000008)
		win_const_mgr.add_const('DEBUG_VALUE_INT32',0x00000003)
		win_const_mgr.add_const('ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA',0x00002072)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_PREFETCH',0x00001000)
		win_const_mgr.add_const('IDM_SAVEBACKGROUND',0x000008D7)
		win_const_mgr.add_const('PDH_DATA_SOURCE_IS_LOG_FILE',0xC0000BCE)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_THREAD_INFO',0x00000800)
		win_const_mgr.add_const('ERROR_DS_CANT_ADD_ATT_VALUES',0x00002080)
		win_const_mgr.add_const('BCSS_IMAGE',0x00000008)
		win_const_mgr.add_const('USER_COMMENT_PARMNUM',0x00000007)
		win_const_mgr.add_const('PFM_OFFSETINDENT',0x80000000)
		win_const_mgr.add_const('DISPID_ONTOOLBAR',0x000000FF)
		win_const_mgr.add_const('IF_TYPE_FR_FORWARD',0x0000009E)
		win_const_mgr.add_const('RQ_MAP_PATH',0x80000000)
		win_const_mgr.add_const('MCI_VCR_RECORD_INITIALIZE',0x00010000)
		win_const_mgr.add_const('SECPKG_ATTR_ISSUER_LIST',0x00000050)
		win_const_mgr.add_const('SO_BROADCAST',0x00000020)
		win_const_mgr.add_const('DEBUG_ENGOPT_IGNORE_DBGHELP_VERSION',0x00000001)
		win_const_mgr.add_const('IDM_AUTOURLDETECT_MODE',0x00000960)
		win_const_mgr.add_const('MMIO_EMPTYBUF',0x00000010)
		win_const_mgr.add_const('TR_END_TO_END',0x00000001)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_BROADCAST_FRAMES_RCV',0x00000004)
		win_const_mgr.add_const('SC_KEYMENU',0x0000F100)
		win_const_mgr.add_const('IF_TYPE_PROTEON_10MBIT',0x0000000C)
		win_const_mgr.add_const('KAGPROP_ODBCSQLOPTIEF',0x00000004)
		win_const_mgr.add_const('RPC_C_QOS_CAPABILITIES_LOCAL_MA_HINT',0x00000010)
		win_const_mgr.add_const('SUBLANG_WOLOF_SENEGAL',0x00000001)
		win_const_mgr.add_const('SPQ_SCAN_FILE_PRESENCE_WITHOUT_SOURCE',0x00000100)
		win_const_mgr.add_const('DAOROWFETCH_CALLEEALLOCATES',0x00000001)
		win_const_mgr.add_const('SUBLANG_TIGRIGNA_ERITREA',0x00000002)
		win_const_mgr.add_const('DNF_DUPPROVIDER',0x00001000)
		win_const_mgr.add_const('SQL_DESC_ROWVER',0x00000023)
		win_const_mgr.add_const('OID_GEN_XMIT_ERROR',0x00020103)
		win_const_mgr.add_const('RPC_S_INVALID_NAME_SYNTAX',0x000006C8)
		win_const_mgr.add_const('INTERNET_STATUS_SENDING_REQUEST',0x0000001E)
		win_const_mgr.add_const('PROP_DELETE',0x00000001)
		win_const_mgr.add_const('MSIM_DISPID_ONSESSIONSTATECHANGE',0x00000E0B)
		win_const_mgr.add_const('SBM_ENABLE_ARROWS',0x000000E4)
		win_const_mgr.add_const('EVENT_MAX_LEVEL',0x00000000)
		win_const_mgr.add_const('IOF_HIDECHANGEICON',0x00000800)
		win_const_mgr.add_const('ROLLBACK_FLAG_NO_UI',0x00000001)
		win_const_mgr.add_const('SHOW_FULLSCREEN',0x00000003)
		win_const_mgr.add_const('ERROR_MEDIA_CHECK',0x000002A7)
		win_const_mgr.add_const('REVEXT_ASPENABLE',0x00000200)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_INVALID_NAME_FLAG',0x00000040)
		win_const_mgr.add_const('SO_RANDOMIZE_PORT',0x00003005)
		win_const_mgr.add_const('LVCF_MINWIDTH',0x00000040)
		win_const_mgr.add_const('MUI_PARTIAL_LANGUAGE',0x00000002)
		win_const_mgr.add_const('CTRY_HONG_KONG',0x00000354)
		win_const_mgr.add_const('LOCALE_SMONTHNAME13',0x0000100E)
		win_const_mgr.add_const('ALG_SID_DSS_PKCS',0x00000001)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2EVENTARGS_STARTLBA',0x00000100)
		win_const_mgr.add_const('FRAME_FPO',0x00000000)
		win_const_mgr.add_const('LOCALE_SMONTHNAME12',0x00000043)
		win_const_mgr.add_const('DBFLAGS_MAXCACHESIZEX100',0x00000010)
		win_const_mgr.add_const('IME_MODE_CODEINPUT',0x00000080)
		win_const_mgr.add_const('MD_BACKUP_FORCE_BACKUP',0x00000004)
		win_const_mgr.add_const('DMBIN_TRACTOR',0x00000008)
		win_const_mgr.add_const('USER_FULL_NAME_PARMNUM',0x0000000B)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_UNAUTH_USER_SUM_FLOW_RATE',0x00000028)
		win_const_mgr.add_const('STGM_SHARE_DENY_NONE',0x00000040)
		win_const_mgr.add_const('KS_NABTS_GROUPID_NETWORK_WIDE_CONTENT_BASE',0x00000860)
		win_const_mgr.add_const('CMSG_CTRL_DEL_ATTR_CERT',0x0000000F)
		win_const_mgr.add_const('D3DPBLENDCAPS_BLENDFACTOR',0x00002000)
		win_const_mgr.add_const('CPEX_DEST_CDECL',0x80000000)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_BASERELOC',0x00000005)
		win_const_mgr.add_const('KS_VIDEO_ALLOC_VPE_SYSTEM',0x00000001)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_PROCESS_TIME',0x00000002)
		win_const_mgr.add_const('LSFW_UNLOCK',0x00000002)
		win_const_mgr.add_const('CR_INVALID_RES_DES',0x00000006)
		win_const_mgr.add_const('MD_PASSPORT_NO_MAPPING',0x00000000)
		win_const_mgr.add_const('SM_CXMINIMIZED',0x00000039)
		win_const_mgr.add_const('IDM_LANGUAGE',0x000008F4)
		win_const_mgr.add_const('IMN_CLOSECANDIDATE',0x00000004)
		win_const_mgr.add_const('ERROR_REPARSE_OBJECT',0x000002F3)
		win_const_mgr.add_const('ETW_UINT32_TYPE_VALUE',0x00000008)
		win_const_mgr.add_const('FCSM_INFOTIP',0x00000004)
		win_const_mgr.add_const('SERVICE_NO_PRIMARY_IDENTITY',0x00000020)
		win_const_mgr.add_const('MDM_MASK_V120_ML',0x00000003)
		win_const_mgr.add_const('DBPROPVAL_BO_REFINTEGRITY',0x00000002)
		win_const_mgr.add_const('PORT_NAMESERVER',0x0000002A)
		win_const_mgr.add_const('ERROR_DS_CANT_ADD_SYSTEM_ONLY',0x000020A6)
		win_const_mgr.add_const('COD_AUDIO_MINOR_HEADSET',0x00000001)
		win_const_mgr.add_const('DISPID_SEARCHCOMMAND_START',0x00000001)
		win_const_mgr.add_const('DS_REPL_NBR_TWO_WAY_SYNC',0x00000200)
		win_const_mgr.add_const('OIC_SAMPLE',0x00007F00)
		win_const_mgr.add_const('OPTION_MESSAGE_LENGTH',0x00000039)
		win_const_mgr.add_const('WLX_SAS_ACTION_SHUTDOWN',0x00000005)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG',0x0000000B)
		win_const_mgr.add_const('CS_E_FIRST',0x80040164)
		win_const_mgr.add_const('CP_MACCP',0x00000002)
		win_const_mgr.add_const('DNS_ERROR_GENERAL_API_BASE',0x0000254E)
		win_const_mgr.add_const('CMSG_CRL_PARAM',0x0000000E)
		win_const_mgr.add_const('RPC_C_OPT_ASYNC_BLOCK',0x0000000F)
		win_const_mgr.add_const('BLLI_L3_PACKET_1024',0x0000000A)
		win_const_mgr.add_const('FWPM_ACTRL_ADD_LINK',0x00000002)
		win_const_mgr.add_const('DXVA_CONFIG_DATA_TYPE_DPXD',0x00000002)
		win_const_mgr.add_const('INTERNET_CONNECTION_MODEM',0x00000001)
		win_const_mgr.add_const('DN_ADDL',0x00000002)
		win_const_mgr.add_const('CTRY_LUXEMBOURG',0x00000160)
		win_const_mgr.add_const('CSIDL_COMMON_DOCUMENTS',0x00000002)
		win_const_mgr.add_const('SQL_DESC_LOCAL_TYPE_NAME',0x0000001D)
		win_const_mgr.add_const('CDO_E_NOT_FOUND',0x800CCE05)
		win_const_mgr.add_const('EMR_SETWINDOWEXTEX',0x00000009)
		win_const_mgr.add_const('PHRASE_SEARCH',0x00000002)
		win_const_mgr.add_const('WM_GETOBJECT',0x0000003D)
		win_const_mgr.add_const('DNSSEC_PROTOCOL_NONE',0x00000000)
		win_const_mgr.add_const('SECURITY_ANONYMOUS_LOGON_RID',0x00000007)
		win_const_mgr.add_const('CDO_E_ADOSTREAM_NOT_BOUND',0x8004022C)
		win_const_mgr.add_const('DDLOCK_DISCARDCONTENTS',0x00002000)
		win_const_mgr.add_const('PP_CONTAINER',0x00000006)
		win_const_mgr.add_const('RIDEV_EXCLUDE',0x00000010)
		win_const_mgr.add_const('FAX_ERR_BAD_GROUP_CONFIGURATION',0x00001B5B)
		win_const_mgr.add_const('STD_PASTE',0x00000002)
		win_const_mgr.add_const('WM_PASTE',0x00000302)
		win_const_mgr.add_const('ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE',0x000036C3)
		win_const_mgr.add_const('DEX_IDS_CANT_FIND_COMPRESSOR',0x0000058D)
		win_const_mgr.add_const('TME_HOVER',0x00000001)
		win_const_mgr.add_const('DDCKEYCAPS_DESTOVERLAYYUV',0x00000100)
		win_const_mgr.add_const('MSGF_COMMCTRL_BEGINDRAG',0x00004200)
		win_const_mgr.add_const('VER_SUITE_EMBEDDED_RESTRICTED',0x00000800)
		win_const_mgr.add_const('TBIMHT_AFTER',0x00000001)
		win_const_mgr.add_const('ISC_RET_NO_ADDITIONAL_TOKEN',0x02000000)
		win_const_mgr.add_const('PDCAP_WAKE_FROM_D3_SUPPORTED',0x00000080)
		win_const_mgr.add_const('NETWORK_ALIVE_WAN',0x00000002)
		win_const_mgr.add_const('ENDSESSION_CRITICAL',0x40000000)
		win_const_mgr.add_const('CBES_EX_PATHWORDBREAKPROC',0x00000004)
		win_const_mgr.add_const('BSIS_LOCKED',0x00000100)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCDEVENTARGS_ESTIMATEDREMAININGTIME',0x00000301)
		win_const_mgr.add_const('CF_NOFACESEL',0x00080000)
		win_const_mgr.add_const('WMDM_SCP_DRMINFO_V2HEADER',0x00000002)
		win_const_mgr.add_const('ERROR_DS_DRA_GENERIC',0x000020F4)
		win_const_mgr.add_const('SQL_BATCH_ROW_COUNT',0x00000078)
		win_const_mgr.add_const('GD_BITMAP',0x00000002)
		win_const_mgr.add_const('SQL_DESC_BASE_TABLE_NAME',0x00000017)
		win_const_mgr.add_const('DM_MODIFY',0x00000008)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_CAN_REVERSE',0x00004004)
		win_const_mgr.add_const('EMR_SETROP2',0x00000014)
		win_const_mgr.add_const('ERROR_DC_NOT_FOUND',0x00000591)
		win_const_mgr.add_const('MCI_VCR_MARK_WRITE',0x00010000)
		win_const_mgr.add_const('BTH_ERROR_HOST_REJECTED_LIMITED_RESOURCES',0x00000000)
		win_const_mgr.add_const('FS_BUSY',0x20000040)
		win_const_mgr.add_const('WLX_SAS_ACTION_DELAYED_FORCE_LOGOFF',0x00000010)
		win_const_mgr.add_const('IDENTIFIER_SDK_MASK',0xF0000000)
		win_const_mgr.add_const('TA_NOUPDATECP',0x00000000)
		win_const_mgr.add_const('LINEDIALTONEMODE_SPECIAL',0x00000002)
		win_const_mgr.add_const('SO_LOOKUP_NAME',0x0000A002)
		win_const_mgr.add_const('DRV_RESERVED',0x00000800)
		win_const_mgr.add_const('ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH',0x00001707)
		win_const_mgr.add_const('IN_CLASSC_NSHIFT',0x00000008)
		win_const_mgr.add_const('MCSC_MONTHBK',0x00000004)
		win_const_mgr.add_const('NABTS_LINES_PER_BUNDLE',0x00000010)
		win_const_mgr.add_const('SV_GLIST_MTIME_PARMNUM',0x00000192)
		win_const_mgr.add_const('WINHTTP_AUTH_SCHEME_DIGEST',0x00000008)
		win_const_mgr.add_const('SF_UNICODE',0x00000010)
		win_const_mgr.add_const('WINHTTP_QUERY_ETAG',0x00000036)
		win_const_mgr.add_const('ALINF_ROLLBKDOALL',0x00000100)
		win_const_mgr.add_const('MPEGLAYER3_FLAG_PADDING_ON',0x00000001)
		win_const_mgr.add_const('SYSTEM_AUDIT_CALLBACK_ACE_TYPE',0x0000000D)
		win_const_mgr.add_const('DISPID_STATUSTEXTCHANGE',0x00000066)
		win_const_mgr.add_const('ERROR_DS_CANT_REMOVE_ATT_CACHE',0x000020D3)
		win_const_mgr.add_const('EMR_ANGLEARC',0x00000029)
		win_const_mgr.add_const('WPCCHANNEL',0x00000010)
		win_const_mgr.add_const('TT_VBR',0x00000008)
		win_const_mgr.add_const('IME_KHOTKEY_SHAPE_TOGGLE',0x00000050)
		win_const_mgr.add_const('TC_SF_X_YINDEP',0x00000020)
		win_const_mgr.add_const('DSOP_FLAG_MULTISELECT',0x00000001)
		win_const_mgr.add_const('JOB_RUN_PERIODICALLY',0x00000001)
		win_const_mgr.add_const('OID_TAPI_ANSWER',0x07030102)
		win_const_mgr.add_const('MMIO_COMPAT',0x00000000)
		win_const_mgr.add_const('LB_SETCARETINDEX',0x0000019E)
		win_const_mgr.add_const('IP_ADAPTER_DHCP_ENABLED',0x00000004)
		win_const_mgr.add_const('DI_DRIVERPAGE_ADDED',0x04000000)
		win_const_mgr.add_const('ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION',0x00001A9A)
		win_const_mgr.add_const('SSRVOPT_SETCONTEXT',0x00000800)
		win_const_mgr.add_const('DDCOLOR_GAMMA',0x00000020)
		win_const_mgr.add_const('CAUSE_REASON_USER',0x00000000)
		win_const_mgr.add_const('IPX_SPXGETCONNECTIONSTATUS',0x0000400B)
		win_const_mgr.add_const('RBS_AUTOSIZE',0x00002000)
		win_const_mgr.add_const('EMO_MOVESELECTION',0x00000004)
		win_const_mgr.add_const('MAX_DEFAULTCHAR',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_PPC_REFHI',0x00000010)
		win_const_mgr.add_const('LL_CONNECTING',0x00000001)
		win_const_mgr.add_const('BLUETOOTH_DEVICE_NAME_SIZE',0x00000100)
		win_const_mgr.add_const('ERROR_SINGLE_INSTANCE_APP',0x00000480)
		win_const_mgr.add_const('FLG_REGSVR_DLLREGISTER',0x00000001)
		win_const_mgr.add_const('WAVE_FORMAT_4M16',0x00000400)
		win_const_mgr.add_const('SQL_DATA_SOURCE_NAME',0x00000002)
		win_const_mgr.add_const('FR_PRIVATE',0x00000010)
		win_const_mgr.add_const('TARGET_IS_NT51_OR_LATER',0x00000000)
		win_const_mgr.add_const('DISPID_ERROR',0x0000000B)
		win_const_mgr.add_const('UOI_IO',0x00000006)
		win_const_mgr.add_const('DISPID_FLAGS',0x00000013)
		win_const_mgr.add_const('DRM_ACTIVATE_SHARED_GROUPIDENTITY',0x00000020)
		win_const_mgr.add_const('SQL_ROWSET_SIZE_DEFAULT',0x00000001)
		win_const_mgr.add_const('ILCF_MOVE',0x00000000)
		win_const_mgr.add_const('MD_NOTIFY_END_OF_REQUEST',0x00000080)
		win_const_mgr.add_const('SPEAKER_TOP_FRONT_CENTER',0x00002000)
		win_const_mgr.add_const('MA_NOACTIVATE',0x00000003)
		win_const_mgr.add_const('D3DPRASTERCAPS_FOGTABLE',0x00000100)
		win_const_mgr.add_const('WINHTTP_ADDREQ_FLAGS_MASK',0xFFFF0000)
		win_const_mgr.add_const('SQL_WARN_NO',0x00000000)
		win_const_mgr.add_const('ITR_LOADER_INDEX',0x00000007)
		win_const_mgr.add_const('TVIF_HANDLE',0x00000010)
		win_const_mgr.add_const('LVS_EX_ONECLICKACTIVATE',0x00000040)
		win_const_mgr.add_const('PIDVSI_FRAME_RATE',0x00000006)
		win_const_mgr.add_const('GOPHER_TYPE_GIF',0x00001000)
		win_const_mgr.add_const('ERROR_SXS_INVALID_DEACTIVATION',0x00003705)
		win_const_mgr.add_const('MIIM_TYPE',0x00000010)
		win_const_mgr.add_const('SNMP_ACCESS_READ_WRITE',0x00000003)
		win_const_mgr.add_const('CAUSE_NO_USER_RESPONDING',0x00000012)
		win_const_mgr.add_const('SIZE_OF_80387_REGISTERS',0x00000050)
		win_const_mgr.add_const('ERROR_NO_SECRETS',0x000021AC)
		win_const_mgr.add_const('D3DTEXOPCAPS_MODULATEINVCOLOR_ADDALPHA',0x00100000)
		win_const_mgr.add_const('SSF_WEBVIEW',0x00020000)
		win_const_mgr.add_const('URLACTION_HTML_SUBMIT_FORMS_FROM',0x00001602)
		win_const_mgr.add_const('TVGN_NEXT',0x00000001)
		win_const_mgr.add_const('CALENDAR_SHOWTIMEAS_BUSY',0x00000002)
		win_const_mgr.add_const('GCS_COMPCLAUSE',0x00000020)
		win_const_mgr.add_const('DDSCAPS_COMPLEX',0x00000008)
		win_const_mgr.add_const('SPI_GETMOUSEHOVERHEIGHT',0x00000064)
		win_const_mgr.add_const('DNS_ERROR_NBSTAT_INIT_FAILED',0x00002591)
		win_const_mgr.add_const('SN_OUTFLAG_WAS_VERIFIED',0x00000001)
		win_const_mgr.add_const('INDEX_GUID_IMAGE',0x00000006)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY13',0x10000000)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY12',0x08000000)
		win_const_mgr.add_const('BDIF_PAIRED',0x00000008)
		win_const_mgr.add_const('DEBUG_REGISTERS_DEFAULT',0x00000000)
		win_const_mgr.add_const('ERROR_WAIT_NO_CHILDREN',0x00000080)
		win_const_mgr.add_const('MSIM_DISPID_ONCONTACTSTATECHANGED',0x00000E05)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY15',0x40000000)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY14',0x20000000)
		win_const_mgr.add_const('SPI_GETDISABLEOVERLAPPEDCONTENT',0x00001040)
		win_const_mgr.add_const('LINETRANSLATERESULT_NOTRANSLATION',0x00000800)
		win_const_mgr.add_const('DNSSEC_PROTOCOL_DNSSEC',0x00000003)
		win_const_mgr.add_const('LANG_QUECHUA',0x00000006)
		win_const_mgr.add_const('ATTR_TARGET_CONVERTED',0x00000001)
		win_const_mgr.add_const('SQL_PARAM_SUCCESS_WITH_INFO',0x00000006)
		win_const_mgr.add_const('IPP_E_SYNCCONFLICT',0xC0048003)
		win_const_mgr.add_const('SCH_CRED_FORMAT_CERT_CONTEXT',0x00000000)
		win_const_mgr.add_const('WKSTA_PIPEINCREMENT_PARMNUM',0x0000002C)
		win_const_mgr.add_const('REGDB_E_LAST',0x8004015F)
		win_const_mgr.add_const('STM_ONLY_THIS_PROTOCOL',0x00000002)
		win_const_mgr.add_const('IPP_E_MARKFOROFFLINE_FAILED',0xC0048006)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_POWER_SUPPLY',0x00000000)
		win_const_mgr.add_const('MSGF_MESSAGEBOX',0x00000001)
		win_const_mgr.add_const('DISPLAYDIB_ZOOM2',0x00000100)
		win_const_mgr.add_const('SQL_DATETIME',0x00000009)
		win_const_mgr.add_const('SYSTEM_ALARM_CALLBACK_ACE_TYPE',0x0000000E)
		win_const_mgr.add_const('IDTB_JUMP1',0x000000DA)
		win_const_mgr.add_const('ERROR_DS_NAME_ERROR_TRUST_REFERRAL',0x00002187)
		win_const_mgr.add_const('ERROR_INVALID_MESSAGENAME',0x000004C1)
		win_const_mgr.add_const('PSR_RI',0x00000029)
		win_const_mgr.add_const('SECURITYMSG_FAILURE',0x00000002)
		win_const_mgr.add_const('DISPID_PARSECOMPLETE',0x00000009)
		win_const_mgr.add_const('NRC_ACTSES',0x00000000)
		win_const_mgr.add_const('SOUND_SYSTEM_RESTOREDOWN',0x0000000B)
		win_const_mgr.add_const('MSIDXSPROP_QUERY_RESTRICTION',0x00000004)
		win_const_mgr.add_const('IDM_IE50_PASTE_MODE',0x00000962)
		win_const_mgr.add_const('OID_FDDI_SMT_HI_VERSION_ID',0x03030203)
		win_const_mgr.add_const('WPF_SHOWPAGE_WELCOME',0x00010000)
		win_const_mgr.add_const('LINECALLFEATURE_MONITORMEDIA',0x00002000)
		win_const_mgr.add_const('PSR_RT',0x0000001B)
		win_const_mgr.add_const('SYMFLAG_FORWARDER',0x00000400)
		win_const_mgr.add_const('DEBUG_MODULE_SECONDARY',0x00000010)
		win_const_mgr.add_const('HTMLDLG_PRINT_TEMPLATE',0x00000080)
		win_const_mgr.add_const('SUBLANG_ARABIC_SYRIA',0x00000000)
		win_const_mgr.add_const('ERROR_LOG_BLOCKS_EXHAUSTED',0x000019CD)
		win_const_mgr.add_const('HEAP_PSEUDO_TAG_FLAG',0x00008000)
		win_const_mgr.add_const('WCM_SETTINGS_ID_FLAG_DEFINITION',0x00000001)
		win_const_mgr.add_const('PORT_IRC',0x000000C2)
		win_const_mgr.add_const('LPV_RESERVED',0x00000000)
		win_const_mgr.add_const('SHDID_COMPUTER_RAMDISK',0x0000000B)
		win_const_mgr.add_const('ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED',0x0000200C)
		win_const_mgr.add_const('WTS_EVENT_CREATE',0x00000001)
		win_const_mgr.add_const('ODA_FOCUS',0x00000004)
		win_const_mgr.add_const('FILTER_TCPUDP_PORT_ANY',0x00000000)
		win_const_mgr.add_const('SPI_GETMENUFADE',0x00001012)
		win_const_mgr.add_const('ASC_RET_CONNECTION',0x00000800)
		win_const_mgr.add_const('SQL_FN_NUM_LOG',0x00000400)
		win_const_mgr.add_const('FWPM_SUBLAYER_FLAG_PERSISTENT',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2_RECORDERSUPPORTED',0x00000800)
		win_const_mgr.add_const('MCI_DGV_STATUS_NOMINAL',0x00020000)
		win_const_mgr.add_const('ACCESS_PERM',0x00000040)
		win_const_mgr.add_const('BN_DISABLE',0x00000004)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MIPFLINEAR',0x00020000)
		win_const_mgr.add_const('SEC_WINNT_AUTH_IDENTITY_UNICODE',0x00000002)
		win_const_mgr.add_const('CHANGER_REPORT_IEPORT_STATE',0x00000800)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_ROAMING_ADHOC',0x00000000)
		win_const_mgr.add_const('INTERNET_PER_CONN_FLAGS',0x00000001)
		win_const_mgr.add_const('HELP_TCARD',0x00008000)
		win_const_mgr.add_const('FACILITY_FWP_ERROR_CODE',0x00000022)
		win_const_mgr.add_const('SVSI_NOTAKEFOCUS',0x40000000)
		win_const_mgr.add_const('RPC_C_OPT_MQ_ACKNOWLEDGE',0x00000004)
		win_const_mgr.add_const('CREDUI_FLAGS_EXPECT_CONFIRMATION',0x00020000)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_SERVICES_ID',0x00000005)
		win_const_mgr.add_const('ERROR_DS_HAVE_PRIMARY_MEMBERS',0x00002149)
		win_const_mgr.add_const('D3DCREATE_ADAPTERGROUP_DEVICE',0x00000200)
		win_const_mgr.add_const('PS_SOLID',0x00000000)
		win_const_mgr.add_const('CERT_STORE_MANIFOLD_FLAG',0x00000100)
		win_const_mgr.add_const('HICF_TOGGLEDROPDOWN',0x00000100)
		win_const_mgr.add_const('HTTP_QUERY_ECHO_REQUEST',0x00000047)
		win_const_mgr.add_const('DS_REPSYNC_URGENT',0x00000040)
		win_const_mgr.add_const('ERROR_DS_MISSING_REQUIRED_ATT',0x0000207C)
		win_const_mgr.add_const('CBA_DEFERRED_SYMBOL_LOAD_PARTIAL',0x00000020)
		win_const_mgr.add_const('D3DTEXOPCAPS_BLENDTEXTUREALPHA',0x00001000)
		win_const_mgr.add_const('FWPM_ACTRL_BEGIN_WRITE_TXN',0x00000008)
		win_const_mgr.add_const('LINECONNECTEDMODE_CONFIRMED',0x00000010)
		win_const_mgr.add_const('DEBUG_EINDEX_FROM_START',0x00000000)
		win_const_mgr.add_const('ICC_TAB_CLASSES',0x00000008)
		win_const_mgr.add_const('POLICY_AUDIT_LOG_ADMIN',0x00000200)
		win_const_mgr.add_const('DXVA_BITSTREAM_CONCEALMENT_NEED_SEVERE',0x00000003)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_IPSECV1_DISABLED',0x00000001)
		win_const_mgr.add_const('DEBUG_LEVEL_SOURCE',0x00000000)
		win_const_mgr.add_const('DEBUG_EXECUTE_ECHO',0x00000001)
		win_const_mgr.add_const('LVGA_HEADER_LEFT',0x00000001)
		win_const_mgr.add_const('NULL_PEN',0x00000008)
		win_const_mgr.add_const('DEBUG_ENGOPT_ALLOW_READ_ONLY_BREAKPOINTS',0x00000400)
		win_const_mgr.add_const('LINEBEARERMODE_PASSTHROUGH',0x00000040)
		win_const_mgr.add_const('RPC_C_MQ_RECOVERABLE',0x00000001)
		win_const_mgr.add_const('IF_TYPE_DIGITALPOWERLINE',0x0000008A)
		win_const_mgr.add_const('CRYPT_STRING_ANY',0x00000007)
		win_const_mgr.add_const('PORT_ANYTERMLINK',0x00000057)
		win_const_mgr.add_const('PHOTO_METERINGMODE_MULTISPOT',0x00000004)
		win_const_mgr.add_const('SEF_DEFAULT_OWNER_FROM_PARENT',0x00000020)
		win_const_mgr.add_const('JOY_BUTTON27',0x04000000)
		win_const_mgr.add_const('JOY_BUTTON26',0x02000000)
		win_const_mgr.add_const('LDAPF_SSLENABLE',0x00000001)
		win_const_mgr.add_const('JOY_BUTTON24',0x00800000)
		win_const_mgr.add_const('JOY_BUTTON23',0x00400000)
		win_const_mgr.add_const('MOD_SYNTH',0x00000002)
		win_const_mgr.add_const('JOY_BUTTON21',0x00100000)
		win_const_mgr.add_const('SF_NOTIFY_ACCESS_DENIED',0x00000800)
		win_const_mgr.add_const('NI_NUMERICHOST',0x00000002)
		win_const_mgr.add_const('PATCH_OPTION_VALID_FLAGS',0xC0FF0007)
		win_const_mgr.add_const('MMIO_FINDRIFF',0x00000020)
		win_const_mgr.add_const('JOY_BUTTON29',0x10000000)
		win_const_mgr.add_const('JOY_BUTTON28',0x08000000)
		win_const_mgr.add_const('WM_NCMOUSEHOVER',0x000002A0)
		win_const_mgr.add_const('HTTP_AUTH_ENABLE_NTLM',0x00000004)
		win_const_mgr.add_const('UNDNAME_NAME_ONLY',0x00001000)
		win_const_mgr.add_const('OPTION_POLICY_FILTER_FOR_NLSR',0x00000015)
		win_const_mgr.add_const('STGTY_REPEAT',0x00000100)
		win_const_mgr.add_const('DBPROPVAL_MR_NOTSUPPORTED',0x00000000)
		win_const_mgr.add_const('PDH_INVALID_HANDLE',0xC0000BBC)
		win_const_mgr.add_const('MMIO_DIRTY',0x10000000)
		win_const_mgr.add_const('LVHT_ONITEMICON',0x00000002)
		win_const_mgr.add_const('WINHTTP_AUTH_SCHEME_PASSPORT',0x00000004)
		win_const_mgr.add_const('OID_FDDI_PORT_AVAILABLE_PATHS',0x03030263)
		win_const_mgr.add_const('IPP_E_CANNOTCREATEOFFLINE',0xC004800F)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_STANDARD_C',0x00000013)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_STANDARD_B',0x00000012)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_STANDARD_A',0x00000011)
		win_const_mgr.add_const('ERROR_DS_NC_MUST_HAVE_NC_PARENT',0x0000212E)
		win_const_mgr.add_const('DISPID_IMULTISESSION_FIRSTDATASESSION',0x00000200)
		win_const_mgr.add_const('MFCLOCK_FREQUENCY_HNS',0x00989680)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_SAMPLE_USES_PREVIOUS_INPUT_FRAME',0x00000008)
		win_const_mgr.add_const('SCARD_SHARE_SHARED',0x00000002)
		win_const_mgr.add_const('SPI_SETMESSAGEDURATION',0x00002017)
		win_const_mgr.add_const('SBT_NOBORDERS',0x00000100)
		win_const_mgr.add_const('SQL_DEFAULT_TXN_ISOLATION',0x0000001A)
		win_const_mgr.add_const('CTL_ANY_SUBJECT_TYPE',0x00000001)
		win_const_mgr.add_const('META_SETPALENTRIES',0x00000037)
		win_const_mgr.add_const('SQL_CONVERT_INTEGER',0x0000003D)
		win_const_mgr.add_const('DSCCIF_HASWIZARDDIALOG',0x00000001)
		win_const_mgr.add_const('MCGIP_CALENDAR',0x00000004)
		win_const_mgr.add_const('WSA_QOS_EPSFILTERSPEC',0x00002B14)
		win_const_mgr.add_const('DTR_CONTROL_DISABLE',0x00000000)
		win_const_mgr.add_const('CTF_WAIT_NO_REENTRANCY',0x00000200)
		win_const_mgr.add_const('DEBUG_REGSRC_FRAME',0x00000002)
		win_const_mgr.add_const('ERROR_LOG_PINNED_ARCHIVE_TAIL',0x000019DF)
		win_const_mgr.add_const('DE_E_FILTER_SCRIPTSELECT',0x80100040)
		win_const_mgr.add_const('ERROR_DS_UNAVAILABLE_CRIT_EXTENSION',0x0000202C)
		win_const_mgr.add_const('WPWIZ_ERROR_STATE_PTR',0xC0042006)
		win_const_mgr.add_const('MFSTARTUP_NOSOCKET',0x00000001)
		win_const_mgr.add_const('VP_CP_CMD_CHANGE',0x00000004)
		win_const_mgr.add_const('DNS_ERROR_NO_TCPIP',0x0000267B)
		win_const_mgr.add_const('CRYPT_OID_INFO_PUBKEY_ENCRYPT_KEY_FLAG',0x40000000)
		win_const_mgr.add_const('WIA_PAGE_USSTATEMENT',0x00000005)
		win_const_mgr.add_const('IDS_DESCRIPTION',0x00000001)
		win_const_mgr.add_const('CREDUI_FLAGS_KEEP_USERNAME',0x00100000)
		win_const_mgr.add_const('CM_PROB_WILL_BE_REMOVED',0x00000015)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_EVENT',0x00000480)
		win_const_mgr.add_const('DBPROPVAL_PT_PROPID',0x00000010)
		win_const_mgr.add_const('EPT_S_CANT_PERFORM_OP',0x000006D8)
		win_const_mgr.add_const('SDP_ATTRIB_HID_REPORT_LIST',0x0000020B)
		win_const_mgr.add_const('IITR_PPN_MASK',0x7FFF000000000000)
		win_const_mgr.add_const('EXPORT_PRIVATE_KEYS',0x00000004)
		win_const_mgr.add_const('SF_NOTIFY_AUTHENTICATION',0x00002000)
		win_const_mgr.add_const('NDIS_DEVICE_WAKE_ON_PATTERN_MATCH_ENABLE',0x00000002)
		win_const_mgr.add_const('SNMPAPI_TL_NOT_AVAILABLE',0x00000066)
		win_const_mgr.add_const('ITSAT_DEFAULT_PRIORITY',0x10000000)
		win_const_mgr.add_const('LVHT_NOWHERE',0x00000001)
		win_const_mgr.add_const('HSE_VECTOR_ELEMENT_TYPE_FILE_HANDLE',0x00000001)
		win_const_mgr.add_const('EN_ALIGN_RTL_EC',0x00000701)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_252',0x00000000)
		win_const_mgr.add_const('LINEQOSSERVICELEVEL_BESTEFFORT',0x00000003)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_250',0x00000000)
		win_const_mgr.add_const('DEBUG_DATA_PROCESSOR_SPEED',0x00000005)
		win_const_mgr.add_const('ERROR_REQ_NOT_ACCEP',0x00000047)
		win_const_mgr.add_const('PFM_SPACEBEFORE',0x00000040)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_255',0x00000000)
		win_const_mgr.add_const('CLIENTSITE_S_LAST',0x0004019F)
		win_const_mgr.add_const('ERROR_INSTALL_PLATFORM_UNSUPPORTED',0x00000661)
		win_const_mgr.add_const('MKF_AVAILABLE',0x00000002)
		win_const_mgr.add_const('TC_UA_ABLE',0x00000800)
		win_const_mgr.add_const('MDMVOL_LOW',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_AUTOZONE_ALREADY_EXISTS',0x0000258A)
		win_const_mgr.add_const('RF_USER_CONFIRMATION',0x08000000)
		win_const_mgr.add_const('CERT_RDN_FORCE_UTF8_UNICODE_FLAG',0x10000000)
		win_const_mgr.add_const('SQL_API_SQLSETPARAM',0x00000016)
		win_const_mgr.add_const('BLLI_L2_X25L',0x00000006)
		win_const_mgr.add_const('AE_RESACCESS',0x00000007)
		win_const_mgr.add_const('PROV_FORTEZZA',0x00000004)
		win_const_mgr.add_const('DE_E_INVALID_REQUEST',0x800C000C)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_NOT_TIME_VALID_FLAG',0x00000001)
		win_const_mgr.add_const('BSF_NAVNOHISTORY',0x00001000)
		win_const_mgr.add_const('SO_RCVBUF',0x00001002)
		win_const_mgr.add_const('ATSC_ETM_LOCATION_NOT_PRESENT',0x00000000)
		win_const_mgr.add_const('LOCALE_REPLACEMENT',0x00000008)
		win_const_mgr.add_const('AVRF_MAX_TRACES',0x00000020)
		win_const_mgr.add_const('IMAGE_SCN_LNK_REMOVE',0x00000800)
		win_const_mgr.add_const('MQMSG_ACKNOWLEDGMENT_NEG_ARRIVAL',0x00000004)
		win_const_mgr.add_const('MSIMWND_DISPID_ONFOCUS',0x000000E4)
		win_const_mgr.add_const('DOF_DIRECTORY',0x00008003)
		win_const_mgr.add_const('DNS_ERROR_RCODE_NOT_IMPLEMENTED',0x0000232C)
		win_const_mgr.add_const('IDI_FORCED_OVL',0x000001F6)
		win_const_mgr.add_const('IDC_VP_EDITABLE',0x000003EA)
		win_const_mgr.add_const('PD_USEDEVMODECOPIES',0x00040000)
		win_const_mgr.add_const('SYNCH_DATA_STORE_PHONEBOOK',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_OP_RELATIVE',0x00000002)
		win_const_mgr.add_const('REGDF_NOTDETIO',0x00000001)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_PRINTER_NAME',0x00000001)
		win_const_mgr.add_const('PIDVSI_FRAME_WIDTH',0x00000003)
		win_const_mgr.add_const('WM_NOTIFYFORMAT',0x00000055)
		win_const_mgr.add_const('KERB_ETYPE_NULL',0x00000000)
		win_const_mgr.add_const('CERT_X500_NAME_STR',0x00000003)
		win_const_mgr.add_const('FPSR_ZD',0x00000002)
		win_const_mgr.add_const('EMR_SETBKCOLOR',0x00000019)
		win_const_mgr.add_const('MOD_RIGHT',0x00004000)
		win_const_mgr.add_const('KSWAVE_COMPATCAPS_OUTPUT',0x00000001)
		win_const_mgr.add_const('SV_AUTOSHARESERVER_PARMNUM',0x00000250)
		win_const_mgr.add_const('IDM_FORECOLOR',0x00000037)
		win_const_mgr.add_const('FPSR_Z1',0x0000001C)
		win_const_mgr.add_const('FPSR_Z0',0x0000000F)
		win_const_mgr.add_const('FPSR_Z3',0x00000036)
		win_const_mgr.add_const('FPSR_Z2',0x00000029)
		win_const_mgr.add_const('DEVPROP_TYPE_FLOAT',0x0000000A)
		win_const_mgr.add_const('ESLFLAG_NEAREST',0x00000002)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_TLS',0x00000009)
		win_const_mgr.add_const('ERROR_INVALID_GROUP_ATTRIBUTES',0x00000541)
		win_const_mgr.add_const('SUBLANG_ENGLISH_INDIA',0x00000010)
		win_const_mgr.add_const('AW_ACTIVATE',0x00020000)
		win_const_mgr.add_const('DNS_ERROR_ZONE_HAS_NO_SOA_RECORD',0x00002585)
		win_const_mgr.add_const('SDP_ATTRIB_SDP_VERSION_NUMBER_LIST',0x00000200)
		win_const_mgr.add_const('CSA_ABC',0x00000002)
		win_const_mgr.add_const('D3DDEVCAPS_DRAWPRIMTLVERTEX',0x00000400)
		win_const_mgr.add_const('FPS_NO_ANSWER',0x20000080)
		win_const_mgr.add_const('PORT_NIFTP',0x0000002F)
		win_const_mgr.add_const('CERT_NAME_STR_FORCE_UTF8_DIR_STR_FLAG',0x00080000)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_DRIVER_NAME',0x00000004)
		win_const_mgr.add_const('RP_DSN_NOTIFY_SUCCESS',0x01000000)
		win_const_mgr.add_const('WMDRM_DEVICE_REFRESHCLOCK',0x00000010)
		win_const_mgr.add_const('IMF_FORCEDISABLE',0x00000004)
		win_const_mgr.add_const('ETO_REVERSE_INDEX_MAP',0x00010000)
		win_const_mgr.add_const('LOCALE_SUPPLEMENTAL',0x00000002)
		win_const_mgr.add_const('OS_WIN95_GOLD',0x00000010)
		win_const_mgr.add_const('WM_SPOOLERSTATUS',0x0000002A)
		win_const_mgr.add_const('VIEW_PRIORITY_STALECACHEHIT',0x00000045)
		win_const_mgr.add_const('DNS_ERROR_RESPONSE_CODES_BASE',0x00002328)
		win_const_mgr.add_const('HTTP_LOG_FIELD_METHOD',0x00000080)
		win_const_mgr.add_const('SQL_FN_NUM_EXP',0x00000100)
		win_const_mgr.add_const('UF_HOMEDIR_REQUIRED',0x00000008)
		win_const_mgr.add_const('SDDL_REVISION_1',0x00000001)
		win_const_mgr.add_const('DEBUG_KERNEL_CONNECTION',0x00000000)
		win_const_mgr.add_const('PCD_MAX_MEMORY',0x00000002)
		win_const_mgr.add_const('D3DFVF_SPECULAR',0x00000080)
		win_const_mgr.add_const('MSG_SERVICE_DELETE',0x00000004)
		win_const_mgr.add_const('GCP_DIACRITIC',0x00000100)
		win_const_mgr.add_const('LDAP_OPT_SIGN',0x00000095)
		win_const_mgr.add_const('CR_INVALID_POINTER',0x00000003)
		win_const_mgr.add_const('OF_HANDLER',0x00000004)
		win_const_mgr.add_const('FLG_ADDREG_NOCLOBBER',0x00000002)
		win_const_mgr.add_const('MCI_OVLY_INFO_TEXT',0x00010000)
		win_const_mgr.add_const('MAPMIME_DEFAULT',0x00000000)
		win_const_mgr.add_const('KRB_NT_UID',0x00000005)
		win_const_mgr.add_const('WINHTTP_OPTION_SECURE_PROTOCOLS',0x00000054)
		win_const_mgr.add_const('ICC_TREEVIEW_CLASSES',0x00000002)
		win_const_mgr.add_const('NDIS_802_11_LENGTH_RATES',0x00000008)
		win_const_mgr.add_const('HKCOMB_CA',0x00000040)
		win_const_mgr.add_const('SF_NOTIFY_ORDER_HIGH',0x00080000)
		win_const_mgr.add_const('CP_HWND',0x00000000)
		win_const_mgr.add_const('LOCALE_FONTSIGNATURE',0x00000058)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_FUNCTION',0x00000065)
		win_const_mgr.add_const('PRINTACTION_TESTPAGE',0x00000004)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2_MEDIAPHYSICALLYBLANK',0x00000700)
		win_const_mgr.add_const('ALG_CLASS_DATA_ENCRYPT',0x00000003)
		win_const_mgr.add_const('DMPAPER_A6_ROTATED',0x00000053)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_LAST_RECOVER',0x00002000)
		win_const_mgr.add_const('DS_REPL_NBR_USE_ASYNC_INTERSITE_TRANSPORT',0x00000080)
		win_const_mgr.add_const('OLEMISC_ALWAYSRUN',0x00000800)
		win_const_mgr.add_const('GPO_INFO_FLAG_NOCHANGES',0x00000080)
		win_const_mgr.add_const('DCI_STATUS_CHROMAKEYCHANGED',0x00000010)
		win_const_mgr.add_const('LINEERR_INVALCONFCALLHANDLE',0x80000020)
		win_const_mgr.add_const('PIDSI_DOC_SECURITY',0x00000013)
		win_const_mgr.add_const('MIXER_SETCONTROLDETAILSF_VALUE',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_IA64_DIR32NB',0x00000010)
		win_const_mgr.add_const('VER_PRIVATE',0x00000000)
		win_const_mgr.add_const('MF_BITMAP',0x00000004)
		win_const_mgr.add_const('ERROR_IPSEC_REPLAY_CHECK_FAILED',0x00003659)
		win_const_mgr.add_const('TMT_ALWAYSSHOWSIZINGBAR',0x000008A0)
		win_const_mgr.add_const('PCF_XONXOFF',0x00000010)
		win_const_mgr.add_const('AE_UASMOD',0x0000000D)
		win_const_mgr.add_const('SECURITY_LOCAL_SERVICE_RID',0x00000013)
		win_const_mgr.add_const('VK_NUMPAD9',0x00000069)
		win_const_mgr.add_const('WINEVENT_OPCODE_START',0x00000001)
		win_const_mgr.add_const('HTTP_INITIALIZE_CONFIG',0x00000002)
		win_const_mgr.add_const('DMPAPER_15X11',0x0000002E)
		win_const_mgr.add_const('PROP_ADD',0x00000000)
		win_const_mgr.add_const('ICDRAW_NOTKEYFRAME',0x08000000)
		win_const_mgr.add_const('FLS_MAXIMUM_AVAILABLE',0x00000080)
		win_const_mgr.add_const('SERVICE_ACCEPT_PAUSE_CONTINUE',0x00000002)
		win_const_mgr.add_const('DISPID_IHTMLPLUGINSCOLLECTION_REFRESH',0x00000002)
		win_const_mgr.add_const('CM_OPEN_CLASS_KEY_BITS',0x00000001)
		win_const_mgr.add_const('HH_SAFE_DISPLAY_TOPIC',0x00000020)
		win_const_mgr.add_const('SC_MANAGER_ENUMERATE_SERVICE',0x00000004)
		win_const_mgr.add_const('FPSR_MBZ0_V',0x00000003)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT',0x000013E0)
		win_const_mgr.add_const('WIA_DPF_FIRST',0x00000D02)
		win_const_mgr.add_const('WSAEMSGSIZE',0x00002738)
		win_const_mgr.add_const('ERROR_DS_RECALCSCHEMA_FAILED',0x000020CC)
		win_const_mgr.add_const('DBSETFUNC_ALL',0x00000001)
		win_const_mgr.add_const('RPC_X_INVALID_PIPE_OBJECT',0x00000726)
		win_const_mgr.add_const('SUBLANG_MARATHI_INDIA',0x00000001)
		win_const_mgr.add_const('LINECALLINFOSTATE_USERUSERINFO',0x00200000)
		win_const_mgr.add_const('VK_NUMPAD2',0x00000062)
		win_const_mgr.add_const('IMEMENUITEM_STRING_SIZE',0x00000050)
		win_const_mgr.add_const('SCRIPT_ENCODE_SECTION',0x00000001)
		win_const_mgr.add_const('PXE_GSI_TRACE_ENABLED',0x00000001)
		win_const_mgr.add_const('IPP_S_TRUNCATED',0x00048105)
		win_const_mgr.add_const('DEBUG_END_PASSIVE',0x00000000)
		win_const_mgr.add_const('GMEM_NOT_BANKED',0x00001000)
		win_const_mgr.add_const('PSH_STRETCHWATERMARK',0x00040000)
		win_const_mgr.add_const('SUBLANG_ARABIC_YEMEN',0x00000009)
		win_const_mgr.add_const('FCW_TOOLBAR',0x00000002)
		win_const_mgr.add_const('TBSTYLE_EX_MIXEDBUTTONS',0x00000008)
		win_const_mgr.add_const('ERROR_NOTIFY_CLEANUP',0x000002E9)
		win_const_mgr.add_const('ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND',0x000032D6)
		win_const_mgr.add_const('MDM_V120_SPEED_64K',0x00000001)
		win_const_mgr.add_const('ESB_ENABLE_BOTH',0x00000000)
		win_const_mgr.add_const('PAN_STROKE_INSTANT_VERT',0x00000008)
		win_const_mgr.add_const('MD_NOTIFY_NONSECURE_PORT',0x00000002)
		win_const_mgr.add_const('WSB_PROP_CXVSCROLL',0x00000008)
		win_const_mgr.add_const('WMDM_RIGHTS_COPY_TO_SDMI_DEVICE',0x00000010)
		win_const_mgr.add_const('D3DCLEAR_ZBUFFER',0x00000002)
		win_const_mgr.add_const('TAPE_DRIVE_END_OF_DATA',0x80010000)
		win_const_mgr.add_const('CACHEGROUP_SEARCH_ALL',0x00000000)
		win_const_mgr.add_const('LINEADDRFEATURE_UNCOMPLETECALL',0x00000040)
		win_const_mgr.add_const('SQL_ROW_DELETED',0x00000001)
		win_const_mgr.add_const('OID_FDDI_MAC_CURRENT_PATH',0x03030224)
		win_const_mgr.add_const('CMC_OTHER_INFO_NO_CHOICE',0x00000000)
		win_const_mgr.add_const('SQL_OJ_LEFT',0x00000001)
		win_const_mgr.add_const('D3DENUM_NO_DRIVERVERSION',0x00000004)
		win_const_mgr.add_const('OID_GEN_MINIPORT_RESTART_ATTRIBUTES',0x0001021D)
		win_const_mgr.add_const('DDSCL_EXCLUSIVE',0x00000010)
		win_const_mgr.add_const('IMAGE_SEPARATION',0x00000040)
		win_const_mgr.add_const('DRV_POWER',0x0000000F)
		win_const_mgr.add_const('DDSCAPS3_LIGHTWEIGHTMIPMAP',0x00000400)
		win_const_mgr.add_const('BM_CLICK',0x000000F5)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_OPENER',0x00000004)
		win_const_mgr.add_const('LINETRANSLATERESULT_INTERNATIONAL',0x00000002)
		win_const_mgr.add_const('EMR_SELECTPALETTE',0x00000030)
		win_const_mgr.add_const('ISR_SP',0x00000024)
		win_const_mgr.add_const('IF_CONNECTION_PASSIVE',0x00000002)
		win_const_mgr.add_const('VARIANT_CALENDAR_THAI',0x00000020)
		win_const_mgr.add_const('ADS_JOB_DELETING',0x00000004)
		win_const_mgr.add_const('PATCH_OPTION_FAIL_IF_BIGGER',0x00100000)
		win_const_mgr.add_const('MDAXIS_CHAPTERS',0x00000004)
		win_const_mgr.add_const('BSF_NOHANG',0x00000008)
		win_const_mgr.add_const('CALLBACK_EVENT',0x00050000)
		win_const_mgr.add_const('PID_IS_DESCRIPTION',0x0000000C)
		win_const_mgr.add_const('LINEERR_INCOMPATIBLEEXTVERSION',0x8000000D)
		win_const_mgr.add_const('AIF_WARNIFSKIP',0x00000001)
		win_const_mgr.add_const('SHPPFW_ASKDIRCREATE',0x00000002)
		win_const_mgr.add_const('CFU_UNDERLINETHICKLONGDASH',0x00000012)
		win_const_mgr.add_const('MCI_QUALITY_ITEM_STILL',0x00004001)
		win_const_mgr.add_const('NDIS_MAC_OPTION_8021Q_VLAN',0x00000200)
		win_const_mgr.add_const('IAS_ATTRIB_OCTETSEQ',0x00000002)
		win_const_mgr.add_const('DRAWPATTERNRECT',0x00000019)
		win_const_mgr.add_const('KS_TVAUDIO_MODE_MONO',0x00000001)
		win_const_mgr.add_const('PC_EXPLICIT',0x00000002)
		win_const_mgr.add_const('CERT_VERIFY_CACHE_ONLY_BASED_REVOCATION',0x00000002)
		win_const_mgr.add_const('WSA_FLAG_ACCESS_SYSTEM_SECURITY',0x00000040)
		win_const_mgr.add_const('INDEX_GUID_RECOGNIZEDSTRING',0x0000000B)
		win_const_mgr.add_const('KSPROPERTY_TYPE_SET',0x00000002)
		win_const_mgr.add_const('OID_FDDI_MAC_NOT_COPIED_THRESHOLD',0x03030247)
		win_const_mgr.add_const('BS_FLAT',0x00008000)
		win_const_mgr.add_const('SQL_CA1_LOCK_EXCLUSIVE',0x00000080)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_W2K3_IGNORE_SCHEDULES',0x00000001)
		win_const_mgr.add_const('ERROR_DS_NAME_REFERENCE_INVALID',0x000020B5)
		win_const_mgr.add_const('DPNHCAPSFLAG_GATEWAYISLOCAL',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_MIPS_REFHI',0x00000004)
		win_const_mgr.add_const('LINECALLINFOSTATE_DISPLAY',0x00100000)
		win_const_mgr.add_const('ERROR_BACKUP_CONTROLLER',0x0000024A)
		win_const_mgr.add_const('VIF_OUTOFSPACE',0x00000100)
		win_const_mgr.add_const('DBPROPVAL_SU_INDEX_DEFINITION',0x00000004)
		win_const_mgr.add_const('POLICY_QOS_INBOUND_INTEGRITY',0x00000008)
		win_const_mgr.add_const('MD_SERVER_COMMAND_PAUSE',0x00000003)
		win_const_mgr.add_const('APPLICATION_ERROR_MASK',0x20000000)
		win_const_mgr.add_const('CERT_NAME_UPN_TYPE',0x00000008)
		win_const_mgr.add_const('GESTURE_CIRCLE_CROSS',0x00000000)
		win_const_mgr.add_const('DISPID_FOLDERCHANGED',0x000000D9)
		win_const_mgr.add_const('TBSTYLE_FLAT',0x00000800)
		win_const_mgr.add_const('GETPRINTINGOFFSET',0x0000000D)
		win_const_mgr.add_const('CDS_NORESET',0x10000000)
		win_const_mgr.add_const('CERT_CRL_SIGN_KEY_USAGE',0x00000002)
		win_const_mgr.add_const('LB_FINDSTRING',0x0000018F)
		win_const_mgr.add_const('FIND_FROMEND',0x00800000)
		win_const_mgr.add_const('PROCESSOR_PPC_620',0x0000026C)
		win_const_mgr.add_const('AE_UAS_USER',0x00000000)
		win_const_mgr.add_const('POLICY_ERRV_IDENTITY_CHANGED',0x00000005)
		win_const_mgr.add_const('INTERNET_OPTION_REFRESH',0x00000025)
		win_const_mgr.add_const('JOYCAPS_POVCTS',0x00000040)
		win_const_mgr.add_const('ERROR_WMI_GUID_NOT_FOUND',0x00001068)
		win_const_mgr.add_const('ERROR_DS_INVALID_NAME_FOR_SPN',0x0000216A)
		win_const_mgr.add_const('MIDI_CACHE_BESTFIT',0x00000002)
		win_const_mgr.add_const('IDM_SETPRINTTEMPLATE',0x000008F8)
		win_const_mgr.add_const('PHONESTATE_LAMP',0x00000040)
		win_const_mgr.add_const('SYMOPT_OMAP_FIND_NEAREST',0x00000020)
		win_const_mgr.add_const('MIXERLINE_TARGETTYPE_WAVEIN',0x00000002)
		win_const_mgr.add_const('TP_ELEMENT_FILE',0x00000002)
		win_const_mgr.add_const('CRYPT_OID_NO_NULL_ALGORITHM_PARA_FLAG',0x00000004)
		win_const_mgr.add_const('CR_PROP_PARENTCA',0x00000009)
		win_const_mgr.add_const('INTERNET_OPTION_DATAFILE_EXT',0x00000060)
		win_const_mgr.add_const('MDPROPVAL_MD_AFTER',0x00000004)
		win_const_mgr.add_const('STREAM_FORMAT_COMPLIB_MODULE',0x00000000)
		win_const_mgr.add_const('TVHT_ONITEMICON',0x00000002)
		win_const_mgr.add_const('SCARD_STATE_ATRMATCH',0x00000040)
		win_const_mgr.add_const('IMEA_PREV',0x00000003)
		win_const_mgr.add_const('MF_COMPONENT_INVALID_EKU',0x00004000)
		win_const_mgr.add_const('HSHELL_ACCESSIBILITYSTATE',0x0000000B)
		win_const_mgr.add_const('IMAGE_OS2_SIGNATURE_LE',0x00004C45)
		win_const_mgr.add_const('DAO_NOMAXLENGTH',0x00000000)
		win_const_mgr.add_const('DMICMMETHOD_NONE',0x00000001)
		win_const_mgr.add_const('URLACTION_SCRIPT_OVERRIDE_SAFETY',0x00001401)
		win_const_mgr.add_const('MAX_ADAPTER_ADDRESS_LENGTH',0x00000008)
		win_const_mgr.add_const('SC_CLOSE',0x0000F060)
		win_const_mgr.add_const('WSB_PROP_CYHSCROLL',0x00000004)
		win_const_mgr.add_const('NI_SETCANDIDATE_PAGESTART',0x00000016)
		win_const_mgr.add_const('DMPAPER_JENV_KAKU2_ROTATED',0x00000054)
		win_const_mgr.add_const('SRRF_ZEROONFAILURE',0x20000000)
		win_const_mgr.add_const('IITWBC_BREAK_AND_STEM',0x00000002)
		win_const_mgr.add_const('WKSTA_SIZWORKBUF_PARMNUM',0x0000001D)
		win_const_mgr.add_const('EDITF_ENABLECHASECLIENTDC',0x00100000)
		win_const_mgr.add_const('IMAGE_SCN_MEM_DISCARDABLE',0x02000000)
		win_const_mgr.add_const('SECPKG_ATTR_STREAM_SIZES',0x00000004)
		win_const_mgr.add_const('FOF_RENAMEONCOLLISION',0x00000008)
		win_const_mgr.add_const('HTCLOSE',0x00000014)
		win_const_mgr.add_const('USN_DELETE_FLAG_DELETE',0x00000001)
		win_const_mgr.add_const('DN_SILENT_INSTALL',0x20000000)
		win_const_mgr.add_const('DS_SCHEMA_GUID_ATTR_SET',0x00000002)
		win_const_mgr.add_const('SQL_SIMULATE_CURSOR',0x0000000A)
		win_const_mgr.add_const('SQL_TC_DDL_IGNORE',0x00000004)
		win_const_mgr.add_const('DM_FORMNAME',0x00010000)
		win_const_mgr.add_const('TIMECODE_SMPTE_COLOR_FRAME',0x00000008)
		win_const_mgr.add_const('RTM_MATCH_OWNER',0x00000001)
		win_const_mgr.add_const('SQL_AF_AVG',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_TITLE',0x00000026)
		win_const_mgr.add_const('D3DPMISCCAPS_CULLNONE',0x00000010)
		win_const_mgr.add_const('VER_SUITE_DATACENTER',0x00000080)
		win_const_mgr.add_const('DDBLT_PRESENTATION',0x10000000)
		win_const_mgr.add_const('ERROR_IO_PENDING',0x000003E5)
		win_const_mgr.add_const('EVENT_ACTIVITY_CTRL_GET_SET_ID',0x00000004)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_DRIVER',0x00800000)
		win_const_mgr.add_const('CBA_DEFERRED_SYMBOL_LOAD_CANCEL',0x00000007)
		win_const_mgr.add_const('RSOP_USER_ACCESS_DENIED',0x00000001)
		win_const_mgr.add_const('TOPIC_SEARCH',0x00000001)
		win_const_mgr.add_const('LINECALLORIGIN_EXTERNAL',0x00000004)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_GOPHER_FIND_HTML',0x0000000A)
		win_const_mgr.add_const('IF_TYPE_SONET_OVERHEAD_CHANNEL',0x000000B9)
		win_const_mgr.add_const('HTTP_QUERY_REFRESH',0x0000002E)
		win_const_mgr.add_const('TMT_COMPOSITED',0x0000089C)
		win_const_mgr.add_const('SUBLANG_ROMANIAN_ROMANIA',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_RCODE_SERVER_FAILURE',0x0000232A)
		win_const_mgr.add_const('INTENT_ABSOLUTE_COLORIMETRIC',0x00000003)
		win_const_mgr.add_const('FS_TURKISH',0x00000010)
		win_const_mgr.add_const('IDB_HIST_SMALL_COLOR',0x00000008)
		win_const_mgr.add_const('WABOBJECT_LDAPURL_RETURN_MAILUSER',0x00000001)
		win_const_mgr.add_const('DFCS_MONO',0x00008000)
		win_const_mgr.add_const('WMPCOREEVENT_SEEK_BASE',0x00001450)
		win_const_mgr.add_const('LINEAGENTSTATUS_ACTIVITYLIST',0x00000010)
		win_const_mgr.add_const('DEX_IDS_NO_SUCH_PROPERTY',0x00000587)
		win_const_mgr.add_const('ISC_RET_CALL_LEVEL',0x00002000)
		win_const_mgr.add_const('DBPROPVAL_CO_EQUALITY',0x00000001)
		win_const_mgr.add_const('DCTT_SUBDEV',0x00000004)
		win_const_mgr.add_const('TASK_SECOND_WEEK',0x00000002)
		win_const_mgr.add_const('MDPROPVAL_FS_FULL_SUPPORT',0x00000001)
		win_const_mgr.add_const('DMORIENT_PORTRAIT',0x00000001)
		win_const_mgr.add_const('DISPATCH_CONSTRUCT',0x00004000)
		win_const_mgr.add_const('MW_BIG_MULTIFILEOPENORD',0x00002711)
		win_const_mgr.add_const('CERT_DATE_STAMP_PROP_ID',0x0000001B)
		win_const_mgr.add_const('MMIO_TOUPPER',0x00000010)
		win_const_mgr.add_const('TAPE_ERASE_LONG',0x00000001)
		win_const_mgr.add_const('SQL_FN_CVT_CAST',0x00000002)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_BITSPERPEL',0x00000400)
		win_const_mgr.add_const('DDFXALPHACAPS_OVERLAYALPHASURFACESNEG',0x00000200)
		win_const_mgr.add_const('EMR_POLYBEZIER',0x00000002)
		win_const_mgr.add_const('PS_DOT',0x00000002)
		win_const_mgr.add_const('AD_GETWP_BMP',0x00000000)
		win_const_mgr.add_const('WS_EX_LEFT',0x00000000)
		win_const_mgr.add_const('HELP_QUIT',0x00000002)
		win_const_mgr.add_const('BLACK_BRUSH',0x00000004)
		win_const_mgr.add_const('CERT_RDN_INT4_STRING',0x0000000B)
		win_const_mgr.add_const('DXVA_ALPHA_BLEND_COMBINATION_BUFFER',0x0000000D)
		win_const_mgr.add_const('DNS_RTYPE_HINFO',0x00000000)
		win_const_mgr.add_const('WM_COMPACTING',0x00000041)
		win_const_mgr.add_const('EXITPUB_FILE',0x00000001)
		win_const_mgr.add_const('ACCESS_SYSTEM_SECURITY',0x01000000)
		win_const_mgr.add_const('IP_ADAPTER_IPV4_ENABLED',0x00000080)
		win_const_mgr.add_const('DXGI_USAGE_BACK_BUFFER',0x00000001)
		win_const_mgr.add_const('DVD_AUDIO_CAPS_MPEG2',0x00000002)
		win_const_mgr.add_const('SSRVOPT_TRACE',0x00000400)
		win_const_mgr.add_const('STI_EVENTHANDLING_ENABLED',0x00000001)
		win_const_mgr.add_const('HH_MAX_TABS',0x00000013)
		win_const_mgr.add_const('INDEX_GUID_INKDRAWING',0x00000005)
		win_const_mgr.add_const('OID_802_11_SUPPORTED_RATES',0x0D01020E)
		win_const_mgr.add_const('SQL_CONVERT_WLONGVARCHAR',0x0000007D)
		win_const_mgr.add_const('ACCESS_DENIED_OBJECT_ACE_TYPE',0x00000006)
		win_const_mgr.add_const('MCI_VCR_SET_RECORD_FORMAT',0x00040000)
		win_const_mgr.add_const('NEXTBAND',0x00000003)
		win_const_mgr.add_const('LB_GETLOCALE',0x000001A6)
		win_const_mgr.add_const('FPS_CALL_DELAYED',0x20002000)
		win_const_mgr.add_const('ERROR_DS_NO_SERVER_OBJECT',0x000021AE)
		win_const_mgr.add_const('CM_LOCATE_DEVNODE_NOVALIDATION',0x00000004)
		win_const_mgr.add_const('DCOMSCM_RESOLVE_USE_ALL_AUTHNSERVICES',0x00000004)
		win_const_mgr.add_const('IP_MAX_MEMBERSHIPS',0x00000014)
		win_const_mgr.add_const('CMSG_INDEFINITE_LENGTH',0xFFFFFFFF)
		win_const_mgr.add_const('D3D10_MIP_LOD_BIAS_MAX',0x0000000F)
		win_const_mgr.add_const('SQL_PROCEDURES',0x00000015)
		win_const_mgr.add_const('FRS_ERR_AUTHENTICATION',0x00001F48)
		win_const_mgr.add_const('JOYCAPS_HASU',0x00000004)
		win_const_mgr.add_const('JOYCAPS_HASV',0x00000008)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INVALIDSWITCH',0x000036F4)
		win_const_mgr.add_const('WM_SETFOCUS',0x00000007)
		win_const_mgr.add_const('JOYCAPS_HASR',0x00000002)
		win_const_mgr.add_const('DS_REPL_NBR_PARTIAL_ATTRIBUTE_SET',0x40000000)
		win_const_mgr.add_const('DEBUG_FORMAT_NO_OVERWRITE',0x80000000)
		win_const_mgr.add_const('SCRIPTITEM_ISVISIBLE',0x00000002)
		win_const_mgr.add_const('LVNI_CUT',0x00000004)
		win_const_mgr.add_const('JOYCAPS_HASZ',0x00000001)
		win_const_mgr.add_const('CERT_FORTEZZA_DATA_PROP_ID',0x00000012)
		win_const_mgr.add_const('TASK_TRIGGER_FLAG_KILL_AT_DURATION_END',0x00000002)
		win_const_mgr.add_const('WHITE_BRUSH',0x00000000)
		win_const_mgr.add_const('WAB_PROFILE_CONTENTS',0x00200000)
		win_const_mgr.add_const('SPFILENOTIFY_ENDDELETE',0x00000006)
		win_const_mgr.add_const('XA_HEURHAZ',0x00000008)
		win_const_mgr.add_const('MCI_SETAUDIO',0x00000873)
		win_const_mgr.add_const('VK_ADD',0x0000006B)
		win_const_mgr.add_const('LOGTOKEN_SETUPAPI_APPLOG',0x00000002)
		win_const_mgr.add_const('S_ALLTHRESHOLD',0x00000002)
		win_const_mgr.add_const('LINEDEVSTATE_REMOVED',0x01000000)
		win_const_mgr.add_const('INTERNET_CUSTOMDIAL_SHOWOFFLINE',0x00000004)
		win_const_mgr.add_const('ERROR_DS_UNICODEPWD_NOT_IN_QUOTES',0x0000216C)
		win_const_mgr.add_const('CERT_NAME_RDN_TYPE',0x00000002)
		win_const_mgr.add_const('IF_TYPE_VOICE_EM',0x00000064)
		win_const_mgr.add_const('FO_MOVE',0x00000001)
		win_const_mgr.add_const('BACKUP_INVALID',0x00000000)
		win_const_mgr.add_const('EN_DRAGDROPDONE',0x00000070)
		win_const_mgr.add_const('SCRIPTINTERRUPT_RAISEEXCEPTION',0x00000002)
		win_const_mgr.add_const('SNMP_ERROR_WRONGTYPE',0x00000007)
		win_const_mgr.add_const('ERROR_INVALID_MEDIA',0x000010CC)
		win_const_mgr.add_const('CSS_ENABLETEMPLATEHANDLE',0x00000040)
		win_const_mgr.add_const('IF_TYPE_MODEM',0x00000030)
		win_const_mgr.add_const('IDTB_SYNC',0x000000CE)
		win_const_mgr.add_const('DB_DISP_ISSUED',0x00000014)
		win_const_mgr.add_const('SQL_SVE_CAST',0x00000002)
		win_const_mgr.add_const('IMF_SMODE_NONE',0x00000002)
		win_const_mgr.add_const('SNMPAPI_HWND_INVALID',0x00000014)
		win_const_mgr.add_const('SPACEPARITY',0x00000004)
		win_const_mgr.add_const('MSGF_MAX',0x00000008)
		win_const_mgr.add_const('BTH_MFG_3COM',0x00000005)
		win_const_mgr.add_const('PROTO_IP_FTP',0x0000271C)
		win_const_mgr.add_const('ERROR_LOGON_FAILURE',0x0000052E)
		win_const_mgr.add_const('DEVICE_STATE_UNPLUGGED',0x00000008)
		win_const_mgr.add_const('INT_ROUTINES_SHIFT',0x00000002)
		win_const_mgr.add_const('CONNECT_INTERACTIVE',0x00000008)
		win_const_mgr.add_const('JIFMK_JPG3',0x0000FFF3)
		win_const_mgr.add_const('JIFMK_JPG2',0x0000FFF2)
		win_const_mgr.add_const('DNF_CLASS_DRIVER',0x00000020)
		win_const_mgr.add_const('JIFMK_JPG0',0x0000FFF0)
		win_const_mgr.add_const('JIFMK_JPG7',0x0000FFF7)
		win_const_mgr.add_const('JIFMK_JPG6',0x0000FFF6)
		win_const_mgr.add_const('JIFMK_JPG5',0x0000FFF5)
		win_const_mgr.add_const('JIFMK_JPG4',0x0000FFF4)
		win_const_mgr.add_const('TMT_OFFSET',0x00000D49)
		win_const_mgr.add_const('JIFMK_JPG9',0x0000FFF9)
		win_const_mgr.add_const('JIFMK_JPG8',0x0000FFF8)
		win_const_mgr.add_const('CF_SETACTIVATEDEFAULT',0x00000004)
		win_const_mgr.add_const('FILE_DEVICE_ACPI',0x00000032)
		win_const_mgr.add_const('OQWF_REMOVESCOPES',0x00000010)
		win_const_mgr.add_const('ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP',0x00001728)
		win_const_mgr.add_const('WMDM_FILE_ATTR_HIDDEN',0x00400000)
		win_const_mgr.add_const('RECOVERY_DEFAULT_PING_INTERVAL',0x00001388)
		win_const_mgr.add_const('TRACE_USE_CONSOLE',0x00000002)
		win_const_mgr.add_const('LIST_MODULES_64BIT',0x00000002)
		win_const_mgr.add_const('ERROR_PIPE_CONNECTED',0x00000217)
		win_const_mgr.add_const('FILE_SYSTEM_DIR',0x00000004)
		win_const_mgr.add_const('LIS_HOTTRACK',0x00000008)
		win_const_mgr.add_const('IF_NOREMOTEICERTADMIN',0x00000010)
		win_const_mgr.add_const('MCI_VCR_STATUS_NUMBER',0x00080000)
		win_const_mgr.add_const('ERROR_TOO_MANY_CMDS',0x00000038)
		win_const_mgr.add_const('WSA_QOS_RESERVED_PETYPE',0x00002B17)
		win_const_mgr.add_const('EC_WRITE_ACCESS',0x00000002)
		win_const_mgr.add_const('HH_HELP_FINDER',0x00000000)
		win_const_mgr.add_const('LINEERR_INVALADDRESSTYPE',0x8000005E)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_NULL',0x00000000)
		win_const_mgr.add_const('CM_LOCATE_DEVNODE_PHANTOM',0x00000001)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_2048BYTES',0x00C00000)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM5C_VAL_POS_X',0x00000010)
		win_const_mgr.add_const('IMAGE_REL_CEE_TOKEN',0x00000006)
		win_const_mgr.add_const('PERF_COUNTER_HISTOGRAM_TYPE',0x80000000)
		win_const_mgr.add_const('MD_LOAD_BALANCER_CAPABILITIES_SOPHISTICATED',0x00000002)
		win_const_mgr.add_const('SQL_SCOPE_CURROW',0x00000000)
		win_const_mgr.add_const('DXVA_BITSTREAM_CONCEALMENT_METHOD_FORWARD',0x00000002)
		win_const_mgr.add_const('KAGPROP_MAXCOLUMNSINTABLE',0x00000010)
		win_const_mgr.add_const('DBPROP_CATALOGLISTID',0x00000009)
		win_const_mgr.add_const('WN_NT_PASSWORD_CHANGED',0x00000002)
		win_const_mgr.add_const('ARW_STARTTOP',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_CEF_ADDR64',0x00000002)
		win_const_mgr.add_const('WSA_FLAG_MULTIPOINT_C_ROOT',0x00000002)
		win_const_mgr.add_const('OID_FDDI_PATH_MAX_T_REQ',0x0303025B)
		win_const_mgr.add_const('MCI_DGV_STATUS_SHARPNESS',0x00004012)
		win_const_mgr.add_const('DISPID_ISSEARCHPROVIDERINSTALLED',0x00000018)
		win_const_mgr.add_const('LV_VIEW_ICON',0x00000000)
		win_const_mgr.add_const('CM_DELETE_CLASS_SUBKEYS',0x00000001)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_WMV9_A',0x00000090)
		win_const_mgr.add_const('ERROR_INVALID_SERVICE_LOCK',0x0000042F)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_WMV9_C',0x00000094)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_WMV9_B',0x00000091)
		win_const_mgr.add_const('SPI_GETMOUSESPEED',0x00000070)
		win_const_mgr.add_const('ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN',0x00002159)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_NO_EDITING_SUBSCRIPTIONS',0x00001D04)
		win_const_mgr.add_const('ACCESS_MAX_MS_OBJECT_ACE_TYPE',0x00000008)
		win_const_mgr.add_const('DIF_UNREMOVE',0x00000016)
		win_const_mgr.add_const('ICMF_CHOOSE_KEYFRAME',0x00000001)
		win_const_mgr.add_const('SP_PARITY_CHECK',0x00000020)
		win_const_mgr.add_const('VER_SUITE_ENTERPRISE',0x00000002)
		win_const_mgr.add_const('CFU_UNDERLINETHICKDASHDOT',0x0000000F)
		win_const_mgr.add_const('MOUSE_MOVE_RELATIVE',0x00000000)
		win_const_mgr.add_const('IPPORT_NTP',0x0000007B)
		win_const_mgr.add_const('BS_SOLID',0x00000000)
		win_const_mgr.add_const('HHWIN_PROP_TAB_HISTORY',0x00000001)
		win_const_mgr.add_const('PWR_OK',0x00000001)
		win_const_mgr.add_const('SERVICE_NOTIFY_CREATED',0x00000080)
		win_const_mgr.add_const('OF_READWRITE',0x00000002)
		win_const_mgr.add_const('ARW_LEFT',0x00000000)
		win_const_mgr.add_const('DMPAPER_PENV_6_ROTATED',0x00000072)
		win_const_mgr.add_const('TXTBIT_SELBARCHANGE',0x00000200)
		win_const_mgr.add_const('CHANGER_STORAGE_SLOT',0x00004000)
		win_const_mgr.add_const('INTERNET_PREFETCH_ABORTED',0x00000002)
		win_const_mgr.add_const('CHANGER_STORAGE_DRIVE',0x00001000)
		win_const_mgr.add_const('SHDID_COMPUTER_IMAGING',0x00000012)
		win_const_mgr.add_const('RTCCS_FORCE_PROFILE',0x00000001)
		win_const_mgr.add_const('DISKQUOTA_STATE_DISABLED',0x00000000)
		win_const_mgr.add_const('WLAN_AVAILABLE_NETWORK_CONNECTED',0x00000001)
		win_const_mgr.add_const('SRRF_NOVIRT',0x40000000)
		win_const_mgr.add_const('ISDB_PCAT_PID',0x00000022)
		win_const_mgr.add_const('SQL_SSF_SUBSTRING',0x00000008)
		win_const_mgr.add_const('NEWFRAME',0x00000001)
		win_const_mgr.add_const('PROTECTION_LEVEL_UNRESTRICTED',0x0000000A)
		win_const_mgr.add_const('FORM_USER',0x00000000)
		win_const_mgr.add_const('PRINTER_STATUS_SERVER_UNKNOWN',0x00800000)
		win_const_mgr.add_const('TVIS_EX_ALL',0x00000002)
		win_const_mgr.add_const('CERT_FILTER_INCLUDE_V1_CERTS',0x00000001)
		win_const_mgr.add_const('KSMETHOD_TYPE_NONE',0x00000000)
		win_const_mgr.add_const('FPS_ANSWERED',0x20800000)
		win_const_mgr.add_const('STI_HW_CONFIG_USB',0x00000004)
		win_const_mgr.add_const('PF_3DNOW_INSTRUCTIONS_AVAILABLE',0x00000007)
		win_const_mgr.add_const('LB_DIR',0x0000018D)
		win_const_mgr.add_const('IOC_VOID',0x20000000)
		win_const_mgr.add_const('SQL_FN_SYS_IFNULL',0x00000004)
		win_const_mgr.add_const('TAPE_DRIVE_INITIATOR',0x00000004)
		win_const_mgr.add_const('LINECALLFEATURE_COMPLETETRANSF',0x00000020)
		win_const_mgr.add_const('WIA_IPS_MAX_VERTICAL_SIZE',0x00001816)
		win_const_mgr.add_const('D3DFMT_R8G8B8',0x00000014)
		win_const_mgr.add_const('CLIPBRD_E_FIRST',0x800401D0)
		win_const_mgr.add_const('JOB_STATUS_BLOCKED_DEVQ',0x00000200)
		win_const_mgr.add_const('IFF_UP',0x00000001)
		win_const_mgr.add_const('IP4_ADDRESS_STRING_BUFFER_LENGTH',0x00000010)
		win_const_mgr.add_const('OID_802_11_NUMBER_OF_ANTENNAS',0x0D01020B)
		win_const_mgr.add_const('WSAEALREADY',0x00002735)
		win_const_mgr.add_const('OCR_NORMAL',0x00007F00)
		win_const_mgr.add_const('PDTIMER_PAUSE',0x00000002)
		win_const_mgr.add_const('LVS_LIST',0x00000003)
		win_const_mgr.add_const('WMPCOREEVENT_WARNING_BASE',0x000015E0)
		win_const_mgr.add_const('UNDNAME_32_BIT_DECODE',0x00000800)
		win_const_mgr.add_const('MD_BACKUP_MAX_VERSION',0x0000270F)
		win_const_mgr.add_const('SM_CYVSCROLL',0x00000014)
		win_const_mgr.add_const('ALERT_SYSTEM_ERROR',0x00000003)
		win_const_mgr.add_const('WMS_STREAM_SHARING_GROUP',0x00000009)
		win_const_mgr.add_const('ERROR_PROMOTION_ACTIVE',0x0000201D)
		win_const_mgr.add_const('ALG_CLASS_SIGNATURE',0x00000001)
		win_const_mgr.add_const('MAX_DEVPROP_TYPEMOD',0x00002000)
		win_const_mgr.add_const('SQL_SQLSTATE_SIZEW',0x0000000A)
		win_const_mgr.add_const('ODT_STATIC',0x00000005)
		win_const_mgr.add_const('DCX_CACHE',0x00000002)
		win_const_mgr.add_const('DMPAPER_B6_JIS',0x00000058)
		win_const_mgr.add_const('FDTF_RTLDATE',0x00000200)
		win_const_mgr.add_const('OF_SHARE_EXCLUSIVE',0x00000010)
		win_const_mgr.add_const('ICM_ON',0x00000002)
		win_const_mgr.add_const('DDCAPS_BLTFOURCC',0x00000100)
		win_const_mgr.add_const('SHCNE_UPDATEIMAGE',0x00008000)
		win_const_mgr.add_const('SV_ENABLESHAREDNETDRIVES_PARMNUM',0x0000021C)
		win_const_mgr.add_const('ILLUMINANT_A',0x00000001)
		win_const_mgr.add_const('SV_MAXWORKITEMIDLETIME_PARMNUM',0x0000022C)
		win_const_mgr.add_const('ERROR_SYNCHRONIZATION_REQUIRED',0x00000239)
		win_const_mgr.add_const('DNS_TYPE_NSAP',0x00000016)
		win_const_mgr.add_const('INTERNET_OPTION_HIBERNATE_INACTIVE_WORKER_THREADS',0x0000005B)
		win_const_mgr.add_const('BATTERY_FLAG_LOW',0x00000002)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_DETECTING_PROXY',0x00001000)
		win_const_mgr.add_const('MFOUTPUTATTRIBUTE_DIGITAL',0x00000001)
		win_const_mgr.add_const('PSH_USEHBMWATERMARK',0x00010000)
		win_const_mgr.add_const('APPCTR_MD_ID_BEGIN_RESERVED',0x00000000)
		win_const_mgr.add_const('ADMIN_STATE_ENABLED',0x00000002)
		win_const_mgr.add_const('SERVICE_START',0x00000010)
		win_const_mgr.add_const('SQL_CONVERT_WVARCHAR',0x0000007E)
		win_const_mgr.add_const('SECPKG_CONTEXT_EXPORT_RESET_NEW',0x00000001)
		win_const_mgr.add_const('GESTURE_INFINITY',0x00000000)
		win_const_mgr.add_const('DIIDFLAG_BITS',0x00000007)
		win_const_mgr.add_const('DNS_RTYPE_NIMLOC',0x00002000)
		win_const_mgr.add_const('TMT_TOOLTIP',0x0000025A)
		win_const_mgr.add_const('LSA_MODE_PASSWORD_PROTECTED',0x00000001)
		win_const_mgr.add_const('NDIS_TIMEOUT_DPC_REQUEST_CAPABILITIES_REVISION_1',0x00000001)
		win_const_mgr.add_const('LVS_EX_DOUBLEBUFFER',0x00010000)
		win_const_mgr.add_const('ATTR_INPUT',0x00000000)
		win_const_mgr.add_const('KSEVENTF_WORKITEM',0x00000020)
		win_const_mgr.add_const('VIF_OUTOFMEMORY',0x00008000)
		win_const_mgr.add_const('WH_JOURNALPLAYBACK',0x00000001)
		win_const_mgr.add_const('D3DPRASTERCAPS_ZBUFFERLESSHSR',0x00008000)
		win_const_mgr.add_const('WM_NCXBUTTONDOWN',0x000000AB)
		win_const_mgr.add_const('SHCNF_DWORD',0x00000003)
		win_const_mgr.add_const('VDMDBG_BREAK_DEBUGGER',0x00000010)
		win_const_mgr.add_const('SAFER_POLICY_BLOCK_CLIENT_UI',0x00002000)
		win_const_mgr.add_const('TVIS_EXPANDPARTIAL',0x00000080)
		win_const_mgr.add_const('WNCON_NOTROUTED',0x00000002)
		win_const_mgr.add_const('IS_TEXT_UNICODE_NULL_BYTES',0x00001000)
		win_const_mgr.add_const('NLS_IME_CONVERSION',0x00800000)
		win_const_mgr.add_const('IDM_DELETE',0x00000011)
		win_const_mgr.add_const('UF_ENCRYPTED_TEXT_PASSWORD_ALLOWED',0x00000080)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_WINEVT_SEND',0x00000009)
		win_const_mgr.add_const('AF_LAT',0x0000000E)
		win_const_mgr.add_const('SCHANNEL_SECRET_PRIVKEY',0x00000002)
		win_const_mgr.add_const('SQL_API_SQLSETCONNECTOPTION',0x00000032)
		win_const_mgr.add_const('CONSOLE_MOUSE_DOWN',0x00000008)
		win_const_mgr.add_const('ERROR_DS_CLIENT_LOOP',0x00002043)
		win_const_mgr.add_const('PRINTER_STATUS_PAGE_PUNT',0x00080000)
		win_const_mgr.add_const('ACM_FORMATENUMF_WFORMATTAG',0x00010000)
		win_const_mgr.add_const('MCI_VCR_SET_PREROLL_DURATION',0x10000000)
		win_const_mgr.add_const('FWPM_ACTRL_BEGIN_READ_TXN',0x00000004)
		win_const_mgr.add_const('CTRY_MACAU',0x00000355)
		win_const_mgr.add_const('SRCINFO_DESCRIPTION',0x00000003)
		win_const_mgr.add_const('DBIMF_NOGRIPPER',0x00000800)
		win_const_mgr.add_const('IDS_TO',0x00011004)
		win_const_mgr.add_const('EC_USEFONTINFO',0x00000000)
		win_const_mgr.add_const('FMEVENT_HELPSTRING',0x0000006A)
		win_const_mgr.add_const('CTL_ENTRY_FROM_PROP_CHAIN_FLAG',0x00000001)
		win_const_mgr.add_const('CERT_NAME_STR_FORWARD_FLAG',0x01000000)
		win_const_mgr.add_const('WINHTTP_QUERY_URI',0x0000000D)
		win_const_mgr.add_const('S_WHITE2048',0x00000006)
		win_const_mgr.add_const('LINECALLFEATURE2_PARKDIRECT',0x00000100)
		win_const_mgr.add_const('PAN_PROPORTION_INDEX',0x00000003)
		win_const_mgr.add_const('WSA_QOS_POLICY_FAILURE',0x00002B03)
		win_const_mgr.add_const('GT_FREE',0x00000007)
		win_const_mgr.add_const('MCI_DGV_CUE_NOSHOW',0x00040000)
		win_const_mgr.add_const('WM_EXITSIZEMOVE',0x00000232)
		win_const_mgr.add_const('LOCALE_SENGLANGUAGE',0x00001001)
		win_const_mgr.add_const('SOUND_SYSTEM_MAXIMIZE',0x00000008)
		win_const_mgr.add_const('SQL_CO_AF',0x00000002)
		win_const_mgr.add_const('EN_PROTECTED',0x00000704)
		win_const_mgr.add_const('PAGEMASK_4KB',0x00000000)
		win_const_mgr.add_const('WAVE_FORMAT_48S16',0x00008000)
		win_const_mgr.add_const('OID_PNP_ENABLE_WAKE_UP',0xFD010106)
		win_const_mgr.add_const('DSBM_CONTEXTMENU',0x00000068)
		win_const_mgr.add_const('DTR_UTBASE_INDEX_TMP',0x00000007)
		win_const_mgr.add_const('SV_TYPE_DOMAIN_BAKCTRL',0x00000010)
		win_const_mgr.add_const('SPI_GETMOUSESONAR',0x0000101C)
		win_const_mgr.add_const('MCI_VCR_SET_SPEED',0x00800000)
		win_const_mgr.add_const('EAP_E_EAPHOST_REMOTE_INVALID_PACKET',0x80420018)
		win_const_mgr.add_const('KERB_WRAP_NO_ENCRYPT',0x80000001)
		win_const_mgr.add_const('IPPORT_NETBIOS_NS',0x00000089)
		win_const_mgr.add_const('LVIS_GLOW',0x00000010)
		win_const_mgr.add_const('TRANSACTIONMANAGER_BIND_TRANSACTION',0x00000020)
		win_const_mgr.add_const('CC_WIDESTYLED',0x00000040)
		win_const_mgr.add_const('CERT_VALIDITY_MASK_VALIDITY',0x00000000)
		win_const_mgr.add_const('ISCSI_SECURITY_FLAG_PFS_ENABLED',0x00000010)
		win_const_mgr.add_const('TF_URP_LOCALTHREAD',0x00000008)
		win_const_mgr.add_const('RTCEF_WATCHER2',0x00080000)
		win_const_mgr.add_const('SYMOPT_ALLOW_ABSOLUTE_SYMBOLS',0x00000800)
		win_const_mgr.add_const('DC_PERSONALITY',0x00000019)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME3',0x00000046)
		win_const_mgr.add_const('AE_SESSLOGOFF',0x00000002)
		win_const_mgr.add_const('NOERROR',0x00000000)
		win_const_mgr.add_const('LINESPECIALINFO_CUSTIRREG',0x00000002)
		win_const_mgr.add_const('ICU_ENCODE_SPACES_ONLY',0x04000000)
		win_const_mgr.add_const('ISR_MBZ0',0x00000018)
		win_const_mgr.add_const('IMN_OPENSTATUSWINDOW',0x00000002)
		win_const_mgr.add_const('CRYPTUI_IGNORE_UNTRUSTED_ROOT',0x00000080)
		win_const_mgr.add_const('IDM_1D_ELEMENT',0x0000095C)
		win_const_mgr.add_const('OID_TAPI_SET_DEV_CONFIG',0x07030120)
		win_const_mgr.add_const('FLG_ADDREG_DELVAL',0x00000004)
		win_const_mgr.add_const('RPC_C_OPT_CALL_TIMEOUT',0x0000000C)
		win_const_mgr.add_const('LOGON_USED_LM_PASSWORD',0x00000008)
		win_const_mgr.add_const('LINECALLINFOSTATE_CALLERID',0x00008000)
		win_const_mgr.add_const('SYMOPT_IGNORE_IMAGEDIR',0x00200000)
		win_const_mgr.add_const('ERROR_DS_ATT_NOT_DEF_FOR_CLASS',0x0000207D)
		win_const_mgr.add_const('SYMOPT_NO_PUBLICS',0x00008000)
		win_const_mgr.add_const('DCICREATEOFFSCREENSURFACE',0x00000002)
		win_const_mgr.add_const('DEBUG_CURRENT_SYMBOL',0x00000001)
		win_const_mgr.add_const('TRUSTERROR_STEP_WVTPARAMS',0x00000000)
		win_const_mgr.add_const('ICDRAW_NULLFRAME',0x10000000)
		win_const_mgr.add_const('JET_BASE_NAME_LENGTH',0x00000003)
		win_const_mgr.add_const('HHWIN_PROP_ONTOP',0x00000001)
		win_const_mgr.add_const('SERVICE_PAUSED',0x00000007)
		win_const_mgr.add_const('ICEE_CREATE_FILE_PE32',0x00000001)
		win_const_mgr.add_const('CSIDL_PRINTERS',0x00000004)
		win_const_mgr.add_const('LINEBEARERMODE_MULTIUSE',0x00000004)
		win_const_mgr.add_const('COPY_PARENT_PROPERTY_VALUES',0x40000000)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_EXTEND',0x00000008)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_RANGE',0x00000035)
		win_const_mgr.add_const('CQPM_ENABLE',0x00000003)
		win_const_mgr.add_const('IDS_CAP_WAVE_ADD_ERROR',0x000001A6)
		win_const_mgr.add_const('D3DTEXOPCAPS_MODULATE',0x00000008)
		win_const_mgr.add_const('ETW_VARIANT_TYPE_VALUE',0x00000074)
		win_const_mgr.add_const('ERROR_CANT_ENABLE_DENY_ONLY',0x00000275)
		win_const_mgr.add_const('NDIS_PROTOCOL_ID_DEFAULT',0x00000000)
		win_const_mgr.add_const('IDS_CODEPAGE',0x0001100D)
		win_const_mgr.add_const('PICTYPE_ENHMETAFILE',0x00000004)
		win_const_mgr.add_const('DOT11_STATUS_PACKET_NOT_REASSEMBLED',0x00002000)
		win_const_mgr.add_const('CERT_COMPARE_PUBKEY_MD5_HASH',0x00000012)
		win_const_mgr.add_const('CONFIGFLAG_NETBOOT_CARD',0x00001000)
		win_const_mgr.add_const('BTH_ERROR_LOCAL_HOST_TERMINATED_CONNECTION',0x00000016)
		win_const_mgr.add_const('WMN_LAST',0x00000000)
		win_const_mgr.add_const('NET_STRING_IPV6_SERVICE',0x00000020)
		win_const_mgr.add_const('MORE_DATA',0x00000001)
		win_const_mgr.add_const('GET_FEATURE_FROM_THREAD_INTRANET',0x00000010)
		win_const_mgr.add_const('VOS__PM16',0x00000002)
		win_const_mgr.add_const('TC_CR_ANY',0x00000010)
		win_const_mgr.add_const('CERT_V1',0x00000000)
		win_const_mgr.add_const('DISPID_NEWFOLDER',0x00000004)
		win_const_mgr.add_const('MARK_HANDLE_TXF_SYSTEM_LOG',0x00000004)
		win_const_mgr.add_const('ERROR_MESSAGE_SYNC_ONLY',0x00000487)
		win_const_mgr.add_const('MONITOR_DEFAULTTOPRIMARY',0x00000001)
		win_const_mgr.add_const('CERT_V2',0x00000001)
		win_const_mgr.add_const('IDS_CAP_STAT_VIDEOONLY',0x00000200)
		win_const_mgr.add_const('IIS_MD_LOG_BASE',0x00000FA0)
		win_const_mgr.add_const('ISOPROTO_INACT_NL',0x00000021)
		win_const_mgr.add_const('D3DTA_ALPHAREPLICATE',0x00000020)
		win_const_mgr.add_const('ERROR_DS_ADD_REPLICA_INHIBITED',0x0000206E)
		win_const_mgr.add_const('ERROR_CLUSTER_INVALID_NETWORK_PROVIDER',0x000013B9)
		win_const_mgr.add_const('SOUND_SYSTEM_MENUPOPUP',0x00000010)
		win_const_mgr.add_const('XACT_S_FIRST',0x0004D000)
		win_const_mgr.add_const('MD_ACR_UNSECURE_PROPS_READ',0x00000080)
		win_const_mgr.add_const('KSMPEGVIDMODE_LTRBOX',0x00000002)
		win_const_mgr.add_const('PD_RESULT_APPLY',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_PROXY_SETTINGS_CHANGED',0x0000005F)
		win_const_mgr.add_const('CM_REGISTRY_BITS',0x00000301)
		win_const_mgr.add_const('DBPROPVAL_LM_SINGLEROW',0x00000002)
		win_const_mgr.add_const('DNF_OEM_F6_INF',0x00004000)
		win_const_mgr.add_const('FWP_OPTION_VALUE_ALLOW_MULTICAST_STATE',0x00000000)
		win_const_mgr.add_const('LVNI_VISIBLEONLY',0x00000040)
		win_const_mgr.add_const('WMDRM_KEYTYPE_RC4',0x00000000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_HOLDMAKESNEW',0x04000000)
		win_const_mgr.add_const('TAPE_DRIVE_SET_EOT_WZ_SIZE',0x00400000)
		win_const_mgr.add_const('BDIF_ADDRESS',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_SUPPORTEDFEATUREPAGES',0x00000208)
		win_const_mgr.add_const('CFE_UNDERLINE',0x00000004)
		win_const_mgr.add_const('MFSESSIONCAP_RATE_REVERSE',0x00000020)
		win_const_mgr.add_const('WSF_VISIBLE',0x00000001)
		win_const_mgr.add_const('SECPKG_ATTR_SESSION_INFO',0x00000005)
		win_const_mgr.add_const('USER_INTERDOMAIN_TRUST_ACCOUNT',0x00000040)
		win_const_mgr.add_const('SPI_SETFILTERKEYS',0x00000033)
		win_const_mgr.add_const('CDO_E_SENDER_REJECTED',0x8004020E)
		win_const_mgr.add_const('RPC_C_IMP_LEVEL_IMPERSONATE',0x00000003)
		win_const_mgr.add_const('PROXIMITY_UNIT_SENTENCE',0x00000001)
		win_const_mgr.add_const('SVSI_ENSUREVISIBLE',0x00000008)
		win_const_mgr.add_const('NTDSCONN_KCC_MINIMIZE_HOPS_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('ISC_REQ_FORWARD_CREDENTIALS',0x00400000)
		win_const_mgr.add_const('ERROR_INVALID_ICON_HANDLE',0x00000586)
		win_const_mgr.add_const('CREDUI_FLAGS_EXCLUDE_CERTIFICATES',0x00000008)
		win_const_mgr.add_const('ETW_NULL_TYPE_VALUE',0x00000000)
		win_const_mgr.add_const('MCI_VCR_SETTIMECODE_RECORD',0x00010000)
		win_const_mgr.add_const('TCP_DELAY_FIN_ACK',0x0000000D)
		win_const_mgr.add_const('NDIS_LINK_STATE_RCV_LINK_SPEED_AUTO_NEGOTIATED',0x00000002)
		win_const_mgr.add_const('IMR_COMPOSITIONFONT',0x00000003)
		win_const_mgr.add_const('DISPID_NEWWINDOW',0x0000006B)
		win_const_mgr.add_const('STI_GENCAP_SUBSET',0x00000020)
		win_const_mgr.add_const('IECN__BASE',0x00000800)
		win_const_mgr.add_const('OID_802_11_PRIVACY_FILTER',0x0D010119)
		win_const_mgr.add_const('HTGROWBOX',0x00000004)
		win_const_mgr.add_const('NETSETUP_DEFER_SPN_SET',0x00000100)
		win_const_mgr.add_const('SQL_RESET_PARAMS',0x00000003)
		win_const_mgr.add_const('KERB_ETYPE_DES3_CBC_SHA1',0x00000007)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_TOKEN',0x00000010)
		win_const_mgr.add_const('DS_REPUPD_WRITEABLE',0x00000002)
		win_const_mgr.add_const('BSF_POSTMESSAGE',0x00000010)
		win_const_mgr.add_const('FACILITY_NDIS',0x00000034)
		win_const_mgr.add_const('PER_USER_POLICY_UNCHANGED',0x00000000)
		win_const_mgr.add_const('LANG_URDU',0x00000020)
		win_const_mgr.add_const('D3DTEXOPCAPS_ADDSIGNED',0x00000080)
		win_const_mgr.add_const('LTP_PC_SMT',0x00000001)
		win_const_mgr.add_const('IPV6_CHECKSUM',0x0000001A)
		win_const_mgr.add_const('MUI_BYPASS_SESSION_BEHAVIOR',0x00000080)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAOEVENTARGS_ESTIMATEDTOTALTIME',0x00000304)
		win_const_mgr.add_const('MCI_OFF',0x00000000)
		win_const_mgr.add_const('NRC_ILLNN',0x00000013)
		win_const_mgr.add_const('FILE_DEVICE_MAILSLOT',0x00000000)
		win_const_mgr.add_const('CMS_SETTARGETPROFILE',0x00000040)
		win_const_mgr.add_const('ALG_SID_AES_256',0x00000010)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_MULTICAST_FRAMES_XMIT',0x00000080)
		win_const_mgr.add_const('ERROR_DS_ROOT_REQUIRES_CLASS_TOP',0x000020F0)
		win_const_mgr.add_const('FACILITY_SETUPAPI',0x0000000F)
		win_const_mgr.add_const('PID_IP',0x00000021)
		win_const_mgr.add_const('DMPAPER_ENV_11',0x00000015)
		win_const_mgr.add_const('DMPAPER_ENV_10',0x00000014)
		win_const_mgr.add_const('ISFB_MASK_VIEWMODE',0x00000004)
		win_const_mgr.add_const('DS_GOOD_TIMESERV_PREFERRED',0x00002000)
		win_const_mgr.add_const('PORT_DSP3270',0x000000F6)
		win_const_mgr.add_const('LINEDISCONNECTMODE_BLOCKED',0x00020000)
		win_const_mgr.add_const('PORT_TYPE_READ',0x00000002)
		win_const_mgr.add_const('IS_TEXT_UNICODE_CONTROLS',0x00000004)
		win_const_mgr.add_const('SPI_SETMOUSETRAILS',0x0000005D)
		win_const_mgr.add_const('HTBORDER',0x00000012)
		win_const_mgr.add_const('SQL_COLUMN_AUTO_INCREMENT',0x0000000B)
		win_const_mgr.add_const('SMART_INVALID_IOCTL',0x00000006)
		win_const_mgr.add_const('WEBPOST_ERROR_SITE_DOESNOTEXIST',0xC004210B)
		win_const_mgr.add_const('ACTCTX_FLAG_HMODULE_VALID',0x00000080)
		win_const_mgr.add_const('TAPE_DRIVE_ERASE_SHORT',0x00000010)
		win_const_mgr.add_const('DISPID_ONMOUSEOVER',0x00000009)
		win_const_mgr.add_const('ERROR_REPARSE',0x000002E5)
		win_const_mgr.add_const('SFVM_GETANIMATION',0x00000044)
		win_const_mgr.add_const('CSIDL_COMMON_DESKTOPDIRECTORY',0x00000019)
		win_const_mgr.add_const('OAFALSE',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_SH3_DIRECT32',0x00000002)
		win_const_mgr.add_const('CERT_REGISTRY_STORE_LM_GPT_FLAG',0x01000000)
		win_const_mgr.add_const('WPF_NO_WIZARD',0x00000002)
		win_const_mgr.add_const('NDIS_MAXIMUM_PORTS',0x01000000)
		win_const_mgr.add_const('SP_RLSD',0x00000040)
		win_const_mgr.add_const('PRINTER_CHANGE_ADD_JOB',0x00000100)
		win_const_mgr.add_const('VFT_APP',0x00000001)
		win_const_mgr.add_const('OID_FDDI_MAC_SMT_ADDRESS',0x0303022D)
		win_const_mgr.add_const('ERROR_EVT_INVALID_QUERY',0x00003A99)
		win_const_mgr.add_const('SWP_NOREDRAW',0x00000008)
		win_const_mgr.add_const('STATE_SYSTEM_LINKED',0x00400000)
		win_const_mgr.add_const('KAGPROP_DRIVERVER',0x00000008)
		win_const_mgr.add_const('PRIVATEOBJECT_ADDRESS',0x00000006)
		win_const_mgr.add_const('THREAD_DIRECT_IMPERSONATION',0x00000200)
		win_const_mgr.add_const('CONTEXT_MENU_UNKNOWN',0x00000006)
		win_const_mgr.add_const('DEBUG_DATA_SPACE_COUNT',0x00000007)
		win_const_mgr.add_const('IMAGE_COMDAT_SELECT_EXACT_MATCH',0x00000004)
		win_const_mgr.add_const('MCI_VD_SPIN_UP',0x00010000)
		win_const_mgr.add_const('MIXER_GETLINEINFOF_QUERYMASK',0x0000000F)
		win_const_mgr.add_const('DFCS_CAPTIONCLOSE',0x00000000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_FWDINTEXTADDR',0x00040000)
		win_const_mgr.add_const('DSA_NOTIFY_MOV',0x00000004)
		win_const_mgr.add_const('SPI_GETFONTSMOOTHINGTYPE',0x0000200A)
		win_const_mgr.add_const('DEBUG_EVENT_SYSTEM_ERROR',0x00000100)
		win_const_mgr.add_const('DRM_PLAYLIST_DATA_V1_VALID',0x00000002)
		win_const_mgr.add_const('SID_REVISION',0x00000001)
		win_const_mgr.add_const('PRF_TRYPROGRAMEXTENSIONS',0x00000002)
		win_const_mgr.add_const('DOWNLOADFACE',0x00000202)
		win_const_mgr.add_const('ERROR_FILE_SYSTEM_LIMITATION',0x00000299)
		win_const_mgr.add_const('PFM_TABLEROWDELIMITER',0x10000000)
		win_const_mgr.add_const('CONTEXT_MENU_DEBUG',0x00000009)
		win_const_mgr.add_const('SNMPAPI_OPERATION_INVALID',0x0000000A)
		win_const_mgr.add_const('MF_16_BYTE_ALIGNMENT',0x00000000)
		win_const_mgr.add_const('LINEINITIALIZEEXOPTION_USEHIDDENWINDOW',0x00000001)
		win_const_mgr.add_const('SPFILEQ_REBOOT_IN_PROGRESS',0x00000004)
		win_const_mgr.add_const('OID_FDDI_SMT_PEER_WRAP_FLAG',0x0303021A)
		win_const_mgr.add_const('TXTLOG_DEVINST',0x00000001)
		win_const_mgr.add_const('DC_EXTRA',0x00000009)
		win_const_mgr.add_const('SMC_GETCONTEXTMENUMODIFIER',0x00000043)
		win_const_mgr.add_const('INTERNET_REQFLAG_NO_HEADERS',0x00000008)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_PROMISCUOUS_CTRL',0x02000000)
		win_const_mgr.add_const('MCI_DGV_RECT',0x00010000)
		win_const_mgr.add_const('SCARD_SCOPE_TERMINAL',0x00000001)
		win_const_mgr.add_const('WMDM_STORAGE_ATTR_HAS_FILES',0x04000000)
		win_const_mgr.add_const('CMF_EXPLORE',0x00000004)
		win_const_mgr.add_const('CRYPTPROTECTMEMORY_BLOCK_SIZE',0x00000010)
		win_const_mgr.add_const('MAPVK_VSC_TO_VK_EX',0x00000003)
		win_const_mgr.add_const('SW_SHOW',0x00000005)
		win_const_mgr.add_const('PHONEHOOKSWITCHMODE_SPEAKER',0x00000004)
		win_const_mgr.add_const('IFS_V',0x0000003F)
		win_const_mgr.add_const('SM_CXDOUBLECLK',0x00000024)
		win_const_mgr.add_const('VK_RCONTROL',0x000000A3)
		win_const_mgr.add_const('ERROR_UNABLE_TO_INVENTORY_DRIVE',0x000010E5)
		win_const_mgr.add_const('SPI_GETMENUDROPALIGNMENT',0x0000001B)
		win_const_mgr.add_const('OID_802_3_XMIT_UNDERRUN',0x01020204)
		win_const_mgr.add_const('STG_LAYOUT_SEQUENTIAL',0x00000000)
		win_const_mgr.add_const('MUTZ_RESERVED',0x00000200)
		win_const_mgr.add_const('HHT_TOLEFT',0x00000800)
		win_const_mgr.add_const('KAGPROP_ACCESSIBLETABLES',0x00000003)
		win_const_mgr.add_const('REGSTR_VAL_VISIBLEBANDS_DEF',0x00000007)
		win_const_mgr.add_const('STATE_SYSTEM_MULTISELECTABLE',0x01000000)
		win_const_mgr.add_const('IPSEC_POLICY_FLAG_ND_SECURE',0x00000002)
		win_const_mgr.add_const('CMSG_COMPUTED_HASH_PARAM',0x00000016)
		win_const_mgr.add_const('ISSCERT_URLMASK_OLD',0x00000000)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_DWORD',0x0000000F)
		win_const_mgr.add_const('AVI_INDEX_OF_INDEXES',0x00000000)
		win_const_mgr.add_const('ACM_MPEG_SINGLECHANNEL',0x00000008)
		win_const_mgr.add_const('OUT_DEVICE_PRECIS',0x00000005)
		win_const_mgr.add_const('POWER_USER_NOTIFY_SHUTDOWN',0x00000010)
		win_const_mgr.add_const('INTERNET_PREFETCH_COMPLETE',0x00000001)
		win_const_mgr.add_const('HSHELL_ACTIVATESHELLWINDOW',0x00000003)
		win_const_mgr.add_const('UM_FOCUS_TYPE_UNKNOWN',0x00000004)
		win_const_mgr.add_const('SEC_COMMIT',0x08000000)
		win_const_mgr.add_const('LINEDEVSTATE_NUMCALLS',0x00000800)
		win_const_mgr.add_const('CERT_ALT_NAME_DNS_NAME',0x00000003)
		win_const_mgr.add_const('OIC_NOTE',0x00007F04)
		win_const_mgr.add_const('SUF_NETRPLBOOT',0x00000080)
		win_const_mgr.add_const('KERB_ETYPE_RC4_HMAC_NT_EXP',0x00000018)
		win_const_mgr.add_const('DDOVER_BOBHARDWARE',0x01000000)
		win_const_mgr.add_const('CREATE_CRED_RESET',0x00000004)
		win_const_mgr.add_const('FPSR_RC3',0x00000031)
		win_const_mgr.add_const('SECPKG_ATTR_C_FULL_ACCESS_TOKEN',0x80000082)
		win_const_mgr.add_const('FPSR_RC1',0x00000017)
		win_const_mgr.add_const('FPSR_RC0',0x0000000A)
		win_const_mgr.add_const('D3D10_SHADER_OPTIMIZATION_LEVEL3',0x00000001)
		win_const_mgr.add_const('D3D10_SHADER_OPTIMIZATION_LEVEL1',0x00000000)
		win_const_mgr.add_const('D3D10_SHADER_OPTIMIZATION_LEVEL0',0x00000001)
		win_const_mgr.add_const('SECPKG_FLAG_MULTI_REQUIRED',0x00000020)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_NATIVE_802_11_ATTRIBUTES',0x000000A1)
		win_const_mgr.add_const('SV_SECURITY_PARMNUM',0x00000195)
		win_const_mgr.add_const('URL_DONT_ESCAPE_EXTRA_INFO',0x02000000)
		win_const_mgr.add_const('KSDATARANGE_REQUIRED_ATTRIBUTES',0x00000001)
		win_const_mgr.add_const('DEBUG_FILTER_SYSTEM_ERROR',0x00000006)
		win_const_mgr.add_const('MUST_REVALIDATE_CACHE_ENTRY',0x00000100)
		win_const_mgr.add_const('IPV6_DROP_MEMBERSHIP',0x0000000D)
		win_const_mgr.add_const('BTH_ERROR_KEY_MISSING',0x00000006)
		win_const_mgr.add_const('OID_TAPI_PROVIDER_INITIALIZE',0x07030118)
		win_const_mgr.add_const('PIDASI_FORMAT',0x00000002)
		win_const_mgr.add_const('IDH_CANCEL',0x00006F1C)
		win_const_mgr.add_const('MFASYNC_CALLBACK_QUEUE_RT',0x00000002)
		win_const_mgr.add_const('BTH_MFG_TI',0x0000000D)
		win_const_mgr.add_const('SQL_CVT_BINARY',0x00000400)
		win_const_mgr.add_const('SV_MAXFREEMFCBS_PARMNUM',0x00000244)
		win_const_mgr.add_const('DOT11_RECV_FLAG_RAW_PACKET',0x00000001)
		win_const_mgr.add_const('PCF_DTRDSR',0x00000001)
		win_const_mgr.add_const('PRODUCT_STORAGE_ENTERPRISE_SERVER',0x00000017)
		win_const_mgr.add_const('SFVM_GETBUTTONS',0x00000006)
		win_const_mgr.add_const('INDEX_GUID_ANALYSISHINTNAME',0x00000000)
		win_const_mgr.add_const('LINEERR_INVALCALLPRIVILEGE',0x8000001A)
		win_const_mgr.add_const('CCH_RM_MAX_SVC_NAME',0x0000003F)
		win_const_mgr.add_const('FAX_PORT_QUERY',0x00000010)
		win_const_mgr.add_const('MDM_SHIFT_V110_SPEED',0x00000000)
		win_const_mgr.add_const('AVIF_COPYRIGHTED',0x00020000)
		win_const_mgr.add_const('ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD',0x0000212B)
		win_const_mgr.add_const('CMSG_HASHED_DATA_V2',0x00000002)
		win_const_mgr.add_const('LPM_PE_APP_IDENTITY',0x00000003)
		win_const_mgr.add_const('MF_MENUBREAK',0x00000040)
		win_const_mgr.add_const('CDBOSC_KILLFOCUS',0x00000001)
		win_const_mgr.add_const('DS_FIXEDSYS',0x00000008)
		win_const_mgr.add_const('SEC_PROTECTED_IMAGE',0x02000000)
		win_const_mgr.add_const('HTTP_QUERY_LOCATION',0x00000021)
		win_const_mgr.add_const('EVCF_DONTSHOWIFZERO',0x00000010)
		win_const_mgr.add_const('SERVICE_RUNS_IN_SYSTEM_PROCESS',0x00000001)
		win_const_mgr.add_const('VIF_ACCESSVIOLATION',0x00000200)
		win_const_mgr.add_const('SERVICE_ACCEPT_NETBINDCHANGE',0x00000010)
		win_const_mgr.add_const('SW_AUTOPROF_SAVE_MASK',0x00000002)
		win_const_mgr.add_const('ODS_INACTIVE',0x00000080)
		win_const_mgr.add_const('NDIS_DEVICE_WAKE_ON_MAGIC_PACKET_ENABLE',0x00000004)
		win_const_mgr.add_const('ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN',0x0000370F)
		win_const_mgr.add_const('GT_UNKNOWN',0x00000000)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_CIRCLE',0x0000000C)
		win_const_mgr.add_const('DS_DIRECTORY_SERVICE_PREFERRED',0x00000020)
		win_const_mgr.add_const('CTRY_GUATEMALA',0x000001F6)
		win_const_mgr.add_const('SECPKG_CALL_WINLOGON',0x00000800)
		win_const_mgr.add_const('BSM_ALLCOMPONENTS',0x00000000)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_SVIDEO_S',0x00008012)
		win_const_mgr.add_const('NTDSTRANSPORT_OPT_BRIDGES_REQUIRED',0x00000001)
		win_const_mgr.add_const('PROCESS_HEAP_UNCOMMITTED_RANGE',0x00000002)
		win_const_mgr.add_const('DBPROP_MSREMOTE_COMMAND_PROPERTIES',0x00000008)
		win_const_mgr.add_const('SE_GROUP_INTEGRITY',0x00000020)
		win_const_mgr.add_const('CRYPT_SGC',0x00000001)
		win_const_mgr.add_const('RBS_DBLCLKTOGGLE',0x00008000)
		win_const_mgr.add_const('HHWIN_BUTTON_ZOOM',0x00000001)
		win_const_mgr.add_const('ET_CMMTYPE',0x00000010)
		win_const_mgr.add_const('ERROR_NOT_CONNECTED',0x000008CA)
		win_const_mgr.add_const('ERROR_INVALID_ENVIRONMENT',0x0000070D)
		win_const_mgr.add_const('TYPE_STRING',0x00000002)
		win_const_mgr.add_const('CM_PROB_SETPROPERTIES_FAILED',0x00000032)
		win_const_mgr.add_const('CHANNEL_EVENT_V1_CONNECTED',0x00000002)
		win_const_mgr.add_const('BTH_MFG_TENOVIS',0x0000002B)
		win_const_mgr.add_const('TMT_USERPICTURE',0x00001389)
		win_const_mgr.add_const('DOWNLOADHEADER',0x0000100F)
		win_const_mgr.add_const('SQL_CONVERT_CHAR',0x00000038)
		win_const_mgr.add_const('ENABLECLASS_SUCCESS',0x00000001)
		win_const_mgr.add_const('SCHEME_LOCAL',0x00000004)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_SPLICEPOINT',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_DUPLICATE_PROGID',0x000036CA)
		win_const_mgr.add_const('ERROR_BROKEN_PIPE',0x0000006D)
		win_const_mgr.add_const('ERROR_EXE_MACHINE_TYPE_MISMATCH',0x000000D8)
		win_const_mgr.add_const('DEBUG_SESSION_ACTIVE',0x00000000)
		win_const_mgr.add_const('OID_FDDI_MAC_BRIDGE_FUNCTIONS',0x03030220)
		win_const_mgr.add_const('D3DDEVCAPS_DRAWPRIMITIVES2',0x00002000)
		win_const_mgr.add_const('CB_SETITEMHEIGHT',0x00000153)
		win_const_mgr.add_const('DT_PATH_ELLIPSIS',0x00004000)
		win_const_mgr.add_const('OPTION_DOMAIN_NAME_SERVERS',0x00000006)
		win_const_mgr.add_const('DDE_FACKREQ',0x00008000)
		win_const_mgr.add_const('MD_ACR_WRITE_DAC',0x00040000)
		win_const_mgr.add_const('PHONEFEATURE_GETDATA',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_I386_SECREL7',0x0000000D)
		win_const_mgr.add_const('SQL_DIAG_DROP_DOMAIN',0x0000001B)
		win_const_mgr.add_const('PHOTO_GAINCONTROL_LOWGAINUP',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_UNLESS_MODIFIED_SINCE',0x00000046)
		win_const_mgr.add_const('INFINFO_INF_NAME_IS_ABSOLUTE',0x00000002)
		win_const_mgr.add_const('DISPID_DDISCFORMAT2DATAEVENTS_UPDATE',0x00000200)
		win_const_mgr.add_const('RSOP_COMPUTER_ACCESS_DENIED',0x00000002)
		win_const_mgr.add_const('COD_MAJOR_BIT_OFFSET',0x00000008)
		win_const_mgr.add_const('SQL_API_SQLENDTRAN',0x000003ED)
		win_const_mgr.add_const('IMAGE_REL_SH3_DIRECT4_LONG',0x00000008)
		win_const_mgr.add_const('POSTSCRIPT_DATA',0x00000025)
		win_const_mgr.add_const('MCIWNDF_NOMENU',0x00000008)
		win_const_mgr.add_const('OID_CO_TAPI_TRANSLATE_NDIS_CALLPARAMS',0xFE001005)
		win_const_mgr.add_const('SERVICE_USER_DEFINED_CONTROL',0x00000100)
		win_const_mgr.add_const('JIFMK_FF',0x0000FFFF)
		win_const_mgr.add_const('DFCS_HOT',0x00001000)
		win_const_mgr.add_const('SI_CONTAINER',0x00000004)
		win_const_mgr.add_const('IPX_DEST_TABLE',0x00000002)
		win_const_mgr.add_const('CR_NO_ARBITRATOR',0x0000001B)
		win_const_mgr.add_const('SPI_SETUIEFFECTS',0x0000103F)
		win_const_mgr.add_const('PRINTER_CHANGE_SET_FORM',0x00020000)
		win_const_mgr.add_const('TMFAIL',0x20000000)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_DATATYPE',0x00000005)
		win_const_mgr.add_const('ENABLE_INSERT_MODE',0x00000020)
		win_const_mgr.add_const('DT_HIDEPREFIX',0x00100000)
		win_const_mgr.add_const('ISOPROTO_INTRAISIS',0x00000023)
		win_const_mgr.add_const('IDM_ALIGNTOGRID',0x00000005)
		win_const_mgr.add_const('IF_TYPE_PROP_MULTIPLEXOR',0x00000036)
		win_const_mgr.add_const('OID_ATM_SUPPORTED_SERVICE_CATEGORY',0x08010102)
		win_const_mgr.add_const('DCICREATEPRIMARYSURFACE',0x00000001)
		win_const_mgr.add_const('CNLEN',0x0000000F)
		win_const_mgr.add_const('URLACTION_SHELL_MOVE_OR_COPY',0x00001802)
		win_const_mgr.add_const('IF_TYPE_LAN',0x00000002)
		win_const_mgr.add_const('MD_ERROR_SUB403_CAL_EXCEEDED',0x0000000F)
		win_const_mgr.add_const('PKR_KEY_LEN',0x00000018)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGFLUSH',0x00000015)
		win_const_mgr.add_const('NOM_BRP',0x00000080)
		win_const_mgr.add_const('ICERR_DONTDRAW',0x00000001)
		win_const_mgr.add_const('ERROR_EVT_FILTER_INVTEST',0x00003AA9)
		win_const_mgr.add_const('HDS_OVERFLOW',0x00001000)
		win_const_mgr.add_const('ERROR_DLL_INIT_FAILED_LOGOFF',0x00000270)
		win_const_mgr.add_const('IDM_ALIGNHORIZONTALCENTERS',0x00000002)
		win_const_mgr.add_const('SIZE_RESTORED',0x00000000)
		win_const_mgr.add_const('NUMCOLORS',0x00000018)
		win_const_mgr.add_const('DDBLTFX_ROTATE180',0x00000010)
		win_const_mgr.add_const('PRODUCT_SERVER_FOR_SMALLBUSINESS',0x00000018)
		win_const_mgr.add_const('PSBTN_FINISH',0x00000002)
		win_const_mgr.add_const('MCI_DGV_COPY_AUDIO_STREAM',0x00020000)
		win_const_mgr.add_const('DISPID_IHTMLPLUGINSCOLLECTION_LENGTH',0x00000001)
		win_const_mgr.add_const('MUI_LANG_NEUTRAL_PE_FILE',0x00000100)
		win_const_mgr.add_const('WB_LEFTBREAK',0x00000006)
		win_const_mgr.add_const('SPQ_SCAN_PRUNE_COPY_QUEUE',0x00000020)
		win_const_mgr.add_const('DNF_UNUSED1',0x00000100)
		win_const_mgr.add_const('DNF_UNUSED2',0x00000200)
		win_const_mgr.add_const('TMT_INTLIST',0x000000D3)
		win_const_mgr.add_const('SSPROP_ENABLEFASTLOAD',0x00000002)
		win_const_mgr.add_const('ARW_BOTTOMLEFT',0x00000000)
		win_const_mgr.add_const('PHOTO_PROGRAMMODE_APERTURE',0x00000003)
		win_const_mgr.add_const('AA_CLOSE',0x00000008)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_CONTROLLERS',0x00000204)
		win_const_mgr.add_const('SQL_GROUP_BY',0x00000058)
		win_const_mgr.add_const('GMEM_DISCARDABLE',0x00000100)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_PARTIALDIAL',0x00010000)
		win_const_mgr.add_const('IMAGE_SCN_MEM_NOT_CACHED',0x04000000)
		win_const_mgr.add_const('SQL_PC_UNKNOWN',0x00000000)
		win_const_mgr.add_const('SECPKG_CRED_INBOUND',0x00000001)
		win_const_mgr.add_const('DMTT_BITMAP',0x00000001)
		win_const_mgr.add_const('DIF_FOUNDDEVICE',0x00000007)
		win_const_mgr.add_const('EAP_E_EAPHOST_FIRST',0x80420000)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_TRUST_USES_AES_KEYS',0x00000100)
		win_const_mgr.add_const('TBSTATE_ELLIPSES',0x00000040)
		win_const_mgr.add_const('ERROR_XMLDSIG_ERROR',0x000005BA)
		win_const_mgr.add_const('AAL5_SSCS_FRAME_RELAY',0x00000004)
		win_const_mgr.add_const('PRF_CHECKVISIBLE',0x00000001)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_ASSUME_UDP_CONTEXT_OUTBOUND',0x00000800)
		win_const_mgr.add_const('SQL_GB_GROUP_BY_EQUALS_SELECT',0x00000001)
		win_const_mgr.add_const('MCI_VCR_SETAUDIO_TO',0x00200000)
		win_const_mgr.add_const('MULTIFILEOPENORD',0x00000601)
		win_const_mgr.add_const('D3D10_EFFECT_VARIABLE_POOLED',0x00000001)
		win_const_mgr.add_const('TCBASE',0x00001D4C)
		win_const_mgr.add_const('HTTP_STATUS_RESET_CONTENT',0x000000CD)
		win_const_mgr.add_const('MIB_IPADDR_DNS_ELIGIBLE',0x00000000)
		win_const_mgr.add_const('SM_CXMIN',0x0000001C)
		win_const_mgr.add_const('VOS__PM32',0x00000003)
		win_const_mgr.add_const('NTDDI_WINXP',0x05010000)
		win_const_mgr.add_const('SES_BEEPONMAXTEXT',0x00000002)
		win_const_mgr.add_const('CSIDL_PROGRAMS',0x00000002)
		win_const_mgr.add_const('SQL_FN_NUM_ABS',0x00000001)
		win_const_mgr.add_const('SNMP_MGMTAPI_INVALID_BUFFER',0x00000030)
		win_const_mgr.add_const('WIA_FILM_COLOR_NEGATIVE',0x00000001)
		win_const_mgr.add_const('BTH_ERROR_HOST_TIMEOUT',0x00000010)
		win_const_mgr.add_const('NCRYPT_ALLOW_DECRYPT_FLAG',0x00000001)
		win_const_mgr.add_const('IDM_STOP',0x0000085A)
		win_const_mgr.add_const('SV_MAXCOPYLENGTH_PARMNUM',0x0000024C)
		win_const_mgr.add_const('VALIDATED_LOGON',0x00000000)
		win_const_mgr.add_const('RPC_S_NOT_ALL_OBJS_UNEXPORTED',0x000006DE)
		win_const_mgr.add_const('RGN_XOR',0x00000003)
		win_const_mgr.add_const('NETE_NOTSUPPORTED',0x0000006D)
		win_const_mgr.add_const('COPYFLG_NOPRUNE',0x00002000)
		win_const_mgr.add_const('IIS_MD_HTTP_BASE',0x000007D0)
		win_const_mgr.add_const('SB_NONE',0x00000000)
		win_const_mgr.add_const('AUTHZ_GENERATE_SUCCESS_AUDIT',0x00000001)
		win_const_mgr.add_const('VK_UP',0x00000026)
		win_const_mgr.add_const('WINEVENT_KEYWORD_AUDIT_FAILURE',0x10000000000000)
		win_const_mgr.add_const('IMAGE_REL_ARM_BLX11',0x00000009)
		win_const_mgr.add_const('CONSOLE_CARET_VISIBLE',0x00000002)
		win_const_mgr.add_const('CHANGER_KEYPAD_ENABLE_DISABLE',0x10000000)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_RELOCATE_FLAG',0x80000000)
		win_const_mgr.add_const('SECURITY_RESERVED_ID_BASE_RID',0x00000051)
		win_const_mgr.add_const('DOT11_PRIORITY_CONTENTION',0x00000000)
		win_const_mgr.add_const('ASC_REQ_NO_TOKEN',0x01000000)
		win_const_mgr.add_const('LOGON_NT_V2',0x00000800)
		win_const_mgr.add_const('DSBM_HELP',0x00000067)
		win_const_mgr.add_const('RPC_S_GROUP_MEMBER_NOT_FOUND',0x0000076A)
		win_const_mgr.add_const('SMTO_BLOCK',0x00000001)
		win_const_mgr.add_const('VK_DBE_ROMAN',0x00000000)
		win_const_mgr.add_const('JOB_STATUS_PRINTING',0x00000010)
		win_const_mgr.add_const('WM_WTSSESSION_CHANGE',0x000002B1)
		win_const_mgr.add_const('TVS_TRACKSELECT',0x00000200)
		win_const_mgr.add_const('ERROR_ASSERTION_FAILURE',0x0000029C)
		win_const_mgr.add_const('DEBUG_OUTPUT_DEBUGGEE',0x00000080)
		win_const_mgr.add_const('CERT_DSS_R_LEN',0x00000014)
		win_const_mgr.add_const('CERT_DATA_ENCIPHERMENT_KEY_USAGE',0x00000010)
		win_const_mgr.add_const('IDM_COLUMNINSERT',0x000008A5)
		win_const_mgr.add_const('PHONEHOOKSWITCHMODE_MIC',0x00000002)
		win_const_mgr.add_const('DISPID_ONBLUR',0x0000000F)
		win_const_mgr.add_const('ERROR_I24_SECTOR_NOT_FOUND',0x00000008)
		win_const_mgr.add_const('XP_CONNECT_DATA',0x00000080)
		win_const_mgr.add_const('SDP_ATTRIB_PAN_WAP_GATEWAY',0x00000307)
		win_const_mgr.add_const('SO_SYNCHRONOUS_ALERT',0x00000010)
		win_const_mgr.add_const('DFM_GETVERBW',0x0000000F)
		win_const_mgr.add_const('PST_SCANNER',0x00000022)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_PRODUCTREVISION',0x00000203)
		win_const_mgr.add_const('TF_SENTENCEMODE_PHRASEPREDICT',0x00000008)
		win_const_mgr.add_const('FRS_ERR_SERVICE_COMM',0x00001F46)
		win_const_mgr.add_const('DFM_GETVERBA',0x00000010)
		win_const_mgr.add_const('SQL_OAC_NONE',0x00000000)
		win_const_mgr.add_const('CPL_STOP',0x00000006)
		win_const_mgr.add_const('DEVPROP_TYPE_UINT16',0x00000005)
		win_const_mgr.add_const('IDS_CAP_RECORDING_ERROR',0x000001AF)
		win_const_mgr.add_const('TAPE_DRIVE_FORMAT_IMMEDIATE',0xC0000000)
		win_const_mgr.add_const('SPFILENOTIFY_QUEUESCAN',0x00000000)
		win_const_mgr.add_const('GC_WCH_FONLYAFTER',0x10000000)
		win_const_mgr.add_const('LINEFEATURE_MAKECALL',0x00000008)
		win_const_mgr.add_const('LINEERR_INVALADDRESSID',0x80000011)
		win_const_mgr.add_const('FIEF_FLAG_FORCE_JITUI',0x00000001)
		win_const_mgr.add_const('ACM_FORMATSUGGESTF_NSAMPLESPERSEC',0x00040000)
		win_const_mgr.add_const('SQL_FN_TD_CURTIME',0x00000200)
		win_const_mgr.add_const('BATTERY_UNKNOWN_RATE',0x80000000)
		win_const_mgr.add_const('ERROR_GROUP_EXISTS',0x00000526)
		win_const_mgr.add_const('SQL_DD_RESTRICT',0x00000002)
		win_const_mgr.add_const('RPC_BUFFER_PARTIAL',0x00002000)
		win_const_mgr.add_const('SSF_HIDDENFILEEXTS',0x00000004)
		win_const_mgr.add_const('POWER_ATTRIBUTE_HIDE',0x00000001)
		win_const_mgr.add_const('LINECALLINFOSTATE_TRUNK',0x00004000)
		win_const_mgr.add_const('WINHTTP_OPTION_UNLOAD_NOTIFY_EVENT',0x00000063)
		win_const_mgr.add_const('MAPI_PW_LAUNCHED_BY_CONFIG',0x00000002)
		win_const_mgr.add_const('IF_TYPE_H323_PROXY',0x000000A5)
		win_const_mgr.add_const('TAPE_DRIVE_LOCK_UNLK_IMMED',0x80000080)
		win_const_mgr.add_const('ISCSI_LOGIN_FLAG_USE_RADIUS_VERIFICATION',0x00000020)
		win_const_mgr.add_const('ERROR_SAME_DRIVE',0x0000008F)
		win_const_mgr.add_const('KS_NABTS_GROUPID_LOCAL_CABLE_SYSTEM_ADVERTISER_BASE',0x000008B0)
		win_const_mgr.add_const('WIN_CERT_TYPE_TS_STACK_SIGNED',0x00000004)
		win_const_mgr.add_const('ERROR_DS_SECURITY_CHECKING_ERROR',0x000020DD)
		win_const_mgr.add_const('DB_DISP_ACTIVE',0x00000008)
		win_const_mgr.add_const('CWP_SKIPTRANSPARENT',0x00000004)
		win_const_mgr.add_const('PP_KEY_TYPE_SUBTYPE',0x0000000A)
		win_const_mgr.add_const('DIF_INSTALLINTERFACES',0x00000020)
		win_const_mgr.add_const('ERROR_SXS_XML_E_MISSINGROOT',0x000036E9)
		win_const_mgr.add_const('RTL_CONDITION_VARIABLE_LOCKMODE_SHARED',0x00000001)
		win_const_mgr.add_const('EC_SEGMENT_STARTED',0x0000001D)
		win_const_mgr.add_const('ERROR_INVALID_TIME',0x0000076D)
		win_const_mgr.add_const('CMSG_KEY_AGREE_ENCRYPT_FREE_PUBKEY_ALG_FLAG',0x00000004)
		win_const_mgr.add_const('KLF_REPLACELANG',0x00000010)
		win_const_mgr.add_const('ERROR_DS_NOT_AN_OBJECT',0x000020A0)
		win_const_mgr.add_const('WMS_CONTAINER_ONDEMAND_PLAYLIST_EMULATING_BCAST',0x00000040)
		win_const_mgr.add_const('EXCHIVERB_SAVEAS',0x0000006A)
		win_const_mgr.add_const('RBN_LAST',0x00000000)
		win_const_mgr.add_const('N_TMASK1',0x000000C0)
		win_const_mgr.add_const('DOSOPTF_INDOSSTART',0x00000040)
		win_const_mgr.add_const('ERROR_CLUSTER_JOIN_IN_PROGRESS',0x000013B1)
		win_const_mgr.add_const('N_TMASK2',0x000000F0)
		win_const_mgr.add_const('PIDSI_CHARCOUNT',0x00000010)
		win_const_mgr.add_const('SDP_ATTRIB_OBJECT_PUSH_SUPPORTED_FORMATS_LIST',0x00000303)
		win_const_mgr.add_const('SQL_API_SQLCOPYDESC',0x000003EC)
		win_const_mgr.add_const('EV_EVENT1',0x00000800)
		win_const_mgr.add_const('WINEVENT_KEYWORD_WDI_CONTEXT',0x2000000000000)
		win_const_mgr.add_const('DEBUG_DISASM_MATCHING_SYMBOLS',0x00000002)
		win_const_mgr.add_const('EV_EVENT2',0x00001000)
		win_const_mgr.add_const('WMPCOREEVENT_CONTROL_BASE',0x000013EC)
		win_const_mgr.add_const('ERROR_DS_OFFSET_RANGE_ERROR',0x00002046)
		win_const_mgr.add_const('PID_LINK_TARGET_TYPE',0x00000003)
		win_const_mgr.add_const('PDH_INVALID_SQLDB',0xC0000BDE)
		win_const_mgr.add_const('OID_FDDI_MAC_LONG_GRP_ADDRESS',0x0303022E)
		win_const_mgr.add_const('RPC_S_WRONG_KIND_OF_BINDING',0x000006A5)
		win_const_mgr.add_const('DI_FLAGSEX_NO_DRVREG_MODIFY',0x00008000)
		win_const_mgr.add_const('CTRY_ALBANIA',0x00000163)
		win_const_mgr.add_const('IPPORT_SNMP',0x000000A1)
		win_const_mgr.add_const('MAPI_E_NOT_SUPPORTED',0x0000001A)
		win_const_mgr.add_const('KS_DVD_COPYRIGHT_MASK',0x00000040)
		win_const_mgr.add_const('FACILITY_WINDOWS',0x00000008)
		win_const_mgr.add_const('GCPCLASS_NUMERICSEPARATOR',0x00000008)
		win_const_mgr.add_const('MCI_GETDEVCAPS_HAS_VIDEO',0x00000003)
		win_const_mgr.add_const('ERROR_CORE_RESOURCE',0x000013A2)
		win_const_mgr.add_const('IF_TYPE_SIP',0x0000001F)
		win_const_mgr.add_const('SOFTDIST_FLAG_USAGE_PRECACHE',0x00000002)
		win_const_mgr.add_const('MCI_DGV_FREEZE_AT',0x00010000)
		win_const_mgr.add_const('ED_AUDIO_18',0x00020000)
		win_const_mgr.add_const('TABLET_DISABLE_FLICKS',0x00010000)
		win_const_mgr.add_const('WN_NETWORK_CLASS',0x00000001)
		win_const_mgr.add_const('RP_EXPANDED',0x00002010)
		win_const_mgr.add_const('EVENTLOG_FULL_INFO',0x00000000)
		win_const_mgr.add_const('LINETERMDEV_HEADSET',0x00000002)
		win_const_mgr.add_const('CLCTL_CLUSTER_BASE',0x00000000)
		win_const_mgr.add_const('BG_S_PARTIAL_COMPLETE',0x00200017)
		win_const_mgr.add_const('PERF_DELTA_BASE',0x00800000)
		win_const_mgr.add_const('IDM_GOFORWARD',0x000008EB)
		win_const_mgr.add_const('VK_HANGUL',0x00000015)
		win_const_mgr.add_const('SP_DATABITS',0x00000004)
		win_const_mgr.add_const('ASC_REQ_DATAGRAM',0x00000400)
		win_const_mgr.add_const('ERROR_IMAGE_NOT_AT_BASE',0x000002BC)
		win_const_mgr.add_const('OID_802_5_PERMANENT_ADDRESS',0x02010101)
		win_const_mgr.add_const('SQL_AD_ADD_CONSTRAINT_INITIALLY_DEFERRED',0x00000020)
		win_const_mgr.add_const('CMSG_UNPROTECTED_ATTR_PARAM',0x00000025)
		win_const_mgr.add_const('MCSC_TRAILINGTEXT',0x00000005)
		win_const_mgr.add_const('SSF_SHOWALLOBJECTS',0x00000001)
		win_const_mgr.add_const('CTL_FIND_SUBJECT',0x00000004)
		win_const_mgr.add_const('SMART_INVALID_DRIVE',0x00000005)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_COLUMNS',0x00000004)
		win_const_mgr.add_const('VFT2_DRV_MOUSE',0x00000005)
		win_const_mgr.add_const('ED_AUDIO_11',0x00000400)
		win_const_mgr.add_const('USER_NORMAL_ACCOUNT',0x00000010)
		win_const_mgr.add_const('D3DDMAPSAMPLER',0x00000100)
		win_const_mgr.add_const('ERROR_IO_DEVICE',0x0000045D)
		win_const_mgr.add_const('WSAEADDRINUSE',0x00002740)
		win_const_mgr.add_const('CRYPT_DOMAIN',0x00000002)
		win_const_mgr.add_const('HTTP_CREATE_REQUEST_QUEUE_FLAG_CONTROLLER',0x00000002)
		win_const_mgr.add_const('DEBUG_PHYSICAL_CACHED',0x00000001)
		win_const_mgr.add_const('IMAGE_SCN_GPREL',0x00008000)
		win_const_mgr.add_const('SUBLANG_SPANISH_BOLIVIA',0x00000010)
		win_const_mgr.add_const('IDB_HIST_PRESSED',0x0000000F)
		win_const_mgr.add_const('FOFX_DONTDISPLAYDESTPATH',0x08000000)
		win_const_mgr.add_const('PRINTER_STATUS_PAPER_PROBLEM',0x00000040)
		win_const_mgr.add_const('DNS_ERROR_NO_DNS_SERVERS',0x0000267C)
		win_const_mgr.add_const('E_SURFACE_NOTMYDC',0x8000C005)
		win_const_mgr.add_const('ERROR_DOWNGRADE_DETECTED',0x000004F1)
		win_const_mgr.add_const('RBBIM_TEXT',0x00000004)
		win_const_mgr.add_const('LVKF_ALT',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_ENUM_TAG',0x0000000F)
		win_const_mgr.add_const('WIA_DPC_EXPOSURE_COMP',0x00000805)
		win_const_mgr.add_const('CRYPT_OID_PUBKEY_SIGN_ONLY_FLAG',0x80000000)
		win_const_mgr.add_const('LINETONEMODE_CUSTOM',0x00000001)
		win_const_mgr.add_const('LINECALLFEATURE2_COMPLINTRUDE',0x00000010)
		win_const_mgr.add_const('SV_MAXPAGEDMEMORYUSAGE_PARMNUM',0x00000201)
		win_const_mgr.add_const('DSOP_FILTER_COMPUTERS',0x00000800)
		win_const_mgr.add_const('DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER',0x0000255A)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2_BYTESPERSECTOR',0x00000104)
		win_const_mgr.add_const('IMAGE_REL_M32R_REFHALF',0x00000008)
		win_const_mgr.add_const('CERT_CLOSE_STORE_CHECK_FLAG',0x00000002)
		win_const_mgr.add_const('IIS_MD_SERVER_BASE',0x000003E8)
		win_const_mgr.add_const('TLS1_ALERT_FATAL',0x00000002)
		win_const_mgr.add_const('RIDEV_INPUTSINK',0x00000100)
		win_const_mgr.add_const('COD_LAN_ACCESS_FULL',0x00000007)
		win_const_mgr.add_const('CRED_PACK_PROTECTED_CREDENTIALS',0x00000001)
		win_const_mgr.add_const('WIA_DPC_RGB_GAIN',0x00000828)
		win_const_mgr.add_const('IMAGE_SCN_MEM_READ',0x40000000)
		win_const_mgr.add_const('WIA_DIP_DEV_DESC',0x00000004)
		win_const_mgr.add_const('PIDSI_YEAR',0x00000005)
		win_const_mgr.add_const('DBPROMPT_COMPLETEREQUIRED',0x00000003)
		win_const_mgr.add_const('MCI_VD_PLAY_REVERSE',0x00010000)
		win_const_mgr.add_const('LOCALE_ITIMEMARKPOSN',0x00001005)
		win_const_mgr.add_const('CHECKSUM_UNICODE_FAILURE',0x00000004)
		win_const_mgr.add_const('SCARD_F_WAITED_TOO_LONG',0x80100007)
		win_const_mgr.add_const('CSCONFIGFLAG_DO_NOT_CREATE',0x00000002)
		win_const_mgr.add_const('PRINTER_CHANGE_CONFIGURE_PORT',0x00200000)
		win_const_mgr.add_const('CTRY_SPAIN',0x00000022)
		win_const_mgr.add_const('SDP_ERROR_INVALID_SDP_VERSION',0x00000001)
		win_const_mgr.add_const('CC_WIDE',0x00000010)
		win_const_mgr.add_const('DB_PT_PROCEDURE',0x00000002)
		win_const_mgr.add_const('RPCFLG_NON_NDR',0x80000000)
		win_const_mgr.add_const('DIRID_SYSTEM',0x0000000B)
		win_const_mgr.add_const('KAGPROP_FORCESSFIREHOSEMODE',0x0000000A)
		win_const_mgr.add_const('WMS_STREAM_FLAGS',0x00000007)
		win_const_mgr.add_const('TYMED_MULTIPAGE_FILE',0x00000100)
		win_const_mgr.add_const('DRAFT_QUALITY',0x00000001)
		win_const_mgr.add_const('SUBLANG_SPANISH_VENEZUELA',0x00000008)
		win_const_mgr.add_const('SQL_PERF_STOP',0x00000002)
		win_const_mgr.add_const('ASC_REQ_USE_SESSION_KEY',0x00000020)
		win_const_mgr.add_const('DDBLT_ZBUFFERDESTOVERRIDE',0x00200000)
		win_const_mgr.add_const('HSHELL_LANGUAGE',0x00000008)
		win_const_mgr.add_const('SECPKG_FLAG_TOKEN_ONLY',0x00000004)
		win_const_mgr.add_const('SHCNE_EXTENDED_EVENT',0x04000000)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_MOVETO',0x00000006)
		win_const_mgr.add_const('SYMF_EXPORT',0x00000200)
		win_const_mgr.add_const('SQL_IK_ASC',0x00000001)
		win_const_mgr.add_const('DMPAPER_JENV_KAKU3_ROTATED',0x00000055)
		win_const_mgr.add_const('MD_EXTLOG_WIN32_STATUS',0x00000800)
		win_const_mgr.add_const('JPEG_PROCESS_BASELINE',0x00000000)
		win_const_mgr.add_const('LC_WIDE',0x00000010)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_WORD',0x0000000D)
		win_const_mgr.add_const('DBPROP_IGNORESBRI',0x0000000E)
		win_const_mgr.add_const('PF_PPC_MOVEMEM_64BIT_OK',0x00000004)
		win_const_mgr.add_const('CR_PROP_FILEVERSION',0x00000001)
		win_const_mgr.add_const('WKSTA_LOGON_DOMAIN_PARMNUM',0x00000008)
		win_const_mgr.add_const('CRLF_SAVE_FAILED_CERTS',0x00000040)
		win_const_mgr.add_const('CF_DSPENHMETAFILE',0x0000008E)
		win_const_mgr.add_const('CM_ADD_ID_BITS',0x00000001)
		win_const_mgr.add_const('D3D10_EFFECT_SINGLE_THREADED',0x00000001)
		win_const_mgr.add_const('PID_IS_URL',0x00000002)
		win_const_mgr.add_const('TMT_ICONEFFECT',0x00000FA9)
		win_const_mgr.add_const('SS_ICON',0x00000003)
		win_const_mgr.add_const('DNS_ERROR_PRIMARY_REQUIRES_DATAFILE',0x000025B3)
		win_const_mgr.add_const('ALG_SID_EXAMPLE',0x00000050)
		win_const_mgr.add_const('FEATURESETTING_PRIVATE_BEGIN',0x00001000)
		win_const_mgr.add_const('DNS_QUERY_NO_RECURSION',0x00000004)
		win_const_mgr.add_const('PC_WIDESTYLED',0x00000040)
		win_const_mgr.add_const('TF_SFT_DOCK',0x00000002)
		win_const_mgr.add_const('MOD_MIDIPORT',0x00000001)
		win_const_mgr.add_const('ISC_REQ_EXTENDED_ERROR',0x00004000)
		win_const_mgr.add_const('RC_STRETCHDIB',0x00002000)
		win_const_mgr.add_const('OID_ATM_LECS_ADDRESS',0x08010209)
		win_const_mgr.add_const('DN_HARDWARE_ENUM',0x00000080)
		win_const_mgr.add_const('FACILITY_DIRECTORYSERVICE',0x00000025)
		win_const_mgr.add_const('NI_MAXHOST',0x00000401)
		win_const_mgr.add_const('DDSCAPS_OPTIMIZED',0x80000000)
		win_const_mgr.add_const('WINHTTP_QUERY_REFERER',0x00000023)
		win_const_mgr.add_const('KS_NABTS_GROUPID_TELEVISION_STATION_CONTENT_BASE',0x00000880)
		win_const_mgr.add_const('SRRF_RT_REG_SZ',0x00000002)
		win_const_mgr.add_const('UNPROTECTED_SACL_SECURITY_INFORMATION',0x10000000)
		win_const_mgr.add_const('WT_EXECUTEINIOTHREAD',0x00000001)
		win_const_mgr.add_const('IDC_GP_CONVERT',0x000003F5)
		win_const_mgr.add_const('S_PERIOD1024',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLPUTDATA',0x00000031)
		win_const_mgr.add_const('SQL_MAX_OPTION_STRING_LENGTH',0x00000100)
		win_const_mgr.add_const('CREDP_FLAGS_DONT_CACHE_TI',0x00000004)
		win_const_mgr.add_const('D3DUSAGE_DMAP',0x00004000)
		win_const_mgr.add_const('LOCKF_PHYSICAL_LOCK',0x00000001)
		win_const_mgr.add_const('VHDR_VALID',0x0000000F)
		win_const_mgr.add_const('DDBD_2',0x00002000)
		win_const_mgr.add_const('TVIS_BOLD',0x00000010)
		win_const_mgr.add_const('IS_TEXT_UNICODE_REVERSE_SIGNATURE',0x00000080)
		win_const_mgr.add_const('DDBD_8',0x00000800)
		win_const_mgr.add_const('SQL_SC_SQL92_ENTRY',0x00000001)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_LSOV2_ENABLED',0x00000002)
		win_const_mgr.add_const('DI_REMOVEDEVICE_GLOBAL',0x00000001)
		win_const_mgr.add_const('ASC_REQ_REPLAY_DETECT',0x00000004)
		win_const_mgr.add_const('SWP_NOSENDCHANGING',0x00000400)
		win_const_mgr.add_const('SQL_MAX_QUALIFIER_NAME_LEN',0x00000022)
		win_const_mgr.add_const('INPUTLANGCHANGE_FORWARD',0x00000002)
		win_const_mgr.add_const('WM_SETCURSOR',0x00000020)
		win_const_mgr.add_const('MAPVK_VK_TO_VSC',0x00000000)
		win_const_mgr.add_const('WMDM_CONTENT_OPERATIONINTERFACE',0x00000010)
		win_const_mgr.add_const('SI_NO_ACL_PROTECT',0x00000200)
		win_const_mgr.add_const('IME_ENTERWORDREGISTERMODE',0x00000018)
		win_const_mgr.add_const('MCI_VCR_RECORD_PREVIEW',0x00040000)
		win_const_mgr.add_const('MIXERCONTROL_CT_SC_METER_POLLED',0x00000000)
		win_const_mgr.add_const('PARTTYPE_FLAG_CONNECTOR',0x00010000)
		win_const_mgr.add_const('SECPKGCONTEXT_CIPHERINFO_V1',0x00000001)
		win_const_mgr.add_const('LUP_NON_AUTHORITATIVE',0x00004000)
		win_const_mgr.add_const('GCP_USEKERNING',0x00000008)
		win_const_mgr.add_const('SORT_HUNGARIAN_TECHNICAL',0x00000001)
		win_const_mgr.add_const('SQL_DIAG_RETURNCODE',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_RGB',0x00004001)
		win_const_mgr.add_const('DNS_RCODE_BADSIG',0x00000010)
		win_const_mgr.add_const('BCP_FMT_DATA_LEN',0x00000003)
		win_const_mgr.add_const('ICQUALITY_LOW',0x00000000)
		win_const_mgr.add_const('REGDB_S_LAST',0x0004015F)
		win_const_mgr.add_const('MD_ERROR_SUB500_BAD_METADATA',0x00000013)
		win_const_mgr.add_const('SERVER_ACCESS_ENUMERATE',0x00000002)
		win_const_mgr.add_const('VCSTATUS_COPY',0x00020000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR',0x000035EC)
		win_const_mgr.add_const('PDH_CSTATUS_INVALID_DATA',0xC0000BBA)
		win_const_mgr.add_const('SV_TYPE_TERMINALSERVER',0x02000000)
		win_const_mgr.add_const('ACMDRIVERDETAILS_LICENSING_CHARS',0x00000080)
		win_const_mgr.add_const('MWMO_INPUTAVAILABLE',0x00000004)
		win_const_mgr.add_const('DEBUG_USER_WINDOWS_PROCESS_SERVER',0x00000001)
		win_const_mgr.add_const('SUBLANG_FINNISH_FINLAND',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_TI_REPEATABLEREAD',0x00010000)
		win_const_mgr.add_const('CERT_FIRST_RESERVED_PROP_ID',0x00000055)
		win_const_mgr.add_const('SRCLIST_SYSIFADMIN',0x00000040)
		win_const_mgr.add_const('MAPI_SIMPLE_STORE_PERMANENT',0x00000003)
		win_const_mgr.add_const('CRL_FIND_ISSUED_BY_DELTA_FLAG',0x00000004)
		win_const_mgr.add_const('ERROR_BASE',0x000059D8)
		win_const_mgr.add_const('PAGEMASK_16MB',0x00000000)
		win_const_mgr.add_const('SERVICE_NOTIFY_DELETE_PENDING',0x00000200)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_FLAG_CERT_CN_INVALID',0x00000010)
		win_const_mgr.add_const('OLECMDARGINDEX_SHOWPAGEACTIONMENU_X',0x00000001)
		win_const_mgr.add_const('USER_ALL_PARAMETERS',0x00200000)
		win_const_mgr.add_const('WKSTA_VER_MAJOR_PARMNUM',0x00000004)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_QUALITY',0x00010000)
		win_const_mgr.add_const('BSF_DONTSHOWNAVCANCELPAGE',0x00004000)
		win_const_mgr.add_const('CTRY_CROATIA',0x00000181)
		win_const_mgr.add_const('HTTP_SEND_RESPONSE_FLAG_ENABLE_NAGLING',0x00000008)
		win_const_mgr.add_const('CTL_MODIFY_REQUEST_ADD_TRUSTED',0x00000003)
		win_const_mgr.add_const('NTDSCONN_OPT_USER_OWNED_SCHEDULE',0x00000001)
		win_const_mgr.add_const('WMPGC_FLAGS_SUPPRESS_DIALOGS',0x00000002)
		win_const_mgr.add_const('SV_THREADPRIORITY_PARMNUM',0x00000214)
		win_const_mgr.add_const('COD_PERIPHERAL_MINOR_JOYSTICK',0x00000001)
		win_const_mgr.add_const('INTERNET_CUSTOMDIAL_CAN_HANGUP',0x00000004)
		win_const_mgr.add_const('AW_HIDE',0x00010000)
		win_const_mgr.add_const('EM_GETMARGINS',0x000000D4)
		win_const_mgr.add_const('HELP_SETWINPOS',0x00000203)
		win_const_mgr.add_const('SQL_COLUMN_NULLABLE',0x00000007)
		win_const_mgr.add_const('CDO_E_BAD_TASKTYPE_ONASSIGN',0x80040237)
		win_const_mgr.add_const('NTM_MULTIPLEMASTER',0x00080000)
		win_const_mgr.add_const('ERROR_DS_DRA_SOURCE_DISABLED',0x00002108)
		win_const_mgr.add_const('TRACE_MESSAGE_SYSTEMINFO',0x00000020)
		win_const_mgr.add_const('CM_REGISTRY_SOFTWARE',0x00000001)
		win_const_mgr.add_const('LINECALLTREATMENT_SILENCE',0x00000001)
		win_const_mgr.add_const('UDS_ALIGNRIGHT',0x00000004)
		win_const_mgr.add_const('NRC_CANOCCR',0x00000024)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNEXPECTEDEOF',0x000036EA)
		win_const_mgr.add_const('VS_FF_PATCHED',0x00000004)
		win_const_mgr.add_const('MIB_IF_TYPE_LOOPBACK',0x00000018)
		win_const_mgr.add_const('BCPKEEPIDENTITY',0x00000008)
		win_const_mgr.add_const('IF_TYPE_V11',0x00000040)
		win_const_mgr.add_const('IMAGE_REL_SH3_DIRECT8_WORD',0x00000004)
		win_const_mgr.add_const('DBPROPVAL_BMK_KEY',0x00000002)
		win_const_mgr.add_const('X3_IMM39_2_SIGN_VAL_POS_X',0x00000014)
		win_const_mgr.add_const('MCI_WAVE_SET_FORMATTAG',0x00010000)
		win_const_mgr.add_const('DBPROPVAL_HT_DIFFERENT_PROVIDERS',0x00000002)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG15',0x00000000)
		win_const_mgr.add_const('MARKPARITY',0x00000003)
		win_const_mgr.add_const('LOCALE_SSHORTESTDAYNAME4',0x00000063)
		win_const_mgr.add_const('LOCALE_SSHORTESTDAYNAME3',0x00000062)
		win_const_mgr.add_const('DNS_ERROR_DP_NOT_ENLISTED',0x000026AF)
		win_const_mgr.add_const('LOCALE_SSHORTESTDAYNAME1',0x00000060)
		win_const_mgr.add_const('CAUSE_RESOURCE_UNAVAILABLE',0x0000002F)
		win_const_mgr.add_const('D3DCREATE_PUREDEVICE',0x00000010)
		win_const_mgr.add_const('IR_STRINGEX',0x00000180)
		win_const_mgr.add_const('LINEERR_DIALPROMPT',0x8000000A)
		win_const_mgr.add_const('CM_DRP_MAX',0x00000024)
		win_const_mgr.add_const('RPC_IF_ALLOW_UNKNOWN_AUTHORITY',0x00000004)
		win_const_mgr.add_const('KS_VIDEOSTREAM_VBI',0x00000010)
		win_const_mgr.add_const('VER_SUITE_TERMINAL',0x00000010)
		win_const_mgr.add_const('RPC_C_HTTP_FLAG_USE_FIRST_AUTH_SCHEME',0x00000002)
		win_const_mgr.add_const('SQL_CS_CREATE_SCHEMA',0x00000001)
		win_const_mgr.add_const('SQL_ALL_TYPES',0x00000000)
		win_const_mgr.add_const('AVISTREAMINFO_FORMATCHANGES',0x00010000)
		win_const_mgr.add_const('UDS_AUTOBUDDY',0x00000010)
		win_const_mgr.add_const('MCI_ANIM_STEP_REVERSE',0x00010000)
		win_const_mgr.add_const('C1_UPPER',0x00000001)
		win_const_mgr.add_const('EC_UNBUILT',0x00000301)
		win_const_mgr.add_const('WIA_LAMP_OFF',0x00000001)
		win_const_mgr.add_const('SQL_DTC_TRANSITION_COST',0x000006D6)
		win_const_mgr.add_const('LDAP_OPT_CACHE_ENABLE',0x00000000)
		win_const_mgr.add_const('CACHE_ENTRY_SYNCTIME_FC',0x00000200)
		win_const_mgr.add_const('ETW_DOUBLE_TYPE_VALUE',0x0000000D)
		win_const_mgr.add_const('MCI_DGV_UPDATE_PAINT',0x00040000)
		win_const_mgr.add_const('SQL_DTR_DROP_TRANSLATION',0x00000001)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG12',0x00000000)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_SOFTWARE_UPDATE',0x00000000)
		win_const_mgr.add_const('MCI_DGV_CAPTURE_AT',0x00020000)
		win_const_mgr.add_const('MD_WARNING_INVALID_DATA',0x000CC805)
		win_const_mgr.add_const('ERROR_I24_BAD_COMMAND',0x00000003)
		win_const_mgr.add_const('SQL_AT_DROP_TABLE_CONSTRAINT_RESTRICT',0x00004000)
		win_const_mgr.add_const('JIFMK_APP5',0x0000FFE5)
		win_const_mgr.add_const('CERT_NAME_STR_ENABLE_T61_UNICODE_FLAG',0x00020000)
		win_const_mgr.add_const('ACM_STREAMOPENF_QUERY',0x00000001)
		win_const_mgr.add_const('DCOMSCM_RESOLVE_DISALLOW_UNSECURE_CALL',0x00000008)
		win_const_mgr.add_const('IDCONTINUE',0x0000000B)
		win_const_mgr.add_const('FC_ALLOCATE_ALL_NODES',0x00000001)
		win_const_mgr.add_const('EN_ALIGN_LTR_EC',0x00000700)
		win_const_mgr.add_const('IOC_WS2',0x08000000)
		win_const_mgr.add_const('RPC_S_COMM_FAILURE',0x0000071C)
		win_const_mgr.add_const('TXTLOG_DRIVER_STORE',0x04000000)
		win_const_mgr.add_const('TMT_IMAGEFILE',0x00000BB9)
		win_const_mgr.add_const('BTH_ADDR_GIAC',0x009E8B33)
		win_const_mgr.add_const('ATA_FLAGS_DRDY_REQUIRED',0x00000001)
		win_const_mgr.add_const('MF_DELETE',0x00000200)
		win_const_mgr.add_const('GMEM_DDESHARE',0x00002000)
		win_const_mgr.add_const('WAM_MD_SERVER_BASE',0x00001D4C)
		win_const_mgr.add_const('ODBC_ERROR_USAGE_UPDATE_FAILED',0x00000011)
		win_const_mgr.add_const('DBG_STACKFAULT',0x00000010)
		win_const_mgr.add_const('ERROR_RESOURCE_LANG_NOT_FOUND',0x00000717)
		win_const_mgr.add_const('EC_STATE_CHANGE',0x00000032)
		win_const_mgr.add_const('KEYEVENTF_UNICODE',0x00000004)
		win_const_mgr.add_const('IF_ENFORCEENCRYPTICERTREQUEST',0x00000200)
		win_const_mgr.add_const('TXTBIT_AUTOWORDSEL',0x00000080)
		win_const_mgr.add_const('ERROR_READ_FAULT',0x0000001E)
		win_const_mgr.add_const('HIST_FORWARD',0x00000001)
		win_const_mgr.add_const('FILE_DEVICE_NETWORK_FILE_SYSTEM',0x00000014)
		win_const_mgr.add_const('IDM_OVERWRITE',0x0000090A)
		win_const_mgr.add_const('MSV1_0_VALIDATION_LOGON_SERVER',0x00000004)
		win_const_mgr.add_const('CERT_STORE_PROV_CLOSE_FUNC',0x00000000)
		win_const_mgr.add_const('DISPID_DOWNLOADBEGIN',0x0000006A)
		win_const_mgr.add_const('SQL_CA1_NEXT',0x00000001)
		win_const_mgr.add_const('PRINTER_STATUS_PROCESSING',0x00004000)
		win_const_mgr.add_const('SPI_SETDOUBLECLKWIDTH',0x0000001D)
		win_const_mgr.add_const('IPDFP_COPY_ALL_FILES',0x00000001)
		win_const_mgr.add_const('TRANSPARENCY_DYNAMIC_FRAME_SUPPORT',0x00000001)
		win_const_mgr.add_const('DISPLAYDIB_INVALIDDIB',0x00000002)
		win_const_mgr.add_const('CAL_KOREA',0x00000005)
		win_const_mgr.add_const('ERROR_DS_NO_REF_DOMAIN',0x0000217F)
		win_const_mgr.add_const('CS_PARENTDC',0x00000080)
		win_const_mgr.add_const('SSA_BREAK',0x00000040)
		win_const_mgr.add_const('FILE_DEVICE_NETWORK_REDIRECTOR',0x00000028)
		win_const_mgr.add_const('WEBPOST_ERROR_EXTENDED_ERROR',0xC0042116)
		win_const_mgr.add_const('INTERNET_CACHE_CONTAINER_AUTODELETE',0x00000002)
		win_const_mgr.add_const('KERB_CHECKSUM_MD5',0x00000007)
		win_const_mgr.add_const('KERB_CHECKSUM_MD4',0x00000002)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_MAINTENANCE',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_DF_INITIALLY_IMMEDIATE',0x00000002)
		win_const_mgr.add_const('DEBUG_OUTPUT_PROMPT',0x00000010)
		win_const_mgr.add_const('HLNF_TRUSTFIRSTDOWNLOAD',0x01000000)
		win_const_mgr.add_const('LINEAGENTFEATURE_AGENTSPECIFIC',0x00000008)
		win_const_mgr.add_const('SO_USELOOPBACK',0x00000040)
		win_const_mgr.add_const('HSHELL_GETMINRECT',0x00000005)
		win_const_mgr.add_const('REGISTERING',0x00000000)
		win_const_mgr.add_const('CSIDL_LOCAL_APPDATA',0x00000001)
		win_const_mgr.add_const('LANG_MALTESE',0x00000003)
		win_const_mgr.add_const('MCI_GETDEVCAPS_CAN_EJECT',0x00000007)
		win_const_mgr.add_const('CRYPT_DECODE_NO_SIGNATURE_BYTE_REVERSAL_FLAG',0x00000008)
		win_const_mgr.add_const('WLX_SAS_ACTION_SWITCH_CONSOLE',0x00000011)
		win_const_mgr.add_const('AUDCLNT_STREAMFLAGS_NOPERSIST',0x00080000)
		win_const_mgr.add_const('SFVM_GETBUTTONINFO',0x00000005)
		win_const_mgr.add_const('SAP_BIT_OFFSET',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_IA64_IMMGPREL64',0x0000001A)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_UNAUTH_USER_FLOW_DURATION',0x0000000C)
		win_const_mgr.add_const('LINEFORWARDMODE_BUSYNAEXTERNAL',0x00004000)
		win_const_mgr.add_const('SETCHARSET',0x00000304)
		win_const_mgr.add_const('SLE_WARNING',0x00000003)
		win_const_mgr.add_const('WIA_DPS_VERTICAL_BED_SIZE',0x00000C03)
		win_const_mgr.add_const('PF_SSE_DAZ_MODE_AVAILABLE',0x0000000B)
		win_const_mgr.add_const('SBSP_CALLERUNTRUSTED',0x00800000)
		win_const_mgr.add_const('XP1_DISCONNECT_DATA',0x00000100)
		win_const_mgr.add_const('TRUSTERROR_STEP_FINAL_POLICYPROV',0x00000024)
		win_const_mgr.add_const('BN_DOUBLECLICKED',0x00000005)
		win_const_mgr.add_const('EM_SETHANDLE',0x000000BC)
		win_const_mgr.add_const('DDOSDCAPS_VALIDSCAPS',0x30004800)
		win_const_mgr.add_const('MCMV_CENTURY',0x00000003)
		win_const_mgr.add_const('IMAGE_REL_SHM_RELHALF',0x00000017)
		win_const_mgr.add_const('COLOR_BACKGROUND',0x00000001)
		win_const_mgr.add_const('IACE_CHILDREN',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_UNKNOWN_ENCODING',0x000036BD)
		win_const_mgr.add_const('NCBADDNAME',0x00000030)
		win_const_mgr.add_const('PS_SHIFT',0x00000002)
		win_const_mgr.add_const('OLEUI_ERR_DIALOGFAILURE',0x00000070)
		win_const_mgr.add_const('MC_CAPS_NONE',0x00000000)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_INTERCOM',0x0000001B)
		win_const_mgr.add_const('TRANSACTION_SAVEPOINT',0x00000040)
		win_const_mgr.add_const('CRYPT_NDR_ENCODING',0x00000002)
		win_const_mgr.add_const('SQL_FN_STR_LEFT',0x00000004)
		win_const_mgr.add_const('RESOURCETYPE_DISK',0x00000001)
		win_const_mgr.add_const('TT_POLYGON_TYPE',0x00000018)
		win_const_mgr.add_const('ERROR_DS_UNAVAILABLE',0x0000200F)
		win_const_mgr.add_const('ERROR_PAGEFILE_QUOTA_EXCEEDED',0x00000237)
		win_const_mgr.add_const('CLFS_SCAN_FORWARD',0x00000002)
		win_const_mgr.add_const('CRYPT_VERIFY_CERT_SIGN_SUBJECT_OCSP_BASIC_SIGNED_RESPONSE',0x00000004)
		win_const_mgr.add_const('DEBUG_GET_PROC_SERVICE_NAME',0x00000004)
		win_const_mgr.add_const('WMAUDIO_BITS_PER_SAMPLE',0x00000010)
		win_const_mgr.add_const('EMR_CREATEPALETTE',0x00000031)
		win_const_mgr.add_const('WM_NCMBUTTONDBLCLK',0x000000A9)
		win_const_mgr.add_const('DDSD_TEXTURESTAGE',0x00100000)
		win_const_mgr.add_const('ISMEX_NOTIFY',0x00000002)
		win_const_mgr.add_const('IDC_OFFLINE_HAND',0x00000067)
		win_const_mgr.add_const('IN_CLASSA_NET',0x00000000)
		win_const_mgr.add_const('LUP_RETURN_ALIASES',0x00000400)
		win_const_mgr.add_const('ERROR_EFS_DISABLED',0x0000177F)
		win_const_mgr.add_const('WIA_DPC_ARTIST',0x0000082B)
		win_const_mgr.add_const('SEE_MASK_CLASSKEY',0x00000003)
		win_const_mgr.add_const('LANG_NEUTRAL',0x00000000)
		win_const_mgr.add_const('IF_TYPE_IMT',0x000000BE)
		win_const_mgr.add_const('VIEW_S_FIRST',0x00040140)
		win_const_mgr.add_const('INHERIT_CALLER_PRIORITY',0x00020000)
		win_const_mgr.add_const('ILLUMINANT_D75',0x00000007)
		win_const_mgr.add_const('CALLBACK_NULL',0x00000000)
		win_const_mgr.add_const('TMT_BGFILL',0x0000089D)
		win_const_mgr.add_const('WS_POPUP',0x80000000)
		win_const_mgr.add_const('WINDOWS_SHUTDOWN',0x00000008)
		win_const_mgr.add_const('DISPID_SETDETAILSSTATE',0x00000014)
		win_const_mgr.add_const('SQL_FN_TD_CURRENT_TIMESTAMP',0x00080000)
		win_const_mgr.add_const('SKF_LWINLATCHED',0x40000000)
		win_const_mgr.add_const('SNMPAPI_SYNTAX_INVALID',0x0000000E)
		win_const_mgr.add_const('ERROR_BAD_DRIVER_LEVEL',0x00000077)
		win_const_mgr.add_const('RC_DI_BITMAP',0x00000080)
		win_const_mgr.add_const('NTDSDSA_OPT_DISABLE_INBOUND_REPL',0x00000001)
		win_const_mgr.add_const('PHONESTATE_HEADSETGAIN',0x00020000)
		win_const_mgr.add_const('DMPAPER_TABLOID',0x00000003)
		win_const_mgr.add_const('SPLITSYM_SYMBOLPATH_IS_SRC',0x00000004)
		win_const_mgr.add_const('JOYERR_BASE',0x000000A0)
		win_const_mgr.add_const('IDM_TRIED_LOCK_ELEMENT',0x00000005)
		win_const_mgr.add_const('COD_PHONE_MINOR_WIRED_MODEM',0x00000004)
		win_const_mgr.add_const('CDO_E_DIRECTORIES_UNREACHABLE',0x80040232)
		win_const_mgr.add_const('ERROR_DS_OBJ_TOO_LARGE',0x00002078)
		win_const_mgr.add_const('SFVSOC_INVALIDATE_ALL',0x00000001)
		win_const_mgr.add_const('TBS_REVERSED',0x00000200)
		win_const_mgr.add_const('IDM_TRIED_IMAGE',0x00000029)
		win_const_mgr.add_const('FD_OOB_BIT',0x00000002)
		win_const_mgr.add_const('FIND_FIRST_EX_CASE_SENSITIVE',0x00000001)
		win_const_mgr.add_const('ELF_DISABLEOPENSOURCE',0x00000004)
		win_const_mgr.add_const('CICAT_STOPPED',0x00000001)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_CHANNEL_UP',0x00000033)
		win_const_mgr.add_const('PDERR_SETUPFAILURE',0x00001001)
		win_const_mgr.add_const('META_PATBLT',0x0000061D)
		win_const_mgr.add_const('SMILANIMATIONCOMPSITE_OFFSET',0x00000E00)
		win_const_mgr.add_const('ERROR_INVALID_GROUPNAME',0x000004B9)
		win_const_mgr.add_const('CS_DBLCLKS',0x00000008)
		win_const_mgr.add_const('RTM_ROUTE_CHANGE_NEW',0x00000002)
		win_const_mgr.add_const('PKCS12_PREFER_CNG_KSP',0x00000100)
		win_const_mgr.add_const('KAGPROP_DRIVERNAME',0x00000007)
		win_const_mgr.add_const('FIND_KEY',0x00000010)
		win_const_mgr.add_const('BAUD_38400',0x00004000)
		win_const_mgr.add_const('EC_CLOCK_CHANGED',0x0000000D)
		win_const_mgr.add_const('OS_HOME',0x00000013)
		win_const_mgr.add_const('WMDM_SCP_UNPROTECTED_OUTPUT',0x00000020)
		win_const_mgr.add_const('KSPROPERTY_WAVE_QUEUED_POSITION',0x00000001)
		win_const_mgr.add_const('LINEFORWARDMODE_NOANSWSPECIFIC',0x00000800)
		win_const_mgr.add_const('DS_SELECT_SECRET_DOMAIN_6_FLAG',0x00000800)
		win_const_mgr.add_const('PROC_THREAD_ATTRIBUTE_ADDITIVE',0x00040000)
		win_const_mgr.add_const('RTCEF_PRESENCE_STATUS',0x01000000)
		win_const_mgr.add_const('STRSAFE_VALID_FLAGS',0x000000FF)
		win_const_mgr.add_const('DT_TOP',0x00000000)
		win_const_mgr.add_const('SQL_CURSOR_KEYSET_DRIVEN',0x00000001)
		win_const_mgr.add_const('LINEPROXYREQUEST_GETAGENTSESSIONINFO',0x0000000F)
		win_const_mgr.add_const('PURGE_RXCLEAR',0x00000008)
		win_const_mgr.add_const('QUERYDIBSUPPORT',0x00000C01)
		win_const_mgr.add_const('FLAGSTATUS_FOLLOWUP',0x00000002)
		win_const_mgr.add_const('NS_NDS',0x00000002)
		win_const_mgr.add_const('ERR_SYSTEM_ERROR',0xE0000006)
		win_const_mgr.add_const('BCRYPT_ECDH_PRIVATE_P256_MAGIC',0x324B4345)
		win_const_mgr.add_const('ERROR_INVALID_TASK_NAME',0x0000060E)
		win_const_mgr.add_const('MAPI_PW_HIDE_SERVICES_LIST',0x00000010)
		win_const_mgr.add_const('MEM_4M',0x00400000)
		win_const_mgr.add_const('ES_SELECTIONBAR',0x01000000)
		win_const_mgr.add_const('DBPROPFLAGS_PERSIST',0x00002000)
		win_const_mgr.add_const('WMDM_E_NOTCERTIFIED',0x80045005)
		win_const_mgr.add_const('XP_DISCONNECT_DATA',0x00000100)
		win_const_mgr.add_const('ODS_DEFAULT',0x00000020)
		win_const_mgr.add_const('JOY_RETURNPOVCTS',0x00000200)
		win_const_mgr.add_const('IN_CLASSB_MAX',0x00010000)
		win_const_mgr.add_const('CBA_DUPLICATE_SYMBOL',0x00000005)
		win_const_mgr.add_const('PSD_ENABLEPAGESETUPTEMPLATE',0x00008000)
		win_const_mgr.add_const('HTTP_STATUS_NOT_FOUND',0x00000194)
		win_const_mgr.add_const('ERROR_SERVICE_ALREADY_RUNNING',0x00000420)
		win_const_mgr.add_const('DBPROPVAL_CU_TABLE_DEFINITION',0x00000002)
		win_const_mgr.add_const('IF_TYPE_OPTICAL_CHANNEL',0x000000C3)
		win_const_mgr.add_const('PROV_RSA_FULL',0x00000001)
		win_const_mgr.add_const('EMR_SETBRUSHORGEX',0x0000000D)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_D75',0x00000016)
		win_const_mgr.add_const('MCGIP_PREV',0x00000002)
		win_const_mgr.add_const('RTM_ROUTE_CHANGE_BEST',0x00010000)
		win_const_mgr.add_const('FVSIF_RECT',0x00000001)
		win_const_mgr.add_const('DDFXALPHACAPS_BLTALPHAPIXELSNEG',0x00000004)
		win_const_mgr.add_const('CRYPT_DEFAULT_CONTEXT_MULTI_CERT_SIGN_OID',0x00000002)
		win_const_mgr.add_const('TXFS_TRANSACTION_STATE_ACTIVE',0x00000001)
		win_const_mgr.add_const('CAL_SYEARMONTH',0x00000002)
		win_const_mgr.add_const('SUBLANG_SAMI_NORTHERN_SWEDEN',0x00000002)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_STATUS',0x0000044E)
		win_const_mgr.add_const('SKF_HOTKEYACTIVE',0x00000004)
		win_const_mgr.add_const('ACCESS_ALLOWED_COMPOUND_ACE_TYPE',0x00000004)
		win_const_mgr.add_const('GENERAL_INFO',0x00000001)
		win_const_mgr.add_const('TB_THUMBPOSITION',0x00000004)
		win_const_mgr.add_const('EMR_STROKEANDFILLPATH',0x0000003F)
		win_const_mgr.add_const('LM20_STXTLEN',0x0000003F)
		win_const_mgr.add_const('CTL_FIND_USAGE',0x00000003)
		win_const_mgr.add_const('PHONESTATE_OWNER',0x00000008)
		win_const_mgr.add_const('ERROR_INVALID_USER_BUFFER',0x000006F8)
		win_const_mgr.add_const('CERT_SET_PROPERTY_IGNORE_PERSIST_ERROR_FLAG',0x80000000)
		win_const_mgr.add_const('ADS_PRINTER_IO_ACTIVE',0x00000100)
		win_const_mgr.add_const('ACTRL_PERM_11',0x00000400)
		win_const_mgr.add_const('WT_TRUSTDBDIALOG_WRITE_LEGACY_REG_FLAG',0x00000100)
		win_const_mgr.add_const('TABLET_DISABLE_PRESSANDHOLD',0x00000001)
		win_const_mgr.add_const('ERROR_EC_LOG_DISABLED',0x00003AE9)
		win_const_mgr.add_const('SOFTDIST_FLAG_USAGE_AUTOINSTALL',0x00000004)
		win_const_mgr.add_const('ERROR_DEPENDENT_SERVICES_RUNNING',0x0000041B)
		win_const_mgr.add_const('CACHE_NOTIFY_FILTER_CHANGED',0x10000000)
		win_const_mgr.add_const('SNMPAPI_SUCCESS',0x00000001)
		win_const_mgr.add_const('CM_HWPI_DOCKED',0x00000002)
		win_const_mgr.add_const('GW_HWNDNEXT',0x00000002)
		win_const_mgr.add_const('EM_SETREADONLY',0x000000CF)
		win_const_mgr.add_const('VIDEO_OUT',0x00000008)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_CANCELWRITE',0x00000203)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_NATOA',0x00003645)
		win_const_mgr.add_const('ENUM_S_FIRST',0x000401B0)
		win_const_mgr.add_const('DISPID_REFRESHOFFLINEDESKTOP',0x00000003)
		win_const_mgr.add_const('ENABLE_TB_BROADCAST',0x00000005)
		win_const_mgr.add_const('WMIREG_FLAG_TRACED_GUID',0x00080000)
		win_const_mgr.add_const('WIA_DPC_TIMELAPSE_NUMBER',0x0000081A)
		win_const_mgr.add_const('DM_SPECVERSION',0x00000320)
		win_const_mgr.add_const('CDO_E_RECIPIENT_MISSING',0x8004020C)
		win_const_mgr.add_const('SQL_SFKU_CASCADE',0x00000001)
		win_const_mgr.add_const('OFN_NOLONGNAMES',0x00040000)
		win_const_mgr.add_const('DTT_SHADOWOFFSET',0x00000001)
		win_const_mgr.add_const('ELEMENT_STATUS_IMPEXP',0x00000002)
		win_const_mgr.add_const('SERVICE_CONFIG_FAILURE_ACTIONS',0x00000002)
		win_const_mgr.add_const('MD_ACCESS_NEGO_CERT',0x00000020)
		win_const_mgr.add_const('SUBLANG_IGBO_NIGERIA',0x00000001)
		win_const_mgr.add_const('AM_LOADSTATUS_OPENING',0x00000005)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_SYSTEM_ERROR',0x00000000)
		win_const_mgr.add_const('SUBLANG_SERBIAN_BOSNIA_HERZEGOVINA_LATIN',0x00000006)
		win_const_mgr.add_const('STRSAFE_MAX_CCH',0x7FFFFFFF)
		win_const_mgr.add_const('SQL_AT_ADD_COLUMN_COLLATION',0x00000080)
		win_const_mgr.add_const('MDPROPVAL_MSF_DRILLDOWNMEMBERTOP',0x00001000)
		win_const_mgr.add_const('ODT_LISTBOX',0x00000002)
		win_const_mgr.add_const('ULONGLONG_ERROR',0x00000000)
		win_const_mgr.add_const('SHGVSPB_PERFOLDER',0x00000004)
		win_const_mgr.add_const('DEBUG_MODULE_SYM_BAD_CHECKSUM',0x00010000)
		win_const_mgr.add_const('BL_80M',0x05000000)
		win_const_mgr.add_const('EN_VSCROLL',0x00000602)
		win_const_mgr.add_const('SYMOPT_LOAD_LINES',0x00000010)
		win_const_mgr.add_const('AF_OP_COMM',0x00000002)
		win_const_mgr.add_const('SQL_AT_CONSTRAINT_NON_DEFERRABLE',0x00080000)
		win_const_mgr.add_const('MCI_DGV_PASTE_VIDEO_STREAM',0x00040000)
		win_const_mgr.add_const('SPDIT_COMPATDRIVER',0x00000002)
		win_const_mgr.add_const('DDSCAPS2_ENABLEALPHACHANNEL',0x20000000)
		win_const_mgr.add_const('SUBLANG_ASSAMESE_INDIA',0x00000001)
		win_const_mgr.add_const('DN_DRIVER_LOADED',0x00000002)
		win_const_mgr.add_const('WIA_DPC_DIGITAL_ZOOM',0x0000081E)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_DISPOSITION',0x0000002F)
		win_const_mgr.add_const('ERROR_NON_DOMAIN_SID',0x000004EA)
		win_const_mgr.add_const('SQL_PARAM_ERROR',0x00000005)
		win_const_mgr.add_const('GDICOMMENT_BEGINGROUP',0x00000002)
		win_const_mgr.add_const('IDM_SHOWPAGESETUP',0x000007DB)
		win_const_mgr.add_const('SCRIPTITEM_ISPERSISTENT',0x00000040)
		win_const_mgr.add_const('SCARD_STATE_UNAVAILABLE',0x00000008)
		win_const_mgr.add_const('IDC_PU_LINKS',0x00000384)
		win_const_mgr.add_const('RP_DSN_HANDLED',0x00000040)
		win_const_mgr.add_const('RTCEF_REGISTRATION_STATE_CHANGE',0x00000002)
		win_const_mgr.add_const('DNS_ERROR_ZONE_REQUIRES_MASTER_IP',0x00002594)
		win_const_mgr.add_const('EVENT_ACTIVITY_CTRL_GET_ID',0x00000001)
		win_const_mgr.add_const('TBS_COMMAND_PRIORITY_HIGH',0x0000012C)
		win_const_mgr.add_const('MUI_LANGUAGE_INSTALLED',0x00000020)
		win_const_mgr.add_const('WIA_DIP_DEV_TYPE',0x00000005)
		win_const_mgr.add_const('FVSIF_PINNED',0x00000002)
		win_const_mgr.add_const('PROPID_M_MSGID_SIZE',0x00000014)
		win_const_mgr.add_const('SECURITY_CREATOR_GROUP_RID',0x00000001)
		win_const_mgr.add_const('LOCALE_ILANGUAGE',0x00000001)
		win_const_mgr.add_const('SND_SENTRY',0x00080000)
		win_const_mgr.add_const('INTERNET_STATUS_REQUEST_COMPLETE',0x00000064)
		win_const_mgr.add_const('PAN_SERIF_EXAGGERATED',0x00000009)
		win_const_mgr.add_const('IOF_CREATEFILEOBJECT',0x00000040)
		win_const_mgr.add_const('HHWIN_PARAM_INFOTYPES',0x00000001)
		win_const_mgr.add_const('IPPROTO_TCP',0x00000006)
		win_const_mgr.add_const('RTL_ENCRYPT_MEMORY_SIZE',0x00000008)
		win_const_mgr.add_const('ERROR_WMI_INVALID_MOF',0x00001072)
		win_const_mgr.add_const('SUBLANG_CZECH_CZECH_REPUBLIC',0x00000001)
		win_const_mgr.add_const('IDM_IMPORT',0x00000056)
		win_const_mgr.add_const('WIA_DEVICE_DIALOG_SINGLE_IMAGE',0x00000002)
		win_const_mgr.add_const('LOG_POLICY_PERSIST',0x00000002)
		win_const_mgr.add_const('LANG_CHINESE',0x00000004)
		win_const_mgr.add_const('PSM_RFCOMM',0x00000003)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_PRESERVE_JOB_TIME',0x00000040)
		win_const_mgr.add_const('SBS_SIZEBOXTOPLEFTALIGN',0x00000002)
		win_const_mgr.add_const('TAPE_DRIVE_ERASE_IMMEDIATE',0x00000080)
		win_const_mgr.add_const('SQL_AD_DROP_DOMAIN_CONSTRAINT',0x00000004)
		win_const_mgr.add_const('WMDM_RIGHTS_COPY_TO_CD',0x00000008)
		win_const_mgr.add_const('WEBDAV_MD_SERVER_BASE',0x00002134)
		win_const_mgr.add_const('WNFMT_INENUM',0x00000010)
		win_const_mgr.add_const('LANG_SLOVENIAN',0x00000024)
		win_const_mgr.add_const('AMINTERLACE_UNUSED',0x00000008)
		win_const_mgr.add_const('CDO_E_NO_DEFAULT_DROP_DIR',0x80040209)
		win_const_mgr.add_const('LDAP_RES_SESSION',0x00000072)
		win_const_mgr.add_const('CM_RESDES_WIDTH_32',0x00000001)
		win_const_mgr.add_const('MCI_WINDOW',0x00000841)
		win_const_mgr.add_const('DNS_TYPE_SIG',0x00000018)
		win_const_mgr.add_const('ERROR_IPSEC_CLEAR_TEXT_DROP',0x0000365C)
		win_const_mgr.add_const('SQL_CONCUR_READ_ONLY',0x00000001)
		win_const_mgr.add_const('SV_INITWORKITEMS_PARMNUM',0x000001F9)
		win_const_mgr.add_const('ERROR_WINDOW_OF_OTHER_THREAD',0x00000580)
		win_const_mgr.add_const('ANSI_VAR_FONT',0x0000000C)
		win_const_mgr.add_const('MD_LOGFILE_PERIOD_MONTHLY',0x00000003)
		win_const_mgr.add_const('CRYPT_SGC_ENUM',0x00000004)
		win_const_mgr.add_const('MIXERLINE_TARGETTYPE_WAVEOUT',0x00000001)
		win_const_mgr.add_const('MOD_LEFT',0x00008000)
		win_const_mgr.add_const('VK_VOLUME_UP',0x000000AF)
		win_const_mgr.add_const('ERROR_AUTHENTICATION_FIREWALL_FAILED',0x0000078F)
		win_const_mgr.add_const('KSDSOUND_BUFFER_CTRL_FREQUENCY',0x00000002)
		win_const_mgr.add_const('FORMAT_MESSAGE_FROM_SYSTEM',0x00001000)
		win_const_mgr.add_const('SRCLIST_USER',0x00000020)
		win_const_mgr.add_const('DEBUG_DATA_SPACE_DEBUGGER_DATA',0x00000006)
		win_const_mgr.add_const('JOB_POSITION_UNSPECIFIED',0x00000000)
		win_const_mgr.add_const('LVCF_ORDER',0x00000020)
		win_const_mgr.add_const('LINESPECIALINFO_UNKNOWN',0x00000008)
		win_const_mgr.add_const('SQL_DIAG_DYNAMIC_FUNCTION',0x00000007)
		win_const_mgr.add_const('TCI_SRCCHARSET',0x00000001)
		win_const_mgr.add_const('CDRF_NOTIFYPOSTERASE',0x00000040)
		win_const_mgr.add_const('SANDBOX_INERT',0x00000002)
		win_const_mgr.add_const('GCT_SHORTCHAR',0x00000002)
		win_const_mgr.add_const('ACM_DRIVERPRIORITYF_ENABLE',0x00000001)
		win_const_mgr.add_const('SECURITY_FLAG_SECURE',0x00000001)
		win_const_mgr.add_const('IDM_PRESTOP',0x000008EC)
		win_const_mgr.add_const('DNF_INET_DRIVER',0x00000080)
		win_const_mgr.add_const('SYMOPT_IGNORE_NT_SYMPATH',0x00001000)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_LOCAL_MACHINE_ENTERPRISE_ID',0x00000009)
		win_const_mgr.add_const('SQL_NO_DATA',0x00000064)
		win_const_mgr.add_const('JOY_CAL_READZONLY',0x01000000)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_TERMINAL_SERVER',0x80010000)
		win_const_mgr.add_const('CACHE_CONFIG_HISTORY_PATHS_FC',0x00000400)
		win_const_mgr.add_const('RPC_C_OPT_MQ_JOURNAL',0x00000003)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_USER_FLOW_DURATION',0x0000000B)
		win_const_mgr.add_const('PARTITION_XENIX_1',0x00000002)
		win_const_mgr.add_const('SERVICE_IP_QUERY_HINT',0x00010000)
		win_const_mgr.add_const('FWPM_CONTEXT_ALE_SET_CONNECTION_LAZY_SD_EVALUATION',0x00000004)
		win_const_mgr.add_const('IDM_RENAME',0x00000055)
		win_const_mgr.add_const('LINECALLFEATURE_SETTERMINAL',0x00800000)
		win_const_mgr.add_const('RTCEF_PROFILE',0x00000400)
		win_const_mgr.add_const('ALG_SID_MAC',0x00000005)
		win_const_mgr.add_const('MCI_OFF_S',0x00008001)
		win_const_mgr.add_const('HICF_ENTERING',0x00000010)
		win_const_mgr.add_const('ERROR_DS_LDAP_SEND_QUEUE_FULL',0x000021A8)
		win_const_mgr.add_const('CDO_E_NOT_OPENED',0x80040202)
		win_const_mgr.add_const('LINEMEDIAMODE_G4FAX',0x00000080)
		win_const_mgr.add_const('ERROR_DS_INVALID_DMD',0x000020A8)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_CLOSEDROP',0x00000020)
		win_const_mgr.add_const('INT8_MAX',0x0000007F)
		win_const_mgr.add_const('DIIRFLAG_HOTPATCH',0x00000008)
		win_const_mgr.add_const('D3DSI_INSTLENGTH_MASK',0x0F000000)
		win_const_mgr.add_const('PBT_APMQUERYSTANDBY',0x00000001)
		win_const_mgr.add_const('GCS_COMPREADATTR',0x00000002)
		win_const_mgr.add_const('RPC_S_INTERFACE_NOT_FOUND',0x000006DF)
		win_const_mgr.add_const('AE_ADMIN',0x00000002)
		win_const_mgr.add_const('DVB_EIT_OTHER_TID',0x0000004F)
		win_const_mgr.add_const('QOS_OBJECT_FRIENDLY_NAME',0x00000005)
		win_const_mgr.add_const('HICF_RESELECT',0x00000040)
		win_const_mgr.add_const('CACHEGROUP_ID_BUILTIN_STICKY',0x1000000000000007)
		win_const_mgr.add_const('EMARCH_ENC_I17_SIGN_VAL_POS_X',0x0000003F)
		win_const_mgr.add_const('DIF_PROPERTYCHANGE',0x00000012)
		win_const_mgr.add_const('RCVD_PATH_TEAR',0x00000001)
		win_const_mgr.add_const('CSBACKUP_TYPE_FULL',0x00000001)
		win_const_mgr.add_const('CVT_MINUTES',0x0000003C)
		win_const_mgr.add_const('SQL_ROW_IDENTIFIER',0x00000001)
		win_const_mgr.add_const('PSINJECT_DOCUMENTPROCESSCOLORSATEND',0x00000015)
		win_const_mgr.add_const('SQL_DIAG_CREATE_CHARACTER_SET',0x00000008)
		win_const_mgr.add_const('BL_LOADER_INDEX',0x00000007)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_MIN',0x00001D00)
		win_const_mgr.add_const('BIND_REPORT_64BIT_VA',0x00000010)
		win_const_mgr.add_const('SCH_CRED_V3',0x00000003)
		win_const_mgr.add_const('OID_CO_ADD_ADDRESS',0xFE000004)
		win_const_mgr.add_const('IME_ITHOTKEY_PREVIOUS_COMPOSITION',0x00000201)
		win_const_mgr.add_const('PDCAP_S3_SUPPORTED',0x00080000)
		win_const_mgr.add_const('CLR_INVALID',0xFFFFFFFF)
		win_const_mgr.add_const('WM_NCRBUTTONDOWN',0x000000A4)
		win_const_mgr.add_const('ASC_REQ_CONNECTION',0x00000800)
		win_const_mgr.add_const('OPTION_ETHERNET_ENCAPSULATION',0x00000024)
		win_const_mgr.add_const('ERROR_DECRYPTION_FAILED',0x00001771)
		win_const_mgr.add_const('D3DSP_WRITEMASK_0',0x00010000)
		win_const_mgr.add_const('D3DSP_WRITEMASK_1',0x00020000)
		win_const_mgr.add_const('D3DSP_WRITEMASK_2',0x00040000)
		win_const_mgr.add_const('MCI_DGV_STATUS_AVGBYTESPERSEC',0x00004028)
		win_const_mgr.add_const('D3DPRESENTFLAG_DISCARD_DEPTHSTENCIL',0x00000002)
		win_const_mgr.add_const('DDENUMRET_CANCEL',0x00000000)
		win_const_mgr.add_const('FWPM_PROVIDER_FLAG_PERSISTENT',0x00000001)
		win_const_mgr.add_const('WIA_DATA_COLOR_THRESHOLD',0x00000004)
		win_const_mgr.add_const('CMSG_ENVELOPED_RECIPIENT_V4',0x00000004)
		win_const_mgr.add_const('FORCED_LOG_CONF',0x00000004)
		win_const_mgr.add_const('PT5',0x00001000)
		win_const_mgr.add_const('ERROR_JOURNAL_DELETE_IN_PROGRESS',0x0000049A)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_DEF_FLOW_RATE',0x00000015)
		win_const_mgr.add_const('WMDM_CONTENT_FOLDER',0x00000008)
		win_const_mgr.add_const('SQL_CVT_CHAR',0x00000001)
		win_const_mgr.add_const('SNMPAPI_TRANSLATED',0x00000000)
		win_const_mgr.add_const('PERCEIVEDFLAG_GDIPLUS',0x00000010)
		win_const_mgr.add_const('SO_SNDBUF',0x00001001)
		win_const_mgr.add_const('MCI_STATUS',0x00000814)
		win_const_mgr.add_const('PAN_XHEIGHT_CONSTANT_SMALL',0x00000002)
		win_const_mgr.add_const('CERT_CA_OCSP_AUTHORITY_INFO_ACCESS_PROP_ID',0x00000051)
		win_const_mgr.add_const('KP_BLOCKLEN',0x00000008)
		win_const_mgr.add_const('OPTION_KEEP_ALIVE_DATA_SIZE',0x00000027)
		win_const_mgr.add_const('VP_CP_CMD_ACTIVATE',0x00000001)
		win_const_mgr.add_const('ERROR_CANT_DELETE_LAST_ITEM',0x000010EF)
		win_const_mgr.add_const('MCI_ANIM_WHERE_SOURCE',0x00020000)
		win_const_mgr.add_const('STI_EVENTHANDLING_POLLING',0x00000002)
		win_const_mgr.add_const('SSA_DZWG',0x00000010)
		win_const_mgr.add_const('MCI_ANIM_WINDOW_ENABLE_STRETCH',0x00100000)
		win_const_mgr.add_const('RASLCPO_PFC',0x00000001)
		win_const_mgr.add_const('ERROR_INSUFFICIENT_POWER',0x0000027F)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_LOAD_CONFIG',0x0000000A)
		win_const_mgr.add_const('MCI_SET_OFF',0x00004000)
		win_const_mgr.add_const('MUI_FILEINFO_VERSION',0x00000001)
		win_const_mgr.add_const('ERROR_EA_ACCESS_DENIED',0x000003E2)
		win_const_mgr.add_const('DB_MODE_SHARE_DENY_READ',0x00000004)
		win_const_mgr.add_const('ISC_REQ_FRAGMENT_TO_FIT',0x00200000)
		win_const_mgr.add_const('WAVE_FORMAT_2S16',0x00000080)
		win_const_mgr.add_const('ERROR_QUORUM_DISK_NOT_FOUND',0x000013DE)
		win_const_mgr.add_const('REGULAR_FONTTYPE',0x00000400)
		win_const_mgr.add_const('ACCESS_RESOURCE_NAME_PARMNUM',0x00000001)
		win_const_mgr.add_const('KP_CLEAR_KEY',0x0000001B)
		win_const_mgr.add_const('KERB_SETPASS_USE_CREDHANDLE',0x00000002)
		win_const_mgr.add_const('GTL_NUMCHARS',0x00000008)
		win_const_mgr.add_const('HTTP_REQUEST_FLAG_MORE_ENTITY_BODY_EXISTS',0x00000001)
		win_const_mgr.add_const('STGM_STRICTOPEN',0x40000000)
		win_const_mgr.add_const('TMT_ROUNDCORNERHEIGHT',0x00000965)
		win_const_mgr.add_const('AE_ACCRESTRICT',0x00000004)
		win_const_mgr.add_const('CONTEXT_S_LAST',0x0004E02F)
		win_const_mgr.add_const('CERT_CHAIN_FIND_BY_ISSUER_NO_KEY_FLAG',0x00004000)
		win_const_mgr.add_const('DNS_UNREGISTER',0x00000002)
		win_const_mgr.add_const('GPO_INFO_FLAG_SLOWLINK',0x00000020)
		win_const_mgr.add_const('SUBLANG_ARABIC_EGYPT',0x00000003)
		win_const_mgr.add_const('SECPKG_CALL_IN_PROC',0x00000010)
		win_const_mgr.add_const('ERROR_ACCESS_DISABLED_WEBBLADE',0x000004FD)
		win_const_mgr.add_const('TBSTATE_HIDDEN',0x00000008)
		win_const_mgr.add_const('OPPROGDLG_DONTDISPLAYDESTPATH',0x00000400)
		win_const_mgr.add_const('PIDMSI_RATING',0x00000009)
		win_const_mgr.add_const('ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR',0x00000315)
		win_const_mgr.add_const('CAL_SSHORTESTDAYNAME3',0x00000033)
		win_const_mgr.add_const('TVHT_ONITEMLABEL',0x00000004)
		win_const_mgr.add_const('EC_BANDWIDTHCHANGE',0x00000048)
		win_const_mgr.add_const('KSEVENTF_SEMAPHORE_HANDLE',0x00000002)
		win_const_mgr.add_const('IF_TYPE_IEEE8023AD_LAG',0x000000A1)
		win_const_mgr.add_const('TH_NETDEV',0x00000001)
		win_const_mgr.add_const('DSBF_DISPLAYNAME',0x00000004)
		win_const_mgr.add_const('ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS',0x00001719)
		win_const_mgr.add_const('DBPROP_USEEXTENDEDDBTYPES',0x00000004)
		win_const_mgr.add_const('SET_FEATURE_ON_PROCESS',0x00000002)
		win_const_mgr.add_const('ADS_SERVICE_ERROR_NORMAL',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_SS_ISTREAM',0x00000002)
		win_const_mgr.add_const('MD_LOGON_BATCH',0x00000001)
		win_const_mgr.add_const('OID_WAN_MEDIUM_SUBTYPE',0x04010105)
		win_const_mgr.add_const('WIA_DPC_FOCAL_LENGTH',0x00000827)
		win_const_mgr.add_const('TXTLOG_DEPTH_INCR',0x00020000)
		win_const_mgr.add_const('RESOURCEMANAGER_RECOVER',0x00000004)
		win_const_mgr.add_const('ATM_ADDR_SIZE',0x00000014)
		win_const_mgr.add_const('CRYPT_USERDATA',0x00000001)
		win_const_mgr.add_const('ICMF_ABOUT_QUERY',0x00000001)
		win_const_mgr.add_const('VOS_NT',0x00040000)
		win_const_mgr.add_const('CSIDL_APPDATA',0x00000001)
		win_const_mgr.add_const('D3DFVF_TEXTUREFORMAT1',0x00000003)
		win_const_mgr.add_const('VK_LWIN',0x0000005B)
		win_const_mgr.add_const('D3DFVF_TEXTUREFORMAT3',0x00000001)
		win_const_mgr.add_const('D3DFVF_TEXTUREFORMAT2',0x00000000)
		win_const_mgr.add_const('NCBRESET',0x00000032)
		win_const_mgr.add_const('MIM_HELPID',0x00000004)
		win_const_mgr.add_const('CAUSE_INVALID_TRANSIT_NETWORK_SELECTION',0x0000005B)
		win_const_mgr.add_const('GIL_DONTCACHE',0x00000010)
		win_const_mgr.add_const('ILS_NORMAL',0x00000000)
		win_const_mgr.add_const('ISC_RET_USE_SESSION_KEY',0x00000020)
		win_const_mgr.add_const('GESTURE_NULL',0x00000000)
		win_const_mgr.add_const('IASSEMBLYCACHEITEM_COMMIT_DISPOSITION_INSTALLED',0x00000001)
		win_const_mgr.add_const('WSA_QOS_TRAFFIC_CTRL_ERROR',0x00002B06)
		win_const_mgr.add_const('SUBLANG_SERBIAN_BOSNIA_HERZEGOVINA_CYRILLIC',0x00000007)
		win_const_mgr.add_const('NOTE_COLOR_LIGHTGREEN',0x00000005)
		win_const_mgr.add_const('DLCTL_PRAGMA_NO_CACHE',0x00004000)
		win_const_mgr.add_const('HF32_DEFAULT',0x00000001)
		win_const_mgr.add_const('GDTR_MAX',0x00000002)
		win_const_mgr.add_const('WIA_COMPRESSION_JBIG',0x00000006)
		win_const_mgr.add_const('TRACK_OFFLINE_CACHE_ENTRY',0x00000010)
		win_const_mgr.add_const('ERROR_TRANSACTION_ALREADY_ABORTED',0x00001A30)
		win_const_mgr.add_const('DS_BACKGROUND_ONLY',0x00000100)
		win_const_mgr.add_const('SV_ENABLEOPLOCKFORCECLOSE_PARMNUM',0x00000219)
		win_const_mgr.add_const('SBM_SETSCROLLINFO',0x000000E9)
		win_const_mgr.add_const('ERROR_ARENA_TRASHED',0x00000007)
		win_const_mgr.add_const('ERROR_ALLOTTED_SPACE_EXCEEDED',0x00000540)
		win_const_mgr.add_const('D3DPTEXTURECAPS_PROJECTED',0x00000400)
		win_const_mgr.add_const('IP_OPT_LSRR',0x00000083)
		win_const_mgr.add_const('LOCALE_IGEOID',0x0000005B)
		win_const_mgr.add_const('LOCALE_SKEYBOARDSTOINSTALL',0x00000005)
		win_const_mgr.add_const('DEBUG_KERNEL_LOCAL',0x00000001)
		win_const_mgr.add_const('VER_PLATFORM_WIN32_WINDOWS',0x00000001)
		win_const_mgr.add_const('CTRY_MACEDONIA',0x00000185)
		win_const_mgr.add_const('VDMADDR_V86',0x00000002)
		win_const_mgr.add_const('TBCD_THUMB',0x00000002)
		win_const_mgr.add_const('SQL_API_SQLSETSTMTOPTION',0x00000033)
		win_const_mgr.add_const('DOT11_STATUS_UNAVAILABLE_BSS',0x00000080)
		win_const_mgr.add_const('DEBUG_NOTIFY_SESSION_INACCESSIBLE',0x00000003)
		win_const_mgr.add_const('SPEAKER_TOP_BACK_CENTER',0x00010000)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2EVENTARGS_TOTALDEVICEBUFFER',0x00000104)
		win_const_mgr.add_const('DNF_EXCLUDEFROMLIST',0x00000004)
		win_const_mgr.add_const('LINECALLFEATURE_COMPLETECALL',0x00000010)
		win_const_mgr.add_const('SOUND_SYSTEM_SHUTDOWN',0x00000002)
		win_const_mgr.add_const('IDM_TRIED_ABSOLUTE_DROP_MODE',0x0000000D)
		win_const_mgr.add_const('STARTF_RUNFULLSCREEN',0x00000020)
		win_const_mgr.add_const('FILE_DEVICE_WPD',0x00000040)
		win_const_mgr.add_const('SERVICE_NOTIFY_STOPPED',0x00000001)
		win_const_mgr.add_const('TSF_COPY_HARD_LINK',0x00000100)
		win_const_mgr.add_const('SETXOFF',0x00000001)
		win_const_mgr.add_const('ERROR_DS_VERSION_CHECK_FAILURE',0x00000283)
		win_const_mgr.add_const('D3DDEVCAPS_EXECUTEVIDEOMEMORY',0x00000020)
		win_const_mgr.add_const('ELF_DISABLECANCELLINK',0x00000010)
		win_const_mgr.add_const('MAPIFORM_OS_WIN_95',0x00000003)
		win_const_mgr.add_const('OID_CO_AF_CLOSE',0xFE00000A)
		win_const_mgr.add_const('DNS_ERROR_DP_ALREADY_ENLISTED',0x000026B0)
		win_const_mgr.add_const('LDAP_OPT_API_FEATURE_INFO',0x00000015)
		win_const_mgr.add_const('IF_TYPE_SMDS_DXI',0x0000002B)
		win_const_mgr.add_const('LCS_GM_IMAGES',0x00000004)
		win_const_mgr.add_const('ERROR_CIRCULAR_DEPENDENCY',0x00000423)
		win_const_mgr.add_const('KL_NAMELENGTH',0x00000009)
		win_const_mgr.add_const('SUBLANG_LUXEMBOURGISH_LUXEMBOURG',0x00000001)
		win_const_mgr.add_const('SCARD_SCOPE_SYSTEM',0x00000002)
		win_const_mgr.add_const('WMS_STREAM_AVG_PACKET_SIZE',0x00000005)
		win_const_mgr.add_const('MSV1_0_GUEST_LOGON',0x00000002)
		win_const_mgr.add_const('WS_ACTIVECAPTION',0x00000001)
		win_const_mgr.add_const('EVENT_TRACE_CONTROL_QUERY',0x00000000)
		win_const_mgr.add_const('FWPM_WEIGHT_RANGE_IPSEC',0x00000000)
		win_const_mgr.add_const('SQL_AT_ADD_TABLE_CONSTRAINT',0x00001000)
		win_const_mgr.add_const('LINECALLFEATURE_BLINDTRANSFER',0x00000008)
		win_const_mgr.add_const('IMAGE_REL_SH3_STARTOF_SECTION',0x0000000C)
		win_const_mgr.add_const('PAN_WEIGHT_BOLD',0x00000008)
		win_const_mgr.add_const('DRV_EXITSESSION',0x0000000B)
		win_const_mgr.add_const('ERROR_LOGON_NOT_GRANTED',0x00000564)
		win_const_mgr.add_const('INTERNET_COOKIE_THIRD_PARTY',0x00000010)
		win_const_mgr.add_const('PIR_OPTION_REALMODE',0x00000008)
		win_const_mgr.add_const('INTERNET_OPTION_CALLBACK',0x00000001)
		win_const_mgr.add_const('RIDEV_REMOVE',0x00000001)
		win_const_mgr.add_const('WINSTA_ACCESSCLIPBOARD',0x00000004)
		win_const_mgr.add_const('META_ROUNDRECT',0x0000061C)
		win_const_mgr.add_const('PRIVATEOBJECT_PHONE',0x00000005)
		win_const_mgr.add_const('PASSTHROUGH',0x00000013)
		win_const_mgr.add_const('SNMPAPI_TL_INVALID_PARAM',0x0000006A)
		win_const_mgr.add_const('NORM_IGNORENONSPACE',0x00000002)
		win_const_mgr.add_const('OID_TAPI_GET_ADDRESS_ID',0x0703010B)
		win_const_mgr.add_const('LINECALLREASON_UNAVAIL',0x00000800)
		win_const_mgr.add_const('EN_OLEOPFAILED',0x00000709)
		win_const_mgr.add_const('DMPAPER_FANFOLD_LGL_GERMAN',0x00000029)
		win_const_mgr.add_const('INTERNET_STATUS_HANDLE_CREATED',0x0000003C)
		win_const_mgr.add_const('TLS1_ALERT_USER_CANCELED',0x0000005A)
		win_const_mgr.add_const('PC_WIDE',0x00000010)
		win_const_mgr.add_const('DD_ROP_SPACE',0x00000100)
		win_const_mgr.add_const('CPL_DYNAMIC_RES',0x00000000)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_HANDLE_CREATED',0x00000400)
		win_const_mgr.add_const('WIA_INTENT_SIZE_MASK',0x000F0000)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_TRANSPORT_CONTROL_DATA',0x00010000)
		win_const_mgr.add_const('TCP_EXPEDITED_1122',0x00000002)
		win_const_mgr.add_const('MIXERCONTROL_CT_CLASS_MASK',0xF0000000)
		win_const_mgr.add_const('DBPROPVAL_IT_BTREE',0x00000001)
		win_const_mgr.add_const('PHONEBUTTONMODE_DISPLAY',0x00000020)
		win_const_mgr.add_const('ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE',0x00001A95)
		win_const_mgr.add_const('ACCESS_GROUP',0x00008000)
		win_const_mgr.add_const('LLMHF_INJECTED',0x00000001)
		win_const_mgr.add_const('CERT_ALT_NAME_URL',0x00000007)
		win_const_mgr.add_const('SSRVOPT_SERVICE',0x00100000)
		win_const_mgr.add_const('ERROR_MACHINE_LOCKED',0x000004F7)
		win_const_mgr.add_const('LV_VIEW_MAX',0x00000004)
		win_const_mgr.add_const('SM_CXMAXTRACK',0x0000003B)
		win_const_mgr.add_const('GGO_NATIVE',0x00000002)
		win_const_mgr.add_const('BLUETOOTH_MAX_NAME_SIZE',0x000000F8)
		win_const_mgr.add_const('WIA_DPS_PREVIEW',0x00000C1C)
		win_const_mgr.add_const('PCM_VERSION_1',0x00000001)
		win_const_mgr.add_const('DWM_TNP_SOURCECLIENTAREAONLY',0x00000010)
		win_const_mgr.add_const('ACTRL_DS_WRITE_PROP',0x00000020)
		win_const_mgr.add_const('WMDM_SCP_PROTECTED_OUTPUT',0x00000010)
		win_const_mgr.add_const('CRYPT_USER_PROTECTED',0x00000002)
		win_const_mgr.add_const('PAN_SERIF_ROUNDED',0x0000000F)
		win_const_mgr.add_const('NCRYPT_UI_FORCE_HIGH_PROTECTION_FLAG',0x00000002)
		win_const_mgr.add_const('SCESTATUS_INVALID_DATA',0x00000003)
		win_const_mgr.add_const('WINEVENT_CHANNEL_GLOBAL_APPLICATION',0x00000009)
		win_const_mgr.add_const('MD_ERROR_SUB404_NO_HANDLER',0x00000004)
		win_const_mgr.add_const('DDGDI_GETHOSTIDENTIFIER',0x00000001)
		win_const_mgr.add_const('WINHTTP_HANDLE_TYPE_SESSION',0x00000001)
		win_const_mgr.add_const('ERRLOC_MEM',0x00000005)
		win_const_mgr.add_const('ERROR_DELETING_ICM_XFORM',0x000007E3)
		win_const_mgr.add_const('PORT_NETBIOSDGM',0x0000008A)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_NTPE3',0x00000000)
		win_const_mgr.add_const('IME_CMODE_EUDC',0x00000200)
		win_const_mgr.add_const('CONTEXT_MENU_VSCROLL',0x0000000A)
		win_const_mgr.add_const('COLOR_TUNE',0x000002CA)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_REVEAL',0x00000018)
		win_const_mgr.add_const('FWPM_NET_EVENT_IKEEXT_MM_FAILURE_FLAG_MULTIPLE',0x00000002)
		win_const_mgr.add_const('HTTP_AUTH_ENABLE_BASIC',0x00000001)
		win_const_mgr.add_const('L2_NOTIFICATION_SOURCE_WLAN_IHV',0x00000000)
		win_const_mgr.add_const('ERROR_INVALID_PRINTER_STATE',0x00000772)
		win_const_mgr.add_const('EM_SCROLL',0x000000B5)
		win_const_mgr.add_const('SEF_AVOID_OWNER_RESTRICTION',0x00001000)
		win_const_mgr.add_const('OBJECT_PUSH_FORMAT_VCARD_2_1',0x00000001)
		win_const_mgr.add_const('ERROR_BAD_DEVICE',0x000004B0)
		win_const_mgr.add_const('CLIENTSITE_S_FIRST',0x00040190)
		win_const_mgr.add_const('DBPROPVAL_CS_UNINITIALIZED',0x00000000)
		win_const_mgr.add_const('OBM_RGARROW',0x00007FEF)
		win_const_mgr.add_const('CERT_COMPARE_CROSS_CERT_DIST_POINTS',0x00000011)
		win_const_mgr.add_const('DEBUG_STATUS_RESTART_REQUESTED',0x0000000A)
		win_const_mgr.add_const('CRYPTPROTECTMEMORY_SAME_LOGON',0x00000002)
		win_const_mgr.add_const('CTLCOLOR_LISTBOX',0x00000002)
		win_const_mgr.add_const('GETEXTENDEDTEXTMETRICS',0x00000100)
		win_const_mgr.add_const('SUBLANG_QUECHUA_BOLIVIA',0x00000001)
		win_const_mgr.add_const('DXVA_BITSTREAM_CONCEALMENT_METHOD_UNSPECIFIED',0x00000000)
		win_const_mgr.add_const('CI_PROVIDER_ALL',0x00000000)
		win_const_mgr.add_const('METHOD_BUFFERED',0x00000000)
		win_const_mgr.add_const('IRTIR_TASK_PENDING',0x00000003)
		win_const_mgr.add_const('NI_SETCANDIDATE_PAGESIZE',0x00000017)
		win_const_mgr.add_const('DISPID_SKIPTABSWELCOME',0x00000015)
		win_const_mgr.add_const('DEBUG_EVENT_SESSION_STATUS',0x00000200)
		win_const_mgr.add_const('ACM_MPEG_STEREO',0x00000001)
		win_const_mgr.add_const('ADMIN_STATE_ENABLED_ONLY_FOR_OPER_STATE_UP',0x00000004)
		win_const_mgr.add_const('CERT_STORE_CTRL_COMMIT_FORCE_FLAG',0x00000001)
		win_const_mgr.add_const('CACHE_ENTRY_HEADERINFO_FC',0x00000400)
		win_const_mgr.add_const('ERROR_DS_SAM_INIT_FAILURE',0x00002138)
		win_const_mgr.add_const('WEBPOST_ERROR_COCREATE_WIZARD',0xC0042110)
		win_const_mgr.add_const('LB_GETANCHORINDEX',0x0000019D)
		win_const_mgr.add_const('SEE_MASK_HMONITOR',0x00200000)
		win_const_mgr.add_const('SUCCESS_SUCCESS',0x00000000)
		win_const_mgr.add_const('LINECALLFEATURE_UNHOLD',0x08000000)
		win_const_mgr.add_const('SVI2_NUM_ELEMENTS',0x0000002C)
		win_const_mgr.add_const('CERT_ACCESS_STATE_SYSTEM_STORE_FLAG',0x00000002)
		win_const_mgr.add_const('KSEVENT_TYPE_ENABLEBUFFERED',0x00000004)
		win_const_mgr.add_const('APPLICATION_UNINSTALL',0x00000001)
		win_const_mgr.add_const('ADS_JOB_OFFLINE',0x00000020)
		win_const_mgr.add_const('IDC_UL_PROGRESS',0x00000408)
		win_const_mgr.add_const('ALLOWED_RETRY',0x00000004)
		win_const_mgr.add_const('WM_MENUGETOBJECT',0x00000124)
		win_const_mgr.add_const('EXITEVENT_CERTREVOKED',0x00000008)
		win_const_mgr.add_const('R2_XORPEN',0x00000007)
		win_const_mgr.add_const('TXTLOG_FILEQ',0x00000004)
		win_const_mgr.add_const('DNS_TYPE_HINFO',0x00000000)
		win_const_mgr.add_const('EM_LINESCROLL',0x000000B6)
		win_const_mgr.add_const('IGNORE',0x00000000)
		win_const_mgr.add_const('CP_INSTALLED',0x00000001)
		win_const_mgr.add_const('VK_BROWSER_FAVORITES',0x000000AB)
		win_const_mgr.add_const('ERROR_EVT_MESSAGE_ID_NOT_FOUND',0x00003AB4)
		win_const_mgr.add_const('RPCFLG_ASYNCHRONOUS',0x40000000)
		win_const_mgr.add_const('SQL_TABLE_STAT',0x00000000)
		win_const_mgr.add_const('URLACTION_SHELL_SHELLEXECUTE',0x00001806)
		win_const_mgr.add_const('NT4_MAJOR_VERSION',0x00000001)
		win_const_mgr.add_const('CBS_DROPDOWNLIST',0x00000003)
		win_const_mgr.add_const('EWX_POWEROFF',0x00000008)
		win_const_mgr.add_const('ADS_SERVICE_STOP_PENDING',0x00000003)
		win_const_mgr.add_const('MEM_1M',0x00100000)
		win_const_mgr.add_const('PORT_MPM',0x0000002D)
		win_const_mgr.add_const('ERROR_SAM_INIT_FAILURE',0x0000215D)
		win_const_mgr.add_const('CM_PROB_HALTED',0x0000002C)
		win_const_mgr.add_const('LVCFMT_FIXED_WIDTH',0x00000100)
		win_const_mgr.add_const('DL_CURSORSET',0x00000000)
		win_const_mgr.add_const('SM_DBCSENABLED',0x0000002A)
		win_const_mgr.add_const('LDAP_OPT_PROMPT_CREDENTIALS',0x0000003F)
		win_const_mgr.add_const('JOB_OBJECT_MSG_END_OF_JOB_TIME',0x00000001)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_DATA_SEGMENTS',0x00000010)
		win_const_mgr.add_const('ERROR_RANGE_LIST_CONFLICT',0x00000273)
		win_const_mgr.add_const('WIA_COMPRESSION_NONE',0x00000000)
		win_const_mgr.add_const('VS_FFI_FILEFLAGSMASK',0x0000003F)
		win_const_mgr.add_const('HTTB_CAPTION',0x00000004)
		win_const_mgr.add_const('STARTF_FORCEONFEEDBACK',0x00000040)
		win_const_mgr.add_const('WIA_DPS_PAGE_SIZE',0x00000C19)
		win_const_mgr.add_const('LOCALE_S1159',0x00000028)
		win_const_mgr.add_const('DISPID_IWBSCRIPTCONTROL_VISIBILITY',0x00000009)
		win_const_mgr.add_const('AA_F_WRITE',0x00000200)
		win_const_mgr.add_const('WM_SIZING',0x00000214)
		win_const_mgr.add_const('SIZE_OF_HALRESERVED_ENTRY',0x00000008)
		win_const_mgr.add_const('GS_HANDOBJ_MAX',0x00000002)
		win_const_mgr.add_const('DXVA_SCAN_METHOD_ALTERNATE_VERTICAL',0x00000001)
		win_const_mgr.add_const('IF_TYPE_PROP_DOCS_WIRELESS_MACLAYER',0x000000B4)
		win_const_mgr.add_const('CRYPT_ACCUMULATIVE_TIMEOUT',0x00000800)
		win_const_mgr.add_const('EDITF_ATTRIBUTECA',0x00000200)
		win_const_mgr.add_const('PRIVATEOBJECT_CALL',0x00000004)
		win_const_mgr.add_const('CONFIGFLAG_NEEDS_FORCED_CONFIG',0x00000800)
		win_const_mgr.add_const('IF_TYPE_PPPMULTILINKBUNDLE',0x0000006C)
		win_const_mgr.add_const('DDCAPS2_PRIMARYGAMMA',0x00020000)
		win_const_mgr.add_const('TBS_COMMAND_PRIORITY_MAX',0x80000000)
		win_const_mgr.add_const('HICF_ARROWKEYS',0x00000002)
		win_const_mgr.add_const('DDSD_ZBUFFERBITDEPTH',0x00000040)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_NETWORKCARD',0x00000009)
		win_const_mgr.add_const('BSIS_ALWAYSGRIPPER',0x00000002)
		win_const_mgr.add_const('PPP_IPCP_VJ',0x00000001)
		win_const_mgr.add_const('LINEERR_INVALDIGITLIST',0x80000026)
		win_const_mgr.add_const('PATCH_OPTION_USE_BEST',0x00000000)
		win_const_mgr.add_const('FACILITY_URT',0x00000013)
		win_const_mgr.add_const('D3DTEXOPCAPS_LERP',0x02000000)
		win_const_mgr.add_const('GCS_COMPSTR',0x00000008)
		win_const_mgr.add_const('MIN_USER_DATATYPE',0x00000100)
		win_const_mgr.add_const('CREATE_SHARED_WOW_VDM',0x00001000)
		win_const_mgr.add_const('SCARD_W_CACHE_ITEM_TOO_BIG',0x80100072)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_LASTNUM',0x00000023)
		win_const_mgr.add_const('DEBUG_PHYSICAL_UNCACHED',0x00000002)
		win_const_mgr.add_const('DNS_ERROR_ZONE_CONFIGURATION_ERROR',0x00002584)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_416',0x801901A0)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_417',0x801901A1)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_414',0x8019019E)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_415',0x8019019F)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_412',0x8019019C)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_413',0x8019019D)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_410',0x8019019A)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_411',0x8019019B)
		win_const_mgr.add_const('NCRYPT_IMPL_REMOVABLE_FLAG',0x00000008)
		win_const_mgr.add_const('IPSEC_CIPHER_CONFIG_CBC_AES_192',0x00000004)
		win_const_mgr.add_const('TF_IPP_FLAG_ENABLED',0x00000002)
		win_const_mgr.add_const('RESTART_NO_HANG',0x00000002)
		win_const_mgr.add_const('INTERNET_STATUS_REQUEST_SENT',0x0000001F)
		win_const_mgr.add_const('LCPRI_HARDRECONFIG',0x0000C000)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_RESERVED10',0x0000000A)
		win_const_mgr.add_const('HSE_TERM_MUST_UNLOAD',0x00000002)
		win_const_mgr.add_const('ALG_SID_SSL3SHAMD5',0x00000008)
		win_const_mgr.add_const('ERROR_DS_DRA_SHUTDOWN',0x0000210F)
		win_const_mgr.add_const('MCI_DGV_STEP_REVERSE',0x00010000)
		win_const_mgr.add_const('GREEK_CHARSET',0x000000A1)
		win_const_mgr.add_const('DBPROPVAL_PT_NAME',0x00000004)
		win_const_mgr.add_const('BCRYPT_KEY_DATA_BLOB_MAGIC',0x00000004)
		win_const_mgr.add_const('MCI_VCR_SET_INDEX',0x00100000)
		win_const_mgr.add_const('XEKL_KEYSIZE_INC',0x00000003)
		win_const_mgr.add_const('DBSETFUNC_NONE',0x00000000)
		win_const_mgr.add_const('FILE_NOTIFY_CHANGE_ATTRIBUTES',0x00000004)
		win_const_mgr.add_const('SFVM_GETSELECTEDOBJECTS',0x00000009)
		win_const_mgr.add_const('DCX_WINDOW',0x00000001)
		win_const_mgr.add_const('WIA_IPA_TYMED',0x0000100C)
		win_const_mgr.add_const('DDCAPS2_CANAUTOGENMIPMAP',0x40000000)
		win_const_mgr.add_const('D3D10_FLOAT_TO_SRGB_EXPONENT_NUMERATOR',0x00000001)
		win_const_mgr.add_const('DDSCAPS2_HARDWAREDEINTERLACE',0x00000000)
		win_const_mgr.add_const('CREATE_FORCEDOS',0x00002000)
		win_const_mgr.add_const('FIXED_BASE',0x00000000)
		win_const_mgr.add_const('ERROR_DS_SRC_AND_DST_NC_IDENTICAL',0x00002125)
		win_const_mgr.add_const('UF_USE_AES_KEYS',0x08000000)
		win_const_mgr.add_const('ERROR_CAN_NOT_COMPLETE',0x000003EB)
		win_const_mgr.add_const('DDF_BUFFER',0x00000040)
		win_const_mgr.add_const('PT_CLOSEFIGURE',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_TR_COMMIT_DC',0x00000001)
		win_const_mgr.add_const('SCRIPTPROP_HACK_FIBERSUPPORT',0x70000000)
		win_const_mgr.add_const('SQL_CA1_BULK_ADD',0x00010000)
		win_const_mgr.add_const('OID_FDDI_MAC_DOWNSTREAM_NBR',0x03030226)
		win_const_mgr.add_const('CHANGER_DRIVE_EMPTY_ON_DOOR_ACCESS',0x20000000)
		win_const_mgr.add_const('IF_TYPE_MF_SIGLINK',0x000000A7)
		win_const_mgr.add_const('TMT_PIXELSPERFRAME',0x0000097B)
		win_const_mgr.add_const('IIS_MD_UT_SERVER',0x00000001)
		win_const_mgr.add_const('HFRMREG_FOLDER',0x00000003)
		win_const_mgr.add_const('ERROR_PRINT_CANCELLED',0x0000003F)
		win_const_mgr.add_const('FLAG_ASSUME_USER_WQLFILTER_TRUE',0x04000000)
		win_const_mgr.add_const('LINEAGENTSTATE_NOTREADY',0x00000002)
		win_const_mgr.add_const('LINEAGENTSTATUS_VALIDNEXTSTATES',0x00000100)
		win_const_mgr.add_const('RM_OPTIONSBASE',0x000003E8)
		win_const_mgr.add_const('ISFB_MASK_COLORS',0x00000020)
		win_const_mgr.add_const('WM_DRAWITEM',0x0000002B)
		win_const_mgr.add_const('ERROR_DS_FILTER_UNKNOWN',0x0000203E)
		win_const_mgr.add_const('F_MISSINGENDTAG',0x00000008)
		win_const_mgr.add_const('EVENT_OBJECT_SHOW',0x00008002)
		win_const_mgr.add_const('WH_KEYBOARD',0x00000002)
		win_const_mgr.add_const('SUBLANG_BOSNIAN_BOSNIA_HERZEGOVINA_LATIN',0x00000005)
		win_const_mgr.add_const('IDM_REDO',0x0000001D)
		win_const_mgr.add_const('DNS_QUERY_NO_NETBT',0x00000080)
		win_const_mgr.add_const('BTH_ERROR_LMP_RESPONSE_TIMEOUT',0x00000022)
		win_const_mgr.add_const('SUBSCRIPTION_CAP_ALLOWCDBURN',0x00000002)
		win_const_mgr.add_const('PORT_PCMAILSRV',0x0000009E)
		win_const_mgr.add_const('INTSERV_VERSION0',0x00000000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_PICKUPCALLWAIT',0x00400000)
		win_const_mgr.add_const('BCRYPT_HASH_OPERATION',0x00000002)
		win_const_mgr.add_const('ICU_NO_ENCODE',0x20000000)
		win_const_mgr.add_const('SQL_STANDARD_CLI_CONFORMANCE',0x000000A6)
		win_const_mgr.add_const('WIA_IPC_AUDIO_DATA',0x00001407)
		win_const_mgr.add_const('D3D10_SRGB_GAMMA',0x00000002)
		win_const_mgr.add_const('SHIMSTCAPFLAG_LOCKABLE',0x00000001)
		win_const_mgr.add_const('WS_CLIPCHILDREN',0x02000000)
		win_const_mgr.add_const('WM_MENURBUTTONUP',0x00000122)
		win_const_mgr.add_const('INTERNET_FLAG_RAW_DATA',0x40000000)
		win_const_mgr.add_const('TAPE_DRIVE_EOT_WZ_SIZE',0x00002000)
		win_const_mgr.add_const('USER_PRIV_PARMNUM',0x00000005)
		win_const_mgr.add_const('SQL_CONVERT_SMALLINT',0x00000041)
		win_const_mgr.add_const('WS_EX_LAYOUTRTL',0x00400000)
		win_const_mgr.add_const('CLCTL_GLOBAL_MASK',0x00000001)
		win_const_mgr.add_const('DEBUG_ANY_ID',0x00000000)
		win_const_mgr.add_const('WS_EX_NOPARENTNOTIFY',0x00000004)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_RECEIVING_RESPONSE',0x00000040)
		win_const_mgr.add_const('LANG_MALAYALAM',0x00000004)
		win_const_mgr.add_const('MSV1_0_AV_FLAG_MIC_HANDSHAKE_MESSAGES',0x00000002)
		win_const_mgr.add_const('FILE_ROOT_DIR',0x00000003)
		win_const_mgr.add_const('LDAP_OPT_PING_WAIT_TIME',0x00000037)
		win_const_mgr.add_const('D3D10_SHADER_PACK_MATRIX_COLUMN_MAJOR',0x00000001)
		win_const_mgr.add_const('SHELLSTATEVERSION_WIN2K',0x0000000A)
		win_const_mgr.add_const('AUTHZ_RM_FLAG_NO_AUDIT',0x00000001)
		win_const_mgr.add_const('KSDSOUND_BUFFER_STATIC',0x00000002)
		win_const_mgr.add_const('OS_DATACENTER',0x00000015)
		win_const_mgr.add_const('PDH_LOG_TYPE_TSV',0x00000002)
		win_const_mgr.add_const('IDI_EXCLAMATION',0x00007F03)
		win_const_mgr.add_const('MCI_DGV_STATUS_SAMPLESPERSEC',0x00004027)
		win_const_mgr.add_const('ABOVE_NORMAL_PRIORITY_CLASS',0x00008000)
		win_const_mgr.add_const('LDAP_MOD_DELETE',0x00000001)
		win_const_mgr.add_const('SQL_FN_NUM_SQRT',0x00004000)
		win_const_mgr.add_const('MSGF_USER',0x00001000)
		win_const_mgr.add_const('DDSCAPS_TEXTURE',0x00001000)
		win_const_mgr.add_const('HDFT_HASNOVALUE',0x00008000)
		win_const_mgr.add_const('SS_NOTIFY',0x00000100)
		win_const_mgr.add_const('OID_FFP_ADAPTER_STATS',0xFC020211)
		win_const_mgr.add_const('SIGNERSCORE_WHQL',0x0D000005)
		win_const_mgr.add_const('XBUTTON1',0x00000001)
		win_const_mgr.add_const('DDCAPS2_VIDEOPORT',0x00000004)
		win_const_mgr.add_const('AF_NETDES',0x0000001C)
		win_const_mgr.add_const('PROP_ID_NULL',0x00000000)
		win_const_mgr.add_const('DRV_CLOSE',0x00000004)
		win_const_mgr.add_const('QOS_OBJECT_STARTING_RATE',0x00000006)
		win_const_mgr.add_const('DDCAPS_ALIGNSTRIDE',0x00000020)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_COPY_TCP',0x00000012)
		win_const_mgr.add_const('ACCESS_SUCCESS_ACL',0x00000080)
		win_const_mgr.add_const('NET_IF_OID_COMPARTMENT_ID',0x00000002)
		win_const_mgr.add_const('VMRBITMAP_HDC',0x00000002)
		win_const_mgr.add_const('FLAG_ASSUME_SLOW_LINK',0x20000000)
		win_const_mgr.add_const('TRUSTEE_ACCESS_ALLOWED',0x00000001)
		win_const_mgr.add_const('IOF_VERIFYSERVERSEXIST',0x00000200)
		win_const_mgr.add_const('ISCSI_TARGET_FLAG_MERGE_TARGET_INFORMATION',0x00000004)
		win_const_mgr.add_const('DISPID_WINDOWSETHEIGHT',0x0000010B)
		win_const_mgr.add_const('ADS_SERVICE_ERROR',0x00000008)
		win_const_mgr.add_const('TXFS_LOGGING_MODE_FULL',0x00000002)
		win_const_mgr.add_const('LB_SETLOCALE',0x000001A5)
		win_const_mgr.add_const('CMS_SETRENDERINTENT',0x00000004)
		win_const_mgr.add_const('BLLI_L2_ISO_1745',0x00000001)
		win_const_mgr.add_const('DFM_MAPCOMMANDNAME',0x0000000D)
		win_const_mgr.add_const('CDO_E_NOT_AVAILABLE',0x80040208)
		win_const_mgr.add_const('PRINTACTION_NETINSTALL',0x00000002)
		win_const_mgr.add_const('DN_BOOT_LOG_PROB',0x80000000)
		win_const_mgr.add_const('XEKL_KEYSPEC_KEYX',0x00000001)
		win_const_mgr.add_const('CRYPT_X931_FORMAT',0x00000004)
		win_const_mgr.add_const('MAX_OBJECTID',0x00000040)
		win_const_mgr.add_const('IPPORT_POP3',0x0000006E)
		win_const_mgr.add_const('D3D10_SHADER_SKIP_OPTIMIZATION',0x00000001)
		win_const_mgr.add_const('CDO_E_INVALID_CONTENT_TYPE',0x80040216)
		win_const_mgr.add_const('RPC_S_ENTRY_ALREADY_EXISTS',0x000006E0)
		win_const_mgr.add_const('UDS_HORZ',0x00000040)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_MIPS',0x00000001)
		win_const_mgr.add_const('REPLACEDLGORD',0x00000605)
		win_const_mgr.add_const('SV_PREFERREDAFFINITY_PARMNUM',0x00000242)
		win_const_mgr.add_const('SCE_LOG_LEVEL_ERROR',0x00000001)
		win_const_mgr.add_const('IDC_PS_CHANGEICON',0x000001FC)
		win_const_mgr.add_const('SCARD_E_INSUFFICIENT_BUFFER',0x80100008)
		win_const_mgr.add_const('SPWP_USE_DEVINFO_DATA',0x00000001)
		win_const_mgr.add_const('CERT_TRUST_INVALID_NAME_CONSTRAINTS',0x00000800)
		win_const_mgr.add_const('PST_LAT',0x00000101)
		win_const_mgr.add_const('TOKEN_ADJUST_PRIVILEGES',0x00000020)
		win_const_mgr.add_const('CRL_REASON_UNSPECIFIED',0x00000000)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_MIN',0x00000000)
		win_const_mgr.add_const('SERVICE_PAUSE_CONTINUE',0x00000040)
		win_const_mgr.add_const('RPC_C_QOS_CAPABILITIES_SCHANNEL_FULL_AUTH_IDENTITY',0x00000020)
		win_const_mgr.add_const('FEI_SENDING',0x00000002)
		win_const_mgr.add_const('DOF_PROGMAN',0x00000001)
		win_const_mgr.add_const('APPCOMMAND_TREBLE_UP',0x00000017)
		win_const_mgr.add_const('SHPWHF_NONETPLACECREATE',0x00000002)
		win_const_mgr.add_const('LINEERR_INVALPARKMODE',0x80000034)
		win_const_mgr.add_const('CREATE_NEW',0x00000001)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_DOCUMENT',0x0000047F)
		win_const_mgr.add_const('STGM_OPEN',0x80000000)
		win_const_mgr.add_const('COD_VERSION',0x00000000)
		win_const_mgr.add_const('PDH_FMT_LARGE',0x00000400)
		win_const_mgr.add_const('KS_AMCONTROL_COLORINFO_PRESENT',0x00000080)
		win_const_mgr.add_const('DOT11_PRIORITY_CONTENTION_FREE',0x00000001)
		win_const_mgr.add_const('CSIDL_COOKIES',0x00000021)
		win_const_mgr.add_const('IOF_CREATENEWOBJECT',0x00000020)
		win_const_mgr.add_const('NET_IF_OPER_STATUS_DOWN_NOT_MEDIA_CONNECTED',0x00000002)
		win_const_mgr.add_const('GESTURE_LEFT_RIGHT',0x00000000)
		win_const_mgr.add_const('DS_ONLY_DO_SITE_NAME',0x00000001)
		win_const_mgr.add_const('EAP_FLAG_USER_AUTH',0x00040000)
		win_const_mgr.add_const('ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER',0x00002148)
		win_const_mgr.add_const('LDAP_RES_DELETE',0x00000006)
		win_const_mgr.add_const('LANG_MAORI',0x00000081)
		win_const_mgr.add_const('DEVPROP_TYPE_DEVPROPTYPE',0x00000016)
		win_const_mgr.add_const('IDM_CUSTOMCONTROL',0x00000053)
		win_const_mgr.add_const('VK_EXECUTE',0x0000002B)
		win_const_mgr.add_const('ERROR_DS_DRA_OUT_SCHEDULE_WINDOW',0x000021A9)
		win_const_mgr.add_const('CAUSE_COND_PERMANENT',0x00000001)
		win_const_mgr.add_const('MSIM_LIST_ALLOW',0x00000002)
		win_const_mgr.add_const('RPC_S_FP_OVERFLOW',0x000006EB)
		win_const_mgr.add_const('CRYPTUI_CERT_MGR_TAB_MASK',0x0000000F)
		win_const_mgr.add_const('PDH_OS_EARLIER_VERSION',0xC0000BFA)
		win_const_mgr.add_const('ERROR_OPEN_FILES',0x00000961)
		win_const_mgr.add_const('BIF_STATUSTEXT',0x00000004)
		win_const_mgr.add_const('SASL_OPTION_SEND_SIZE',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_NO_SECURITY_CONTEXT',0x000013C3)
		win_const_mgr.add_const('OID_802_5_FREQUENCY_ERRORS',0x02020205)
		win_const_mgr.add_const('SQL_SCROLL_OPTIONS',0x0000002C)
		win_const_mgr.add_const('WINHTTP_QUERY_HOST',0x00000037)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_STORAGE',0x00000010)
		win_const_mgr.add_const('VDMADDR_PM32',0x00000010)
		win_const_mgr.add_const('LB_SRC_ADDR_USE_DSTADDR_FLAG',0x00000002)
		win_const_mgr.add_const('SSWF_NONE',0x00000000)
		win_const_mgr.add_const('CANCELLED_OPERATION',0x0000000D)
		win_const_mgr.add_const('STI_SUBSCRIBE_FLAG_WINDOW',0x00000001)
		win_const_mgr.add_const('MCGIP_CALENDARROW',0x00000007)
		win_const_mgr.add_const('NDIS_802_11_AI_REQFI_CURRENTAPADDRESS',0x00000004)
		win_const_mgr.add_const('PHONESTATE_SPEAKERGAIN',0x00004000)
		win_const_mgr.add_const('DDCOLOR_COLORENABLE',0x00000040)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_IS_GROUP_CACHING_ENABLED',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_DOWN',0x000013BA)
		win_const_mgr.add_const('ERROR_FILE_TOO_LARGE',0x000000DF)
		win_const_mgr.add_const('BI_JPEG',0x00000004)
		win_const_mgr.add_const('DNS_TYPE_RT',0x00000015)
		win_const_mgr.add_const('SMINIT_TOPLEVEL',0x00000004)
		win_const_mgr.add_const('WINWATCHNOTIFY_DESTROY',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_CORRUPTION',0x00003703)
		win_const_mgr.add_const('SQL_INDEX_CLUSTERED',0x00000001)
		win_const_mgr.add_const('CI_STATE_HIGH_IO',0x00000100)
		win_const_mgr.add_const('DNS_INFO_ADDED_LOCAL_WINS',0x00002619)
		win_const_mgr.add_const('MCAST_UNBLOCK_SOURCE',0x0000002C)
		win_const_mgr.add_const('IMAGE_REL_IA64_PCREL21B',0x00000006)
		win_const_mgr.add_const('CRYPT_RECIPIENT',0x00000010)
		win_const_mgr.add_const('DE_E_FILTER_FRAMESET',0x80100001)
		win_const_mgr.add_const('BS_PUSHBUTTON',0x00000000)
		win_const_mgr.add_const('DNS_RTYPE_MB',0x00000700)
		win_const_mgr.add_const('DDPCAPS_ALLOW256',0x00000040)
		win_const_mgr.add_const('PERFSTATE_POLICY_CHANGE_SINGLE',0x00000001)
		win_const_mgr.add_const('SECPKG_INTERFACE_VERSION_2',0x00020000)
		win_const_mgr.add_const('HH_TP_HELP_CONTEXTMENU',0x00000010)
		win_const_mgr.add_const('DNS_TYPE_RP',0x00000011)
		win_const_mgr.add_const('WMDM_E_INTERFACEDEAD',0x80045001)
		win_const_mgr.add_const('IPX_DSTYPE',0x00004002)
		win_const_mgr.add_const('WM_THEMECHANGED',0x0000031A)
		win_const_mgr.add_const('OPENPROPS_INHIBITPIF',0x00008000)
		win_const_mgr.add_const('EC_LEFTMARGIN',0x00000001)
		win_const_mgr.add_const('ETW_STRING_TYPE_VALUE',0x00000002)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_CAN_PREROLL',0x00004007)
		win_const_mgr.add_const('AM_LOADSTATUS_LOCATING',0x00000003)
		win_const_mgr.add_const('IDS_CAP_ERRORPALSAVE',0x00000195)
		win_const_mgr.add_const('RESOURCETYPE_RESERVED',0x00000008)
		win_const_mgr.add_const('E_SURFACE_DISCARDED',0x8000C003)
		win_const_mgr.add_const('DSQPF_ENABLEADVANCEDFEATURES',0x00000010)
		win_const_mgr.add_const('PRODUCT_STORAGE_WORKGROUP_SERVER',0x00000016)
		win_const_mgr.add_const('SOCK_STREAM',0x00000001)
		win_const_mgr.add_const('EVENT_TRACE_PRIVATE_LOGGER_MODE',0x00000800)
		win_const_mgr.add_const('COOKIE_DOWNGRADED_CACHE_ENTRY',0x00004000)
		win_const_mgr.add_const('PORT_NQS',0x0000025F)
		win_const_mgr.add_const('WIA_IPA_ITEM_TIME',0x00001004)
		win_const_mgr.add_const('RPC_C_USE_INTRANET_PORT',0x00000002)
		win_const_mgr.add_const('URLACTION_WINFX_SETUP',0x00002600)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_HOURS',0x00000304)
		win_const_mgr.add_const('LVS_ALIGNLEFT',0x00000800)
		win_const_mgr.add_const('COD_PERIPHERAL_MINOR_KEYBOARD_MASK',0x00000010)
		win_const_mgr.add_const('TBDDRET_NODEFAULT',0x00000001)
		win_const_mgr.add_const('SFVM_FSNOTIFY',0x0000000E)
		win_const_mgr.add_const('CTL_FIND_NO_LIST_ID_CBDATA',0xFFFFFFFF)
		win_const_mgr.add_const('DTT_APPLYOVERLAY',0x00000001)
		win_const_mgr.add_const('CB_MULTIPLEADDSTRING',0x00000163)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2ERASE_ERASEMEDIA',0x00000201)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_BLACKHOLE',0x00000002)
		win_const_mgr.add_const('RPC_S_PROFILE_NOT_ADDED',0x00000785)
		win_const_mgr.add_const('SQL_CLOSE',0x00000000)
		win_const_mgr.add_const('ERROR_INVALID_COMPUTERNAME',0x000004BA)
		win_const_mgr.add_const('RASLCPO_DES_56',0x00000008)
		win_const_mgr.add_const('APD_COPY_ALL_FILES',0x00000004)
		win_const_mgr.add_const('FILE_FILE_COMPRESSION',0x00000010)
		win_const_mgr.add_const('FEI_JOB_QUEUED',0x00000016)
		win_const_mgr.add_const('DDOVER_DEGRADEARGBSCALING',0x04000000)
		win_const_mgr.add_const('DEBUG_MODNAME_MODULE',0x00000001)
		win_const_mgr.add_const('SQL_STATIC_CURSOR_ATTRIBUTES2',0x000000A8)
		win_const_mgr.add_const('SQL_STATIC_CURSOR_ATTRIBUTES1',0x000000A7)
		win_const_mgr.add_const('MCI_DGV_FILE_MODE_SAVING_S',0x00008004)
		win_const_mgr.add_const('TAPE_DRIVE_SEQUENTIAL_SMKS',0x80200000)
		win_const_mgr.add_const('AUTO_SOURCE',0x00008000)
		win_const_mgr.add_const('RQ_RESOLVE_REQUEST_CACHE',0x00000008)
		win_const_mgr.add_const('CERT_CHAIN_CROSS_CERT_DOWNLOAD_INTERVAL_HOURS_DEFAULT',0x00000018)
		win_const_mgr.add_const('MAPI_ENVELOPE_ONLY',0x00000040)
		win_const_mgr.add_const('MCI_VCR_STATUS_PREROLL_DURATION',0x00004023)
		win_const_mgr.add_const('CRYPT_TYPE2_FORMAT',0x00000002)
		win_const_mgr.add_const('CONTEXT_E_LAST',0x8004E02F)
		win_const_mgr.add_const('LINEADDRESSTYPE_IPADDRESS',0x00000010)
		win_const_mgr.add_const('MODALS_MAX_PASSWD_AGE_PARMNUM',0x00000002)
		win_const_mgr.add_const('MDMSPKRFLAG_OFF',0x00000001)
		win_const_mgr.add_const('OLEUI_FALSE',0x00000000)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_FORCE_KCC_W2K_ELECTION',0x00000001)
		win_const_mgr.add_const('TTF_SUBCLASS',0x00000010)
		win_const_mgr.add_const('MAX_EVENT',0x00000068)
		win_const_mgr.add_const('CBS_OWNERDRAWFIXED',0x00000010)
		win_const_mgr.add_const('ICC_WIN95_CLASSES',0x000000FF)
		win_const_mgr.add_const('PROPID_QUERY_WORKID',0x00000005)
		win_const_mgr.add_const('IF_ADMIN_STATUS_UP',0x00000001)
		win_const_mgr.add_const('MAX_GUID_STRING_LEN',0x00000027)
		win_const_mgr.add_const('PERF_MAX_INSTANCE_NAME',0x00000400)
		win_const_mgr.add_const('SQL_CDO_COLLATION',0x00000008)
		win_const_mgr.add_const('TXFS_RM_FLAG_RESET_RM_AT_NEXT_START',0x00004000)
		win_const_mgr.add_const('STREAM_SET_ENCRYPTION',0x00000003)
		win_const_mgr.add_const('RPC_C_QOS_IDENTITY_DYNAMIC',0x00000001)
		win_const_mgr.add_const('TXTLOG_TIMESTAMP',0x00010000)
		win_const_mgr.add_const('HELP_COMMAND',0x00000102)
		win_const_mgr.add_const('PRINTER_CHANGE_ADD_PRINT_PROCESSOR',0x01000000)
		win_const_mgr.add_const('FACILITY_WINRM',0x00000033)
		win_const_mgr.add_const('FAULT_ACTION_SPECIFIC_MAX',0x00000383)
		win_const_mgr.add_const('CHANNEL_FLAG_FIRST',0x00000001)
		win_const_mgr.add_const('DNS_RCODE_YXDOMAIN',0x00000006)
		win_const_mgr.add_const('ERROR_VALIDATE_CONTINUE',0x00000271)
		win_const_mgr.add_const('PDH_STRING_NOT_FOUND',0xC0000BD4)
		win_const_mgr.add_const('REO_DONTNEEDPALETTE',0x00000020)
		win_const_mgr.add_const('CTL_MODIFY_REQUEST_ADD_NOT_TRUSTED',0x00000001)
		win_const_mgr.add_const('IDD_ACMFILTERCHOOSE_CMB_FILTERTAG',0x00000065)
		win_const_mgr.add_const('ERROR_LOG_CONTAINER_STATE_INVALID',0x000019F2)
		win_const_mgr.add_const('MAPI_E_TOO_MANY_RECIPIENTS',0x0000000A)
		win_const_mgr.add_const('CDO_E_UNCAUGHT_EXCEPTION',0x80040201)
		win_const_mgr.add_const('SBSP_KEEPSAMETEMPLATE',0x00020000)
		win_const_mgr.add_const('INTERNET_OPTION_NET_SPEED',0x0000003D)
		win_const_mgr.add_const('LINEERR_INVALDEVICEHANDLE',0x80000024)
		win_const_mgr.add_const('COPYFLG_NODECOMP',0x00000800)
		win_const_mgr.add_const('D3DCS_PLANE5',0x00000800)
		win_const_mgr.add_const('PIDDSI_PRESFORMAT',0x00000003)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_HOST',0x00000080)
		win_const_mgr.add_const('INTERNET_STATE_DISCONNECTED',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_TC_DDL_COMMIT',0x00000002)
		win_const_mgr.add_const('IPPORT_DISCARD',0x00000009)
		win_const_mgr.add_const('SHI1005_FLAGS_DFS',0x00000001)
		win_const_mgr.add_const('CFM_CHARSET',0x08000000)
		win_const_mgr.add_const('TVIF_STATE',0x00000008)
		win_const_mgr.add_const('ERROR_DS_FOREST_VERSION_TOO_LOW',0x00002175)
		win_const_mgr.add_const('DMICMMETHOD_SYSTEM',0x00000002)
		win_const_mgr.add_const('IDS_CAP_READONLYFILE',0x0000019D)
		win_const_mgr.add_const('WKSTA_USERAWWRITE_PARMNUM',0x00000037)
		win_const_mgr.add_const('PHONEFEATURE_SETVOLUMEHEADSET',0x08000000)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_SECURITY',0x00000004)
		win_const_mgr.add_const('SPDRP_CAPABILITIES',0x0000000F)
		win_const_mgr.add_const('EXECUTE_OFFLINE_DIAGS',0x000000D4)
		win_const_mgr.add_const('SQL_ISV_VIEW_COLUMN_USAGE',0x00100000)
		win_const_mgr.add_const('PXE_PROV_FILTER_DHCP_ONLY',0x00000001)
		win_const_mgr.add_const('SHTDN_REASON_VALID_BIT_MASK',0x00000000)
		win_const_mgr.add_const('SG_CONSTRAINED_GROUP',0x00000002)
		win_const_mgr.add_const('IDS_CAP_STAT_CAP_AUDIO',0x000001FD)
		win_const_mgr.add_const('IP_VERSION_SHIFT',0x00000004)
		win_const_mgr.add_const('DEBUG_TYPEOPTS_FORCERADIX_OUTPUT',0x00000004)
		win_const_mgr.add_const('RTM_MATCH_INTERFACE',0x00000010)
		win_const_mgr.add_const('DNS_ERROR_ZONE_BASE',0x00002580)
		win_const_mgr.add_const('AE_RESACCESS2',0x00000012)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_GAMMA',0x00004005)
		win_const_mgr.add_const('LINEAGENTSTATUS_ACTIVITY',0x00000008)
		win_const_mgr.add_const('DIGCDP_FLAG_REMOTE_BASIC',0x00000003)
		win_const_mgr.add_const('WSAEADDRNOTAVAIL',0x00002741)
		win_const_mgr.add_const('WINHTTP_AUTOPROXY_AUTO_DETECT',0x00000001)
		win_const_mgr.add_const('HTTP_QUERY_UPGRADE',0x00000040)
		win_const_mgr.add_const('CRL_DIST_POINT_FULL_NAME',0x00000001)
		win_const_mgr.add_const('SPEAKER_TOP_FRONT_RIGHT',0x00004000)
		win_const_mgr.add_const('EAP_I_EAPHOST_EAP_NEGOTIATION_FAILED',0x40420016)
		win_const_mgr.add_const('RATING_THREE_STARS_SET',0x00000032)
		win_const_mgr.add_const('ERROR_DS_PARENT_IS_AN_ALIAS',0x0000208A)
		win_const_mgr.add_const('ACM_FORMATSUGGESTF_WFORMATTAG',0x00010000)
		win_const_mgr.add_const('DAOROWFETCH_ODBCNEXT',0x00000010)
		win_const_mgr.add_const('SPI_GETLOWPOWERTIMEOUT',0x0000004F)
		win_const_mgr.add_const('PDH_LOG_OPT_APPEND',0x08000000)
		win_const_mgr.add_const('JIFMK_DNL',0x0000FFDC)
		win_const_mgr.add_const('MM_SNDBLST_WAVEOUT',0x00000006)
		win_const_mgr.add_const('COOKIE_OP_GET',0x00000004)
		win_const_mgr.add_const('PTE_CACHE_MASK',0x00000000)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_CAN_LOCK',0x00004000)
		win_const_mgr.add_const('COLOR_ELEMENT',0x000002CC)
		win_const_mgr.add_const('SL_SERVER_ZONE',0x0000B000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_ACDGROUP',0x40000000)
		win_const_mgr.add_const('DE_E_DOWNLOAD_FAILURE',0x800C0008)
		win_const_mgr.add_const('L2_NOTIFICATION_SOURCE_DOT3_AUTO_CONFIG',0x00000000)
		win_const_mgr.add_const('TH32CS_SNAPHEAPLIST',0x00000001)
		win_const_mgr.add_const('RDW_INVALIDATE',0x00000001)
		win_const_mgr.add_const('MDPROPVAL_MOQ_DIM_HIER',0x00000010)
		win_const_mgr.add_const('SERVICE_ACCEPT_PARAMCHANGE',0x00000008)
		win_const_mgr.add_const('SERVICE_CONTROL_NETBINDADD',0x00000007)
		win_const_mgr.add_const('CE_RXPARITY',0x00000004)
		win_const_mgr.add_const('KAGPROPVAL_CONCUR_ROWVER',0x00000001)
		win_const_mgr.add_const('FWPM_LAYER_FLAG_BUFFERED',0x00000008)
		win_const_mgr.add_const('RASTER_FONTTYPE',0x00000001)
		win_const_mgr.add_const('FACILITY_WMAAECMA',0x000007CC)
		win_const_mgr.add_const('CTF_FREELIBANDEXIT',0x00000010)
		win_const_mgr.add_const('KEYEVENTF_SCANCODE',0x00000008)
		win_const_mgr.add_const('WB_NEXTBREAK',0x00000007)
		win_const_mgr.add_const('CHANNEL_OPTION_PRI_HIGH',0x08000000)
		win_const_mgr.add_const('CDEF_DEVMON_PNP_DEVICE',0x00000040)
		win_const_mgr.add_const('TC_SA_INTEGER',0x00000080)
		win_const_mgr.add_const('SERVICE_FLAG_DEFER',0x00000001)
		win_const_mgr.add_const('ALG_TYPE_BLOCK',0x00000003)
		win_const_mgr.add_const('ERROR_PASSWORD_RESTRICTION',0x0000052D)
		win_const_mgr.add_const('KSEVENTF_SEMAPHORE_OBJECT',0x00000008)
		win_const_mgr.add_const('URLACTION_ACTIVEX_OVERRIDE_SCRIPT_SAFETY',0x00001203)
		win_const_mgr.add_const('TRACE_USE_DATE',0x00000008)
		win_const_mgr.add_const('CDERR_FINDRESFAILURE',0x00000006)
		win_const_mgr.add_const('IP_ADAPTER_ADDRESS_TRANSIENT',0x00000002)
		win_const_mgr.add_const('MAX_LINKID_TEXT',0x00000030)
		win_const_mgr.add_const('CM_CREATE_DEVNODE_NO_WAIT_INSTALL',0x00000001)
		win_const_mgr.add_const('S_LEGATO',0x00000001)
		win_const_mgr.add_const('DMBIN_LARGEFMT',0x0000000A)
		win_const_mgr.add_const('COD_AUDIO_MINOR_VIDEO_CAMERA',0x0000000C)
		win_const_mgr.add_const('WIA_IPS_MIN_HORIZONTAL_SIZE',0x00001817)
		win_const_mgr.add_const('LANG_KANNADA',0x00000004)
		win_const_mgr.add_const('MCI_VCR_STATUS_COUNTER_FORMAT',0x00004010)
		win_const_mgr.add_const('D3DCAPS3_ALPHA_FULLSCREEN_FLIP_OR_DISCARD',0x00000020)
		win_const_mgr.add_const('DRIVERSIGN_NONE',0x00000000)
		win_const_mgr.add_const('PDH_INVALID_BUFFER',0xC0000BC1)
		win_const_mgr.add_const('SP_NOTREPORTED',0x00004000)
		win_const_mgr.add_const('CACHE_NOTIFY_UPDATE_URL',0x00000004)
		win_const_mgr.add_const('DDE_FBUSY',0x00004000)
		win_const_mgr.add_const('CLASSFACTORY_E_FIRST',0x80040110)
		win_const_mgr.add_const('CERT_CHAIN_USE_LOCAL_MACHINE_STORE',0x00000008)
		win_const_mgr.add_const('SQL_API_SQLPARAMDATA',0x00000030)
		win_const_mgr.add_const('LVHT_EX_GROUP_STATEICON',0x01000000)
		win_const_mgr.add_const('LINETRANSLATERESULT_LOCAL',0x00000008)
		win_const_mgr.add_const('CAL_SDAYNAME1',0x00000007)
		win_const_mgr.add_const('ERROR_NOTHING_TO_TERMINATE',0x000002F6)
		win_const_mgr.add_const('EPR_270',0x00000001)
		win_const_mgr.add_const('EVENT_SRCSPEW_START',0x00000064)
		win_const_mgr.add_const('KAGPROP_CURSOR',0x00000006)
		win_const_mgr.add_const('DRM_AL_FETCHNOADVISORY',0x00000008)
		win_const_mgr.add_const('DNS_RTYPE_GID',0x00006600)
		win_const_mgr.add_const('CAL_SDAYNAME7',0x00000000)
		win_const_mgr.add_const('ISR_NAT_PAGE',0x00000002)
		win_const_mgr.add_const('PROCESS_DUP_HANDLE',0x00000040)
		win_const_mgr.add_const('ERROR_DS_CANT_RETRIEVE_ATTS',0x00002121)
		win_const_mgr.add_const('IOCPARM_MASK',0x00000007)
		win_const_mgr.add_const('ERROR_INVALID_THREAD_ID',0x000005A4)
		win_const_mgr.add_const('NDIS_802_11_AI_RESFI_CAPABILITIES',0x00000001)
		win_const_mgr.add_const('ERROR_CTX_WINSTATION_BUSY',0x00001B70)
		win_const_mgr.add_const('CAL_SDAYNAME5',0x00000000)
		win_const_mgr.add_const('TRUSTERROR_MAX_STEPS',0x00000026)
		win_const_mgr.add_const('LOCALGROUP_COMMENT_PARMNUM',0x00000002)
		win_const_mgr.add_const('DCB_DISABLE',0x00000008)
		win_const_mgr.add_const('RTR_INFO_BLOCK_VERSION',0x00000001)
		win_const_mgr.add_const('MSIM_DISPID_ONLOCALFRIENDLYNAMECHANGERESULT',0x00000E07)
		win_const_mgr.add_const('LANG_GEORGIAN',0x00000037)
		win_const_mgr.add_const('LCS_GM_BUSINESS',0x00000001)
		win_const_mgr.add_const('CERT_CREATE_CONTEXT_NO_ENTRY_FLAG',0x00000008)
		win_const_mgr.add_const('CERT_CHAIN_THREAD_STORE_SYNC',0x00000002)
		win_const_mgr.add_const('REG_EXPAND_SZ',0x00000002)
		win_const_mgr.add_const('TASK_NOVEMBER',0x00000400)
		win_const_mgr.add_const('DSPROVIDER_UNUSED_3',0x00000008)
		win_const_mgr.add_const('DSPROVIDER_UNUSED_2',0x00000004)
		win_const_mgr.add_const('DSPROVIDER_UNUSED_1',0x00000002)
		win_const_mgr.add_const('DSPROVIDER_UNUSED_0',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_PARTIAL_WRITE',0x00001722)
		win_const_mgr.add_const('ILR_HORIZONTAL_CENTER',0x00000001)
		win_const_mgr.add_const('DXGI_CPU_ACCESS_FIELD',0x0000000F)
		win_const_mgr.add_const('ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY',0x000002FA)
		win_const_mgr.add_const('ABN_WINDOWARRANGE',0x00000003)
		win_const_mgr.add_const('MCI_DGV_DELETE_VIDEO_STREAM',0x00040000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_AUTH_FAIL',0x000035E9)
		win_const_mgr.add_const('OID_FDDI_SMT_ECM_STATE',0x03030215)
		win_const_mgr.add_const('SQL_SQ_IN',0x00000004)
		win_const_mgr.add_const('DB_DISP_FOREIGN',0x0000000C)
		win_const_mgr.add_const('WMDM_STATUS_STORAGECONTROL_MOVING',0x00010000)
		win_const_mgr.add_const('ERROR_MCA_INVALID_CAPABILITIES_STRING',0x00003B60)
		win_const_mgr.add_const('SQL_FN_NUM_MOD',0x00000800)
		win_const_mgr.add_const('SERVICE_LOGON_FAILED',0x00000020)
		win_const_mgr.add_const('SP_PROT_UNI_SERVER',0x40000000)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_AMD64',0x00008664)
		win_const_mgr.add_const('SQL_SP_OVERLAPS',0x00000080)
		win_const_mgr.add_const('RBBIM_LPARAM',0x00000400)
		win_const_mgr.add_const('PFD_GENERIC_FORMAT',0x00000040)
		win_const_mgr.add_const('WKSTA_LOGON_SERVER_PARMNUM',0x00000009)
		win_const_mgr.add_const('WIA_IPA_ITEM_FLAGS',0x00001005)
		win_const_mgr.add_const('SUBLANG_MONGOLIAN_PRC',0x00000002)
		win_const_mgr.add_const('CR_PROP_BASECRL',0x00000011)
		win_const_mgr.add_const('DMPAPER_B5_JIS_ROTATED',0x00000050)
		win_const_mgr.add_const('CM_DISABLE_HARDWARE',0x00000002)
		win_const_mgr.add_const('SECPKG_ATTR_DCE_INFO',0x00000003)
		win_const_mgr.add_const('ERROR_RDP_PROTOCOL_ERROR',0x00001B99)
		win_const_mgr.add_const('DEX_IDS_INVALID_DEFAULT_DXT',0x00000584)
		win_const_mgr.add_const('MF_HELP',0x00004000)
		win_const_mgr.add_const('DSECAF_NOTLISTED',0x00000001)
		win_const_mgr.add_const('CM_PROB_NORMAL_CONFLICT',0x0000000C)
		win_const_mgr.add_const('ERROR_BAD_FILE_TYPE',0x000000DE)
		win_const_mgr.add_const('SQL_U_UNION',0x00000001)
		win_const_mgr.add_const('DIF_ADDPROPERTYPAGE_BASIC',0x00000024)
		win_const_mgr.add_const('FEI_COMPLETED',0x00000004)
		win_const_mgr.add_const('DMICM_USER',0x00000100)
		win_const_mgr.add_const('CERT_ENHKEY_USAGE_PROP_ID',0x00000009)
		win_const_mgr.add_const('NETLOGON_CONTROL_BREAKPOINT',0x0000FFFF)
		win_const_mgr.add_const('ERROR_PATCH_DECODE_FAILURE',0xC00E4101)
		win_const_mgr.add_const('SSPROP_FASTLOADKEEPIDENTITY',0x0000000B)
		win_const_mgr.add_const('MCI_NOTIFY_ABORTED',0x00000004)
		win_const_mgr.add_const('WLAN_MAX_PHY_INDEX',0x00000040)
		win_const_mgr.add_const('WMDRM_SECURITY_PERFORM_INDIV',0x00000001)
		win_const_mgr.add_const('IDM_NOACTIVATEJAVAAPPLETS',0x0000091E)
		win_const_mgr.add_const('LVCDRF_NOSELECT',0x00010000)
		win_const_mgr.add_const('NOTIFY_FOR_ALL_SESSIONS',0x00000001)
		win_const_mgr.add_const('SCH_CRED_FORMAT_CERT_HASH',0x00000001)
		win_const_mgr.add_const('META_STRETCHBLT',0x00000B23)
		win_const_mgr.add_const('DISPID_ISDIRTY',0x00000016)
		win_const_mgr.add_const('KSDATAFORMAT_BIT_TEMPORAL_COMPRESSION',0x00000000)
		win_const_mgr.add_const('DE_E_CONNECTION_TIMEOUT',0x800C000B)
		win_const_mgr.add_const('ASC_REQ_USE_DCE_STYLE',0x00000200)
		win_const_mgr.add_const('ERROR_NO_PROMOTION_ACTIVE',0x0000201E)
		win_const_mgr.add_const('WM_IME_SETCONTEXT',0x00000281)
		win_const_mgr.add_const('CMSG_ENVELOPE_ALGORITHM_PARAM',0x0000000F)
		win_const_mgr.add_const('PO_REN_PORT',0x00000034)
		win_const_mgr.add_const('IDM_HORIZONTALLINE',0x00000866)
		win_const_mgr.add_const('ICW_MAX_RASNAME',0x00000100)
		win_const_mgr.add_const('RR_MBZ1',0x00000020)
		win_const_mgr.add_const('ERROR_DS_INAPPROPRIATE_AUTH',0x00002029)
		win_const_mgr.add_const('IIS_MD_VR_BASE',0x00000BB8)
		win_const_mgr.add_const('ERROR_TOO_MANY_POSTS',0x0000012A)
		win_const_mgr.add_const('ES_SYSTEM_REQUIRED',0x00000001)
		win_const_mgr.add_const('RR_MBZ0',0x00000001)
		win_const_mgr.add_const('SQL_OJ_FULL',0x00000004)
		win_const_mgr.add_const('IDM_VIEWPRETRANSFORMSOURCE',0x00000943)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_DPC',0x00000020)
		win_const_mgr.add_const('LINEERR_BEARERMODEUNAVAIL',0x80000003)
		win_const_mgr.add_const('STGM_SHARE_DENY_READ',0x00000030)
		win_const_mgr.add_const('IMAGE_REL_CEF_SECTION',0x00000004)
		win_const_mgr.add_const('ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE',0x000013A7)
		win_const_mgr.add_const('ERROR_CLIPBOARD_NOT_OPEN',0x0000058A)
		win_const_mgr.add_const('CRYPT_CREATE_SALT',0x00000004)
		win_const_mgr.add_const('_MM_HINT_NTA',0x00000000)
		win_const_mgr.add_const('MAX_HOSTNAME_LEN',0x00000080)
		win_const_mgr.add_const('ERROR_CONTEXT_EXPIRED',0x0000078B)
		win_const_mgr.add_const('SCRIPTINFO_IUNKNOWN',0x00000001)
		win_const_mgr.add_const('BCRYPT_DSA_PRIVATE_MAGIC',0x56505344)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_CLIENTNAME',0x0000010A)
		win_const_mgr.add_const('URLPOLICY_JAVA_MEDIUM',0x00020000)
		win_const_mgr.add_const('SECPKG_ATTR_LOCAL_CRED',0x00000052)
		win_const_mgr.add_const('MM_MIXM_CONTROL_CHANGE',0x000003D1)
		win_const_mgr.add_const('MAX_RADIUS_ADDRESS_LEN',0x00000029)
		win_const_mgr.add_const('ERROR_TRANSACTION_ALREADY_COMMITTED',0x00001A31)
		win_const_mgr.add_const('SQL_IC_UPPER',0x00000001)
		win_const_mgr.add_const('MCI_VCR_STATUS_PLAY_FORMAT',0x00004005)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_IS_AUTO_TOPOLOGY_DISABLED',0x00000001)
		win_const_mgr.add_const('OPTION_TRAILERS',0x00000022)
		win_const_mgr.add_const('INTERNET_OPEN_TYPE_PRECONFIG',0x00000000)
		win_const_mgr.add_const('R2_MERGEPEN',0x0000000F)
		win_const_mgr.add_const('LINEDEVSTATE_OTHER',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNCLOSEDSTARTTAG',0x000036EC)
		win_const_mgr.add_const('CRL_REASON_AFFILIATION_CHANGED',0x00000003)
		win_const_mgr.add_const('DMBIN_MIDDLE',0x00000003)
		win_const_mgr.add_const('GET_MODULE_HANDLE_EX_FLAG_UNCHANGED_REFCOUNT',0x00000002)
		win_const_mgr.add_const('SHDID_COMPUTER_NETDRIVE',0x00000009)
		win_const_mgr.add_const('TF_USE_DEFAULT_WORKER',0x00000000)
		win_const_mgr.add_const('SERIAL_IOC_MCR_DTR',0x00000001)
		win_const_mgr.add_const('PDERR_RETDEFFAILURE',0x00001003)
		win_const_mgr.add_const('JOB_OBJECT_SET_SECURITY_ATTRIBUTES',0x00000010)
		win_const_mgr.add_const('DISPID_PHISHINGENABLED',0x00000013)
		win_const_mgr.add_const('SHTDN_REASON_MAJOR_NONE',0x00000000)
		win_const_mgr.add_const('DVB_EIT_ACTUAL_TID',0x0000004E)
		win_const_mgr.add_const('PBT_APMQUERYSTANDBYFAILED',0x00000003)
		win_const_mgr.add_const('CRYPT_FLAG_SSL3',0x00000004)
		win_const_mgr.add_const('CRYPT_FLAG_SSL2',0x00000002)
		win_const_mgr.add_const('GESTURE_DIGIT_5',0x00000000)
		win_const_mgr.add_const('ERROR_DIR_NOT_EMPTY',0x00000091)
		win_const_mgr.add_const('GESTURE_DIGIT_7',0x00000000)
		win_const_mgr.add_const('COLOR_HUE',0x000002BF)
		win_const_mgr.add_const('GESTURE_DIGIT_1',0x00000000)
		win_const_mgr.add_const('GESTURE_DIGIT_0',0x00000000)
		win_const_mgr.add_const('GESTURE_DIGIT_3',0x00000000)
		win_const_mgr.add_const('GESTURE_DIGIT_2',0x00000000)
		win_const_mgr.add_const('VTBIT_UI1',0x00000001)
		win_const_mgr.add_const('LIS_FOCUSED',0x00000001)
		win_const_mgr.add_const('WM_COMMAND',0x00000111)
		win_const_mgr.add_const('VTBIT_UI2',0x00000001)
		win_const_mgr.add_const('GESTURE_DIGIT_9',0x00000000)
		win_const_mgr.add_const('GESTURE_DIGIT_8',0x00000000)
		win_const_mgr.add_const('SQL_API_SQLMORERESULTS',0x0000003D)
		win_const_mgr.add_const('GESTURE_BRACKET_UNDER',0x00000000)
		win_const_mgr.add_const('ERROR_PATCH_NEWER_FORMAT',0xC00E4103)
		win_const_mgr.add_const('POLICY_ERRV_NO_RESOURCES',0x00000034)
		win_const_mgr.add_const('WINHTTP_OPTION_SPN',0x00000060)
		win_const_mgr.add_const('DISPID_CREATESUBSCRIPTION',0x0000000B)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_FAILSSPINIT',0x0000361D)
		win_const_mgr.add_const('REPL_INTEGRITY_TREE',0x00000002)
		win_const_mgr.add_const('MAXEAPCODE',0x00000004)
		win_const_mgr.add_const('SQL_FN_STR_LCASE',0x00000040)
		win_const_mgr.add_const('ERROR_DS_REFUSING_FSMO_ROLES',0x000020F1)
		win_const_mgr.add_const('DVB_TOT_TID',0x00000073)
		win_const_mgr.add_const('PROP_SM_CXDLG',0x000000D4)
		win_const_mgr.add_const('ERROR_NO_VOLUME_LABEL',0x0000007D)
		win_const_mgr.add_const('URLOSTRM_USECACHEDCOPY_ONLY',0x00000001)
		win_const_mgr.add_const('MSIDXSPROP_RESULTS_FOUND',0x00000007)
		win_const_mgr.add_const('ERROR_PNP_REBOOT_REQUIRED',0x0000027E)
		win_const_mgr.add_const('X509_NDR_ENCODING',0x00000002)
		win_const_mgr.add_const('OCR_SIZE',0x00007F80)
		win_const_mgr.add_const('ERROR_DRIVE_LOCKED',0x0000006C)
		win_const_mgr.add_const('WGL_SWAP_MAIN_PLANE',0x00000001)
		win_const_mgr.add_const('ERROR_OBJECT_NAME_EXISTS',0x000002BA)
		win_const_mgr.add_const('DNS_ERROR_SOA_DELETE_INVALID',0x00002592)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATAEVENTARGS_ESTIMATEDTOTALTIME',0x00000302)
		win_const_mgr.add_const('LVTVIF_EXTENDED',0x00000004)
		win_const_mgr.add_const('CPF_SIGNATURE_ERROR',0x00000080)
		win_const_mgr.add_const('MQMSG_AUTH_LEVEL_NONE',0x00000000)
		win_const_mgr.add_const('MCI_GETDEVCAPS_CAN_SAVE',0x00000009)
		win_const_mgr.add_const('CTRY_BAHRAIN',0x000003CD)
		win_const_mgr.add_const('IME_REQUEST_CONVERT',0x00000001)
		win_const_mgr.add_const('DS_REPSYNCALL_SKIP_INITIAL_CHECK',0x00000010)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_HASH_SIZE',0x00003630)
		win_const_mgr.add_const('MD_EXTLOG_HOST',0x00100000)
		win_const_mgr.add_const('OID_WAN_CO_SET_LINK_INFO',0x04010181)
		win_const_mgr.add_const('ERROR_DS_DRA_INTERNAL_ERROR',0x000020FA)
		win_const_mgr.add_const('PORT_COURIER',0x00000212)
		win_const_mgr.add_const('SUBLANG_SPANISH_ARGENTINA',0x00000000)
		win_const_mgr.add_const('FR_NOWHOLEWORD',0x00001000)
		win_const_mgr.add_const('RPC_C_LISTEN_MAX_CALLS_DEFAULT',0x000004D2)
		win_const_mgr.add_const('CM_CDMASK_DEVINST',0x00000001)
		win_const_mgr.add_const('SSA_TAB',0x00000002)
		win_const_mgr.add_const('COLOR_GREEN',0x000002C3)
		win_const_mgr.add_const('SCARD_PRESENT',0x00000002)
		win_const_mgr.add_const('DBPROP_CI_SCOPE_FLAGS',0x00000004)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_FWDSTATUSVALID',0x00020000)
		win_const_mgr.add_const('TRUST_AUTH_TYPE_CLEAR',0x00000002)
		win_const_mgr.add_const('CSBFT_DATABASE_DIRECTORY',0x00000040)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_START_TIME',0x00000011)
		win_const_mgr.add_const('CMSG_DATA_FLAG',0x00000001)
		win_const_mgr.add_const('ODBC_SYSTEM_DSN',0x00000002)
		win_const_mgr.add_const('DT_RTLREADING',0x00020000)
		win_const_mgr.add_const('CRYPTUI_SELECT_ISSUEDBY_COLUMN',0x00000002)
		win_const_mgr.add_const('CSIDL_COMMON_ALTSTARTUP',0x00000001)
		win_const_mgr.add_const('PERF_DETAIL_NOVICE',0x00000064)
		win_const_mgr.add_const('SQL_BS_ROW_COUNT_EXPLICIT',0x00000002)
		win_const_mgr.add_const('DISPID_GETERRORURL',0x00000012)
		win_const_mgr.add_const('SYMF_CONSTANT',0x00000100)
		win_const_mgr.add_const('LINEPARKMODE_NONDIRECTED',0x00000002)
		win_const_mgr.add_const('ERROR_NO_SHUTDOWN_IN_PROGRESS',0x0000045C)
		win_const_mgr.add_const('ADS_JOB_PAUSED',0x00000001)
		win_const_mgr.add_const('BATTERY_DISCHARGE_FLAGS_ENABLE',0x80000000)
		win_const_mgr.add_const('SBSP_UNTRUSTEDFORDOWNLOAD',0x02000000)
		win_const_mgr.add_const('USER_PROFILE',0x00000034)
		win_const_mgr.add_const('DDCAPS2_CANMANAGERESOURCE',0x10000000)
		win_const_mgr.add_const('DBT_VOLLOCKQUERYUNLOCK',0x00008044)
		win_const_mgr.add_const('DEBUG_REQUEST_GET_WIN32_MAJOR_MINOR_VERSIONS',0x00000006)
		win_const_mgr.add_const('ERROR_PRINT_MONITOR_IN_USE',0x00000BC0)
		win_const_mgr.add_const('RTM_MATCH_NEIGHBOUR',0x00000002)
		win_const_mgr.add_const('QOS_CLASS4',0x00000004)
		win_const_mgr.add_const('QOS_CLASS0',0x00000000)
		win_const_mgr.add_const('PDH_SQL_ALLOC_FAILED',0xC0000BE0)
		win_const_mgr.add_const('QOS_CLASS2',0x00000002)
		win_const_mgr.add_const('CERT_STORE_PROV_NO_PERSIST_FLAG',0x00000004)
		win_const_mgr.add_const('DXVA_QUERYORREPLYFUNCFLAG_DECODER_PROBE_QUERY',0x00FFFFF1)
		win_const_mgr.add_const('LOGON32_LOGON_NEW_CREDENTIALS',0x00000009)
		win_const_mgr.add_const('FW_MEDIUM',0x000001F4)
		win_const_mgr.add_const('USER_USE_DES_KEY_ONLY',0x00008000)
		win_const_mgr.add_const('NETE_CONNMODE',0x0000000C)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_IS_FRAGMENT_GROUP',0x00000040)
		win_const_mgr.add_const('SQL_CP_ONE_PER_HENV',0x00000002)
		win_const_mgr.add_const('MCI_OVLY_GETDEVCAPS_MAX_WINDOWS',0x00004003)
		win_const_mgr.add_const('SOUND_SYSTEM_QUESTION',0x00000005)
		win_const_mgr.add_const('APPCOMMAND_FIND',0x0000001C)
		win_const_mgr.add_const('DEBUG_CES_ALL',0x00000000)
		win_const_mgr.add_const('WAVE_FILTER_VOLUME',0x00000001)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_ADMINS',0x00000200)
		win_const_mgr.add_const('D3DPS20CAPS_PREDICATION',0x00000001)
		win_const_mgr.add_const('META_SETTEXTJUSTIFICATION',0x0000020A)
		win_const_mgr.add_const('CFM_DISABLED',0x00002000)
		win_const_mgr.add_const('SECPKG_ATTR_SERVER_AUTH_FLAGS',0x80000083)
		win_const_mgr.add_const('GUI_SYSTEMMENUMODE',0x00000008)
		win_const_mgr.add_const('BASE_VAL_WIA_ERROR',0x00000000)
		win_const_mgr.add_const('SNMP_ERROR_NOTWRITABLE',0x00000011)
		win_const_mgr.add_const('NCBADDGRNAME',0x00000036)
		win_const_mgr.add_const('HCBT_SETFOCUS',0x00000009)
		win_const_mgr.add_const('IFS_VALID',0x00000001)
		win_const_mgr.add_const('WAVEIN_MAPPER_STATUS_MAPPED',0x00000001)
		win_const_mgr.add_const('OID_FDDI_MAC_SHORT_GRP_ADDRESS',0x0303022F)
		win_const_mgr.add_const('PRINTER_ENUM_HIDE',0x01000000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_RECEIVE',0x0000000B)
		win_const_mgr.add_const('WINEVENT_OPCODE_DC_START',0x00000003)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MIPFPOINT',0x00010000)
		win_const_mgr.add_const('GESTURE_DIAGONAL_LEFTUP',0x00000000)
		win_const_mgr.add_const('DMPAPER_12X11',0x0000005A)
		win_const_mgr.add_const('ILDI_RESETACCESS',0x00000004)
		win_const_mgr.add_const('DMPAPER_A5_TRANSVERSE',0x0000003D)
		win_const_mgr.add_const('SECURITY_PACKAGE_BASE_RID',0x00000040)
		win_const_mgr.add_const('PRIORITY_EQUAL_LAST',0x00000000)
		win_const_mgr.add_const('URLMON_OPTION_USE_BROWSERAPPSDOCUMENTS',0x10000010)
		win_const_mgr.add_const('ERROR_SXS_XML_E_BADXMLDECL',0x000036E8)
		win_const_mgr.add_const('NDIS_PROT_OPTION_ESTIMATED_LENGTH',0x00000001)
		win_const_mgr.add_const('MUI_LANGUAGE_NAME',0x00000008)
		win_const_mgr.add_const('IMPORTANCE_NORMAL_MIN',0x00000002)
		win_const_mgr.add_const('DISPID_ONVISIBLE',0x000000FE)
		win_const_mgr.add_const('GETDEVICEUNITS',0x0000002A)
		win_const_mgr.add_const('ERRCLASS_BADFMT',0x00000009)
		win_const_mgr.add_const('MD_ERROR_READ_METABASE_FILE',0x800CC819)
		win_const_mgr.add_const('IMAGE_SEPARATE_DEBUG_FLAGS_MASK',0x00008000)
		win_const_mgr.add_const('PFA_FULL_INTERWORD',0x00000004)
		win_const_mgr.add_const('SPQ_SCAN_FILE_VALIDITY',0x00000002)
		win_const_mgr.add_const('IDENTIFY_BUFFER_SIZE',0x00000200)
		win_const_mgr.add_const('DS_REPADD_FULL_REPLICA',0x01000000)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_STILL',0x00800000)
		win_const_mgr.add_const('ISC_RET_USED_COLLECTED_CREDS',0x00000040)
		win_const_mgr.add_const('CERT_DISPWELL_DISTRUST_LEAF_CERT',0x00000007)
		win_const_mgr.add_const('LINETRANSFERMODE_CONFERENCE',0x00000002)
		win_const_mgr.add_const('IDM_FONTNAME',0x00000012)
		win_const_mgr.add_const('SCS_CAP_MAKEREAD',0x00000002)
		win_const_mgr.add_const('LDAP_MSG_ONE',0x00000000)
		win_const_mgr.add_const('TRANSACTION_ROLLBACK',0x00000010)
		win_const_mgr.add_const('CMSG_SIGNED',0x00000002)
		win_const_mgr.add_const('HTTP_QUERY_PROXY_CONNECTION',0x00000045)
		win_const_mgr.add_const('CR_PROP_KRACERTSTATE',0x0000001B)
		win_const_mgr.add_const('D3DCAPS2_DYNAMICTEXTURES',0x20000000)
		win_const_mgr.add_const('WMDM_MODE_RECURSIVE',0x00001000)
		win_const_mgr.add_const('SQL_NON_NULLABLE_COLUMNS',0x0000004B)
		win_const_mgr.add_const('ALG_SID_SSL2_MASTER',0x00000005)
		win_const_mgr.add_const('OTD_NONCLIENT',0x00000002)
		win_const_mgr.add_const('D3DTEXOPCAPS_SUBTRACT',0x00000200)
		win_const_mgr.add_const('DEX_IDS_GRAPH_ERROR',0x00000593)
		win_const_mgr.add_const('CTRY_INDIA',0x0000005B)
		win_const_mgr.add_const('KSPIN_FLAG_INITIATE_PROCESSING_ON_EVERY_ARRIVAL',0x00000020)
		win_const_mgr.add_const('LINEERR_ADDRESSBLOCKED',0x80000053)
		win_const_mgr.add_const('NON_PAGED_DEBUG_SIGNATURE',0x00004E49)
		win_const_mgr.add_const('UMS_LISTBOX_USERS',0x00000000)
		win_const_mgr.add_const('PAN_MIDLINE_STANDARD_POINTED',0x00000003)
		win_const_mgr.add_const('SPI_GETGRADIENTCAPTIONS',0x00001008)
		win_const_mgr.add_const('ISFB_STATE_ALLOWRENAME',0x00000002)
		win_const_mgr.add_const('IDF_NOBEEP',0x00000200)
		win_const_mgr.add_const('TMT_FILLCOLORHINT',0x00000EED)
		win_const_mgr.add_const('TBIF_NOTOOLBAR',0x00030000)
		win_const_mgr.add_const('DISPID_SQMENABLED',0x00000012)
		win_const_mgr.add_const('ERROR_IPSEC_MM_AUTH_IN_USE',0x000032D4)
		win_const_mgr.add_const('SPFILENOTIFY_BACKUPERROR',0x00000016)
		win_const_mgr.add_const('WMDM_S_NOT_ALL_PROPERTIES_APPLIED',0x00045001)
		win_const_mgr.add_const('MH_DELETE',0x00000003)
		win_const_mgr.add_const('LINECALLPARTYID_NAME',0x00000004)
		win_const_mgr.add_const('OID_GEN_MEDIA_IN_USE',0x00010104)
		win_const_mgr.add_const('HSE_URL_FLAGS_REQUIRE_CERT',0x00000040)
		win_const_mgr.add_const('BS_LEFTTEXT',0x00000020)
		win_const_mgr.add_const('CRYPT_ACQUIRE_ONLY_NCRYPT_KEY_FLAG',0x00040000)
		win_const_mgr.add_const('TM_RESUME',0x00000001)
		win_const_mgr.add_const('SERVICE_CONFIG_DELAYED_AUTO_START_INFO',0x00000003)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID',0x00003640)
		win_const_mgr.add_const('LVGS_SUBSETLINKFOCUSED',0x00000080)
		win_const_mgr.add_const('SQL_GB_GROUP_BY_CONTAINS_SELECT',0x00000002)
		win_const_mgr.add_const('SCARD_STATE_EMPTY',0x00000010)
		win_const_mgr.add_const('LINECALLPARAMFLAGS_BLOCKID',0x00000004)
		win_const_mgr.add_const('MCI_STATUS_TIME_FORMAT',0x00000006)
		win_const_mgr.add_const('VER_ERR_ITEM_1',0x00000080)
		win_const_mgr.add_const('PROCESS_TRACE_MODE_RAW_TIMESTAMP',0x00001000)
		win_const_mgr.add_const('AUTHZ_RM_FLAG_INITIALIZE_UNDER_IMPERSONATION',0x00000002)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_INF',0x0000000A)
		win_const_mgr.add_const('MIXER_GETLINEINFOF_COMPONENTTYPE',0x00000003)
		win_const_mgr.add_const('PS_COMPONENT_ADAPTER',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_M32R_ADDR32NB',0x00000002)
		win_const_mgr.add_const('RPC_CALL_STATUS_DISCONNECTED',0x00000002)
		win_const_mgr.add_const('DEVPROP_TYPEMOD_LIST',0x00002000)
		win_const_mgr.add_const('ERROR_UNABLE_TO_MOVE_REPLACEMENT_2',0x00000499)
		win_const_mgr.add_const('INTERNET_DEFAULT_SOCKS_PORT',0x00000438)
		win_const_mgr.add_const('MCI_SEQ_STATUS_PORT',0x00004003)
		win_const_mgr.add_const('IDM_TABLE',0x000008BC)
		win_const_mgr.add_const('CERT_LOGOTYPE_BITS_IMAGE_RESOLUTION_CHOICE',0x00000001)
		win_const_mgr.add_const('STATE_SYSTEM_EXPANDED',0x00000200)
		win_const_mgr.add_const('STAT_COALESCE_COMP_ALL_NOISE',0x00002000)
		win_const_mgr.add_const('INTERNET_SERVICE_URL',0x00000000)
		win_const_mgr.add_const('IP_MIB_ADDRTABLE_ENTRY_ID',0x00000102)
		win_const_mgr.add_const('_WIN32_WINNT_WIN2K',0x00000500)
		win_const_mgr.add_const('XINPUT_DEVSUBTYPE_GAMEPAD',0x00000001)
		win_const_mgr.add_const('DV_AUDIOSMP',0x38000000)
		win_const_mgr.add_const('TBSTYLE_NOPREFIX',0x00000020)
		win_const_mgr.add_const('TMT_URL',0x0000025E)
		win_const_mgr.add_const('WIA_IPC_TIMEDELAY',0x0000140A)
		win_const_mgr.add_const('ICW_CHECKSTATUS',0x00000001)
		win_const_mgr.add_const('LINEADDRESSSTATE_OTHER',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_OVER',0x00200000)
		win_const_mgr.add_const('TAPE_QUERY_DEVICE_ERROR_DATA',0x00000004)
		win_const_mgr.add_const('USER_SERVER_TRUST_ACCOUNT',0x00000100)
		win_const_mgr.add_const('ERROR_SERVICE_EXISTS',0x00000431)
		win_const_mgr.add_const('AAL5_SSCS_SSCOP_NON_ASSURED',0x00000002)
		win_const_mgr.add_const('CF_DSPMETAFILEPICT',0x00000083)
		win_const_mgr.add_const('SQL_DESC_NUM_PREC_RADIX',0x00000020)
		win_const_mgr.add_const('CM_DRP_ADDRESS',0x0000001D)
		win_const_mgr.add_const('ERROR_DEVICE_ENUMERATION_ERROR',0x00000288)
		win_const_mgr.add_const('WSPDESCRIPTION_LEN',0x000000FF)
		win_const_mgr.add_const('BTH_ERROR_PAIRING_WITH_UNIT_KEY_NOT_SUPPORTED',0x00000029)
		win_const_mgr.add_const('MCI_DGV_PUT_VIDEO',0x00100000)
		win_const_mgr.add_const('TB_TOP',0x00000006)
		win_const_mgr.add_const('TRANSFORM_CTM',0x0000100B)
		win_const_mgr.add_const('IDM_FIRE_PRINTTEMPLATEDOWN',0x00003A99)
		win_const_mgr.add_const('ACM_FORMATDETAILSF_FORMAT',0x00000001)
		win_const_mgr.add_const('MSDRM_POLICY_ZONE',0x00009300)
		win_const_mgr.add_const('NTDSCONN_KCC_RING_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('CHANNEL_EVENT_CONNECTED',0x00000001)
		win_const_mgr.add_const('NDIS_MEDIA_CAP_TRANSMIT',0x00000001)
		win_const_mgr.add_const('PORT_LPD725',0x000002D5)
		win_const_mgr.add_const('ABM_GETTASKBARPOS',0x00000005)
		win_const_mgr.add_const('ERROR_FLOPPY_VOLUME',0x00000248)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_VOLUMEDOWN',0x00000014)
		win_const_mgr.add_const('SQL_CVT_INTERVAL_DAY_TIME',0x00100000)
		win_const_mgr.add_const('PATCH_OPTION_NO_REBASE',0x00040000)
		win_const_mgr.add_const('WLX_SAS_TYPE_AUTHENTICATED',0x00000007)
		win_const_mgr.add_const('SCARD_POWERED',0x00000004)
		win_const_mgr.add_const('TRUST_DIRECTION_INBOUND',0x00000001)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_MEMORY_PAGE_FAULTS',0x00001000)
		win_const_mgr.add_const('ERROR_EA_FILE_CORRUPT',0x00000114)
		win_const_mgr.add_const('LSP_LOCAL_CACHE',0x00000080)
		win_const_mgr.add_const('GETVECTORPENSIZE',0x0000001A)
		win_const_mgr.add_const('WM_NCACTIVATE',0x00000086)
		win_const_mgr.add_const('DM_DISPLAYORIENTATION',0x00000080)
		win_const_mgr.add_const('MAX_INSTANCE_VALUE',0x0000270F)
		win_const_mgr.add_const('MNS_NOCHECK',0x80000000)
		win_const_mgr.add_const('WMIGUID_READ_DESCRIPTION',0x00000008)
		win_const_mgr.add_const('SCARD_E_SHARING_VIOLATION',0x8010000B)
		win_const_mgr.add_const('SNMP_ERROR_BADVALUE',0x00000003)
		win_const_mgr.add_const('STAP_ALLOW_NONCLIENT',0x00000001)
		win_const_mgr.add_const('PLAL_ALERT_CMD_LINE_U_TEXT',0x00004000)
		win_const_mgr.add_const('HTTP_ADDREQ_INDEX_MASK',0x0000FFFF)
		win_const_mgr.add_const('CERT_INFO_SIGNATURE_ALGORITHM_FLAG',0x00000003)
		win_const_mgr.add_const('MAX_L2CAP_PING_DATA_LENGTH',0x0000002C)
		win_const_mgr.add_const('PORT_VID',0x00000301)
		win_const_mgr.add_const('PSM_TCS_BIN',0x00000005)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_INDEPENDENT_RANGES',0x00001000)
		win_const_mgr.add_const('DICS_DISABLE',0x00000002)
		win_const_mgr.add_const('CREATEDC_PRESENT',0x00000002)
		win_const_mgr.add_const('RPC_S_CALL_IN_PROGRESS',0x000006FF)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_TOP',0x00000015)
		win_const_mgr.add_const('VM_OUTLINE',0x00000002)
		win_const_mgr.add_const('DCBA_FACEDOWNNONE',0x00000100)
		win_const_mgr.add_const('DDCAPS2_CANBOBNONINTERLEAVED',0x00000020)
		win_const_mgr.add_const('LANG_KHMER',0x00000053)
		win_const_mgr.add_const('DDPF_ALPHAPREMULT',0x00008000)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_SECURE_FAILURE',0x00010000)
		win_const_mgr.add_const('DISPID_PRIVACYIMPACTEDSTATECHANGE',0x00000110)
		win_const_mgr.add_const('DEBUG_VALUE_VECTOR64',0x0000000A)
		win_const_mgr.add_const('BCRYPT_SUPPORTED_PAD_ROUTER',0x00000001)
		win_const_mgr.add_const('ERROR_MONITORS_NOT_SUPPORTED',0x000000A5)
		win_const_mgr.add_const('PARITY_ODD',0x00000200)
		win_const_mgr.add_const('ISFB_STATE_DEFAULT',0x00000000)
		win_const_mgr.add_const('FP_MD_ID_END_RESERVED',0x00000008)
		win_const_mgr.add_const('BCPBATCH',0x00000004)
		win_const_mgr.add_const('DNS_RTYPE_RP',0x00001100)
		win_const_mgr.add_const('MAX_FDCONSTRAINTNAME_LENGTH',0x00000064)
		win_const_mgr.add_const('ISCSI_LOGIN_OPTIONS_PASSWORD',0x00000040)
		win_const_mgr.add_const('IDI_RESOURCELAST',0x000000A1)
		win_const_mgr.add_const('COLOR_ADD',0x000002C8)
		win_const_mgr.add_const('HC_ACTION',0x00000000)
		win_const_mgr.add_const('PRODUCT_HOME_SERVER',0x00000013)
		win_const_mgr.add_const('PROP_ALL',0x80000000)
		win_const_mgr.add_const('MCAST_CLIENT_ID_LEN',0x00000011)
		win_const_mgr.add_const('IDM_TRIED_SHOWBORDERS',0x00000037)
		win_const_mgr.add_const('DS_MODALFRAME',0x00000080)
		win_const_mgr.add_const('SQL_CT_CONSTRAINT_NAME_DEFINITION',0x00002000)
		win_const_mgr.add_const('CR_PROP_CAXCHGCERT',0x0000000F)
		win_const_mgr.add_const('PGK_SHIFT',0x00000001)
		win_const_mgr.add_const('WIA_PAGE_ISO_C0',0x0000001C)
		win_const_mgr.add_const('CR_INVALID_LOAD_TYPE',0x00000019)
		win_const_mgr.add_const('LDAP_SSL_GC_PORT',0x00000CC5)
		win_const_mgr.add_const('VER_PLATFORMID',0x00000008)
		win_const_mgr.add_const('AE_LIM_INVAL_WKSTA',0x00000003)
		win_const_mgr.add_const('ERROR_NOT_CURRENT_CTRY',0x000000CC)
		win_const_mgr.add_const('RP_FORCE',0x00000001)
		win_const_mgr.add_const('ISDB_SDTT_TID',0x000000C3)
		win_const_mgr.add_const('PKCS12_ALLOW_OVERWRITE_KEY',0x00004000)
		win_const_mgr.add_const('NOTIFY_FOR_THIS_SESSION',0x00000000)
		win_const_mgr.add_const('PIFPARAMSSIZE',0x00000040)
		win_const_mgr.add_const('RFCOMM_CMD_RPN_RESPONSE',0x00000005)
		win_const_mgr.add_const('MCI_QUALITY_ALG',0x00040000)
		win_const_mgr.add_const('ERROR_UNEXPECTED_MM_CREATE_ERR',0x0000022C)
		win_const_mgr.add_const('ABM_SETSTATE',0x00000000)
		win_const_mgr.add_const('MIXERLINE_TARGETTYPE_MIDIOUT',0x00000003)
		win_const_mgr.add_const('TASK_FEBRUARY',0x00000002)
		win_const_mgr.add_const('SUBLANG_ENGLISH_CARIBBEAN',0x00000009)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_PEER_DISASSOCIATED_END',0x00000002)
		win_const_mgr.add_const('INTERNET_COOKIE_ECTX_3RDPARTY',0x80000000)
		win_const_mgr.add_const('DB_BINDFLAGS_OVERWRITE',0x00000040)
		win_const_mgr.add_const('FALT',0x00000010)
		win_const_mgr.add_const('OFASI_OPENDESKTOP',0x00000002)
		win_const_mgr.add_const('URLPOLICY_JAVA_CUSTOM',0x00800000)
		win_const_mgr.add_const('DTR_VIDEO_INDEX',0x00000003)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_PAYLOAD',0x00003613)
		win_const_mgr.add_const('MCI_ANIM_PUT_SOURCE',0x00020000)
		win_const_mgr.add_const('PRF_CLIENT',0x00000004)
		win_const_mgr.add_const('IF_TYPE_DVB_ASI_IN',0x000000AC)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_IS_REDUNDANT_SERVER_TOPOLOGY_ENABLED',0x00000001)
		win_const_mgr.add_const('SECBUFFER_CHANGE_PASS_RESPONSE',0x0000000F)
		win_const_mgr.add_const('OID_802_3_MAXIMUM_LIST_SIZE',0x01010104)
		win_const_mgr.add_const('LINEDEVSTATUSFLAGS_LOCKED',0x00000008)
		win_const_mgr.add_const('ERROR_CTX_INVALID_MODEMNAME',0x00001B62)
		win_const_mgr.add_const('RI_MOUSE_LEFT_BUTTON_UP',0x00000002)
		win_const_mgr.add_const('MAPIFORM_OS_WIN_31',0x00000001)
		win_const_mgr.add_const('PAN_LETT_NORMAL_WEIGHTED',0x00000003)
		win_const_mgr.add_const('OFN_NOTESTFILECREATE',0x00010000)
		win_const_mgr.add_const('IDM_SHOWUNKNOWNTAGS',0x00000916)
		win_const_mgr.add_const('PROC_THREAD_ATTRIBUTE_INPUT',0x00020000)
		win_const_mgr.add_const('NTM_ITALIC',0x00000001)
		win_const_mgr.add_const('DDSD_CAPS',0x00000001)
		win_const_mgr.add_const('TBIF_LPARAM',0x00000010)
		win_const_mgr.add_const('DBIMF_USECHEVRON',0x00000080)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_EXPORT',0x00000000)
		win_const_mgr.add_const('MCI_DGV_FILE_MODE_IDLE',0x00000004)
		win_const_mgr.add_const('SNMPAPI_CONTEXT_INVALID',0x00000003)
		win_const_mgr.add_const('DNS_UPDATE_SECURITY_USE_DEFAULT',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_REAL_TIME_MODE',0x00000100)
		win_const_mgr.add_const('CREATE_ALWAYS',0x00000002)
		win_const_mgr.add_const('SQL_DESC_ALLOC_AUTO',0x00000001)
		win_const_mgr.add_const('SCARD_E_NO_FILE',0x80100026)
		win_const_mgr.add_const('DMBIN_ONLYONE',0x00000001)
		win_const_mgr.add_const('SQL_REFRESH',0x00000001)
		win_const_mgr.add_const('PORT_CSNETNS',0x00000069)
		win_const_mgr.add_const('CF_SCREENFONTS',0x00000001)
		win_const_mgr.add_const('FWPM_PROVIDER_FLAG_DISABLED',0x00000010)
		win_const_mgr.add_const('LOCALE_SISO639LANGNAME',0x00000059)
		win_const_mgr.add_const('IDM_TRISTATEUNDERLINE',0x00000061)
		win_const_mgr.add_const('VK_RMENU',0x000000A5)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNCLOSEDTAG',0x000036E4)
		win_const_mgr.add_const('DS_REPADD_USE_COMPRESSION',0x00000100)
		win_const_mgr.add_const('EC_PALETTE_CHANGED',0x00000009)
		win_const_mgr.add_const('DEBUG_VALUE_INT8',0x00000001)
		win_const_mgr.add_const('TMT_BORDERCOLORHINT',0x00000EEE)
		win_const_mgr.add_const('CLIP_DEFAULT_PRECIS',0x00000000)
		win_const_mgr.add_const('OID_FDDI_LONG_MAX_LIST_SIZE',0x03010104)
		win_const_mgr.add_const('CHANNEL_RC_BAD_PROC',0x0000000B)
		win_const_mgr.add_const('COOKIE_REJECTED_CACHE_ENTRY',0x00008000)
		win_const_mgr.add_const('NRC_INVDDID',0x0000003B)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_REJECT',0x00000010)
		win_const_mgr.add_const('OID_ATM_XMIT_CELLS_OK',0x08020102)
		win_const_mgr.add_const('WMDM_STORAGECAP_FILELIMITEXISTS',0x00000020)
		win_const_mgr.add_const('ISMEX_SEND',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_LITERAL',0x00000004)
		win_const_mgr.add_const('GSS_ALLOW_INHERITED_COMMON',0x00000001)
		win_const_mgr.add_const('TBIF_STANDARDTOOLBAR',0x00020000)
		win_const_mgr.add_const('CSVER_MAJOR_WIN2K',0x00000001)
		win_const_mgr.add_const('TF_RIUIE_CONTEXT',0x00000001)
		win_const_mgr.add_const('ENUM_E_LAST',0x800401BF)
		win_const_mgr.add_const('LSA_MODE_INDIVIDUAL_ACCOUNTS',0x00000002)
		win_const_mgr.add_const('ENABLE_HISTORY_BUFFER',0x00000010)
		win_const_mgr.add_const('IMAGE_REL_EBC_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_DROP',0x00000003)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_NUMBER_OF_MARKS',0x00004005)
		win_const_mgr.add_const('AUTHZ_REQUIRE_S4U_LOGON',0x00000004)
		win_const_mgr.add_const('LVS_SINGLESEL',0x00000004)
		win_const_mgr.add_const('EXITEVENT_CERTISSUED',0x00000001)
		win_const_mgr.add_const('DEBUG_SYMTYPE_NONE',0x00000000)
		win_const_mgr.add_const('MIXERCONTROL_CT_SUBCLASS_MASK',0x0F000000)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_DEF_SUM_PEAK_RATE',0x00000029)
		win_const_mgr.add_const('NETSCAPE_SSL_CA_CERT_TYPE',0x00000004)
		win_const_mgr.add_const('DM_PAPERSIZE',0x00000002)
		win_const_mgr.add_const('OFFSET_VECTOR_EXC_GENERAL',0x00004400)
		win_const_mgr.add_const('CERT_STORE_ADD_REPLACE_EXISTING_INHERIT_PROPERTIES',0x00000005)
		win_const_mgr.add_const('FR_DIALOGTERM',0x00000040)
		win_const_mgr.add_const('ADOR_VERSION',0x00000006)
		win_const_mgr.add_const('WS_VISIBLE',0x10000000)
		win_const_mgr.add_const('MCI_DGV_SIGNAL_USERVAL',0x00040000)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_RECEIVING',0x00000040)
		win_const_mgr.add_const('ABSOLUTE',0x00000001)
		win_const_mgr.add_const('FOF_FILESONLY',0x00000080)
		win_const_mgr.add_const('DSROLE_PRIMARY_DOMAIN_GUID_PRESENT',0x01000000)
		win_const_mgr.add_const('WH_CBT',0x00000005)
		win_const_mgr.add_const('LVFI_PARAM',0x00000001)
		win_const_mgr.add_const('WNPERM_DLG_PERM',0x00000000)
		win_const_mgr.add_const('UM_FOCUS_TYPE_LM',0x00000003)
		win_const_mgr.add_const('IDM_APPLYNORMAL',0x000008CE)
		win_const_mgr.add_const('VOS_DOS',0x00010000)
		win_const_mgr.add_const('OF_DELETE',0x00000200)
		win_const_mgr.add_const('STD_BOOKMARKLENGTH',0x00000001)
		win_const_mgr.add_const('PSR_MFL',0x00000004)
		win_const_mgr.add_const('WAVE_FORMAT_2S08',0x00000020)
		win_const_mgr.add_const('PSR_MFH',0x00000005)
		win_const_mgr.add_const('ERROR_DEVICE_NOT_PARTITIONED',0x00000453)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INVALID_UNICODE',0x000036E1)
		win_const_mgr.add_const('MAX_EVENT_FILTER_DATA_SIZE',0x00000400)
		win_const_mgr.add_const('WMS_STREAM_RELIABLE_FLAG',0x00000002)
		win_const_mgr.add_const('MD_ERROR_SUB403_CERT_TIME_INVALID',0x00000011)
		win_const_mgr.add_const('SNMPAPI_V1_SUPPORT',0x00000001)
		win_const_mgr.add_const('WLX_LOGON_OPT_NO_PROFILE',0x00000001)
		win_const_mgr.add_const('SECPKG_CALL_CLEANUP',0x00000020)
		win_const_mgr.add_const('OBJ_MEMDC',0x0000000A)
		win_const_mgr.add_const('CMSG_CONTENT_PARAM',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_ARM_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('DTS_UPDOWN',0x00000001)
		win_const_mgr.add_const('WLAN_PROFILE_CONNECTION_MODE_AUTO',0x00020000)
		win_const_mgr.add_const('FILE_DELETE_CHILD',0x00000040)
		win_const_mgr.add_const('MCI_STATUS_ITEM',0x00000100)
		win_const_mgr.add_const('DRM_SERVER_ISSUANCELICENSE',0x00000008)
		win_const_mgr.add_const('DISPID_NAVIGATEERROR',0x0000010F)
		win_const_mgr.add_const('WMDRM_DELETE_LICENSE_MARK_FOR_PURGE',0x00000002)
		win_const_mgr.add_const('KSRELATIVEEVENT_FLAG_HANDLE',0x00000001)
		win_const_mgr.add_const('SFGAO_PKEYSFGAOMASK',0x81044010)
		win_const_mgr.add_const('RC_STRETCHBLT',0x00000800)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_DISK_IO_INIT',0x00000400)
		win_const_mgr.add_const('ENM_OBJECTPOSITIONS',0x02000000)
		win_const_mgr.add_const('GDICOMMENT_ENDGROUP',0x00000003)
		win_const_mgr.add_const('PM_NOYIELD',0x00000002)
		win_const_mgr.add_const('DBPROP_GENERATEPARSETREE',0x0000000A)
		win_const_mgr.add_const('PF_SSE3_INSTRUCTIONS_AVAILABLE',0x0000000D)
		win_const_mgr.add_const('NCRYPTBUFFER_PKCS_ATTRS',0x0000002C)
		win_const_mgr.add_const('SW_ERASE',0x00000004)
		win_const_mgr.add_const('DMMEDIA_GLOSSY',0x00000003)
		win_const_mgr.add_const('LINEFORWARDMODE_BUSY',0x00000010)
		win_const_mgr.add_const('SQL_SCCO_OPT_VALUES',0x00000008)
		win_const_mgr.add_const('DPNHQUERYADDRESS_TCP',0x00000001)
		win_const_mgr.add_const('LINEMEDIAMODE_ADSI',0x00002000)
		win_const_mgr.add_const('URLACTION_HTML_FONT_DOWNLOAD',0x00001604)
		win_const_mgr.add_const('SHGVSPB_PERUSER',0x00000001)
		win_const_mgr.add_const('OID_FDDI_LEM_REJECTS',0x03020108)
		win_const_mgr.add_const('SCHEME_DONOTUSE',0x00000040)
		win_const_mgr.add_const('SPEAKER_FRONT_LEFT_OF_CENTER',0x00000040)
		win_const_mgr.add_const('FACILITY_DPLAY',0x00000015)
		win_const_mgr.add_const('INTERNET_OPTION_URL',0x00000022)
		win_const_mgr.add_const('ACMDRIVERDETAILS_SUPPORTF_DISABLED',0x80000000)
		win_const_mgr.add_const('SPINST_SINGLESECTION',0x00010000)
		win_const_mgr.add_const('TVGN_NEXTVISIBLE',0x00000006)
		win_const_mgr.add_const('SECURITY_FLAG_PCT4',0x00000010)
		win_const_mgr.add_const('CMSG_CTRL_DEL_SIGNER_UNAUTH_ATTR',0x00000009)
		win_const_mgr.add_const('RPC_C_HTTP_AUTHN_SCHEME_DIGEST',0x00000008)
		win_const_mgr.add_const('IDM_DISABLE_EDITFOCUS_UI',0x00000964)
		win_const_mgr.add_const('ALG_SID_RSA_ENTRUST',0x00000003)
		win_const_mgr.add_const('RTS_CONTROL_HANDSHAKE',0x00000002)
		win_const_mgr.add_const('DEBUG_DATA_KTHREAD_OFFSET',0x00000002)
		win_const_mgr.add_const('CRSWPP_FAILED_AUTH',0xC0042208)
		win_const_mgr.add_const('MCI_DGV_SAVE_KEEPRESERVE',0x00040000)
		win_const_mgr.add_const('IDC_CI_GROUP',0x00000078)
		win_const_mgr.add_const('D3DSP_SRCMOD_SHIFT',0x00000018)
		win_const_mgr.add_const('TIME_SAMPLES',0x00000002)
		win_const_mgr.add_const('TF_RIUIE_VERTICALORDER',0x00000010)
		win_const_mgr.add_const('OPER_STATE_STARTING',0x00000004)
		win_const_mgr.add_const('SFVM_GETPANE',0x0000003B)
		win_const_mgr.add_const('SQL_LOCK_EXCLUSIVE',0x00000001)
		win_const_mgr.add_const('ES_RIGHT',0x00000002)
		win_const_mgr.add_const('VK_DBE_ENTERIMECONFIGMODE',0x00000000)
		win_const_mgr.add_const('SCARD_SCOPE_USER',0x00000000)
		win_const_mgr.add_const('SDDL_ALIAS_SIZE',0x00000002)
		win_const_mgr.add_const('ISR_SS_TRAP',0x00000003)
		win_const_mgr.add_const('SQL_INTERVAL_DAY_TO_MINUTE',0x00000064)
		win_const_mgr.add_const('OID_FDDI_UPSTREAM_NODE_LONG',0x03020102)
		win_const_mgr.add_const('UNDNAME_NO_MS_KEYWORDS',0x00000002)
		win_const_mgr.add_const('DSQPF_ENABLEADMINFEATURES',0x00000008)
		win_const_mgr.add_const('LINECALLSTATE_DISCONNECTED',0x00004000)
		win_const_mgr.add_const('WEBPOST_ERROR_ENUM_PROVS',0xC004210D)
		win_const_mgr.add_const('CERT_PE_IMAGE_DIGEST_ALL_IMPORT_INFO',0x00000004)
		win_const_mgr.add_const('ISFB_STATE_BTNMINSIZE',0x00000100)
		win_const_mgr.add_const('VARIANT_CALENDAR_HIJRI',0x00000008)
		win_const_mgr.add_const('DXVA_COMPBUFFER_TYPE_THAT_IS_NOT_USED',0x00000000)
		win_const_mgr.add_const('INTERNET_OPTION_MAX_CONNS_PER_SERVER',0x00000049)
		win_const_mgr.add_const('COLOR_BOX1',0x000002D0)
		win_const_mgr.add_const('INT64_MAX',0x7FFFFFFFFFFFFFFF)
		win_const_mgr.add_const('TIMER_MODIFY_STATE',0x00000002)
		win_const_mgr.add_const('SRRF_RT_REG_DWORD',0x00000010)
		win_const_mgr.add_const('WINHTTP_OPTION_PARENT_HANDLE',0x00000015)
		win_const_mgr.add_const('CRYPTUI_SELECT_ISSUEDTO_COLUMN',0x00000001)
		win_const_mgr.add_const('DE_E_CANNOT_INSTANTIATE_OBJECT',0x800C0010)
		win_const_mgr.add_const('WMDM_STATUS_STORAGECONTROL_DELETING',0x00004000)
		win_const_mgr.add_const('LINECALLREASON_CALLCOMPLETION',0x00000080)
		win_const_mgr.add_const('SPOST_MAX',0x00000003)
		win_const_mgr.add_const('FAX_JOB_QUERY',0x00000002)
		win_const_mgr.add_const('IN6ADDR_6TO4PREFIX_LENGTH',0x00000010)
		win_const_mgr.add_const('SET_REPAIR_VALID_MASK',0x0000000F)
		win_const_mgr.add_const('VK_OEM_4',0x000000DB)
		win_const_mgr.add_const('VK_OEM_5',0x000000DC)
		win_const_mgr.add_const('ABM_GETSTATE',0x00000004)
		win_const_mgr.add_const('VK_OEM_7',0x000000DE)
		win_const_mgr.add_const('D3DPRESENT_INTERVAL_FOUR',0x00000008)
		win_const_mgr.add_const('TRUSTERROR_STEP_FINAL_INITPROV',0x0000001F)
		win_const_mgr.add_const('LOGFLAGS_SEEK',0x00000002)
		win_const_mgr.add_const('ACM_FILTERENUMF_DWFILTERTAG',0x00010000)
		win_const_mgr.add_const('DV_ERR_BASE',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT',0x000025EE)
		win_const_mgr.add_const('SHTDN_REASON_MAJOR_POWER',0x00060000)
		win_const_mgr.add_const('CBN_DBLCLK',0x00000002)
		win_const_mgr.add_const('ERROR_DS_NON_BASE_SEARCH',0x00002120)
		win_const_mgr.add_const('AF_NETBIOS',0x00000011)
		win_const_mgr.add_const('SHTDN_REASON_FLAG_DIRTY_PROBLEM_ID_REQUIRED',0x02000000)
		win_const_mgr.add_const('TRACE_MESSAGE_COMPONENTID',0x00000004)
		win_const_mgr.add_const('LB_FINDSTRINGEXACT',0x000001A2)
		win_const_mgr.add_const('WMN_FIRST',0x00000000)
		win_const_mgr.add_const('OID_DOT11_NDIS_START',0x0D010300)
		win_const_mgr.add_const('DC_BRUSH',0x00000012)
		win_const_mgr.add_const('ERROR_VOLUME_CONTAINS_SYS_FILES',0x000010F1)
		win_const_mgr.add_const('ADAM_REPL_AUTHENTICATION_MODE_MUTUAL_AUTH_REQUIRED',0x00000002)
		win_const_mgr.add_const('SYMOPT_OVERWRITE',0x00100000)
		win_const_mgr.add_const('WS_EX_CONTEXTHELP',0x00000400)
		win_const_mgr.add_const('LB_GETLISTBOXINFO',0x000001B2)
		win_const_mgr.add_const('CHANNEL_EVENT_DISCONNECTED',0x00000003)
		win_const_mgr.add_const('DISPID_ONCLICK',0x0000000A)
		win_const_mgr.add_const('PRINTER_STATUS_IO_ACTIVE',0x00000100)
		win_const_mgr.add_const('LB_SETCOLUMNWIDTH',0x00000195)
		win_const_mgr.add_const('ERROR_OUTOFMEMORY',0x0000000E)
		win_const_mgr.add_const('WINHTTP_QUERY_FROM',0x0000001F)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_HANDLE_CREATED',0x00000400)
		win_const_mgr.add_const('CRYPT_RC2_64BIT_VERSION',0x00000078)
		win_const_mgr.add_const('INCLUDED_FCI',0x00000001)
		win_const_mgr.add_const('PD_NOWARNING',0x00000080)
		win_const_mgr.add_const('IMF_CLOSESTATUSWINDOW',0x00000008)
		win_const_mgr.add_const('LINEERR_INVALDIGITS',0x80000028)
		win_const_mgr.add_const('WS_EX_WINDOWEDGE',0x00000100)
		win_const_mgr.add_const('AUDIOMEDIATYPE_EQUAL_FORMAT_DATA',0x00000004)
		win_const_mgr.add_const('PARITY_NONE',0x00000100)
		win_const_mgr.add_const('GPO_INFO_FLAG_LINKTRANSITION',0x00000100)
		win_const_mgr.add_const('ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF',0x0000218D)
		win_const_mgr.add_const('FPS_ROUTING',0x20400000)
		win_const_mgr.add_const('WINHTTP_DISABLE_KEEP_ALIVE',0x00000008)
		win_const_mgr.add_const('S_WHITE1024',0x00000005)
		win_const_mgr.add_const('EVENT_TRACE_USE_KBYTES_FOR_SIZE',0x00002000)
		win_const_mgr.add_const('GESTURE_DOUBLE_ARROW_UP',0x00000000)
		win_const_mgr.add_const('SQL_CA2_OPT_ROWVER_CONCURRENCY',0x00000004)
		win_const_mgr.add_const('RPC_C_IMP_LEVEL_DELEGATE',0x00000004)
		win_const_mgr.add_const('D3DVTXPCAPS_LOCALVIEWER',0x00000020)
		win_const_mgr.add_const('SPDRP_LEGACYBUSTYPE',0x00000014)
		win_const_mgr.add_const('RSC_MBZ1',0x0000001E)
		win_const_mgr.add_const('SM_CYDRAG',0x00000045)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_USER_FLOW_COUNT',0x00000003)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_USAGE_PRIVILEGES',0x00000006)
		win_const_mgr.add_const('DFCS_FLAT',0x00004000)
		win_const_mgr.add_const('MCI_BREAK',0x00000811)
		win_const_mgr.add_const('SQL_TXN_CAPABLE',0x0000002E)
		win_const_mgr.add_const('ERROR_IO_PRIVILEGE_FAILED',0x0000023B)
		win_const_mgr.add_const('PHONEFEATURE_GETLAMP',0x00000200)
		win_const_mgr.add_const('EMR_CREATECOLORSPACE',0x00000063)
		win_const_mgr.add_const('ERROR_DS_DRA_MISSING_PARENT',0x0000210C)
		win_const_mgr.add_const('ERROR_HWNDS_HAVE_DIFF_PARENT',0x000005A1)
		win_const_mgr.add_const('WNSRCH_REFRESH_FIRST_LEVEL',0x00000001)
		win_const_mgr.add_const('SPQ_SCAN_USE_CALLBACK_SIGNERINFO',0x00000040)
		win_const_mgr.add_const('SCRIPTTEXT_ISPERSISTENT',0x00000040)
		win_const_mgr.add_const('EMR_POLYBEZIER16',0x00000055)
		win_const_mgr.add_const('ERROR_FUNCTION_FAILED',0x0000065B)
		win_const_mgr.add_const('EVENTLOG_BACKWARDS_READ',0x00000008)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_CA_REV_UNKNOWN_FLAG',0x00000400)
		win_const_mgr.add_const('BTH_MFG_ERICSSON',0x00000000)
		win_const_mgr.add_const('PO_TRANSITION_VETO_TYPE_SERVICE',0x00000002)
		win_const_mgr.add_const('D3DSP_DSTMOD_SHIFT',0x00000014)
		win_const_mgr.add_const('WM_CHAR',0x00000102)
		win_const_mgr.add_const('NRC_SYSTEM',0x00000040)
		win_const_mgr.add_const('ERROR_DS_NAMING_MASTER_GC',0x0000214B)
		win_const_mgr.add_const('SMC_DEFAULTICON',0x00000016)
		win_const_mgr.add_const('FRS_ERR_SYSVOL_POPULATE',0x00001F4D)
		win_const_mgr.add_const('GT_USECRLF',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_IF_RANGE',0x0000003A)
		win_const_mgr.add_const('ERROR_DS_OPERATIONS_ERROR',0x00002020)
		win_const_mgr.add_const('CRYPT_ACQUIRE_ALLOW_NCRYPT_KEY_FLAG',0x00010000)
		win_const_mgr.add_const('LOAD_LIBRARY_AS_DATAFILE_EXCLUSIVE',0x00000040)
		win_const_mgr.add_const('IOF_CHECKDISPLAYASICON',0x00000010)
		win_const_mgr.add_const('KSPIN_FLAG_IMPLEMENT_CLOCK',0x00400000)
		win_const_mgr.add_const('OID_GEN_RECEIVE_SCALE_CAPABILITIES',0x00010203)
		win_const_mgr.add_const('USER_LOGON_SERVER_PARMNUM',0x00000017)
		win_const_mgr.add_const('MB_YESNOCANCEL',0x00000003)
		win_const_mgr.add_const('SHCNE_ATTRIBUTES',0x00000800)
		win_const_mgr.add_const('SASL_OPTION_AUTHZ_STRING',0x00000003)
		win_const_mgr.add_const('DXVA_ENCRYPTPROTOCOLFUNCFLAG_HOST',0x00FFFF00)
		win_const_mgr.add_const('EMR_RESERVED_117',0x00000075)
		win_const_mgr.add_const('DS_REPMOD_UPDATE_TRANSPORT',0x00000010)
		win_const_mgr.add_const('D3DUSAGE_QUERY_VERTEXTEXTURE',0x00100000)
		win_const_mgr.add_const('WCT_MAX_NODE_COUNT',0x00000010)
		win_const_mgr.add_const('ERROR_DEPENDENT_RESOURCE_EXISTS',0x00001389)
		win_const_mgr.add_const('DBT_DEVTYP_PORT',0x00000003)
		win_const_mgr.add_const('ERROR_SXS_POLICY_PARSE_ERROR',0x000036CD)
		win_const_mgr.add_const('PCMCIA_OPT_AUTOMEM',0x00000004)
		win_const_mgr.add_const('CB_GETDROPPEDWIDTH',0x00000015)
		win_const_mgr.add_const('WMS_CONTAINER_LOG_PHYSICAL_URL',0x0000000E)
		win_const_mgr.add_const('ILD_TRANSPARENT',0x00000001)
		win_const_mgr.add_const('X3_P_INST_WORD_POS_X',0x00000000)
		win_const_mgr.add_const('IMR_QUERYCHARPOSITION',0x00000006)
		win_const_mgr.add_const('LOCALE_SDAYNAME6',0x0000002F)
		win_const_mgr.add_const('ERROR_RESUME_HIBERNATION',0x000002D7)
		win_const_mgr.add_const('CM_DRP_SECURITY_SDS',0x00000019)
		win_const_mgr.add_const('SV_TYPE_SERVER_OSF',0x00100000)
		win_const_mgr.add_const('SV_MINFREECONNECTIONS_PARMNUM',0x0000021D)
		win_const_mgr.add_const('INTERNET_OPTION_AUTODIAL_MODE',0x00000052)
		win_const_mgr.add_const('EC_OPENING_FILE',0x00000010)
		win_const_mgr.add_const('SQL_COLUMN_SCALE',0x00000005)
		win_const_mgr.add_const('OID_802_3_XMIT_DEFERRED',0x01020201)
		win_const_mgr.add_const('LANG_BULGARIAN',0x00000002)
		win_const_mgr.add_const('LDAP_RES_BIND',0x00000061)
		win_const_mgr.add_const('SERVICETYPE_GUARANTEED',0x00000003)
		win_const_mgr.add_const('FPSR_PC0',0x00000008)
		win_const_mgr.add_const('DEVPROP_TYPE_STRING_INDIRECT',0x00000019)
		win_const_mgr.add_const('RF_PERFORMSLINEBREAKING',0x00010000)
		win_const_mgr.add_const('LINEAGENTFEATURE_SETAGENTSTATE',0x00000002)
		win_const_mgr.add_const('GCS_COMPREADSTR',0x00000001)
		win_const_mgr.add_const('IDC_IO_CREATENEW',0x00000834)
		win_const_mgr.add_const('TMT_INFOBK',0x00000659)
		win_const_mgr.add_const('GL_ID_PRIVATE_LAST',0x0000FFFF)
		win_const_mgr.add_const('CP_NONE',0x00000000)
		win_const_mgr.add_const('SECBUFFER_READONLY',0x80000000)
		win_const_mgr.add_const('LANG_MANIPURI',0x00000058)
		win_const_mgr.add_const('MIXER_OBJECTF_WAVEOUT',0x10000000)
		win_const_mgr.add_const('NDIS_PROT_OPTION_NO_RSVD_ON_RCVPKT',0x00000004)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_FLUSHONPAUSE',0x00000080)
		win_const_mgr.add_const('OID_FDDI_SMT_T_NOTIFY',0x0303020F)
		win_const_mgr.add_const('SHUTDOWN_RESTARTAPPS',0x00000080)
		win_const_mgr.add_const('SQL_UNSPECIFIED',0x00000000)
		win_const_mgr.add_const('CRYPT_SEC_DESCR',0x00000001)
		win_const_mgr.add_const('CRYPT_OVERWRITE',0x00000001)
		win_const_mgr.add_const('SM_CMONITORS',0x00000050)
		win_const_mgr.add_const('IDM_SUPERSCRIPT',0x000008C8)
		win_const_mgr.add_const('D3DTA_TEMP',0x00000005)
		win_const_mgr.add_const('KP_SALT_EX',0x0000000A)
		win_const_mgr.add_const('OID_GEN_XMIT_DISCARDS',0x0002021C)
		win_const_mgr.add_const('WT_TRUSTDBDIALOG_ONLY_PUB_TAB_FLAG',0x00000002)
		win_const_mgr.add_const('FILE_ATTRIBUTE_DEVICE',0x00000040)
		win_const_mgr.add_const('CBN_SETFOCUS',0x00000003)
		win_const_mgr.add_const('TVIS_SELECTED',0x00000002)
		win_const_mgr.add_const('CTRY_OMAN',0x000003C8)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_NO_PUBLIC_KEY',0x00003604)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_MAX_WINDOWS',0x00004003)
		win_const_mgr.add_const('STGM_FAILIFTHERE',0x00000000)
		win_const_mgr.add_const('GL_APPLICATION_RESOLVE_MODULES',0x00000400)
		win_const_mgr.add_const('CR_PROP_CASIGCERTCOUNT',0x0000000B)
		win_const_mgr.add_const('RPC_C_PROFILE_DEFAULT_ELT',0x00000000)
		win_const_mgr.add_const('LWA_COLORKEY',0x00000001)
		win_const_mgr.add_const('TXTLOG_INF',0x00000002)
		win_const_mgr.add_const('MQ_LOOKUP_RECEIVE_PREV',0x40000022)
		win_const_mgr.add_const('KSEVENT_TYPE_QUERYBUFFER',0x00000400)
		win_const_mgr.add_const('SERIAL_IOC_MCR_OUT1',0x00000004)
		win_const_mgr.add_const('SNMPAPI_CONTEXT_UNKNOWN',0x00000004)
		win_const_mgr.add_const('INTERNET_CUSTOMDIAL_WILL_SUPPLY_STATE',0x00000002)
		win_const_mgr.add_const('CRYPT_FIND_SILENT_KEYSET_FLAG',0x00000040)
		win_const_mgr.add_const('DLLVER_QFE_MASK',0x0000FFFF)
		win_const_mgr.add_const('PIR_STATUS_TABLE_BAD',0x00000005)
		win_const_mgr.add_const('VIEW_SMALLICONS',0x00000001)
		win_const_mgr.add_const('ERROR_LOG_CORRUPTION_DETECTED',0x00001AA1)
		win_const_mgr.add_const('SHPWLEN',0x00000008)
		win_const_mgr.add_const('IP_RECVRTHDR',0x00000026)
		win_const_mgr.add_const('MCI_DGV_STATUS_AUDIO_RECORD',0x00000401)
		win_const_mgr.add_const('KSPROBE_STREAMREAD',0x00000000)
		win_const_mgr.add_const('SPI_SETICONTITLELOGFONT',0x00000022)
		win_const_mgr.add_const('CRYPT_PRIORITY_TOP',0x00000000)
		win_const_mgr.add_const('CMSG_CERT_COUNT_PARAM',0x0000000B)
		win_const_mgr.add_const('SMDM_TOOLBAR',0x00000004)
		win_const_mgr.add_const('EMR_MIN',0x00000001)
		win_const_mgr.add_const('CMC_LENGTH_UNKNOWN',0xFFFFFFFF)
		win_const_mgr.add_const('SV_LMANNOUNCE_PARMNUM',0x00000206)
		win_const_mgr.add_const('PRF_OWNED',0x00000020)
		win_const_mgr.add_const('PERF_COLLECT_START',0x00000005)
		win_const_mgr.add_const('CS_DELETE_TRANSFORM',0x00000003)
		win_const_mgr.add_const('SE_PRIVILEGE_ENABLED_BY_DEFAULT',0x00000001)
		win_const_mgr.add_const('PRODUCT_ENTERPRISE_SERVER_IA64',0x0000000F)
		win_const_mgr.add_const('MCI_ANIM_GETDEVCAPS_FAST_RATE',0x00004002)
		win_const_mgr.add_const('MC_SUPPORTED_COLOR_TEMPERATURE_8200K',0x00000010)
		win_const_mgr.add_const('DEFAULT_MINIMUM_ENTITIES',0x00000020)
		win_const_mgr.add_const('PRIMARY_CRED_PACKAGE_MASK',0x00000000)
		win_const_mgr.add_const('JIFMK_DQT',0x0000FFDB)
		win_const_mgr.add_const('LINETRANSLATERESULT_DIALBILLING',0x00000040)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_IPSECV1_ESP_ENABLED',0x00000003)
		win_const_mgr.add_const('EMO_EXPANDSELECTION',0x00000000)
		win_const_mgr.add_const('WMDM_FILE_ATTR_AUDIO',0x00001000)
		win_const_mgr.add_const('WIA_DIP_DEV_NAME',0x00000007)
		win_const_mgr.add_const('L2_NOTIFICATION_SOURCE_WLAN_ACM',0x00000000)
		win_const_mgr.add_const('RPC_QUERY_IS_CLIENT_LOCAL',0x00000020)
		win_const_mgr.add_const('ERROR_PRINTER_DRIVER_BLOCKED',0x00000BC6)
		win_const_mgr.add_const('DDEDM_STANDARDVGAMODES',0x00000002)
		win_const_mgr.add_const('DTR_LOADER_INDEX',0x00000007)
		win_const_mgr.add_const('LVIF_COLFMT',0x00010000)
		win_const_mgr.add_const('DC_COLORDEVICE',0x00000020)
		win_const_mgr.add_const('INFINFO_DEFAULT_SEARCH',0x00000003)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_MEASURES',0x00000005)
		win_const_mgr.add_const('ERROR_DATATYPE_MISMATCH',0x0000065D)
		win_const_mgr.add_const('IIS_MD_LOGCUSTOM_BASE',0x00001194)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCDEVENTARGS_CURRENTTRACKNUMBER',0x00000300)
		win_const_mgr.add_const('MM_MIM_LONGDATA',0x000003C4)
		win_const_mgr.add_const('LINECALLREASON_CAMPEDON',0x00004000)
		win_const_mgr.add_const('PORT_MSGICP',0x0000001D)
		win_const_mgr.add_const('IPPORT_NETBIOS_SSN',0x0000008B)
		win_const_mgr.add_const('RPC_C_BINDING_MIN_TIMEOUT',0x00000000)
		win_const_mgr.add_const('BG_E_INVALID_CREDENTIALS',0x80200040)
		win_const_mgr.add_const('ERROR_INVALID_LIBRARY',0x000010CD)
		win_const_mgr.add_const('SNMP_ERROR_INCONSISTENTVALUE',0x0000000C)
		win_const_mgr.add_const('CMSG_CTRL_DECRYPT',0x00000002)
		win_const_mgr.add_const('DISPID_DOWNLOADCOMPLETE',0x00000068)
		win_const_mgr.add_const('ERROR_LOG_CONTAINER_LIMIT_EXCEEDED',0x000019D9)
		win_const_mgr.add_const('ERROR_DS_ALIAS_PROBLEM',0x00002031)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_MINUTES',0x00000404)
		win_const_mgr.add_const('PID_DISPLACED_DATE',0x00000003)
		win_const_mgr.add_const('BS_USERBUTTON',0x00000008)
		win_const_mgr.add_const('PID_HTMLINFOTIPFILE',0x00000005)
		win_const_mgr.add_const('SQL_OJ_RIGHT',0x00000002)
		win_const_mgr.add_const('ERROR_FIRMWARE_UPDATED',0x000002D8)
		win_const_mgr.add_const('ERROR_SOME_NOT_MAPPED',0x00000515)
		win_const_mgr.add_const('LINEAGENTSTATUS_VALIDSTATES',0x00000080)
		win_const_mgr.add_const('FILE_DEVICE_DATALINK',0x00000005)
		win_const_mgr.add_const('XP1_EXPEDITED_DATA',0x00000040)
		win_const_mgr.add_const('SPDRP_BUSTYPEGUID',0x00000013)
		win_const_mgr.add_const('BPPF_ERASE',0x00000001)
		win_const_mgr.add_const('D3DVTXPCAPS_TEXGEN_SPHEREMAP',0x00000100)
		win_const_mgr.add_const('ERROR_DS_ATT_SCHEMA_REQ_SYNTAX',0x000020E0)
		win_const_mgr.add_const('SPI_SETMOUSEKEYS',0x00000037)
		win_const_mgr.add_const('TMT_GRADIENTCOLOR5',0x00000EE6)
		win_const_mgr.add_const('TMT_GRADIENTCOLOR4',0x00000EE5)
		win_const_mgr.add_const('TMT_GRADIENTCOLOR3',0x00000EE4)
		win_const_mgr.add_const('DEBUG_ATTACH_DEFAULT',0x00000000)
		win_const_mgr.add_const('TMT_GRADIENTCOLOR1',0x00000EE2)
		win_const_mgr.add_const('PORT_LINK',0x000000F5)
		win_const_mgr.add_const('INTERNET_OPTION_SECURITY_KEY_BITNESS',0x00000024)
		win_const_mgr.add_const('CONFIGFLAG_PARTIAL_LOG_CONF',0x00002000)
		win_const_mgr.add_const('ERROR_FILE_EXISTS',0x00000050)
		win_const_mgr.add_const('ERROR_MARSHALL_OVERFLOW',0x0000025B)
		win_const_mgr.add_const('MCI_VCR_SETAUDIO_SOURCE',0x00020000)
		win_const_mgr.add_const('CM_DRP_LOCATION_PATHS',0x00000024)
		win_const_mgr.add_const('IGIMIF_RIGHTMENU',0x00000001)
		win_const_mgr.add_const('ERROR_DS_THREAD_LIMIT_EXCEEDED',0x0000218B)
		win_const_mgr.add_const('ERROR_DS_PDC_OPERATION_IN_PROGRESS',0x0000212A)
		win_const_mgr.add_const('IDM_ADDFAVORITES',0x000008D5)
		win_const_mgr.add_const('TBS_DOWNISLEFT',0x00000400)
		win_const_mgr.add_const('MD_MAX_ERROR_FILES',0x00002704)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_2BYTES',0x00200000)
		win_const_mgr.add_const('ERROR_DS_DRA_ACCESS_DENIED',0x00002105)
		win_const_mgr.add_const('LINECALLFEATURE_GENERATETONE',0x00000400)
		win_const_mgr.add_const('CRYPT_IMPL_REMOVABLE',0x00000008)
		win_const_mgr.add_const('EVENT_SYSTEM_DESKTOPSWITCH',0x00000020)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_TRANSPORT_HEADER_SIZE',0x00000400)
		win_const_mgr.add_const('HCBT_CLICKSKIPPED',0x00000006)
		win_const_mgr.add_const('PD_DISABLEPRINTTOFILE',0x00080000)
		win_const_mgr.add_const('WMDM_STORAGE_ATTR_NONREMOVABLE',0x00000004)
		win_const_mgr.add_const('NIF_REALTIME',0x00000040)
		win_const_mgr.add_const('WOW64_MAXIMUM_SUPPORTED_EXTENSION',0x00000200)
		win_const_mgr.add_const('ADMIN_STATE_DISABLED',0x00000001)
		win_const_mgr.add_const('PS_8K',0x0000000D)
		win_const_mgr.add_const('SQL_API_SQLPREPARE',0x00000013)
		win_const_mgr.add_const('ALG_SID_AES_128',0x0000000E)
		win_const_mgr.add_const('CERT_TRUST_IS_NOT_SIGNATURE_VALID',0x00000008)
		win_const_mgr.add_const('IF_TYPE_PROP_VIRTUAL',0x00000035)
		win_const_mgr.add_const('DSBI_RETURN_FORMAT',0x00100000)
		win_const_mgr.add_const('OID_TCP_TASK_OFFLOAD',0xFC010201)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_IS_FRAGMENT',0x00000020)
		win_const_mgr.add_const('SC_MAXIMIZE',0x0000F030)
		win_const_mgr.add_const('ERROR_RPL_NOT_ALLOWED',0x00000FA6)
		win_const_mgr.add_const('OID_FDDI_IF_DESCR',0x03030279)
		win_const_mgr.add_const('CM_NO_EDITTRUST',0x00000080)
		win_const_mgr.add_const('TMSUSPEND',0x02000000)
		win_const_mgr.add_const('ETW_DATETIME_TYPE_VALUE',0x00000077)
		win_const_mgr.add_const('BTH_MFG_MOTOROLA',0x00000008)
		win_const_mgr.add_const('SQL_MAX_TABLE_NAME_LEN',0x00000023)
		win_const_mgr.add_const('NIM_ADD',0x00000000)
		win_const_mgr.add_const('COD_LAN_ACCESS_33_USED',0x00000002)
		win_const_mgr.add_const('MIN_IF_TYPE',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_NTSC',0x00004000)
		win_const_mgr.add_const('WIA_DONT_USE_SEGMENTATION_FILTER',0x00000001)
		win_const_mgr.add_const('TF_DISABLE_DICTATION',0x00000002)
		win_const_mgr.add_const('ERROR_WINDOW_NOT_DIALOG',0x0000058C)
		win_const_mgr.add_const('AUDIOMEDIATYPE_EQUAL_FORMAT_TYPES',0x00000002)
		win_const_mgr.add_const('LVS_SMALLICON',0x00000002)
		win_const_mgr.add_const('IDS_CAP_WAVE_PREPARE_ERROR',0x000001A5)
		win_const_mgr.add_const('LINEDEVSTATUSFLAGS_INSERVICE',0x00000004)
		win_const_mgr.add_const('CRYPTPROTECT_PROMPT_ON_PROTECT',0x00000002)
		win_const_mgr.add_const('PRINTER_CHANGE_FAILED_CONNECTION_PRINTER',0x00000008)
		win_const_mgr.add_const('MD_EXTLOG_BYTES_SENT',0x00001000)
		win_const_mgr.add_const('NTDSCONN_KCC_STALE_SERVERS_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('TF_TMAE_UIELEMENTENABLEDONLY',0x00000004)
		win_const_mgr.add_const('QUERY_ACTCTX_FLAG_NO_ADDREF',0x80000000)
		win_const_mgr.add_const('FLG_PROFITEM_CSIDL',0x00000008)
		win_const_mgr.add_const('LINEMEDIACONTROL_RATENORMAL',0x00000080)
		win_const_mgr.add_const('AUTHZ_AUDIT_INSTANCE_INFORMATION',0x00000002)
		win_const_mgr.add_const('PROPCALLER_MASK',0x00000000)
		win_const_mgr.add_const('DEBUG_MODNAME_LOADED_IMAGE',0x00000002)
		win_const_mgr.add_const('HSE_APP_FLAG_IN_PROCESS',0x00000000)
		win_const_mgr.add_const('DVD_AUDIO_CAPS_LPCM',0x00000004)
		win_const_mgr.add_const('IDC_BZ_RETRY',0x00000258)
		win_const_mgr.add_const('POWER_FORCE_TRIGGER_RESET',0x80000000)
		win_const_mgr.add_const('TO_DISABLECUSTOMTEXTOUT',0x00000004)
		win_const_mgr.add_const('DNS_UPDATE_REMOTE_SERVER',0x00004000)
		win_const_mgr.add_const('CERT_CHAIN_REVOCATION_CHECK_CHAIN',0x20000000)
		win_const_mgr.add_const('HP_ALGID',0x00000001)
		win_const_mgr.add_const('SSRVOPT_PARENTWIN',0x00000080)
		win_const_mgr.add_const('MAPI_USE_DEFAULT',0x00000040)
		win_const_mgr.add_const('ERROR_DS_NO_ATTRIBUTE_OR_VALUE',0x0000200A)
		win_const_mgr.add_const('ICW_MAX_SERVERNAME',0x00000040)
		win_const_mgr.add_const('VALIDATEUNC_NOUI',0x00000002)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_NO_OPTIONAL_DATA',0x00000200)
		win_const_mgr.add_const('SE_PRIVILEGE_USED_FOR_ACCESS',0x80000000)
		win_const_mgr.add_const('ILD_NORMAL',0x00000000)
		win_const_mgr.add_const('WIA_MAJOR_EVENT_PICTURE_TAKEN',0x00000003)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_25',0x00000019)
		win_const_mgr.add_const('MPV_INBOUND_CUTOFF_EXCEEDED',0x00000001)
		win_const_mgr.add_const('SERVICE_INSTALLED',0x00000003)
		win_const_mgr.add_const('OID_802_5_BURST_ERRORS',0x02020201)
		win_const_mgr.add_const('VECTOR_RANK_INNER',0x00000002)
		win_const_mgr.add_const('IDM_REFRESH',0x000008FC)
		win_const_mgr.add_const('CALERT_SYSTEM',0x00000006)
		win_const_mgr.add_const('TMNOFLAGS',0x00000000)
		win_const_mgr.add_const('MCI_ANIM_WINDOW_TEXT',0x00080000)
		win_const_mgr.add_const('HIGH_PRIORITY_CLASS',0x00000080)
		win_const_mgr.add_const('ERROR_RANGE_NOT_FOUND',0x00000284)
		win_const_mgr.add_const('SV_RESTRICTNULLSESSACCESS_PARMNUM',0x0000023D)
		win_const_mgr.add_const('BG_E_ERROR_CONTEXT_QUEUE_MANAGER_NOTIFICATION',0x8020000C)
		win_const_mgr.add_const('CDO_E_MULTIPART_NO_DATA',0x8004021B)
		win_const_mgr.add_const('HP_TLS1PRF_LABEL',0x00000006)
		win_const_mgr.add_const('DDBLT_ALPHASRCNEG',0x00000080)
		win_const_mgr.add_const('DISPID_PRINTTEMPLATEINSTANTIATION',0x000000E1)
		win_const_mgr.add_const('LANG_SWAHILI',0x00000041)
		win_const_mgr.add_const('CR_DEVNODE_HAS_REQS',0x0000000A)
		win_const_mgr.add_const('WINHTTP_AUTH_TARGET_PROXY',0x00000001)
		win_const_mgr.add_const('SERVICES',0x00000002)
		win_const_mgr.add_const('LVCFMT_NO_DPI_SCALE',0x00040000)
		win_const_mgr.add_const('CRYPT_FIND_USER_KEYSET_FLAG',0x00000001)
		win_const_mgr.add_const('CERT_CHAIN_FIND_BY_ISSUER_LOCAL_MACHINE_FLAG',0x00000008)
		win_const_mgr.add_const('TAPE_DRIVE_SET_PADDING',0x80000400)
		win_const_mgr.add_const('CR_FLG_ENROLLONBEHALFOF',0x00000010)
		win_const_mgr.add_const('LOCALE_SNEGATIVESIGN',0x00000051)
		win_const_mgr.add_const('MAX_CONFIG_VALUE',0x0000270F)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_WRITEMEDIA',0x00000201)
		win_const_mgr.add_const('SETUP_SERVER_IS_UP_TO_DATE_FLAG',0x00004000)
		win_const_mgr.add_const('AD_APPLY_REFRESH',0x00000004)
		win_const_mgr.add_const('GL_CUSTOM_NOTIFICATION',0x00004000)
		win_const_mgr.add_const('SKF_TWOKEYSOFF',0x00000100)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_NEXTTRACK',0x0000000B)
		win_const_mgr.add_const('CREDUIWIN_ENUMERATE_CURRENT_USER',0x00000200)
		win_const_mgr.add_const('LVBKIF_FLAG_ALPHABLEND',0x20000000)
		win_const_mgr.add_const('PIDVSI_SAMPLE_SIZE',0x00000009)
		win_const_mgr.add_const('MB_RTLREADING',0x00100000)
		win_const_mgr.add_const('SMC_GETSFINFO',0x00000006)
		win_const_mgr.add_const('POLICY_AUDIT_EVENT_FAILURE',0x00000002)
		win_const_mgr.add_const('DDLOCK_NODIRTYUPDATE',0x00010000)
		win_const_mgr.add_const('X3_IMM39_1_SIGN_VAL_POS_X',0x00000024)
		win_const_mgr.add_const('SQL_API_SQLGETTYPEINFO',0x0000002F)
		win_const_mgr.add_const('USN_REASON_EA_CHANGE',0x00000400)
		win_const_mgr.add_const('TXTBIT_USEPASSWORD',0x00000010)
		win_const_mgr.add_const('LOCALE_SDAYNAME3',0x0000002C)
		win_const_mgr.add_const('ERROR_LOG_METADATA_CORRUPT',0x000019D4)
		win_const_mgr.add_const('DM_COLLATE',0x00008000)
		win_const_mgr.add_const('CACHEGROUP_FLAG_NONPURGEABLE',0x00000001)
		win_const_mgr.add_const('ATE_INDIRECT',0x0000003E)
		win_const_mgr.add_const('CAL_SABBREVMONTHNAME10',0x00000002)
		win_const_mgr.add_const('D3D10_MULTISAMPLE_ANTIALIAS_LINE_WIDTH',0x00000001)
		win_const_mgr.add_const('IP_ADAPTER_IPV6_OTHER_STATEFUL_CONFIG',0x00000020)
		win_const_mgr.add_const('PRESENTED_TYPE_ALIGN_8',0x00000040)
		win_const_mgr.add_const('IMGANIM_ANIMATED',0x10000000)
		win_const_mgr.add_const('PTE_VALID',0x00000000)
		win_const_mgr.add_const('TRACE_NO_STDINFO',0x00000001)
		win_const_mgr.add_const('CHANGER_MOVE_RETRACTS_IEPORT',0x80000400)
		win_const_mgr.add_const('WAB_USE_OE_SENDMAIL',0x00000001)
		win_const_mgr.add_const('SV_TYPE_POTENTIAL_BROWSER',0x00010000)
		win_const_mgr.add_const('ES_LOWERCASE',0x00000010)
		win_const_mgr.add_const('PRESENTED_TYPE_ALIGN_4',0x00000020)
		win_const_mgr.add_const('SYSPAL_NOSTATIC',0x00000002)
		win_const_mgr.add_const('DEX_IDS_GRID_ERROR',0x00000594)
		win_const_mgr.add_const('SECPKG_ATTR_ISSUER_LIST_EX',0x00000059)
		win_const_mgr.add_const('REO_OPEN',0x04000000)
		win_const_mgr.add_const('CTL_FIND_ANY',0x00000000)
		win_const_mgr.add_const('RIS_INTERFACE_ADDRESS_CHANGE',0x00000000)
		win_const_mgr.add_const('DCBA_FACEUPNONE',0x00000000)
		win_const_mgr.add_const('CRYPT_LAST_OID_GROUP_ID',0x00000009)
		win_const_mgr.add_const('OLEUI_OK',0x00000001)
		win_const_mgr.add_const('WMS_VER_MINOR',0x00000000)
		win_const_mgr.add_const('WEBPOST_ERROR_HTTP_GET_FAILED',0x4004211A)
		win_const_mgr.add_const('SKF_HOTKEYSOUND',0x00000010)
		win_const_mgr.add_const('DYNAWIZ_FLAG_PAGESADDED',0x00000001)
		win_const_mgr.add_const('SECPKG_ATTR_CONNECTION_INFO',0x00000005)
		win_const_mgr.add_const('LINEDISCONNECTMODE_NOANSWER',0x00000040)
		win_const_mgr.add_const('IMAGE_REL_M32R_PCREL24',0x00000005)
		win_const_mgr.add_const('SE_ERR_SHARE',0x0000001A)
		win_const_mgr.add_const('DM_TTOPTION',0x00004000)
		win_const_mgr.add_const('PRIVACY_URLHASPOSTDATA',0x00080000)
		win_const_mgr.add_const('LINECALLFEATURE2_ONESTEPTRANSFER',0x00000002)
		win_const_mgr.add_const('KSEVENT_TYPE_BASICSUPPORT',0x00000200)
		win_const_mgr.add_const('MAPI_E_DISK_FULL',0x00000004)
		win_const_mgr.add_const('ERROR_DS_COMPARE_FALSE',0x00002025)
		win_const_mgr.add_const('SP_PROT_SSL2_CLIENT',0x00000008)
		win_const_mgr.add_const('DC_NUP',0x00000021)
		win_const_mgr.add_const('WKSTA_FORCECORECREATEMODE_PARMNUM',0x0000003C)
		win_const_mgr.add_const('ERROR_DS_DOMAIN_VERSION_TOO_HIGH',0x00002174)
		win_const_mgr.add_const('MIXERCONTROL_CT_SC_LIST_SINGLE',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_USE_PROCTIME',0x00000001)
		win_const_mgr.add_const('ERROR_INVALID_OWNER',0x0000051B)
		win_const_mgr.add_const('LVFI_NEARESTXY',0x00000040)
		win_const_mgr.add_const('PROCESSOR_IDLESTATE_POLICY_COUNT',0x00000003)
		win_const_mgr.add_const('ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE',0x000002D0)
		win_const_mgr.add_const('DSGIF_GETDEFAULTICON',0x00000010)
		win_const_mgr.add_const('SQL_SET_NULL',0x00000002)
		win_const_mgr.add_const('DNS_MAX_NAME_LENGTH',0x000000FF)
		win_const_mgr.add_const('PRINTER_ENUM_FAVORITE',0x00000004)
		win_const_mgr.add_const('INTERNET_CONNECTION_OFFLINE',0x00000020)
		win_const_mgr.add_const('GROUP_NAME_PARMNUM',0x00000001)
		win_const_mgr.add_const('MSCS_MD_ID_BEGIN_RESERVED',0x00000000)
		win_const_mgr.add_const('SCARD_STATE_UNKNOWN',0x00000004)
		win_const_mgr.add_const('ET_SIGNATURE',0x00000100)
		win_const_mgr.add_const('BEGIN_PATH',0x00001000)
		win_const_mgr.add_const('EC_ERRORABORT',0x00000003)
		win_const_mgr.add_const('WINHTTP_QUERY_PROXY_CONNECTION',0x00000045)
		win_const_mgr.add_const('CDEF_DEVMON_DMO',0x00000020)
		win_const_mgr.add_const('NDIS_INTERRUPT_MODERATION_PARAMETERS_REVISION_1',0x00000001)
		win_const_mgr.add_const('DISPID_ICONSIZECHANGED',0x000000D7)
		win_const_mgr.add_const('KSPRIORITY_NORMAL',0x40000000)
		win_const_mgr.add_const('BLLI_L3_T70',0x0000000A)
		win_const_mgr.add_const('CONTEXT_MENU_DEFAULT',0x00000000)
		win_const_mgr.add_const('TBNF_IMAGE',0x00000001)
		win_const_mgr.add_const('BST_FOCUS',0x00000008)
		win_const_mgr.add_const('WAM_MD_ID_END_RESERVED',0x00000007)
		win_const_mgr.add_const('AI_PASSIVE',0x00000001)
		win_const_mgr.add_const('ENUMPAPERBINS',0x0000001F)
		win_const_mgr.add_const('CRSWPP_ERROR_FIRST',0x40042200)
		win_const_mgr.add_const('CERT_MAX_ASN_ENCODED_DSS_SIGNATURE_LEN',0x00000002)
		win_const_mgr.add_const('ERROR_RESOURCE_TYPE_NOT_FOUND',0x00000715)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_SERVICE_CC1',0x00000010)
		win_const_mgr.add_const('SPCRP_EXCLUSIVE',0x0000001A)
		win_const_mgr.add_const('FS_COMPLETED',0x20000008)
		win_const_mgr.add_const('ICMODE_QUERY',0x00000004)
		win_const_mgr.add_const('DM_INTERLACED',0x00000002)
		win_const_mgr.add_const('DEBUG_STACK_FRAME_NUMBERS',0x00000040)
		win_const_mgr.add_const('MD_LOGFILE_PERIOD_HOURLY',0x00000004)
		win_const_mgr.add_const('PLA_CAPABILITY_V1_SESSION',0x00000002)
		win_const_mgr.add_const('GPO_BROWSE_NOCOMPUTERS',0x00000002)
		win_const_mgr.add_const('WIA_PAGE_CUSTOM',0x00000002)
		win_const_mgr.add_const('PHOTOACQ_NO_GALLERY_LAUNCH',0x00000001)
		win_const_mgr.add_const('TNS_TYPE_NATIONAL',0x00000040)
		win_const_mgr.add_const('JET_MAX_COMPUTERNAME_LENGTH',0x0000000F)
		win_const_mgr.add_const('MIXERCONTROL_CONTROLF_DISABLED',0x80000000)
		win_const_mgr.add_const('CM_PROB_HELD_FOR_EJECT',0x0000002F)
		win_const_mgr.add_const('ACM_MPEG_LAYER1',0x00000001)
		win_const_mgr.add_const('ACM_MPEG_LAYER2',0x00000002)
		win_const_mgr.add_const('ACM_MPEG_LAYER3',0x00000004)
		win_const_mgr.add_const('IDM_BRINGFORWARD',0x0000000A)
		win_const_mgr.add_const('LOGTOKEN_UNSPECIFIED',0x00000000)
		win_const_mgr.add_const('CHANNEL_EVENT_WRITE_COMPLETE',0x0000000B)
		win_const_mgr.add_const('CRYPT_IMPL_HARDWARE',0x00000001)
		win_const_mgr.add_const('ET_CONNECTIONSPACE',0x00000080)
		win_const_mgr.add_const('DIGCF_ALLCLASSES',0x00000004)
		win_const_mgr.add_const('MQ_DENY_NONE',0x00000000)
		win_const_mgr.add_const('TIME_SMPTE',0x00000008)
		win_const_mgr.add_const('NLS_KATAKANA',0x00020000)
		win_const_mgr.add_const('NETBIOS_GROUP_NAME',0x00000001)
		win_const_mgr.add_const('DNS_QUERY_BYPASS_CACHE',0x00000008)
		win_const_mgr.add_const('KERBEROS_REVISION',0x00000006)
		win_const_mgr.add_const('SQL_SQ_QUANTIFIED',0x00000008)
		win_const_mgr.add_const('SECBUFFER_RESERVED',0x60000000)
		win_const_mgr.add_const('PSD_DISABLEMARGINS',0x00000010)
		win_const_mgr.add_const('LOGON_NO_OPTIMIZED',0x00020000)
		win_const_mgr.add_const('ERROR_TM_IDENTITY_MISMATCH',0x00001ABD)
		win_const_mgr.add_const('PDH_END_OF_LOG_FILE',0x800007DA)
		win_const_mgr.add_const('CERT_NEXT_UPDATE_LOCATION_PROP_ID',0x0000000A)
		win_const_mgr.add_const('FILE_CASE_PRESERVED_NAMES',0x00000002)
		win_const_mgr.add_const('ERROR_INSTALL_REMOTE_PROHIBITED',0x0000066D)
		win_const_mgr.add_const('IPX_UPDATE_INTERVAL_DEFVAL',0x0000003C)
		win_const_mgr.add_const('MCI_VCR_STATUS_FRAME_RATE',0x00004001)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_FLAG_INVALID_CERT',0x00000002)
		win_const_mgr.add_const('MFBYTESTREAM_IS_DIRECTORY',0x00000080)
		win_const_mgr.add_const('DMI_BKCOLOR',0x00000002)
		win_const_mgr.add_const('ED_AUDIO_22',0x00200000)
		win_const_mgr.add_const('ED_AUDIO_23',0x00400000)
		win_const_mgr.add_const('ED_AUDIO_20',0x00080000)
		win_const_mgr.add_const('ED_AUDIO_21',0x00100000)
		win_const_mgr.add_const('ERR_ABORT_SEARCH',0xE0000007)
		win_const_mgr.add_const('ED_AUDIO_24',0x00800000)
		win_const_mgr.add_const('TARGET_IS_NT40_OR_LATER',0x00000000)
		win_const_mgr.add_const('OF_CAP_CANCLOSE',0x00000002)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_USERS',0x00000201)
		win_const_mgr.add_const('ERROR_OUT_OF_PAPER',0x0000001C)
		win_const_mgr.add_const('SCH_CRED_IGNORE_NO_REVOCATION_CHECK',0x00000800)
		win_const_mgr.add_const('LCMAP_BYTEREV',0x00000800)
		win_const_mgr.add_const('INFOTIPSIZE',0x00000400)
		win_const_mgr.add_const('PROC_IDLE_BUCKET_COUNT',0x00000006)
		win_const_mgr.add_const('OID_WAN_GET_INFO',0x04010107)
		win_const_mgr.add_const('ERROR_CANCEL_VIOLATION',0x000000AD)
		win_const_mgr.add_const('CBEIF_IMAGE',0x00000002)
		win_const_mgr.add_const('OQWF_ISSUEONOPEN',0x00000040)
		win_const_mgr.add_const('PAN_SERIF_SQUARE_COVE',0x00000004)
		win_const_mgr.add_const('HSE_URL_FLAGS_MAP_CERT',0x00000080)
		win_const_mgr.add_const('ERROR_INVALID_PATCH_XML',0x00000672)
		win_const_mgr.add_const('ERROR_DS_DRA_EXTN_CONNECTION_FAILED',0x00002112)
		win_const_mgr.add_const('DI_DIDCLASS',0x00000020)
		win_const_mgr.add_const('ERROR_REGISTRY_CORRUPT',0x000003F7)
		win_const_mgr.add_const('TF_LBI_STATUS_BTN_TOGGLED',0x00010000)
		win_const_mgr.add_const('IDM_TRIED_CUT',0x0000001F)
		win_const_mgr.add_const('ERROR_LOG_SECTOR_INVALID',0x000019C8)
		win_const_mgr.add_const('DNF_INF_IS_SIGNED',0x00002000)
		win_const_mgr.add_const('WIA_IPS_YPOS',0x00001806)
		win_const_mgr.add_const('DN_APM_ENUMERATOR',0x08000000)
		win_const_mgr.add_const('BTH_ADDR_LIAC',0x009E8B00)
		win_const_mgr.add_const('E_SURFACE_UNKNOWN_FORMAT',0x8000C001)
		win_const_mgr.add_const('PROP_START_TIME',0x00000010)
		win_const_mgr.add_const('ASC_RET_FRAGMENT_ONLY',0x00800000)
		win_const_mgr.add_const('IDM_NONBREAK',0x0000086B)
		win_const_mgr.add_const('SVAUD_GOODNETLOGON',0x00000060)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_QM_LIMIT',0x0000363C)
		win_const_mgr.add_const('CRYPT_STRING_NOCR',0x80000000)
		win_const_mgr.add_const('DNS_STATUS_SINGLE_PART_NAME',0x00002557)
		win_const_mgr.add_const('ERROR_RING2SEG_MUST_BE_MOVABLE',0x000000C8)
		win_const_mgr.add_const('CREDENTIAL_SUB_TYPE_X509_V3_CERT',0x00000004)
		win_const_mgr.add_const('LDAP_OPT_REFERRAL_CALLBACK',0x00000070)
		win_const_mgr.add_const('TMT_VERSION',0x0000025F)
		win_const_mgr.add_const('ERROR_DBG_REPLY_LATER',0x000002B1)
		win_const_mgr.add_const('OUT_PS_ONLY_PRECIS',0x0000000A)
		win_const_mgr.add_const('GESTURE_DOUBLE_ARROW_LEFT',0x00000000)
		win_const_mgr.add_const('LINEEQOSINFO_ADMISSIONFAILURE',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_USERNAME',0x0000001C)
		win_const_mgr.add_const('PAN_XHEIGHT_CONSTANT_STD',0x00000003)
		win_const_mgr.add_const('WLX_DESKTOP_NAME',0x00000001)
		win_const_mgr.add_const('URL_UNESCAPE_INPLACE',0x00100000)
		win_const_mgr.add_const('DBT_VOLLOCKLOCKFAILED',0x00008043)
		win_const_mgr.add_const('LVNI_TORIGHT',0x00000800)
		win_const_mgr.add_const('SQL_TXN_VERSIONING',0x00000010)
		win_const_mgr.add_const('SQL_POS_DELETE',0x00000008)
		win_const_mgr.add_const('DEBUG_CES_RADIX',0x00000080)
		win_const_mgr.add_const('CERT_VALIDITY_EXPLICITLY_DISTRUSTED',0x01000000)
		win_const_mgr.add_const('HSHELL_SYSMENU',0x00000009)
		win_const_mgr.add_const('SQL_CA_SS_BASE',0x000004B0)
		win_const_mgr.add_const('WIA_PROP_LIST',0x00000020)
		win_const_mgr.add_const('LINECALLINFOSTATE_REDIRECTIONID',0x00040000)
		win_const_mgr.add_const('TLS1_ALERT_UNSUPPORTED_CERT',0x0000002B)
		win_const_mgr.add_const('DCBA_FACEDOWNLEFT',0x00000102)
		win_const_mgr.add_const('D3DPRASTERCAPS_ZFOG',0x00200000)
		win_const_mgr.add_const('TLOG_FORE',0x00000001)
		win_const_mgr.add_const('MCI_DGV_WHERE_VIDEO',0x00100000)
		win_const_mgr.add_const('CRYPT_SECRETDIGEST',0x00000001)
		win_const_mgr.add_const('SDP_ATTRIB_HID_COUNTRY_CODE',0x00000203)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_TRANSLATIONS',0x00000003)
		win_const_mgr.add_const('TBIF_STATE',0x00000004)
		win_const_mgr.add_const('RSC_LOADRS',0x00000010)
		win_const_mgr.add_const('BSF_UISETBYAUTOMATION',0x00000100)
		win_const_mgr.add_const('TVS_EX_DRAWIMAGEASYNC',0x00000400)
		win_const_mgr.add_const('SHARE_TYPE_PARMNUM',0x00000003)
		win_const_mgr.add_const('HDS_DRAGDROP',0x00000040)
		win_const_mgr.add_const('IDM_SHADOWED',0x00000042)
		win_const_mgr.add_const('IDM_ALIGNRIGHT',0x00000004)
		win_const_mgr.add_const('WINHTTP_IGNORE_REQUEST_TOTAL_LENGTH',0x00000000)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_USER_FLOW_COUNT',0x00000007)
		win_const_mgr.add_const('FILE_DEVICE_MIDI_OUT',0x00000000)
		win_const_mgr.add_const('LCSEX_TEMPPROFILE',0x00000002)
		win_const_mgr.add_const('MB_RIGHT',0x00080000)
		win_const_mgr.add_const('SMDM_SHELLFOLDER',0x00000001)
		win_const_mgr.add_const('REPL_STATE_NO_SYNC',0x00000002)
		win_const_mgr.add_const('POLICY_LOCATOR_SUB_TYPE_UNICODE_DN',0x00000002)
		win_const_mgr.add_const('DSICCF_IGNORETREATASLEAF',0x00000001)
		win_const_mgr.add_const('USN_REASON_HARD_LINK_CHANGE',0x00010000)
		win_const_mgr.add_const('NDIS_STATISTICS_INFO_REVISION_1',0x00000001)
		win_const_mgr.add_const('EVENT_SYSTEM_ALERT',0x00000002)
		win_const_mgr.add_const('PSINJECT_PAGETRAILER',0x00000067)
		win_const_mgr.add_const('LB_SRC_MASK_LATE_FLAG',0x00000010)
		win_const_mgr.add_const('DIRID_FONTS',0x00000014)
		win_const_mgr.add_const('FILE_DEVICE_CONTROLLER',0x00000004)
		win_const_mgr.add_const('TF_TMAE_COMLESS',0x00000008)
		win_const_mgr.add_const('CPF_DELTA',0x00000002)
		win_const_mgr.add_const('TBSTATE_MARKED',0x00000080)
		win_const_mgr.add_const('LINEAGENTSTATUS_STATE',0x00000002)
		win_const_mgr.add_const('WINHTTP_TIME_FORMAT_BUFSIZE',0x0000003E)
		win_const_mgr.add_const('EC_STARVATION',0x00000017)
		win_const_mgr.add_const('USN_SOURCE_REPLICATION_MANAGEMENT',0x00000004)
		win_const_mgr.add_const('WIA_IPS_SHOW_PREVIEW_CONTROL',0x00000C1F)
		win_const_mgr.add_const('ERROR_CTX_MODEM_RESPONSE_VOICE',0x00001B68)
		win_const_mgr.add_const('KP_HIGHEST_VERSION',0x00000029)
		win_const_mgr.add_const('RATING_FOUR_STARS_SET',0x0000004B)
		win_const_mgr.add_const('DEBUG_GETMOD_NO_UNLOADED_MODULES',0x00000002)
		win_const_mgr.add_const('MCI_DGV_INFO_VIDEO_QUALITY',0x00004003)
		win_const_mgr.add_const('SPOST_PATH',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SOURCE_LEFT',0x00000001)
		win_const_mgr.add_const('PROV_EC_ECNRA_SIG',0x0000000F)
		win_const_mgr.add_const('MM_LOENGLISH',0x00000004)
		win_const_mgr.add_const('ERROR_PRINT_MONITOR_ALREADY_INSTALLED',0x00000BBE)
		win_const_mgr.add_const('SCRIPTTEXT_HOSTMANAGESSOURCE',0x00000080)
		win_const_mgr.add_const('CDERR_MEMLOCKFAILURE',0x0000000A)
		win_const_mgr.add_const('GCS_RESULTCLAUSE',0x00001000)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_UNAUTH_USER_PEAK_RATE',0x00000020)
		win_const_mgr.add_const('MDM_V120_SPEED_DEFAULT',0x00000000)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_XMIT_DISCARDS',0x00008000)
		win_const_mgr.add_const('NETERR_RING_STATUS_SIGNAL_LOST',0x00008000)
		win_const_mgr.add_const('ISDB_ERT_TID',0x000000D1)
		win_const_mgr.add_const('TMSTARTRSCAN',0x01000000)
		win_const_mgr.add_const('DXGI_MWA_NO_PRINT_SCREEN',0x00000001)
		win_const_mgr.add_const('X3_EMPTY_SIZE_X',0x00000002)
		win_const_mgr.add_const('ERROR_COMMITMENT_MINIMUM',0x0000027B)
		win_const_mgr.add_const('ITSAT_MIN_PRIORITY',0x00000000)
		win_const_mgr.add_const('ERROR_DS_STRING_SD_CONVERSION_FAILED',0x0000214A)
		win_const_mgr.add_const('INTERNET_OPTION_PROXY_PASSWORD',0x0000002C)
		win_const_mgr.add_const('SQL_SDF_CURRENT_TIMESTAMP',0x00000004)
		win_const_mgr.add_const('DOT11_STATUS_EXCESSIVE_DATA_LENGTH',0x00000100)
		win_const_mgr.add_const('AE_SESSLOGON',0x00000001)
		win_const_mgr.add_const('KSPROPERTY_CAMERACONTROL_FLAGS_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('LANG_DUTCH',0x00000013)
		win_const_mgr.add_const('IGP_SELECT',0x00000018)
		win_const_mgr.add_const('LDAP_RES_ADD',0x00000069)
		win_const_mgr.add_const('LVSICF_NOINVALIDATEALL',0x00000001)
		win_const_mgr.add_const('WNCON_DYNAMIC',0x00000008)
		win_const_mgr.add_const('WM_IMEKEYUP',0x00000291)
		win_const_mgr.add_const('SQL_CA2_CRC_APPROXIMATE',0x00002000)
		win_const_mgr.add_const('ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE',0x0000212F)
		win_const_mgr.add_const('IP_PROTOCOL_UUID16',0x00000009)
		win_const_mgr.add_const('EXTENSION_ORIGIN_CACERT',0x00090000)
		win_const_mgr.add_const('OID_TCP_TASK_IPSEC_ADD_SA',0xFC010202)
		win_const_mgr.add_const('STRSAFE_NULL_ON_FAILURE',0x00000800)
		win_const_mgr.add_const('ERROR_WINS_INTERNAL',0x00000FA0)
		win_const_mgr.add_const('INTERNET_STATUS_CONNECTED_TO_SERVER',0x00000015)
		win_const_mgr.add_const('NCBHANGUP',0x00000012)
		win_const_mgr.add_const('SUBLANG_SPANISH_GUATEMALA',0x00000004)
		win_const_mgr.add_const('VIF_SRCOLD',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_CEE_SECTION',0x00000004)
		win_const_mgr.add_const('MDPROPVAL_MF_SCOPE_SESSION',0x00000010)
		win_const_mgr.add_const('FEATURESETTING_PSLEVEL',0x00000002)
		win_const_mgr.add_const('BATTERY_SET_DISCHARGE_SUPPORTED',0x00000002)
		win_const_mgr.add_const('ERROR_NO_PAGEFILE',0x00000242)
		win_const_mgr.add_const('IDM_TRIED_INSERTROW',0x0000000E)
		win_const_mgr.add_const('TAPE_LONG_FILEMARKS',0x00000003)
		win_const_mgr.add_const('VCSTATUS_SUBMIT',0x00080000)
		win_const_mgr.add_const('LVGIT_UNFOLDED',0x00000001)
		win_const_mgr.add_const('GW_ENABLEDPOPUP',0x00000006)
		win_const_mgr.add_const('RSVP_WILDCARD_STYLE',0x00000001)
		win_const_mgr.add_const('MD_ERROR_SUB403_APPPOOL_DENIED',0x00000012)
		win_const_mgr.add_const('CRYPT_ARCHIVE',0x00000100)
		win_const_mgr.add_const('SQLMONEYN',0x00000006)
		win_const_mgr.add_const('DEVICE_NOTIFY_ALL_INTERFACE_CLASSES',0x00000004)
		win_const_mgr.add_const('STDPROP_SORTKEY',0x00000064)
		win_const_mgr.add_const('KAGPROP_STRINGFUNCTIONS',0x00000014)
		win_const_mgr.add_const('CSIDL_PROGRAM_FILES',0x00000026)
		win_const_mgr.add_const('FILTERED_LOG_CONF',0x00000001)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_FUNCTIONS',0x00000004)
		win_const_mgr.add_const('DISPID_IMULTISESSION_FREESECTORS',0x00000204)
		win_const_mgr.add_const('COD_IMAGING_MINOR_SCANNER_MASK',0x00000010)
		win_const_mgr.add_const('ERROR_RESOURCE_CALL_TIMED_OUT',0x00001716)
		win_const_mgr.add_const('EMR_ARCTO',0x00000037)
		win_const_mgr.add_const('BATTERY_UNKNOWN_TIME',0xFFFFFFFF)
		win_const_mgr.add_const('VER_NUM_BITS_PER_CONDITION_MASK',0x00000003)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_FILTER_ATTACH_PARAMETERS',0x00000099)
		win_const_mgr.add_const('DNS_RTYPE_NULL',0x00000000)
		win_const_mgr.add_const('DRM_EL_ISSUERNAME',0x00002000)
		win_const_mgr.add_const('CDO_E_PROP_NOT_FOUND',0x8004021E)
		win_const_mgr.add_const('WMAUDIO_MAX_CHANNELS',0x00000002)
		win_const_mgr.add_const('PRESENTED_TYPE_NO_FLAG_SET',0x00000000)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_DISK',0x00000008)
		win_const_mgr.add_const('WINHTTP_ADDREQ_INDEX_MASK',0x0000FFFF)
		win_const_mgr.add_const('COD_AUDIO_MINOR_VCR',0x0000000B)
		win_const_mgr.add_const('TMT_FROMCOLOR2',0x000007D2)
		win_const_mgr.add_const('TMT_FROMCOLOR1',0x000007D1)
		win_const_mgr.add_const('D3DFMT_R5G6B5',0x00000017)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_CLOSETRAY',0x00000101)
		win_const_mgr.add_const('TMT_FROMCOLOR5',0x000007D5)
		win_const_mgr.add_const('TMT_FROMCOLOR4',0x000007D4)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_OMAP_FROM_SRC',0x00000008)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_KEY_USAGE',0x000035FA)
		win_const_mgr.add_const('SS_GRAYFRAME',0x00000008)
		win_const_mgr.add_const('PCIC_DEFAULT_IRQMASK',0x00001468)
		win_const_mgr.add_const('CM_DRP_SERVICE',0x00000005)
		win_const_mgr.add_const('CONSOLE_APPLICATION_16BIT',0x00000001)
		win_const_mgr.add_const('TRACE_MESSAGE_GUID',0x00000002)
		win_const_mgr.add_const('TXTBIT_USECURRENTBKG',0x00200000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_USEDSECTORSONMEDIA',0x00000106)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_MIPSFPU16',0x00000466)
		win_const_mgr.add_const('TMT_GRADIENTRATIO3',0x00000968)
		win_const_mgr.add_const('TMT_GRADIENTRATIO2',0x00000967)
		win_const_mgr.add_const('TMT_GRADIENTRATIO1',0x00000966)
		win_const_mgr.add_const('RGN_AND',0x00000001)
		win_const_mgr.add_const('DEBUG_STACK_PARAMETERS',0x00000080)
		win_const_mgr.add_const('IOCTL_IP_GET_BEST_INTERFACE',0x00000069)
		win_const_mgr.add_const('LINECARDOPTION_PREDEFINED',0x00000001)
		win_const_mgr.add_const('SDP_ERROR_INSUFFICIENT_RESOURCES',0x00000006)
		win_const_mgr.add_const('SPI_GETFOCUSBORDERWIDTH',0x0000200E)
		win_const_mgr.add_const('SPFILENOTIFY_NEEDMEDIA',0x00000000)
		win_const_mgr.add_const('CBES_EX_TEXTENDELLIPSIS',0x00000020)
		win_const_mgr.add_const('GW_CHILD',0x00000005)
		win_const_mgr.add_const('SPFILENOTIFY_STARTSUBQUEUE',0x00000003)
		win_const_mgr.add_const('MCI_DGV_CUT_VIDEO_STREAM',0x00040000)
		win_const_mgr.add_const('CSIDL_COMMON_OEM_LINKS',0x00000003)
		win_const_mgr.add_const('ERROR_LOG_NO_RESTART',0x000019D3)
		win_const_mgr.add_const('CRYPTPROTECT_LOCAL_MACHINE',0x00000004)
		win_const_mgr.add_const('ETW_INT32_TYPE_VALUE',0x00000007)
		win_const_mgr.add_const('LINEFORWARDMODE_UNAVAIL',0x00020000)
		win_const_mgr.add_const('ERROR_BAD_PIPE',0x000000E6)
		win_const_mgr.add_const('LANG_THAI',0x00000001)
		win_const_mgr.add_const('DEBUG_USER_WINDOWS_IDNA',0x00000002)
		win_const_mgr.add_const('SNMPAPI_INDEX_INVALID',0x00000007)
		win_const_mgr.add_const('MDTREEOP_SIBLINGS',0x00000002)
		win_const_mgr.add_const('KP_OAEP_PARAMS',0x00000024)
		win_const_mgr.add_const('RR_PS_LEN',0x00000006)
		win_const_mgr.add_const('WH_KEYBOARD_LL',0x0000000D)
		win_const_mgr.add_const('MIDIPATCHSIZE',0x00000080)
		win_const_mgr.add_const('HH_SET_EXCLUSIVE_FILTER',0x00000019)
		win_const_mgr.add_const('PRINTER_CHANGE_ADD_FORM',0x00010000)
		win_const_mgr.add_const('MCI_DGV_WHERE_SOURCE',0x00020000)
		win_const_mgr.add_const('WM_ENTERIDLE',0x00000121)
		win_const_mgr.add_const('SIZEOF_IP4_ADDRESS',0x00000004)
		win_const_mgr.add_const('KERB_ETYPE_RSA_PUB',0x0000000A)
		win_const_mgr.add_const('SECURITY_FLAG_UNKNOWNBIT',0x80000000)
		win_const_mgr.add_const('BTH_ERROR_SCO_OFFSET_REJECTED',0x00000001)
		win_const_mgr.add_const('NETBIOS_TYPE_QUICK_GROUP',0x00000003)
		win_const_mgr.add_const('MD_EXPORT_INHERITED',0x00000001)
		win_const_mgr.add_const('ALG_SID_SAFERSK64',0x00000007)
		win_const_mgr.add_const('JIFMK_EXP',0x0000FFDF)
		win_const_mgr.add_const('IDC_IO_LINKFILE',0x00000836)
		win_const_mgr.add_const('ICERR_STOPDRAWING',0x00000004)
		win_const_mgr.add_const('PROP_LG_CXDLG',0x000000FC)
		win_const_mgr.add_const('MCI_WAVE_SET_BITSPERSAMPLE',0x00200000)
		win_const_mgr.add_const('CSIDL_FLAG_PER_USER_INIT',0x00000800)
		win_const_mgr.add_const('HIST_NO_OF_BUCKETS',0x00000018)
		win_const_mgr.add_const('INVALID_VIDEO_FORMAT',0x00000000)
		win_const_mgr.add_const('FWPM_CALLOUT_FLAG_PERSISTENT',0x00010000)
		win_const_mgr.add_const('CTRY_BRUNEI_DARUSSALAM',0x000002A1)
		win_const_mgr.add_const('NS_SAP',0x00000001)
		win_const_mgr.add_const('ERROR_CONNECTION_REFUSED',0x000004C9)
		win_const_mgr.add_const('PORT_PRINTSRV',0x000000AA)
		win_const_mgr.add_const('CREDUI_FLAGS_SHOW_SAVE_CHECK_BOX',0x00000040)
		win_const_mgr.add_const('PAN_STRAIGHT_ARMS_VERT',0x00000004)
		win_const_mgr.add_const('EC_DVDBASE',0x00000100)
		win_const_mgr.add_const('IOF_SHOWINSERTCONTROL',0x00001000)
		win_const_mgr.add_const('TPM_CENTERALIGN',0x00000004)
		win_const_mgr.add_const('SPOST_NONE',0x00000000)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_FILE',0x00000067)
		win_const_mgr.add_const('ERROR_DISK_CORRUPT',0x00000571)
		win_const_mgr.add_const('IDS_CAP_STAT_FRAMESDROPPED',0x00000201)
		win_const_mgr.add_const('AVSTREAMMASTER_AUDIO',0x00000000)
		win_const_mgr.add_const('MS_G723_CPU',0x00000046)
		win_const_mgr.add_const('HTTP_STATUS_SERVER_ERROR',0x000001F4)
		win_const_mgr.add_const('DISPID_IHTMLDLGSAFEHELPER_GETCHARSET',0x00000002)
		win_const_mgr.add_const('PROPID_QM_BASE',0x000000C8)
		win_const_mgr.add_const('INTERNET_AUTODIAL_OVERRIDE_NET_PRESENT',0x00000008)
		win_const_mgr.add_const('VFF_CURNEDEST',0x00000001)
		win_const_mgr.add_const('OPF_NOFILLDEFAULT',0x00000002)
		win_const_mgr.add_const('CBENF_ESCAPE',0x00000003)
		win_const_mgr.add_const('ETO_CLIPPED',0x00000004)
		win_const_mgr.add_const('DISPID_ONADDRESSBAR',0x00000105)
		win_const_mgr.add_const('MCI_PLAY',0x00000806)
		win_const_mgr.add_const('TIME_BYTES',0x00000004)
		win_const_mgr.add_const('IDS_CAP_FILEEXISTS',0x00000193)
		win_const_mgr.add_const('PORT_OMSERV',0x000002FC)
		win_const_mgr.add_const('PARITY_SPACE',0x00001000)
		win_const_mgr.add_const('IMAGE_REL_MIPS_PAIR',0x00000025)
		win_const_mgr.add_const('CSC_CACHE_MANUAL_REINT',0x00000000)
		win_const_mgr.add_const('URLACTION_ACTIVEX_DYNSRC_VIDEO_AND_ANIMATION',0x0000120A)
		win_const_mgr.add_const('AM_QUERY_DECODER_VMR_SUPPORT',0x00000001)
		win_const_mgr.add_const('CERT_STORE_SIGNATURE_FLAG',0x00000001)
		win_const_mgr.add_const('IF_TYPE_DTM',0x0000008C)
		win_const_mgr.add_const('TAPE_DRIVE_WRITE_MARK_IMMED',0x90000000)
		win_const_mgr.add_const('CFERR_CHOOSEFONTCODES',0x00002000)
		win_const_mgr.add_const('ERROR_SET_NOT_FOUND',0x00000492)
		win_const_mgr.add_const('DC_MEDIATYPES',0x00000023)
		win_const_mgr.add_const('SND_NODEFAULT',0x00000002)
		win_const_mgr.add_const('ERROR_CTX_CLIENT_LICENSE_IN_USE',0x00001B8C)
		win_const_mgr.add_const('MDM_HDLCPPP_AUTH_DEFAULT',0x00000000)
		win_const_mgr.add_const('OID_802_3_PERMANENT_ADDRESS',0x01010101)
		win_const_mgr.add_const('SECPKG_ATTR_CREDENTIAL_NAME',0x00000010)
		win_const_mgr.add_const('MDM_V120_ML_DEFAULT',0x00000000)
		win_const_mgr.add_const('WM_ACTIVATE',0x00000006)
		win_const_mgr.add_const('MCI_VCR_STATUS_POSTROLL_DURATION',0x00004024)
		win_const_mgr.add_const('CAL_SDAYNAME4',0x00000000)
		win_const_mgr.add_const('ERROR_QUORUM_RESOURCE',0x0000139C)
		win_const_mgr.add_const('VIEW_SORTTYPE',0x00000007)
		win_const_mgr.add_const('ACCESSIBILITY_SETTING',0x00000003)
		win_const_mgr.add_const('CRYPTPROTECT_PROMPT_RESERVED',0x00000004)
		win_const_mgr.add_const('EC_CONTENTPROPERTY_CHANGED',0x00000047)
		win_const_mgr.add_const('TASK_FLAG_HIDDEN',0x00000200)
		win_const_mgr.add_const('ERROR_DISK_QUOTA_EXCEEDED',0x0000050F)
		win_const_mgr.add_const('MQ_LOOKUP_RECEIVE_FIRST',0x40000024)
		win_const_mgr.add_const('EMR_HEADER',0x00000001)
		win_const_mgr.add_const('CICAT_ALL_OPENED',0x00000020)
		win_const_mgr.add_const('OCR_IBEAM',0x00007F01)
		win_const_mgr.add_const('SS_REALSIZECONTROL',0x00000040)
		win_const_mgr.add_const('TTF_TRACK',0x00000020)
		win_const_mgr.add_const('D3DCAPS_READ_SCANLINE',0x00020000)
		win_const_mgr.add_const('GETPHYSPAGESIZE',0x0000000C)
		win_const_mgr.add_const('DEBUG_ADDSYNTHSYM_DEFAULT',0x00000000)
		win_const_mgr.add_const('MCI_DGV_STATUS_FRAME_RATE',0x00000400)
		win_const_mgr.add_const('SPDRP_CHARACTERISTICS',0x0000001B)
		win_const_mgr.add_const('EC_OPEN_EXISTING',0x00000002)
		win_const_mgr.add_const('CGD_UNKNOWN_PROPERTY',0x00000000)
		win_const_mgr.add_const('IDTB_JUMP2',0x000000DB)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_SHARED',0x00000008)
		win_const_mgr.add_const('TA_RTLREADING',0x00000100)
		win_const_mgr.add_const('SVAUD_BADUSE',0x00001800)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_USER_SUM_PEAK_RATE',0x0000002B)
		win_const_mgr.add_const('SMART_INVALID_REGISTER',0x00000008)
		win_const_mgr.add_const('IDS_CAP_OUTOFMEM',0x00000192)
		win_const_mgr.add_const('DDBLT_ALPHAEDGEBLEND',0x00000010)
		win_const_mgr.add_const('DLCTL_NO_SCRIPTS',0x00000080)
		win_const_mgr.add_const('LINECARDOPTION_HIDDEN',0x00000002)
		win_const_mgr.add_const('LPV_MAX_PRIORITY',0x0000FF00)
		win_const_mgr.add_const('QUOTA_LIMITS_HARDWS_MIN_ENABLE',0x00000001)
		win_const_mgr.add_const('SAFER_MAX_HASH_SIZE',0x00000040)
		win_const_mgr.add_const('LINE_APPNEWCALL',0x00000017)
		win_const_mgr.add_const('WNODE_FLAG_SEVERITY_MASK',0x00000000)
		win_const_mgr.add_const('ERRLOC_DISK',0x00000002)
		win_const_mgr.add_const('ERRCLASS_CANT',0x0000000E)
		win_const_mgr.add_const('DDCOLOR_SATURATION',0x00000008)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_CREATOR_GROUP',0x80000200)
		win_const_mgr.add_const('WMIREG_FLAG_EXPENSIVE',0x00000001)
		win_const_mgr.add_const('SQL_ATTR_ROW_STATUS_PTR',0x00000019)
		win_const_mgr.add_const('TCP_OFFLOAD_NO_PREFERENCE',0x00000000)
		win_const_mgr.add_const('KAGPROPVAL_CONCUR_READ_ONLY',0x00000008)
		win_const_mgr.add_const('LINE_APPNEWCALLHUB',0x00000020)
		win_const_mgr.add_const('RTCRF_REGISTER_ALL',0x0000000F)
		win_const_mgr.add_const('WIA_IPA_ICM_PROFILE_NAME',0x00001018)
		win_const_mgr.add_const('EVENTLOG_PAIRED_EVENT_INACTIVE',0x00000010)
		win_const_mgr.add_const('CCHFORMNAME',0x00000020)
		win_const_mgr.add_const('SQL_SQL92_FOREIGN_KEY_DELETE_RULE',0x0000009C)
		win_const_mgr.add_const('EXP_DARWIN_ID_SIG',0xA0000006)
		win_const_mgr.add_const('ISSCERT_FTPURL_OLD',0x00000004)
		win_const_mgr.add_const('SQL_CREATE_ASSERTION',0x0000007F)
		win_const_mgr.add_const('WNODE_FLAG_METHOD_ITEM',0x00008000)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_LOWLEVCOMP',0x00000004)
		win_const_mgr.add_const('SQL_TABLE_TERM',0x0000002D)
		win_const_mgr.add_const('IEIFLAG_CACHE',0x00000002)
		win_const_mgr.add_const('CLASSFACTORY_S_FIRST',0x00040110)
		win_const_mgr.add_const('OLEMISC_INVISIBLEATRUNTIME',0x00000400)
		win_const_mgr.add_const('CRYPTUI_ONLY_OPEN_ROOT_STORE',0x00000200)
		win_const_mgr.add_const('BACKUP_OBJECT_ID',0x00000007)
		win_const_mgr.add_const('SUBLANG_KOREAN',0x00000001)
		win_const_mgr.add_const('BCN_LAST',0x00000000)
		win_const_mgr.add_const('SQL_BCP_OFF',0x00000000)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_PROCEDURES',0x00000004)
		win_const_mgr.add_const('WB_RIGHTBREAK',0x00000007)
		win_const_mgr.add_const('MDM_SHIFT_V120_SPEED',0x00000000)
		win_const_mgr.add_const('SNMPLISTEN_USEENTITY_ADDR',0x00000000)
		win_const_mgr.add_const('SPI_SETDEFAULTINPUTLANG',0x0000005A)
		win_const_mgr.add_const('SQL_API_SQLERROR',0x0000000A)
		win_const_mgr.add_const('DCI_CHROMAKEY',0x00000020)
		win_const_mgr.add_const('CLOSEPROPS_NONE',0x00000000)
		win_const_mgr.add_const('PDH_LOG_FILE_TOO_SMALL',0xC0000BDC)
		win_const_mgr.add_const('ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER',0x000004FE)
		win_const_mgr.add_const('WKSTA_READAHEADTHRUPUT_PARMNUM',0x0000003E)
		win_const_mgr.add_const('VER_ERR_SIG_MASK',0x07000000)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_MAINTENANCE',0x00000002)
		win_const_mgr.add_const('LAPI_MINOR_VER1',0x00000001)
		win_const_mgr.add_const('DEBUG_SYSVERSTR_SERVICE_PACK',0x00000000)
		win_const_mgr.add_const('ATM_AESA',0x00000002)
		win_const_mgr.add_const('CERT_AUTH_ROOT_AUTO_UPDATE_DISABLE_UNTRUSTED_ROOT_LOGGING_FLAG',0x00000001)
		win_const_mgr.add_const('URLACTION_ALLOW_RESTRICTEDPROTOCOLS',0x00002300)
		win_const_mgr.add_const('NETSCAPE_SMIME_CA_CERT_TYPE',0x00000002)
		win_const_mgr.add_const('TR_NO_END_TO_END',0x00000002)
		win_const_mgr.add_const('CRYPT_UM',0x00000001)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_SEEK_ACCURACY',0x00004002)
		win_const_mgr.add_const('CRYPTUI_SELECT_LOCATION_COLUMN',0x00000010)
		win_const_mgr.add_const('WT_EXECUTELONGFUNCTION',0x00000010)
		win_const_mgr.add_const('PORT_BGP',0x000000B3)
		win_const_mgr.add_const('SNMP_MGMTAPI_TIMEOUT',0x00000028)
		win_const_mgr.add_const('DNS_TYPE_TSIG',0x00000000)
		win_const_mgr.add_const('SV_HIDDEN',0x00000001)
		win_const_mgr.add_const('DM_COPY',0x00000002)
		win_const_mgr.add_const('CDERR_INITIALIZATION',0x00000002)
		win_const_mgr.add_const('ERROR_INVALID_NAME',0x0000007B)
		win_const_mgr.add_const('OID_GEN_BROADCAST_FRAMES_RCV',0x0002020C)
		win_const_mgr.add_const('PPP_CCP_ENCRYPTION128BIT',0x00000040)
		win_const_mgr.add_const('APPCOMMAND_LAUNCH_MEDIA_SELECT',0x00000010)
		win_const_mgr.add_const('DDBLT_ROTATIONANGLE',0x00040000)
		win_const_mgr.add_const('DATA_S_FIRST',0x00040130)
		win_const_mgr.add_const('IF_TYPE_SS7_SIGLINK',0x0000009C)
		win_const_mgr.add_const('WNODE_FLAG_FIXED_INSTANCE_SIZE',0x00000010)
		win_const_mgr.add_const('ADOR_MINOR',0x00000000)
		win_const_mgr.add_const('ERROR_DS_OBJECT_RESULTS_TOO_LARGE',0x00002038)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_GENERIC',0x00004005)
		win_const_mgr.add_const('ERROR_SXS_IDENTITY_PARSE_ERROR',0x0000370D)
		win_const_mgr.add_const('OCSP_SUCCESSFUL_RESPONSE',0x00000000)
		win_const_mgr.add_const('WM_VKEYTOITEM',0x0000002E)
		win_const_mgr.add_const('CRYPT_SSL2_FALLBACK',0x00000002)
		win_const_mgr.add_const('TRANSPORT_TYPE_CN',0x00000001)
		win_const_mgr.add_const('GET_TAPE_MEDIA_INFORMATION',0x00000000)
		win_const_mgr.add_const('DISPID_VIEWMODECHANGED',0x000000CD)
		win_const_mgr.add_const('BM_GETCHECK',0x000000F0)
		win_const_mgr.add_const('JS_RETRIES_EXCEEDED',0x00000040)
		win_const_mgr.add_const('IME_GETVERSION',0x00000007)
		win_const_mgr.add_const('IPPORT_SNMP_TRAP',0x000000A2)
		win_const_mgr.add_const('OID_ATM_CALL_ALERTING',0x0801020C)
		win_const_mgr.add_const('TAPE_DRIVE_REWIND_IMMEDIATE',0x80000008)
		win_const_mgr.add_const('RPC_X_NULL_REF_POINTER',0x000006F4)
		win_const_mgr.add_const('PORT_UNISYSCAM',0x000000B6)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_INTERNET',0x00000001)
		win_const_mgr.add_const('DBSETFUNC_DISTINCT',0x00000002)
		win_const_mgr.add_const('DOF_MULTIPLE',0x00008004)
		win_const_mgr.add_const('SCRIPTSTAT_STATEMENT_COUNT',0x00000001)
		win_const_mgr.add_const('IME_REGWORD_STYLE_USER_LAST',0xFFFFFFFF)
		win_const_mgr.add_const('DDSCAPS3_AUTOGENMIPMAP',0x00000800)
		win_const_mgr.add_const('MAPI_E_FAILURE',0x00000002)
		win_const_mgr.add_const('SERVICE_CREATE_WITH_STORE',0x00000004)
		win_const_mgr.add_const('CRSWPP_PROJECT_BINDING_INCOMPLETE',0xC0042205)
		win_const_mgr.add_const('LINECALLSTATE_BUSY',0x00000040)
		win_const_mgr.add_const('SSRVOPT_NOCOPY',0x00000040)
		win_const_mgr.add_const('REVEXT_CDPURLMASK_OLD',0x00000000)
		win_const_mgr.add_const('CRYPT_DELETEKEYSET',0x00000010)
		win_const_mgr.add_const('MCI_VCR_STATUS_VIDEO_SOURCE',0x00004008)
		win_const_mgr.add_const('SQL_INTEGRITY',0x00000049)
		win_const_mgr.add_const('IDM_MP_MYPICS',0x000008EF)
		win_const_mgr.add_const('PHONEFEATURE_GETHOOKSWITCHHEADSET',0x00000100)
		win_const_mgr.add_const('ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE',0x00003B67)
		win_const_mgr.add_const('DEVPROP_TYPE_FILETIME',0x00000010)
		win_const_mgr.add_const('LANG_ITALIAN',0x00000010)
		win_const_mgr.add_const('IDD_DYNAWIZ_SELECTCLASS_PAGE',0x0000271C)
		win_const_mgr.add_const('DISKQUOTA_USER_ACCOUNT_INVALID',0x00000003)
		win_const_mgr.add_const('MD_APPPOOL_STATE_STARTED',0x00000002)
		win_const_mgr.add_const('IDC_PANTOOL_HAND_CLOSED',0x00000069)
		win_const_mgr.add_const('MIB_IPADDR_DYNAMIC',0x00000004)
		win_const_mgr.add_const('WMDM_FILE_ATTR_CANMOVE',0x00010000)
		win_const_mgr.add_const('WSABASEERR',0x00002710)
		win_const_mgr.add_const('DNOBJECT_FAL',0x00000011)
		win_const_mgr.add_const('ILD_DPISCALE',0x00004000)
		win_const_mgr.add_const('SCESVC_ENUMERATION_MAX',0x00000064)
		win_const_mgr.add_const('LDAP_VLVINFO_VERSION',0x00000001)
		win_const_mgr.add_const('CERT_BIOMETRIC_PICTURE_TYPE',0x00000000)
		win_const_mgr.add_const('WTS_WSD_LOGOFF',0x00000001)
		win_const_mgr.add_const('MD_IMPORT_MERGE',0x00000004)
		win_const_mgr.add_const('TAPE_DRIVE_ABSOLUTE_BLK',0x80001000)
		win_const_mgr.add_const('DDENUMSURFACES_ALL',0x00000001)
		win_const_mgr.add_const('WMS_CONTAINER_ALLOW_PLAYLIST_SKIP_BACKWARD',0x00000200)
		win_const_mgr.add_const('FILE_DEVICE_BLUETOOTH',0x00000041)
		win_const_mgr.add_const('TMT_ATLASRECT',0x00001F42)
		win_const_mgr.add_const('ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED',0x00003B03)
		win_const_mgr.add_const('SAFER_LEVEL_OPEN',0x00000001)
		win_const_mgr.add_const('MCI_DGV_PASTE_INSERT',0x00080000)
		win_const_mgr.add_const('BDIF_CONNECTED',0x00000020)
		win_const_mgr.add_const('SHDID_NET_OTHER',0x00000011)
		win_const_mgr.add_const('FIND_FROM_START',0x00000008)
		win_const_mgr.add_const('API_SEND_REQUEST',0x00000005)
		win_const_mgr.add_const('NETLOGON_CONTROL_CHANGE_PASSWORD',0x00000009)
		win_const_mgr.add_const('INSTALLMESSAGE_TYPEMASK',0xFF000000)
		win_const_mgr.add_const('ECO_AUTOWORDSELECTION',0x00000001)
		win_const_mgr.add_const('LCPRI_RESTART',0x00008000)
		win_const_mgr.add_const('ERROR_DS_DSA_MUST_BE_INT_MASTER',0x00002096)
		win_const_mgr.add_const('LPD_SHARE_DEPTH',0x00000040)
		win_const_mgr.add_const('ERROR_CTX_INVALID_PD',0x00001B5A)
		win_const_mgr.add_const('DSS_UNION',0x00000010)
		win_const_mgr.add_const('DEBUG_EXPR_CPLUSPLUS',0x00000001)
		win_const_mgr.add_const('USER_FPSR_INITIAL',0x9804C0270033F)
		win_const_mgr.add_const('SFVM_REARRANGE',0x00000001)
		win_const_mgr.add_const('JOB_RUNS_TODAY',0x00000004)
		win_const_mgr.add_const('OS_TERMINALREMOTEADMIN',0x0000000F)
		win_const_mgr.add_const('OID_FDDI_SHORT_MAX_LIST_SIZE',0x03010108)
		win_const_mgr.add_const('CCS_VERT',0x00000080)
		win_const_mgr.add_const('WM_MBUTTONUP',0x00000208)
		win_const_mgr.add_const('DISPID_FOCUS',0x00000004)
		win_const_mgr.add_const('RID_HEADER',0x10000005)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_PALHANDLE',0x00004007)
		win_const_mgr.add_const('DBPROPVAL_PT_GUID_PROPID',0x00000002)
		win_const_mgr.add_const('DEBUG_OUTCTL_LOG_ONLY',0x00000004)
		win_const_mgr.add_const('ED_AUDIO_1',0x00000001)
		win_const_mgr.add_const('ILGT_ASYNC',0x00000001)
		win_const_mgr.add_const('IDM_VERTSPACEMAKEEQUAL',0x00000031)
		win_const_mgr.add_const('LOCALE_WINDOWS',0x00000001)
		win_const_mgr.add_const('NET_IF_OID_IF_ENTRY',0x00000004)
		win_const_mgr.add_const('WIA_IPA_MIN_BUFFER_SIZE',0x00001016)
		win_const_mgr.add_const('PC_POLYGON',0x00000001)
		win_const_mgr.add_const('ERROR_NO_MORE_USER_HANDLES',0x00000486)
		win_const_mgr.add_const('WM_NCRBUTTONDBLCLK',0x000000A6)
		win_const_mgr.add_const('SQL_DA_DROP_ASSERTION',0x00000001)
		win_const_mgr.add_const('LINE_ADDRESSSTATE',0x00000000)
		win_const_mgr.add_const('DISPID_MOVESELECTIONDOWN',0x00000002)
		win_const_mgr.add_const('IDM_SCROLL_UP',0x00000951)
		win_const_mgr.add_const('OID_LTALK_RANDOM_CTS_ERRORS',0x05020205)
		win_const_mgr.add_const('IPPORT_WHOSERVER',0x00000201)
		win_const_mgr.add_const('RPC_C_AUTHN_LEVEL_CONNECT',0x00000002)
		win_const_mgr.add_const('MIIM_STATE',0x00000001)
		win_const_mgr.add_const('COMP_ELEM_TYPE',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SIGNAL_POSITION',0x00100000)
		win_const_mgr.add_const('ERROR_TRANSACTIONMANAGER_NOT_ONLINE',0x00001A3F)
		win_const_mgr.add_const('GESTURE_LETTER_Q',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_P',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_S',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_R',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_U',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_T',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_W',0x00000000)
		win_const_mgr.add_const('PHOTO_GAINCONTROL_HIGHGAINDOWN',0x00000004)
		win_const_mgr.add_const('GESTURE_LETTER_Y',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_X',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_Z',0x00000000)
		win_const_mgr.add_const('FACILITY_SXS',0x00000017)
		win_const_mgr.add_const('GESTURE_LETTER_A',0x00000000)
		win_const_mgr.add_const('DTT_SHADOWTYPE',0x00000001)
		win_const_mgr.add_const('GESTURE_LETTER_C',0x00000000)
		win_const_mgr.add_const('OID_GEN_MULTICAST_BYTES_RCV',0x00020209)
		win_const_mgr.add_const('GESTURE_LETTER_E',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_D',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_G',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_F',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_I',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_H',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_K',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_J',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_M',0x00000000)
		win_const_mgr.add_const('SFGAO_COMPRESSED',0x04000000)
		win_const_mgr.add_const('GESTURE_LETTER_O',0x00000000)
		win_const_mgr.add_const('GESTURE_LETTER_N',0x00000000)
		win_const_mgr.add_const('IMAGE_CURSOR',0x00000002)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_NAVIGATOR',0x00000005)
		win_const_mgr.add_const('SHCNEE_MSI_UNINSTALL',0x00000005)
		win_const_mgr.add_const('KSAUDIO_QUALITY_PC',0x00000001)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_IS_LOOPBACK',0x00000001)
		win_const_mgr.add_const('GDIPLUS_TS_RECORD',0x0000101B)
		win_const_mgr.add_const('MSIASSEMBLYINFO_NETASSEMBLY',0x00000000)
		win_const_mgr.add_const('SQL_FN_STR_LENGTH',0x00000010)
		win_const_mgr.add_const('FEI_HANDLED',0x00000001)
		win_const_mgr.add_const('DSGIF_DEFAULTISCONTAINER',0x00000020)
		win_const_mgr.add_const('BN_HILITE',0x00000002)
		win_const_mgr.add_const('USE_FORCE',0x00000001)
		win_const_mgr.add_const('SAFER_CRITERIA_IMAGEPATH',0x00000001)
		win_const_mgr.add_const('USER_NAME_PARMNUM',0x00000001)
		win_const_mgr.add_const('AGP_FLAG_NO_2X_RATE',0x00000002)
		win_const_mgr.add_const('VFT2_FONT_RASTER',0x00000001)
		win_const_mgr.add_const('CVT_BASE',0x000003E8)
		win_const_mgr.add_const('INTERNET_FLAG_FORMS_SUBMIT',0x00000040)
		win_const_mgr.add_const('DEBUG_CDS_DATA',0x00000002)
		win_const_mgr.add_const('SHOP_PRINTERNAME',0x00000001)
		win_const_mgr.add_const('IIS_MD_FILE_PROP_BASE',0x00001770)
		win_const_mgr.add_const('ERROR_CANT_WAIT',0x0000022A)
		win_const_mgr.add_const('FLASHW_STOP',0x00000000)
		win_const_mgr.add_const('SPINT_ACTIVE',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_UNREACHABLE',0x000013BB)
		win_const_mgr.add_const('SCARD_E_ICC_CREATEORDER',0x80100021)
		win_const_mgr.add_const('PIR_OPTION_MSSPEC',0x00000004)
		win_const_mgr.add_const('STATUSMSG_OPTION_SETFOREGROUND',0x00000002)
		win_const_mgr.add_const('IF_TYPE_IPOVER_CDLC',0x0000006D)
		win_const_mgr.add_const('SQL_ATTR_APP_ROW_DESC',0x0000271A)
		win_const_mgr.add_const('CM_HIDE_DETAILPAGE',0x00000100)
		win_const_mgr.add_const('PCF_RTSCTS',0x00000002)
		win_const_mgr.add_const('PHONEERR_REINIT',0x90000023)
		win_const_mgr.add_const('KSAUDDECOUTMODE_SPDIFF',0x00000004)
		win_const_mgr.add_const('IME_CMODE_CHARCODE',0x00000020)
		win_const_mgr.add_const('CERT_LOGOTYPE_COLOR_IMAGE_INFO_CHOICE',0x00000002)
		win_const_mgr.add_const('RBBS_TOPALIGN',0x00000800)
		win_const_mgr.add_const('IMAGE_REL_MIPS_REFWORD',0x00000002)
		win_const_mgr.add_const('C1_XDIGIT',0x00000080)
		win_const_mgr.add_const('SECPKG_CLIENT_THREAD_TERMINATED',0x00000002)
		win_const_mgr.add_const('SSWF_WINDOW',0x00000002)
		win_const_mgr.add_const('CMSG_CONTENT_ENCRYPT_FREE_OBJID_FLAG',0x00000002)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_GUESTS',0x00000222)
		win_const_mgr.add_const('MB_CANCELTRYCONTINUE',0x00000006)
		win_const_mgr.add_const('SCARD_E_DUPLICATE_READER',0x8010001B)
		win_const_mgr.add_const('FPSR_V1',0x0000001A)
		win_const_mgr.add_const('FPSR_V0',0x0000000D)
		win_const_mgr.add_const('FPSR_V3',0x00000034)
		win_const_mgr.add_const('FPSR_V2',0x00000027)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_PRE_FETCH_OCSP',0x00000003)
		win_const_mgr.add_const('SHCNE_DISKEVENTS',0x0002381F)
		win_const_mgr.add_const('DEBUG_BREAK_IO',0x00000008)
		win_const_mgr.add_const('SFC_SCAN_NORMAL',0x00000000)
		win_const_mgr.add_const('EMR_ELLIPSE',0x0000002A)
		win_const_mgr.add_const('IMAGEHLP_SYMBOL_INFO_VALUEPRESENT',0x00000001)
		win_const_mgr.add_const('IASSEMBLYCACHE_UNINSTALL_DISPOSITION_ALREADY_UNINSTALLED',0x00000003)
		win_const_mgr.add_const('EAP_E_USER_LAST',0x804201FF)
		win_const_mgr.add_const('VFT2_FONT_VECTOR',0x00000002)
		win_const_mgr.add_const('TMMULTIPLE',0x00400000)
		win_const_mgr.add_const('ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION',0x00001AB6)
		win_const_mgr.add_const('D3DPCMPCAPS_EQUAL',0x00000004)
		win_const_mgr.add_const('MSGF_SCROLLBAR',0x00000005)
		win_const_mgr.add_const('DISPID_DELETESUBSCRIPTION',0x0000000C)
		win_const_mgr.add_const('MD_APP_POOL_RECYCLE_TIME',0x00000001)
		win_const_mgr.add_const('PENDING_DELETE_CACHE_ENTRY',0x00400000)
		win_const_mgr.add_const('FWPM_LAYER_FLAG_CLASSIFY_MOSTLY',0x00000004)
		win_const_mgr.add_const('COD_LAN_ACCESS_99_USED',0x00000006)
		win_const_mgr.add_const('DMBIN_AUTO',0x00000007)
		win_const_mgr.add_const('ERROR_HOST_NODE_NOT_RESOURCE_OWNER',0x00001397)
		win_const_mgr.add_const('CMSG_CTRL_DEL_CERT',0x0000000B)
		win_const_mgr.add_const('SQL_PS_POSITIONED_DELETE',0x00000001)
		win_const_mgr.add_const('TMT_ALIAS',0x0000057C)
		win_const_mgr.add_const('FPSR_VD',0x00000000)
		win_const_mgr.add_const('SYSTEM_AUDIT_CALLBACK_OBJECT_ACE_TYPE',0x0000000F)
		win_const_mgr.add_const('MSIM_DISPID_ON_NM_ACCEPTED',0x00000E14)
		win_const_mgr.add_const('STGOPTIONS_VERSION',0x00000000)
		win_const_mgr.add_const('TASK_AUGUST',0x00000080)
		win_const_mgr.add_const('KSDSOUND_BUFFER_LOCHARDWARE',0x00000004)
		win_const_mgr.add_const('CTRY_SYRIA',0x000003C3)
		win_const_mgr.add_const('FAX_JOB_MANAGE',0x00000040)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_MINUTE_TO_SECOND',0x00008000)
		win_const_mgr.add_const('DFM_WM_DRAWITEM',0x00000007)
		win_const_mgr.add_const('DRM_EL_SPECIFIED_GROUPIDENTITY',0x00000010)
		win_const_mgr.add_const('CMSG_SIGNER_AUTH_ATTR_PARAM',0x00000009)
		win_const_mgr.add_const('TPM_HORIZONTAL',0x00000000)
		win_const_mgr.add_const('PHOTOACQ_ENABLE_THUMBNAIL_CACHING',0x00000080)
		win_const_mgr.add_const('VIEW_VIEWMENU',0x0000000C)
		win_const_mgr.add_const('MSIDXSPROP_PARSE_TREE',0x00000005)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_AUTORECONNECT',0x00000400)
		win_const_mgr.add_const('FONTMAPPER_MAX',0x0000000A)
		win_const_mgr.add_const('MMIO_CREATERIFF',0x00000020)
		win_const_mgr.add_const('PIDVSI_STREAM_NAME',0x00000002)
		win_const_mgr.add_const('OID_FDDI_SMT_MANUFACTURER_DATA',0x03030205)
		win_const_mgr.add_const('DBPROPVAL_OO_BLOB',0x00000001)
		win_const_mgr.add_const('WM_SETHOTKEY',0x00000032)
		win_const_mgr.add_const('SMINIT_HORIZONTAL',0x20000000)
		win_const_mgr.add_const('DDCAPS_BLTCOLORFILL',0x04000000)
		win_const_mgr.add_const('LINEPROXYREQUEST_CREATEAGENTSESSION',0x0000000C)
		win_const_mgr.add_const('CTRY_SERBIA',0x0000017D)
		win_const_mgr.add_const('ERROR_DYNLINK_FROM_INVALID_RING',0x000000C4)
		win_const_mgr.add_const('ISC_RET_REPLAY_DETECT',0x00000004)
		win_const_mgr.add_const('PROV_RSA_SCHANNEL',0x0000000C)
		win_const_mgr.add_const('REO_GETOBJ_ALL_INTERFACES',0x00000007)
		win_const_mgr.add_const('COD_LAN_MINOR_MASK',0x0000001C)
		win_const_mgr.add_const('EMR_SETPOLYFILLMODE',0x00000013)
		win_const_mgr.add_const('INTERNET_PER_CONN_AUTODISCOVERY_FLAGS',0x00000005)
		win_const_mgr.add_const('SF_NOTIFY_ORDER_MEDIUM',0x00040000)
		win_const_mgr.add_const('SQL_CONNECT_OPT_DRVR_START',0x000003E8)
		win_const_mgr.add_const('ERROR_CTX_BAD_VIDEO_MODE',0x00001B71)
		win_const_mgr.add_const('SQL_ACTIVE_CONNECTIONS',0x00000000)
		win_const_mgr.add_const('SQL_SRJO_UNION_JOIN',0x00000200)
		win_const_mgr.add_const('IP_FLAG_REVERSE',0x00000001)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_NO_CHANGE',0x00000000)
		win_const_mgr.add_const('IF_TYPE_PROP_POINT2POINT_SERIAL',0x00000016)
		win_const_mgr.add_const('IMAGE_REL_PPC_SECRELHI',0x00000014)
		win_const_mgr.add_const('JS_INPROGRESS',0x00000001)
		win_const_mgr.add_const('IMGLOAD_ERROR',0x00800000)
		win_const_mgr.add_const('DNS_ERROR_RCODE',0x00002520)
		win_const_mgr.add_const('DBPROPVAL_CO_CASEINSENSITIVE',0x00000008)
		win_const_mgr.add_const('MCI_VCR_STATUS_TIMECODE_TYPE',0x00004012)
		win_const_mgr.add_const('MAPI_UNREAD',0x00000001)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_GLOBAL_OBJECT_RENAME_TABLE',0x00000008)
		win_const_mgr.add_const('SCARD_T1_PROLOGUE_LENGTH',0x00000003)
		win_const_mgr.add_const('SHCNF_PRINTERW',0x00000006)
		win_const_mgr.add_const('WINEVENT_KEYWORD_RESERVED_58',0x400000000000000)
		win_const_mgr.add_const('CRYPTUI_DISABLE_HTMLLINK',0x00010000)
		win_const_mgr.add_const('LINEMEDIAMODE_DIGITALDATA',0x00000100)
		win_const_mgr.add_const('DS_DOMAIN_IN_FOREST',0x00000001)
		win_const_mgr.add_const('ERROR_MCA_UNSUPPORTED_MCCS_VERSION',0x00003B64)
		win_const_mgr.add_const('OID_GEN_INIT_TIME_MS',0x00020213)
		win_const_mgr.add_const('SERVICE_CTRL_CONTINUE',0x00000002)
		win_const_mgr.add_const('DNS_QUERY_USE_TCP_ONLY',0x00000002)
		win_const_mgr.add_const('SHCNF_PRINTERA',0x00000002)
		win_const_mgr.add_const('EAP_E_USER_CERT_REJECTED',0x80420105)
		win_const_mgr.add_const('D3D10_LINEAR_GAMMA',0x00000001)
		win_const_mgr.add_const('ICU_REJECT_USERPWD',0x00004000)
		win_const_mgr.add_const('USER_CALL_NEW_CORRELATION_DESC',0x00000200)
		win_const_mgr.add_const('SQL_ATTR_ENABLE_AUTO_IPD',0x0000000F)
		win_const_mgr.add_const('WIA_DPS_OPTICAL_YRES',0x00000C13)
		win_const_mgr.add_const('ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED',0x000002FB)
		win_const_mgr.add_const('MD_NETLOGON_WKS_IP',0x00000001)
		win_const_mgr.add_const('VK_OEM_ENLW',0x000000F4)
		win_const_mgr.add_const('CERT_VALIDITY_NO_TRUST_DATA',0x80000000)
		win_const_mgr.add_const('ERROR_INVALID_STARTING_CODESEG',0x000000BC)
		win_const_mgr.add_const('VK_BROWSER_REFRESH',0x000000A8)
		win_const_mgr.add_const('CERT_CHAIN_DISABLE_PASS1_QUALITY_FILTERING',0x00000040)
		win_const_mgr.add_const('SHIFT_PRESSED',0x00000010)
		win_const_mgr.add_const('RPC_S_INVALID_VERS_OPTION',0x000006DC)
		win_const_mgr.add_const('SQL_MAX_LENGTH',0x00000003)
		win_const_mgr.add_const('NS_NLA',0x0000000F)
		win_const_mgr.add_const('SDP_ATTRIB_DI_VENDOR_ID_SOURCE',0x00000205)
		win_const_mgr.add_const('PFD_SUPPORT_DIRECTDRAW',0x00002000)
		win_const_mgr.add_const('WC_DISCARDNS',0x00000010)
		win_const_mgr.add_const('ATSC_VCT_TERR_TID',0x000000C8)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_UNRESTRICTED',0x0000FFFF)
		win_const_mgr.add_const('LGRPID_VIETNAMESE',0x00000000)
		win_const_mgr.add_const('DWLP_MSGRESULT',0x00000000)
		win_const_mgr.add_const('IDM_UNBOOKMARK',0x00000850)
		win_const_mgr.add_const('DESKTOPVERTRES',0x00000075)
		win_const_mgr.add_const('PBT_APMSUSPEND',0x00000004)
		win_const_mgr.add_const('QS_HOTKEY',0x00000080)
		win_const_mgr.add_const('DISABLE_IA32RSB_FIX',0x0000000B)
		win_const_mgr.add_const('PROCESSOR_HITACHI_SH3',0x00002713)
		win_const_mgr.add_const('PROCESSOR_HITACHI_SH4',0x00002715)
		win_const_mgr.add_const('OID_GEN_RESET_COUNTS',0x00020214)
		win_const_mgr.add_const('LVS_EX_AUTOCHECKSELECT',0x08000000)
		win_const_mgr.add_const('UI_CAP_ROTANY',0x00000004)
		win_const_mgr.add_const('SPQ_SCAN_FILE_COMPARISON',0x00000200)
		win_const_mgr.add_const('MSV1_0_SUBAUTHENTICATION_DLL_RAS',0x00000002)
		win_const_mgr.add_const('BTH_MFG_MITSIBUSHI',0x00000014)
		win_const_mgr.add_const('PAN_STROKE_GRADUAL_TRAN',0x00000003)
		win_const_mgr.add_const('PORT_SUBMIT',0x00000305)
		win_const_mgr.add_const('URLACTION_FEATURE_WINDOW_RESTRICTIONS',0x00002102)
		win_const_mgr.add_const('LINEAGENTSTATUSEX_UPDATEINFO',0x00000004)
		win_const_mgr.add_const('LVIF_PARAM',0x00000004)
		win_const_mgr.add_const('KP_IV',0x00000001)
		win_const_mgr.add_const('PATCH_OPTION_NO_CHECKSUM',0x00200000)
		win_const_mgr.add_const('CI_STATE_RECOVERING',0x00000020)
		win_const_mgr.add_const('HIST_ADDTOFAVORITES',0x00000003)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_ENCRYPT',0x0000362A)
		win_const_mgr.add_const('ERROR_LOG_GROWTH_FAILED',0x00001AB1)
		win_const_mgr.add_const('WM_MDICREATE',0x00000220)
		win_const_mgr.add_const('REG_PROCESS_PRIVATE',0x00000020)
		win_const_mgr.add_const('DBPROPVAL_SQL_SUBMINIMUM',0x00000200)
		win_const_mgr.add_const('MCI_VCR_SET_TAPE_LENGTH',0x01000000)
		win_const_mgr.add_const('HTTP_LOG_FIELD_DATE',0x00000001)
		win_const_mgr.add_const('PID_INTSITE_CONTENTLEN',0x0000000A)
		win_const_mgr.add_const('ERROR_DS_SUBREF_MUST_HAVE_PARENT',0x000020A4)
		win_const_mgr.add_const('BSF_TOPBROWSER',0x00000800)
		win_const_mgr.add_const('CACHE_HEADER_DATA_NOTIFICATION_HWND',0x00000003)
		win_const_mgr.add_const('SNMP_MGMTAPI_INVALID_SESSION',0x0000002F)
		win_const_mgr.add_const('IMPORT_OBJECT_HDR_SIG2',0x00000000)
		win_const_mgr.add_const('SKF_INDICATOR',0x00000020)
		win_const_mgr.add_const('LINEERR_NOTOWNER',0x80000046)
		win_const_mgr.add_const('EVENT_HEADER_PROPERTY_XML',0x00000001)
		win_const_mgr.add_const('TIME_FORCE24HOURFORMAT',0x00000008)
		win_const_mgr.add_const('CE_IOE',0x00000400)
		win_const_mgr.add_const('LDAP_DIRSYNC_ANCESTORS_FIRST_ORDER',0x00000800)
		win_const_mgr.add_const('HSE_EXEC_URL_IGNORE_CURRENT_INTERCEPTOR',0x00000004)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_FRAME_RATE',0x00004008)
		win_const_mgr.add_const('SOFTDIST_FLAG_USAGE_EMAIL',0x00000001)
		win_const_mgr.add_const('DNS_TYPE_OPT',0x00000029)
		win_const_mgr.add_const('RTM_DEST_FLAG_FWD_ENGIN_ADD',0x00000002)
		win_const_mgr.add_const('ERROR_RXACT_STATE_CREATED',0x000002BD)
		win_const_mgr.add_const('DSBI_INCLUDEHIDDEN',0x00020000)
		win_const_mgr.add_const('DBPROP_MSREMOTE_TRANSACT_UPDATES',0x00000007)
		win_const_mgr.add_const('SOCK_SEQPACKET',0x00000005)
		win_const_mgr.add_const('LF_FULLFACESIZE',0x00000040)
		win_const_mgr.add_const('PSNRET_INVALID_NOCHANGEPAGE',0x00000002)
		win_const_mgr.add_const('ETW_PTVECTOR_TYPE_VALUE',0x00000075)
		win_const_mgr.add_const('WNODE_FLAG_USE_MOF_PTR',0x00100000)
		win_const_mgr.add_const('UF_SMARTCARD_REQUIRED',0x00040000)
		win_const_mgr.add_const('RRF_RT_REG_QWORD',0x00000040)
		win_const_mgr.add_const('XEPR_CADNS',0x00000001)
		win_const_mgr.add_const('BTH_ERROR_ROLE_CHANGE_NOT_ALLOWED',0x00000021)
		win_const_mgr.add_const('AF_TCNPROCESS',0x0000001D)
		win_const_mgr.add_const('MP_STATUS_BAD_MAIL',0x00000003)
		win_const_mgr.add_const('DXGI_MWA_NO_ALT_ENTER',0x00000001)
		win_const_mgr.add_const('KERB_USE_DEFAULT_TICKET_FLAGS',0x00000000)
		win_const_mgr.add_const('SHACF_FILESYS_DIRS',0x00000020)
		win_const_mgr.add_const('ILC_MIRROR',0x00002000)
		win_const_mgr.add_const('LOCALE_ICENTURY',0x00000024)
		win_const_mgr.add_const('SCF_ISSECURE',0x00000001)
		win_const_mgr.add_const('MSV1_0_MAX_AVL_SIZE',0x0000FA00)
		win_const_mgr.add_const('AVIFILEINFO_COPYRIGHTED',0x00020000)
		win_const_mgr.add_const('OS_WIN98_GOLD',0x00000006)
		win_const_mgr.add_const('ACPI_PPM_HARDWARE_ALL',0x000000FE)
		win_const_mgr.add_const('PERF_COUNTER_QUEUELEN',0x00050000)
		win_const_mgr.add_const('D3DPRASTERCAPS_MULTISAMPLE_TOGGLE',0x08000000)
		win_const_mgr.add_const('ARCONTENT_PHASE_FINAL',0x40000000)
		win_const_mgr.add_const('MHDR_INQUEUE',0x00000004)
		win_const_mgr.add_const('DLCTL_NO_METACHARSET',0x00010000)
		win_const_mgr.add_const('FILE_DEVICE_NULL',0x00000015)
		win_const_mgr.add_const('MANAGED_APPS_FROMCATEGORY',0x00000002)
		win_const_mgr.add_const('AE_LIM_DELETED',0x00000005)
		win_const_mgr.add_const('PGM_FIRST',0x00001400)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_TOTAL_PAGES',0x00000014)
		win_const_mgr.add_const('PROV_EC_ECNRA_FULL',0x00000011)
		win_const_mgr.add_const('XEPR_CAFRIENDLYNAME',0x00000003)
		win_const_mgr.add_const('IDC_IO_RESULTTEXT',0x0000083D)
		win_const_mgr.add_const('WLX_SAS_ACTION_SHUTDOWN_REBOOT',0x0000000B)
		win_const_mgr.add_const('JOY_BUTTON25',0x01000000)
		win_const_mgr.add_const('PSINJECT_PSADOBE',0x00000002)
		win_const_mgr.add_const('DS_REPADD_INITIAL',0x00000004)
		win_const_mgr.add_const('DDSD_HEIGHT',0x00000002)
		win_const_mgr.add_const('PAN_WEIGHT_MEDIUM',0x00000006)
		win_const_mgr.add_const('TNS_PLAN_CARRIER_ID_CODE',0x00000001)
		win_const_mgr.add_const('NET_STRING_IPV6_ADDRESS_NO_SCOPE',0x00000010)
		win_const_mgr.add_const('PERF_DISPLAY_PER_SEC',0x10000000)
		win_const_mgr.add_const('LDAP_FILTER_APPROX',0x00000000)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_RAS_SERVERS',0x00000229)
		win_const_mgr.add_const('STDPROP_SORTORDINAL',0x00000066)
		win_const_mgr.add_const('CM_PROB_DRIVER_FAILED_LOAD',0x00000027)
		win_const_mgr.add_const('JOY_BUTTON22',0x00200000)
		win_const_mgr.add_const('SLMFLAG_VIRTUAL',0x00000001)
		win_const_mgr.add_const('PID_INTSITE_ICONINDEX',0x00000014)
		win_const_mgr.add_const('DMPAPER_LEGAL',0x00000005)
		win_const_mgr.add_const('D3D10_FLOAT_TO_SRGB_EXPONENT_DENOMINATOR',0x00000002)
		win_const_mgr.add_const('DISPID_SHOWBORDERS',0x0000000C)
		win_const_mgr.add_const('CDO_E_CONTENTPROPXML_PARSE_FAILED',0x8004022F)
		win_const_mgr.add_const('SECPKG_INTERFACE_VERSION',0x00010000)
		win_const_mgr.add_const('JOY_BUTTON20',0x00080000)
		win_const_mgr.add_const('EVENT_OBJECT_PARENTCHANGE',0x0000800F)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_ALREADY_DOWN',0x000013C6)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_FILTER_PAUSE_PARAMETERS',0x0000009A)
		win_const_mgr.add_const('DATE_SHORTDATE',0x00000001)
		win_const_mgr.add_const('TEXTCAPS',0x00000022)
		win_const_mgr.add_const('SM_CXMINSPACING',0x0000002F)
		win_const_mgr.add_const('SVI3_NUM_ELEMENTS',0x0000002D)
		win_const_mgr.add_const('SQL_DESC_NULLABLE',0x000003F0)
		win_const_mgr.add_const('ELF_VENDOR_SIZE',0x00000004)
		win_const_mgr.add_const('SI_PAGE_TITLE',0x00000800)
		win_const_mgr.add_const('TXTLOG_SIGVERIF',0x00000020)
		win_const_mgr.add_const('ACN_START',0x00000001)
		win_const_mgr.add_const('CR_FREE_RESOURCES',0x00000029)
		win_const_mgr.add_const('RPC_C_OPT_DONT_LINGER',0x0000000D)
		win_const_mgr.add_const('SM_CXHTHUMB',0x0000000A)
		win_const_mgr.add_const('WIA_DPC_EXPOSURE_INDEX',0x00000823)
		win_const_mgr.add_const('CR_FLG_ENFORCEUTF8',0x00000100)
		win_const_mgr.add_const('NI_CLOSECANDIDATE',0x00000011)
		win_const_mgr.add_const('BIF_RAWDEVICENEEDSDRIVER',0x00000002)
		win_const_mgr.add_const('ERROR_CLUSTER_NODE_SHUTTING_DOWN',0x000013D1)
		win_const_mgr.add_const('RPC_S_PROTSEQ_NOT_FOUND',0x000006D0)
		win_const_mgr.add_const('PHONEFEATURE_SETVOLUMEHANDSET',0x02000000)
		win_const_mgr.add_const('ISC_RET_MUTUAL_AUTH',0x00000002)
		win_const_mgr.add_const('ML_NO_CROSSCODEPAGE',0x00000000)
		win_const_mgr.add_const('EAP_CONFIG_INPUT_FIELD_PROPS_NON_DISPLAYABLE',0x00000001)
		win_const_mgr.add_const('ENABLE_QUICK_EDIT_MODE',0x00000040)
		win_const_mgr.add_const('PD_NOSELECTION',0x00000004)
		win_const_mgr.add_const('ERROR_INVALID_DWP_HANDLE',0x0000057D)
		win_const_mgr.add_const('SERVICE_ACCEPT_PRESHUTDOWN',0x00000100)
		win_const_mgr.add_const('DISPID_DFILESYSTEMIMAGEEVENTS_UPDATE',0x00000100)
		win_const_mgr.add_const('PROCESSOR_MOTOROLA_821',0x00000335)
		win_const_mgr.add_const('SW_FORCEMINIMIZE',0x0000000B)
		win_const_mgr.add_const('WIA_PAGE_JIS_B4',0x0000002B)
		win_const_mgr.add_const('WIA_PAGE_JIS_B5',0x0000002C)
		win_const_mgr.add_const('WIA_PAGE_JIS_B6',0x0000002D)
		win_const_mgr.add_const('OID_FDDI_IF_ADMIN_STATUS',0x0303027E)
		win_const_mgr.add_const('WIA_PAGE_JIS_B0',0x00000027)
		win_const_mgr.add_const('WIA_IPS_LAMP_AUTO_OFF',0x00000C22)
		win_const_mgr.add_const('EXECUTE_FLAG_HTTP_CACHE_ELIGIBLE',0x00000040)
		win_const_mgr.add_const('OID_FDDI_MAC_FRAME_ERROR_THRESHOLD',0x03030245)
		win_const_mgr.add_const('CRYPT_IMPL_SOFTWARE',0x00000002)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_SUPPORTEDPROFILES',0x0000020A)
		win_const_mgr.add_const('IMAGE_NUMBEROF_DIRECTORY_ENTRIES',0x00000010)
		win_const_mgr.add_const('PID_ATALK',0x00000029)
		win_const_mgr.add_const('WIA_PAGE_JIS_B9',0x00000030)
		win_const_mgr.add_const('MAX_PHYSICAL_SHIFT',0x0000002C)
		win_const_mgr.add_const('IMAGE_REL_AMD64_SECTION',0x0000000A)
		win_const_mgr.add_const('RESOURCEMANAGER_QUERY_INFORMATION',0x00000001)
		win_const_mgr.add_const('LB_GETCURSEL',0x00000188)
		win_const_mgr.add_const('COD_PHONE_MINOR_UNCLASSIFIED',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_MODE_RESERVED',0x00100000)
		win_const_mgr.add_const('MM_MAX_AXES_NAMELEN',0x00000010)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_BORLAND',0x00000009)
		win_const_mgr.add_const('MD_ACCESS_NO_REMOTE_SCRIPT',0x00004000)
		win_const_mgr.add_const('OID_TCP_OFFLOAD_CURRENT_CONFIG',0xFC01020B)
		win_const_mgr.add_const('BLLI_L2_Q921',0x00000002)
		win_const_mgr.add_const('LANG_AMHARIC',0x00000005)
		win_const_mgr.add_const('SBT_OWNERDRAW',0x00001000)
		win_const_mgr.add_const('PHONEERR_INVALAPPNAME',0x90000008)
		win_const_mgr.add_const('RPC_C_STATS_CALLS_OUT',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT',0x000036FB)
		win_const_mgr.add_const('AE_CONNSTOP',0x00000005)
		win_const_mgr.add_const('PORT_TACACSDS',0x00000041)
		win_const_mgr.add_const('BS_MONOPATTERN',0x00000009)
		win_const_mgr.add_const('PAN_CONTRAST_LOW',0x00000004)
		win_const_mgr.add_const('MAX_FRIENDLYNAME',0x00000040)
		win_const_mgr.add_const('KSPROPERTY_CAMERACONTROL_FLAGS_RELATIVE',0x00000000)
		win_const_mgr.add_const('TRACE_MESSAGE_TIMESTAMP',0x00000008)
		win_const_mgr.add_const('KAGPROP_BLOBSONFOCURSOR',0x00000008)
		win_const_mgr.add_const('INTERNET_OPTION_ASYNC_PRIORITY',0x00000010)
		win_const_mgr.add_const('CHECKPOINT',0x00000007)
		win_const_mgr.add_const('SE_SACL_DEFAULTED',0x00000020)
		win_const_mgr.add_const('NULL',0x00000000)
		win_const_mgr.add_const('DISPID_FILTERINVOKED',0x000000DA)
		win_const_mgr.add_const('CTRY_SLOVENIA',0x00000182)
		win_const_mgr.add_const('GMMP_USE_HIGH_RESOLUTION_POINTS',0x00000002)
		win_const_mgr.add_const('SE_GROUP_ENABLED_BY_DEFAULT',0x00000002)
		win_const_mgr.add_const('FS_GREEK',0x00000008)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD',0x00003641)
		win_const_mgr.add_const('LINEDISCONNECTMODE_QOSUNAVAIL',0x00010000)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_CAN_FREEZE',0x0000401B)
		win_const_mgr.add_const('MCIWNDF_RECORD',0x00002000)
		win_const_mgr.add_const('DFCS_BUTTONCHECK',0x00000000)
		win_const_mgr.add_const('PHOTO_METERINGMODE_AVERAGE',0x00000001)
		win_const_mgr.add_const('FOF_WANTMAPPINGHANDLE',0x00000020)
		win_const_mgr.add_const('GMR_DAYSTATE',0x00000001)
		win_const_mgr.add_const('WKSTA_MAXWRKCACHE_PARMNUM',0x00000011)
		win_const_mgr.add_const('SQL_CREATE_SCHEMA',0x00000083)
		win_const_mgr.add_const('SOCKET_SETTINGS_IPSEC_SKIP_FILTER_INSTANTIATION',0x00000001)
		win_const_mgr.add_const('ICMODE_DRAW',0x00000008)
		win_const_mgr.add_const('IDM_SCROLL_HERE',0x0000094C)
		win_const_mgr.add_const('DBPROPVAL_OS_DISABLEALL',0x00000000)
		win_const_mgr.add_const('DISPID_BRANDIMAGEURI',0x00000014)
		win_const_mgr.add_const('DI_FLAGSEX_SEARCH_PUBLISHED_INFS',0x80000000)
		win_const_mgr.add_const('VFT2_DRV_VERSIONED_PRINTER',0x0000000C)
		win_const_mgr.add_const('SO_BTH_ENCRYPT',0x00000002)
		win_const_mgr.add_const('NDIS_MAC_OPTION_RESERVED',0x80000000)
		win_const_mgr.add_const('DDL_READWRITE',0x00000000)
		win_const_mgr.add_const('ERROR_DS_CANT_DEREF_ALIAS',0x00002091)
		win_const_mgr.add_const('ERROR_INSTALL_LANGUAGE_UNSUPPORTED',0x00000657)
		win_const_mgr.add_const('IDM_HELP_CONTENT',0x000008AC)
		win_const_mgr.add_const('EC_CREATE_NEW',0x00000001)
		win_const_mgr.add_const('BLLI_L3_IPI_IP',0x000000CC)
		win_const_mgr.add_const('PSR_MBZ3_V',0x00000003)
		win_const_mgr.add_const('COD_AUDIO_MINOR_MICROPHONE',0x00000004)
		win_const_mgr.add_const('LOGON_PKINIT',0x00010000)
		win_const_mgr.add_const('NETSETUP_JOIN_DOMAIN',0x00000001)
		win_const_mgr.add_const('BLLI_L3_USER_SPECIFIED',0x00000010)
		win_const_mgr.add_const('AUTH_REQ_ALLOW_POSTDATE',0x00000004)
		win_const_mgr.add_const('HDF_RTLREADING',0x00000004)
		win_const_mgr.add_const('ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR',0x00002193)
		win_const_mgr.add_const('GL_ID_REVERSECONVERSION',0x00000029)
		win_const_mgr.add_const('ASN_UNIVERSAL',0x00000000)
		win_const_mgr.add_const('MCI_VCR_SETAUDIO_MONITOR',0x00040000)
		win_const_mgr.add_const('DIF_ADDREMOTEPROPERTYPAGE_ADVANCED',0x00000028)
		win_const_mgr.add_const('SQL_DESC_SCALE',0x000003EE)
		win_const_mgr.add_const('IF_TYPE_SONET_VT',0x00000033)
		win_const_mgr.add_const('URLACTION_SHELL_EXECUTE_MODRISK',0x00001807)
		win_const_mgr.add_const('MAX_PROFILE_LEN',0x00000050)
		win_const_mgr.add_const('BLLI_L3_PACKET_128',0x00000007)
		win_const_mgr.add_const('ERROR_NO_MEDIA_IN_DRIVE',0x00000458)
		win_const_mgr.add_const('CB_MAX_DISK_NAME',0x00000100)
		win_const_mgr.add_const('PERCEIVEDFLAG_UNDEFINED',0x00000000)
		win_const_mgr.add_const('THREAD_QUERY_INFORMATION',0x00000040)
		win_const_mgr.add_const('CERT_SET_KEY_CONTEXT_PROP_ID',0x00000001)
		win_const_mgr.add_const('AI_V4MAPPED',0x00000800)
		win_const_mgr.add_const('NETLOGON_HAS_IP',0x00000010)
		win_const_mgr.add_const('FILE_ATTRIBUTE_NORMAL',0x00000080)
		win_const_mgr.add_const('D3DPTEXTURECAPS_VOLUMEMAP_POW2',0x00040000)
		win_const_mgr.add_const('SERVICE_CONFIG_DESCRIPTION',0x00000001)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_PACKET_DIRECTION',0x00040000)
		win_const_mgr.add_const('DMICMMETHOD_DEVICE',0x00000004)
		win_const_mgr.add_const('PS_64K',0x00000010)
		win_const_mgr.add_const('DXVA_SCAN_METHOD_ARBITRARY',0x00000003)
		win_const_mgr.add_const('WSA_QOS_REQUEST_CONFIRMED',0x00002B01)
		win_const_mgr.add_const('SHDID_FS_FILE',0x00000002)
		win_const_mgr.add_const('IPV6_ADD_IFLIST',0x0000001D)
		win_const_mgr.add_const('USN_REASON_DATA_EXTEND',0x00000002)
		win_const_mgr.add_const('SCARD_E_UNKNOWN_RES_MNG',0x8010002B)
		win_const_mgr.add_const('PFS_EC_MASK',0x0000003F)
		win_const_mgr.add_const('DS_KDC_REQUIRED',0x00000400)
		win_const_mgr.add_const('TAPE_FILEMARKS',0x00000001)
		win_const_mgr.add_const('SUBLANG_AZERI_LATIN',0x00000001)
		win_const_mgr.add_const('SIO_GET_ATM_CONNECTION_ID',0x50160004)
		win_const_mgr.add_const('IDM_GETBLOCKFMTS',0x000008B9)
		win_const_mgr.add_const('OLEUI_ERR_LOCALMEMALLOC',0x00000071)
		win_const_mgr.add_const('DRM_AUTO_GENERATE_KEY',0x00000010)
		win_const_mgr.add_const('LINECALLPARAMFLAGS_ORIGOFFHOOK',0x00000008)
		win_const_mgr.add_const('PTA_INITIAL',0x00000001)
		win_const_mgr.add_const('HHT_ONFILTERBUTTON',0x00000020)
		win_const_mgr.add_const('PORT_TELL',0x000002F2)
		win_const_mgr.add_const('SERVICE_INTERACTIVE_PROCESS',0x00000100)
		win_const_mgr.add_const('SQL_CONCUR_VALUES',0x00000004)
		win_const_mgr.add_const('MD_LOGON_NETWORK',0x00000002)
		win_const_mgr.add_const('IME_KHOTKEY_HANJACONVERT',0x00000051)
		win_const_mgr.add_const('POLICY_LOCATOR_SUB_TYPE_ASCII_DN_ENC',0x00000003)
		win_const_mgr.add_const('CRL_REASON_CA_COMPROMISE',0x00000002)
		win_const_mgr.add_const('WAVE_FORMAT_96S08',0x00020000)
		win_const_mgr.add_const('FOFX_PRESERVEFILEEXTENSIONS',0x00200000)
		win_const_mgr.add_const('ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER',0x000021A7)
		win_const_mgr.add_const('LANG_HAUSA',0x00000068)
		win_const_mgr.add_const('DISKQUOTA_USERNAME_RESOLVE_SYNC',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_SH3_PCREL8_LONG',0x0000000A)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_ENABLE_RESERVE',0x20000000)
		win_const_mgr.add_const('SPDRP_CONFIGFLAGS',0x0000000A)
		win_const_mgr.add_const('SMART_INVALID_COMMAND',0x00000003)
		win_const_mgr.add_const('S_PT_NO_CONFLICT',0x00040001)
		win_const_mgr.add_const('SQL_SSF_CONVERT',0x00000001)
		win_const_mgr.add_const('IDS_CAP_NO_PALETTE_WARN',0x000001B3)
		win_const_mgr.add_const('FW_NORMAL',0x00000190)
		win_const_mgr.add_const('DEBUG_STACK_SOURCE_LINE',0x00000004)
		win_const_mgr.add_const('DDCAPS_CANBLTSYSMEM',0x80000000)
		win_const_mgr.add_const('SIZE_T_ERROR',0x00000000)
		win_const_mgr.add_const('ADOR_MAJOR',0x00000006)
		win_const_mgr.add_const('ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN',0x00002142)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_CONTRAST',0x00004002)
		win_const_mgr.add_const('TVCDRF_NOIMAGES',0x00010000)
		win_const_mgr.add_const('EXCHIVERB_PRINT',0x00000069)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_MINUTE',0x00000080)
		win_const_mgr.add_const('DOT11_STATUS_SUCCESS',0x00000001)
		win_const_mgr.add_const('SQL_MORE_INFO_NO',0x00000000)
		win_const_mgr.add_const('PIDSI_KEYWORDS',0x00000005)
		win_const_mgr.add_const('CAUSE_LOC_PRIVATE_REMOTE',0x00000005)
		win_const_mgr.add_const('ECO_NOHIDESEL',0x00000100)
		win_const_mgr.add_const('DT_WORDBREAK',0x00000010)
		win_const_mgr.add_const('DBT_VOLLOCKQUERYLOCK',0x00008041)
		win_const_mgr.add_const('SAMPLE_SEQ_CONTENT_B_FRAME',0x00000003)
		win_const_mgr.add_const('ERROR_NO_SUCH_SITE',0x000004E1)
		win_const_mgr.add_const('CBES_EX_NOEDITIMAGE',0x00000001)
		win_const_mgr.add_const('CHANGER_RESERVED_BIT',0x80000000)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_LOG_FILE',0x0000000F)
		win_const_mgr.add_const('URLACTION_COOKIES_THIRD_PARTY',0x00001A05)
		win_const_mgr.add_const('STRINGFORMAT_ASCII',0x00000001)
		win_const_mgr.add_const('MAPVK_VK_TO_VSC_EX',0x00000004)
		win_const_mgr.add_const('TRANSACTION_MANAGER_VOLATILE',0x00000001)
		win_const_mgr.add_const('KSAUDIO_STEREO_SPEAKER_GEOMETRY_MAX',0x000000B4)
		win_const_mgr.add_const('CFM_COLOR',0x40000000)
		win_const_mgr.add_const('ILS_ALPHA',0x00000008)
		win_const_mgr.add_const('RPC_S_UUID_NO_ADDRESS',0x000006CB)
		win_const_mgr.add_const('VIFF_FORCEINSTALL',0x00000001)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_CERT',0x00000001)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_SAMPLE_OUTPUT_FRAME',0x00000002)
		win_const_mgr.add_const('DISABLE_UNSAFE_FILL',0x0000000E)
		win_const_mgr.add_const('ACCESS_EXEC',0x00000008)
		win_const_mgr.add_const('SHPPFW_NOWRITECHECK',0x00000008)
		win_const_mgr.add_const('BL_KERNEL_INDEX',0x00000001)
		win_const_mgr.add_const('URL_APPLY_GUESSSCHEME',0x00000002)
		win_const_mgr.add_const('TCP_OFFLOAD_PREFERENCE',0x0000000B)
		win_const_mgr.add_const('DIF_REGISTER_COINSTALLERS',0x00000022)
		win_const_mgr.add_const('HLNF_CALLERUNTRUSTED',0x00200000)
		win_const_mgr.add_const('HIGH_SURROGATE_START',0x00000000)
		win_const_mgr.add_const('FLASHMODE_AUTO',0x00000001)
		win_const_mgr.add_const('WTS_PROTOCOL_TYPE_CONSOLE',0x00000000)
		win_const_mgr.add_const('IPX_RECEIVE_BROADCAST',0x0000400F)
		win_const_mgr.add_const('ERROR_IPSEC_TUNNEL_FILTER_EXISTS',0x000032D8)
		win_const_mgr.add_const('STATE_TIMEOUT',0x00000004)
		win_const_mgr.add_const('RTL_CRITICAL_SECTION_FLAG_NO_DEBUG_INFO',0x01000000)
		win_const_mgr.add_const('SERVICE_CONFIG_SERVICE_SID_INFO',0x00000005)
		win_const_mgr.add_const('DS_LDAP_FLAG',0x00000008)
		win_const_mgr.add_const('ASC_RET_NO_ADDITIONAL_TOKEN',0x02000000)
		win_const_mgr.add_const('LANG_BASE_OFFSET_INDEX',0x00000002)
		win_const_mgr.add_const('CACHE_CONFIG_CONTENT_USAGE_FC',0x00002000)
		win_const_mgr.add_const('PHONEERR_INVALEXTVERSION',0x9000000E)
		win_const_mgr.add_const('IMC_GETSTATUSWINDOWPOS',0x0000000F)
		win_const_mgr.add_const('MIXER_GETCONTROLDETAILSF_LISTTEXT',0x00000001)
		win_const_mgr.add_const('FORMATDLGORD30',0x00000608)
		win_const_mgr.add_const('PS_MAXLINKTYPES',0x00000008)
		win_const_mgr.add_const('MIXERCONTROL_CT_UNITS_BOOLEAN',0x00010000)
		win_const_mgr.add_const('ENM_DROPFILES',0x00100000)
		win_const_mgr.add_const('ERROR_ALERTED',0x000002E3)
		win_const_mgr.add_const('WS_EX_ACCEPTFILES',0x00000010)
		win_const_mgr.add_const('NETE_NOACCESS',0x00000002)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_COMPARTMENT_ID',0x00000800)
		win_const_mgr.add_const('DMPAPER_ISO_B4',0x0000002A)
		win_const_mgr.add_const('DEVICEPOWER_FILTER_ON_NAME',0x02000000)
		win_const_mgr.add_const('EAP_E_SERVER_CERT_REVOKED',0x80420203)
		win_const_mgr.add_const('RPC_CALL_ATTRIBUTES_VERSION',0x00000001)
		win_const_mgr.add_const('PIDSI_EDITTIME',0x00000000)
		win_const_mgr.add_const('SB_LINELEFT',0x00000000)
		win_const_mgr.add_const('ADS_PRINTER_INITIALIZING',0x00008000)
		win_const_mgr.add_const('AEC_MODE_PASS_THROUGH',0x00000000)
		win_const_mgr.add_const('WIA_PAGE_CUSTOM_BASE',0x00008000)
		win_const_mgr.add_const('SQL_SUCCESS',0x00000000)
		win_const_mgr.add_const('CP_OPEN',0x00000001)
		win_const_mgr.add_const('IN6ADDR_V4MAPPEDPREFIX_LENGTH',0x00000060)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_HAS_TIMECODE',0x0000400A)
		win_const_mgr.add_const('DTPB_USECTLCOLORSTATIC',0x00000002)
		win_const_mgr.add_const('DRIVER_UNTRUSTED_RANK',0x00008000)
		win_const_mgr.add_const('FAULT_INVALID_ARG',0x00000192)
		win_const_mgr.add_const('PDH_NO_MORE_DATA',0xC0000BCC)
		win_const_mgr.add_const('CERT_ALT_NAME_OTHER_NAME',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_IA64_SECTION',0x0000000B)
		win_const_mgr.add_const('SEEK_END',0x00000002)
		win_const_mgr.add_const('WIA_IPA_ITEM_SIZE',0x00001014)
		win_const_mgr.add_const('TRACE_MESSAGE_POINTER64',0x00000080)
		win_const_mgr.add_const('KS_BI_BITFIELDS',0x00000003)
		win_const_mgr.add_const('DDWAITVB_BLOCKEND',0x00000004)
		win_const_mgr.add_const('SQL_CT_COLUMN_COLLATION',0x00000800)
		win_const_mgr.add_const('MOUSE_EVENT',0x00000002)
		win_const_mgr.add_const('BST_HOT',0x00000200)
		win_const_mgr.add_const('SSPROP_ALLOWNATIVEVARIANT',0x00000003)
		win_const_mgr.add_const('TABLE_ROW_DELETED',0x00000004)
		win_const_mgr.add_const('SI_EDIT_AUDITS',0x00000002)
		win_const_mgr.add_const('SAFER_POLICY_UIFLAGS_MASK',0x000000FF)
		win_const_mgr.add_const('GAA_FLAG_INCLUDE_WINS_INFO',0x00000040)
		win_const_mgr.add_const('IDM_CENTERVERTICALLY',0x0000000D)
		win_const_mgr.add_const('BTH_MFG_LUCENT',0x00000007)
		win_const_mgr.add_const('COD_PERIPHERAL_MINOR_SENSING',0x00000004)
		win_const_mgr.add_const('ERROR_CANTWRITE',0x000003F5)
		win_const_mgr.add_const('FILE_TRAVERSE',0x00000020)
		win_const_mgr.add_const('TAPE_ERASE_SHORT',0x00000000)
		win_const_mgr.add_const('GC_WCH_CONTAINER',0x00000002)
		win_const_mgr.add_const('RECOVERED_WRITES_VALID',0x00000001)
		win_const_mgr.add_const('STI_ONLINESTATE_OFFLINE',0x00000040)
		win_const_mgr.add_const('ACM_METRIC_COUNT_DISABLED',0x00000005)
		win_const_mgr.add_const('DEBUG_REQUEST_SET_LOCAL_IMPLICIT_COMMAND_LINE',0x00000009)
		win_const_mgr.add_const('MCAST_LEAVE_SOURCE_GROUP',0x0000002E)
		win_const_mgr.add_const('LINEDISCONNECTMODE_TEMPFAILURE',0x00008000)
		win_const_mgr.add_const('ERROR_NEGATIVE_SEEK',0x00000083)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_YEAR',0x00000008)
		win_const_mgr.add_const('XINPUT_DEVTYPE_GAMEPAD',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SRC_LEFT_S',0x00008020)
		win_const_mgr.add_const('D3DTA_SPECULAR',0x00000004)
		win_const_mgr.add_const('LSA_FOREST_TRUST_RECORD_TYPE_UNRECOGNIZED',0x80000000)
		win_const_mgr.add_const('ERROR_DS_NO_TREE_DELETE_ABOVE_NC',0x00002135)
		win_const_mgr.add_const('SQL_DT_DROP_TABLE',0x00000001)
		win_const_mgr.add_const('WIA_DPC_FOCUS_DISTANCE',0x00000826)
		win_const_mgr.add_const('USN_REASON_STREAM_CHANGE',0x00200000)
		win_const_mgr.add_const('FACILITY_CERT',0x0000000B)
		win_const_mgr.add_const('ACMDRIVERDETAILS_COPYRIGHT_CHARS',0x00000050)
		win_const_mgr.add_const('BOM_LEGACYBIDICLASS',0x00000040)
		win_const_mgr.add_const('SE_RM_CONTROL_VALID',0x00004000)
		win_const_mgr.add_const('PORT_CISCOFNA',0x00000082)
		win_const_mgr.add_const('SQL_SC_SQL92_INTERMEDIATE',0x00000004)
		win_const_mgr.add_const('EXIT_THREAD_DEBUG_EVENT',0x00000004)
		win_const_mgr.add_const('BSIS_SINGLECLICK',0x00000008)
		win_const_mgr.add_const('DBFLAGS_LOGFILESIZE16MB',0x00000100)
		win_const_mgr.add_const('CM_REGISTER_DEVICE_DRIVER_REMOVABLE',0x00000002)
		win_const_mgr.add_const('IDYES',0x00000006)
		win_const_mgr.add_const('DC_STAPLE',0x0000001E)
		win_const_mgr.add_const('IDM_CHANGEFONT',0x000008C0)
		win_const_mgr.add_const('RAS_EAP_FLAG_GUEST_ACCESS',0x00000040)
		win_const_mgr.add_const('POLLWRBAND',0x00000020)
		win_const_mgr.add_const('MINIDUMP_THREAD_INFO_INVALID_INFO',0x00000008)
		win_const_mgr.add_const('JOB_OBJECT_SECURITY_RESTRICTED_TOKEN',0x00000002)
		win_const_mgr.add_const('NCBCANCEL',0x00000035)
		win_const_mgr.add_const('LVCFMT_LEFT',0x00000000)
		win_const_mgr.add_const('WKSTA_MAXCMDS_PARMNUM',0x0000000F)
		win_const_mgr.add_const('KSNODEPIN_AEC_RENDER_OUT',0x00000000)
		win_const_mgr.add_const('WLX_OPTION_CONTEXT_POINTER',0x00000002)
		win_const_mgr.add_const('MCI_LIST',0x00000878)
		win_const_mgr.add_const('DXVA_CONFIG_BLEND_TYPE_BACK_HARDWARE',0x00000001)
		win_const_mgr.add_const('RBBS_BREAK',0x00000001)
		win_const_mgr.add_const('ACTCTX_FLAG_RESOURCE_NAME_VALID',0x00000008)
		win_const_mgr.add_const('DISPLAYDIB_END',0x00004000)
		win_const_mgr.add_const('ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS',0x0000171F)
		win_const_mgr.add_const('DBPROPVAL_FU_CATALOG',0x00000008)
		win_const_mgr.add_const('ERROR_DISK_REPAIR_DISABLED',0x0000030C)
		win_const_mgr.add_const('IDF_NOFOREGROUND',0x00000400)
		win_const_mgr.add_const('WIA_DPC_CONTRAST',0x00000820)
		win_const_mgr.add_const('SPI_GETSELECTIONFADE',0x00001014)
		win_const_mgr.add_const('SSA_HOTKEYONLY',0x00002400)
		win_const_mgr.add_const('DEX_IDS_BAD_SOURCE_NAME',0x00000578)
		win_const_mgr.add_const('IPPORT_IMAP3',0x000000DC)
		win_const_mgr.add_const('TMT_FILENAME',0x000000CE)
		win_const_mgr.add_const('IMAGE_DLLCHARACTERISTICS_TERMINAL_SERVER_AWARE',0x00008000)
		win_const_mgr.add_const('ENLISTMENT_SUBORDINATE_RIGHTS',0x00000008)
		win_const_mgr.add_const('ERROR_REMOTE_STORAGE_NOT_ACTIVE',0x000010FF)
		win_const_mgr.add_const('SV_ALIST_MTIME_PARMNUM',0x00000193)
		win_const_mgr.add_const('VK_END',0x00000023)
		win_const_mgr.add_const('EPT_S_NOT_REGISTERED',0x000006D9)
		win_const_mgr.add_const('HHT_ONDIVIDER',0x00000004)
		win_const_mgr.add_const('DNS_TYPE_ANY',0x00000000)
		win_const_mgr.add_const('NET_STRING_IPV6_NETWORK',0x00000080)
		win_const_mgr.add_const('OID_FDDI_DOWNSTREAM_NODE_LONG',0x03020103)
		win_const_mgr.add_const('WINHTTP_ADDREQ_FLAG_COALESCE_WITH_COMMA',0x40000000)
		win_const_mgr.add_const('RSC_BE',0x00000004)
		win_const_mgr.add_const('FEATURESETTING_NEGATIVE',0x00000005)
		win_const_mgr.add_const('WM_DEADCHAR',0x00000103)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_RESOLVING_NAME',0x00000001)
		win_const_mgr.add_const('HTTP_QUERY_WWW_AUTHENTICATE',0x00000028)
		win_const_mgr.add_const('IF_TYPE_RADIO_MAC',0x000000BC)
		win_const_mgr.add_const('IME_MODE_ALPHANUMERIC',0x00000001)
		win_const_mgr.add_const('DEBUG_ENGOPT_DISALLOW_IMAGE_FILE_MAPPING',0x00020000)
		win_const_mgr.add_const('LDAP_OPT_TCP_KEEPALIVE',0x00000040)
		win_const_mgr.add_const('WSB_PROP_CYVSCROLL',0x00000001)
		win_const_mgr.add_const('PURGE_TXABORT',0x00000001)
		win_const_mgr.add_const('TRANSACTION_PROPAGATE',0x00000020)
		win_const_mgr.add_const('COD_AUDIO_MINOR_SET_TOP_BOX',0x00000009)
		win_const_mgr.add_const('PIDDRSI_PLAYCOUNT',0x00000004)
		win_const_mgr.add_const('MQ_LOOKUP_RECEIVE_LAST',0x40000028)
		win_const_mgr.add_const('SRRF_RT_ANY',0x00000000)
		win_const_mgr.add_const('CC_RGBINIT',0x00000001)
		win_const_mgr.add_const('AVCTP_PROTOCOL_UUID16',0x00000017)
		win_const_mgr.add_const('IMAGE_REL_CEE_SECREL',0x00000005)
		win_const_mgr.add_const('KERB_REFRESH_SCCRED_GETTGT',0x00000001)
		win_const_mgr.add_const('KERB_CHECKSUM_KRB_DES_MAC_K',0x00000005)
		win_const_mgr.add_const('CERT_NEW_KEY_PROP_ID',0x0000004A)
		win_const_mgr.add_const('SHFMT_ID_DEFAULT',0x0000FFFF)
		win_const_mgr.add_const('DLGWINDOWEXTRA',0x00000030)
		win_const_mgr.add_const('CREDSSP_SERVER_AUTH_CERTIFICATE',0x00000002)
		win_const_mgr.add_const('RPC_S_PROCNUM_OUT_OF_RANGE',0x000006D1)
		win_const_mgr.add_const('D3DVS_SWIZZLE_MASK',0x00FF0000)
		win_const_mgr.add_const('PORT_ATZIS',0x000000CE)
		win_const_mgr.add_const('KAGPROP_OJCAPABILITY',0x00000005)
		win_const_mgr.add_const('NS_PEER_BROWSE',0x00000003)
		win_const_mgr.add_const('ERROR_RECEIVE_PARTIAL',0x000002C3)
		win_const_mgr.add_const('WEBPOST_ERROR_PROV_EP',0xC0042106)
		win_const_mgr.add_const('STGM_SHARE_EXCLUSIVE',0x00000010)
		win_const_mgr.add_const('DS_REPMOD_UPDATE_FLAGS',0x00000001)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_251',0x00000000)
		win_const_mgr.add_const('DMPAPER_A5',0x0000000B)
		win_const_mgr.add_const('SS_CENTERIMAGE',0x00000200)
		win_const_mgr.add_const('CTRY_DENMARK',0x0000002D)
		win_const_mgr.add_const('NORM_LINGUISTIC_CASING',0x08000000)
		win_const_mgr.add_const('SQL_FN_NUM_COT',0x00000080)
		win_const_mgr.add_const('SQL_FN_NUM_COS',0x00000040)
		win_const_mgr.add_const('IDC_PANTOOL_HAND_OPEN',0x00000068)
		win_const_mgr.add_const('MDM_X75_DATA_128K',0x00000002)
		win_const_mgr.add_const('MD_EXTLOG_URI_STEM',0x00000100)
		win_const_mgr.add_const('MDPROPVAL_MSF_MTD',0x00000100)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_RESIZEBY',0x00000008)
		win_const_mgr.add_const('ENABLECLASS_FAILURE',0x00000002)
		win_const_mgr.add_const('HDS_HORZ',0x00000000)
		win_const_mgr.add_const('GCPCLASS_NEUTRAL',0x00000003)
		win_const_mgr.add_const('MDMSPKRFLAG_DIAL',0x00000002)
		win_const_mgr.add_const('SPINST_INI2REG',0x00000008)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_12',0x00000000)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_SH4',0x00000001)
		win_const_mgr.add_const('WMS_STREAM_ID',0x00000000)
		win_const_mgr.add_const('BSIS_PREFERNOLINEBREAK',0x00000080)
		win_const_mgr.add_const('IOCTL_STORAGE_BC_VERSION',0x00000001)
		win_const_mgr.add_const('CRYPT_ENCRYPT_ALG_OID_GROUP_ID',0x00000002)
		win_const_mgr.add_const('RTM_NOTIFY_ONLY_MARKED_DESTS',0x00010000)
		win_const_mgr.add_const('IACE_DEFAULT',0x00000010)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNEXPECTED_STANDALONE',0x000036F7)
		win_const_mgr.add_const('SRC_FLAGS_CABFILE',0x00000010)
		win_const_mgr.add_const('CP_DIRECT',0x00000002)
		win_const_mgr.add_const('QUALITATIVE_SERV',0x00000006)
		win_const_mgr.add_const('CTF_WAIT_ALLOWCOM',0x00000040)
		win_const_mgr.add_const('SSPROP_COL_COLLATIONNAME',0x0000000E)
		win_const_mgr.add_const('XACT_E_LAST',0x8004D029)
		win_const_mgr.add_const('DI_FLAGSEX_RESERVED1',0x00400000)
		win_const_mgr.add_const('ERROR_TRANSACTION_INTEGRITY_VIOLATED',0x00001A46)
		win_const_mgr.add_const('DEBUG_DATA_SPACE_PHYSICAL',0x00000001)
		win_const_mgr.add_const('PRIORITY_BIT',0x00000008)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_SECTION',0x0000000E)
		win_const_mgr.add_const('SQL_AT_DROP_COLUMN',0x00000002)
		win_const_mgr.add_const('META_EXCLUDECLIPRECT',0x00000415)
		win_const_mgr.add_const('PROTO_IP_BGMP',0x0000000B)
		win_const_mgr.add_const('SBSP_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('DIGCDP_FLAG_BASIC',0x00000001)
		win_const_mgr.add_const('ERROR_NO_MORE_ITEMS',0x00000103)
		win_const_mgr.add_const('SV_MAXTHREADSPERQUEUE_PARMNUM',0x0000024A)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_WRITE',0x00000200)
		win_const_mgr.add_const('CREDENTIAL_SUB_TYPE_ASCII_ID',0x00000001)
		win_const_mgr.add_const('SMTP_MD_ID_END_RESERVED',0x00000009)
		win_const_mgr.add_const('DT_CENTER',0x00000001)
		win_const_mgr.add_const('LINEAGENTSTATE_READY',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_I386_SECTION',0x0000000A)
		win_const_mgr.add_const('DPD_DELETE_UNUSED_FILES',0x00000001)
		win_const_mgr.add_const('SQLVARIANT',0x00000062)
		win_const_mgr.add_const('DISPID_IADCCTL_SHOWPOSTSETUP',0x00000104)
		win_const_mgr.add_const('PHOTOACQ_DISABLE_PLUGINS',0x00000004)
		win_const_mgr.add_const('LB_SELECTSTRING',0x0000018C)
		win_const_mgr.add_const('CERT_VERIFY_REV_ACCUMULATIVE_TIMEOUT_FLAG',0x00000004)
		win_const_mgr.add_const('TTF_CENTERTIP',0x00000002)
		win_const_mgr.add_const('IMPORTANCE_NORMAL_MAX',0x00000004)
		win_const_mgr.add_const('DEBUG_ASMOPT_IGNORE_OUTPUT_WIDTH',0x00000004)
		win_const_mgr.add_const('WS2API_DECNET_MAX',0x0000000A)
		win_const_mgr.add_const('ERROR_CTX_WD_NOT_FOUND',0x00001B5C)
		win_const_mgr.add_const('PID_CREATE_DTM',0x0000000C)
		win_const_mgr.add_const('CAUSE_TOO_MANY_PENDING_ADD_PARTY',0x0000005C)
		win_const_mgr.add_const('SV_TYPE_CLUSTER_NT',0x01000000)
		win_const_mgr.add_const('LANG_MONGOLIAN',0x00000050)
		win_const_mgr.add_const('IS_TEXT_UNICODE_DBCS_LEADBYTE',0x00000400)
		win_const_mgr.add_const('ERROR_DS_STRONG_AUTH_REQUIRED',0x00002028)
		win_const_mgr.add_const('IME_MODE_ROMAN',0x00000020)
		win_const_mgr.add_const('SQL_COLUMN_OWNER_NAME',0x00000010)
		win_const_mgr.add_const('ERROR_CANTOPEN',0x000003F3)
		win_const_mgr.add_const('SUBLANG_YAKUT_RUSSIA',0x00000001)
		win_const_mgr.add_const('KSSTREAM_FAILUREEXCEPTION',0x00002000)
		win_const_mgr.add_const('UM_SELTYPE_GROUP',0x00000020)
		win_const_mgr.add_const('SSPROPVAL_COMMANDTYPE_REGULAR',0x00000015)
		win_const_mgr.add_const('DISPID_DWRITEENGINE2EVENTS_UPDATE',0x00000100)
		win_const_mgr.add_const('FILE_DEVICE_NAMED_PIPE',0x00000011)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_RECORD',0x00400000)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SRC_AVERAGE_S',0x00008022)
		win_const_mgr.add_const('MDPROPVAL_MSF_PERIODSTODATE',0x00000010)
		win_const_mgr.add_const('FS_NO_DIAL_TONE',0x20000200)
		win_const_mgr.add_const('MDAXIS_ROWS',0x00000001)
		win_const_mgr.add_const('INITIALIZE_NEGOTIATION',0xFFFFFFFF)
		win_const_mgr.add_const('SORT_GERMAN_PHONE_BOOK',0x00000001)
		win_const_mgr.add_const('CF_TTONLY',0x00040000)
		win_const_mgr.add_const('DMPAPER_JENV_KAKU3',0x00000048)
		win_const_mgr.add_const('MUI_LIP_LANGUAGE',0x00000004)
		win_const_mgr.add_const('WB_PREVBREAK',0x00000006)
		win_const_mgr.add_const('E_FILTER_SCRIPTSELECT',0x80100040)
		win_const_mgr.add_const('ERROR_DS_DRA_BUSY',0x000020F6)
		win_const_mgr.add_const('ERROR_NO_SPOOL_SPACE',0x0000003E)
		win_const_mgr.add_const('SES_USEATFONT',0x00040000)
		win_const_mgr.add_const('CONNECT_TEMPORARY',0x00000004)
		win_const_mgr.add_const('LINEADDRESSMODE_ADDRESSID',0x00000001)
		win_const_mgr.add_const('NS_STDA',0x0000001F)
		win_const_mgr.add_const('SCARD_STATE_UNPOWERED',0x00000400)
		win_const_mgr.add_const('MCI_VCR_STATUS_RECORD_FORMAT',0x00004004)
		win_const_mgr.add_const('ANYSIZE_ARRAY',0x00000001)
		win_const_mgr.add_const('OID_ATM_CALL_NOTIFY',0x0801020E)
		win_const_mgr.add_const('CERT_PHYSICAL_STORE_PREDEFINED_ENUM_FLAG',0x00000001)
		win_const_mgr.add_const('MDPROPVAL_MSF_DRILLUPMEMBER',0x00010000)
		win_const_mgr.add_const('NUMBER_OF_FWP_ENTRIES',0x00000008)
		win_const_mgr.add_const('WH_SHELL',0x0000000A)
		win_const_mgr.add_const('DBT_VOLLOCKLOCKTAKEN',0x00008042)
		win_const_mgr.add_const('FLG_ADDPROPERTY_OR',0x00000008)
		win_const_mgr.add_const('PD_ENABLESETUPTEMPLATE',0x00008000)
		win_const_mgr.add_const('LVKF_CONTROL',0x00000002)
		win_const_mgr.add_const('DVB_SIT_TID',0x0000007F)
		win_const_mgr.add_const('AF_IRDA',0x0000001A)
		win_const_mgr.add_const('INPLACE_S_LAST',0x000401AF)
		win_const_mgr.add_const('SQL_PARAM_ARRAY_SELECTS',0x0000009A)
		win_const_mgr.add_const('LVHT_EX_FOOTER',0x08000000)
		win_const_mgr.add_const('ERROR_DLL_NOT_FOUND',0x00000485)
		win_const_mgr.add_const('COPYFLG_REPLACEONLY',0x00000400)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_RECTANGLE',0x00000017)
		win_const_mgr.add_const('HSHELL_WINDOWDESTROYED',0x00000002)
		win_const_mgr.add_const('MAP_COMPOSITE',0x00000040)
		win_const_mgr.add_const('D3DDEVCAPS_NPATCHES',0x01000000)
		win_const_mgr.add_const('DSROLE_UPGRADE_IN_PROGRESS',0x00000004)
		win_const_mgr.add_const('CM_GETIDLIST_FILTER_POWERRELATIONS',0x00000010)
		win_const_mgr.add_const('TF_TMF_ACTIVATED',0x80000000)
		win_const_mgr.add_const('MSIMWND_DISPID_ONMOVE',0x000000E0)
		win_const_mgr.add_const('DNS_ERROR_DP_NOT_AVAILABLE',0x000026B1)
		win_const_mgr.add_const('LVIS_OVERLAYMASK',0x00000F00)
		win_const_mgr.add_const('SPI_GETFOCUSBORDERHEIGHT',0x00002010)
		win_const_mgr.add_const('DEBUG_OUTCTL_SEND_MASK',0x00000007)
		win_const_mgr.add_const('SECBUFFER_STREAM_HEADER',0x00000007)
		win_const_mgr.add_const('INTERNET_CUSTOMDIAL_CONNECT',0x00000000)
		win_const_mgr.add_const('ERROR_CTX_GRAPHICS_INVALID',0x00001B7B)
		win_const_mgr.add_const('SQL_API_SQLPROCEDURECOLUMNS',0x00000042)
		win_const_mgr.add_const('SF_DENIED_BY_CONFIG',0x00010000)
		win_const_mgr.add_const('ERROR_CURRENT_DIRECTORY',0x00000010)
		win_const_mgr.add_const('LPD_SUPPORT_OPENGL',0x00000020)
		win_const_mgr.add_const('L2_NOTIFICATION_CODE_PUBLIC_BEGIN',0x00000000)
		win_const_mgr.add_const('WIA_DPS_TRANSPARENCY',0x00000C1D)
		win_const_mgr.add_const('SCOPE_FLAG_MASK',0x00000000)
		win_const_mgr.add_const('KSPIN_FLAG_GENERATE_EOS_EVENTS',0x00200000)
		win_const_mgr.add_const('STRINGFORMAT_UNICODE',0x00000003)
		win_const_mgr.add_const('DEBUG_REGISTERS_INT64',0x00000002)
		win_const_mgr.add_const('WIA_MAX_CTX_SIZE',0x01000000)
		win_const_mgr.add_const('CERT_PUBKEY_ALG_PARA_PROP_ID',0x00000016)
		win_const_mgr.add_const('ERROR_DS_DRA_MAIL_PROBLEM',0x000020FF)
		win_const_mgr.add_const('SUBSCRIPTION_CAP_ALTLOGIN',0x00000080)
		win_const_mgr.add_const('CMSG_CTRL_ADD_CMS_SIGNER_INFO',0x00000014)
		win_const_mgr.add_const('CTFMODEBIAS_DEFAULT',0x00000000)
		win_const_mgr.add_const('EMR_SETTEXTCOLOR',0x00000018)
		win_const_mgr.add_const('LINECALLREASON_REMINDER',0x00000200)
		win_const_mgr.add_const('BSF_THEATERMODE',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_CO_BEGINSWITH',0x00000020)
		win_const_mgr.add_const('BACKUP_ALTERNATE_DATA',0x00000004)
		win_const_mgr.add_const('MD_ROOT_ENABLE_HISTORY',0x0000270C)
		win_const_mgr.add_const('SQL_SPECIAL_CHARACTERS',0x0000005E)
		win_const_mgr.add_const('AA_F_ACL',0x00000800)
		win_const_mgr.add_const('NWF_OPERATIONAL_OID',0x00000001)
		win_const_mgr.add_const('ERROR_INSTALL_LOG_FAILURE',0x00000656)
		win_const_mgr.add_const('JT_SEND',0x00000001)
		win_const_mgr.add_const('SV_TYPE_SERVER_MFPN',0x00004000)
		win_const_mgr.add_const('GET_FEATURE_FROM_REGISTRY',0x00000004)
		win_const_mgr.add_const('DLL_PROCESS_ATTACH',0x00000001)
		win_const_mgr.add_const('DWORDLONG_MAX',0x00000000)
		win_const_mgr.add_const('PPP_LCP_PAP',0x0000C023)
		win_const_mgr.add_const('WM_TIMECHANGE',0x0000001E)
		win_const_mgr.add_const('DWL_MSGRESULT',0x00000000)
		win_const_mgr.add_const('MD_EXTLOG_COOKIE',0x00020000)
		win_const_mgr.add_const('SDP_ATTRIB_DI_SPECIFICATION_ID',0x00000200)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_501',0x801901F5)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_502',0x801901F6)
		win_const_mgr.add_const('REVEXT_CDPENABLE',0x00000100)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_504',0x801901F8)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_505',0x801901F9)
		win_const_mgr.add_const('DBPROPVAL_CM_TRANSACTIONS',0x00000001)
		win_const_mgr.add_const('ERROR_INVALID_OPLOCK_PROTOCOL',0x0000012D)
		win_const_mgr.add_const('PHOTOACQ_ABORT_ON_SETTINGS_UPDATE',0x00000800)
		win_const_mgr.add_const('SS_WHITERECT',0x00000006)
		win_const_mgr.add_const('JS_PENDING',0x00000000)
		win_const_mgr.add_const('DMBIN_CASSETTE',0x0000000E)
		win_const_mgr.add_const('SQL_CONVERT_WCHAR',0x0000007A)
		win_const_mgr.add_const('KERB_ETYPE_DSA_SIGN',0x00000008)
		win_const_mgr.add_const('IMAGE_REL_AMD64_PAIR',0x0000000F)
		win_const_mgr.add_const('AVIIF_NOTIME',0x00000100)
		win_const_mgr.add_const('SECPKG_ATTR_NEGOTIATION_INFO',0x0000000C)
		win_const_mgr.add_const('DIRID_COMMON_APPDATA',0x00004023)
		win_const_mgr.add_const('URLPOLICY_MASK_PERMISSIONS',0x00000000)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_WORLD',0x80000010)
		win_const_mgr.add_const('IMAP_MD_ID_BEGIN_RESERVED',0x00000000)
		win_const_mgr.add_const('SHGVSPB_ALLFOLDERS',0x00000008)
		win_const_mgr.add_const('SCHANNEL_ALERT',0x00000002)
		win_const_mgr.add_const('DBG_INSTRFAULT',0x00000009)
		win_const_mgr.add_const('CBN_EDITCHANGE',0x00000005)
		win_const_mgr.add_const('COMP_ELEM_SOURCE',0x00000200)
		win_const_mgr.add_const('USN_REASON_COMPRESSION_CHANGE',0x00020000)
		win_const_mgr.add_const('INTERNET_OPTION_OFFLINE_SEMANTICS',0x00000034)
		win_const_mgr.add_const('LINEROAMMODE_ROAMA',0x00000008)
		win_const_mgr.add_const('HELP_FINDER',0x00000000)
		win_const_mgr.add_const('KSPIN_FLAG_SPLITTER',0x00020000)
		win_const_mgr.add_const('IDM_MP_PRINTPICTURE',0x000008F1)
		win_const_mgr.add_const('URLACTION_INFODELIVERY_CURR_MAX',0x00001D06)
		win_const_mgr.add_const('PAN_XHEIGHT_CONSTANT_LARGE',0x00000004)
		win_const_mgr.add_const('_SS_MAXSIZE',0x00000080)
		win_const_mgr.add_const('INTERNET_STATUS_CTL_RESPONSE_RECEIVED',0x0000002A)
		win_const_mgr.add_const('SECURITY_IE_STATE_GREEN',0x00000000)
		win_const_mgr.add_const('INTERNET_STATE_IDLE',0x00000100)
		win_const_mgr.add_const('DMPAPER_A_PLUS',0x00000039)
		win_const_mgr.add_const('TVIS_STATEIMAGEMASK',0x0000F000)
		win_const_mgr.add_const('URLACTION_DOWNLOAD_MIN',0x00001000)
		win_const_mgr.add_const('ERROR_CTX_WINSTATION_ACCESS_DENIED',0x00001B85)
		win_const_mgr.add_const('IDI_PROBLEM_OVL',0x000001F4)
		win_const_mgr.add_const('CM_DELETE_CLASS_ONLY',0x00000000)
		win_const_mgr.add_const('MD_DIRBROW_LOADDEFAULT',0x40000000)
		win_const_mgr.add_const('IDM_FLAT',0x00000036)
		win_const_mgr.add_const('CMSG_CMS_RECIPIENT_INDEX_PARAM',0x00000022)
		win_const_mgr.add_const('SQLMONEY',0x00000003)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_WEEKS',0x00000104)
		win_const_mgr.add_const('ADS_PRINTER_PAPER_JAM',0x00000004)
		win_const_mgr.add_const('WTS_CONSOLE_CONNECT',0x00000001)
		win_const_mgr.add_const('WKSTA_PLATFORM_ID_PARMNUM',0x00000064)
		win_const_mgr.add_const('SQL_SDF_CURRENT_DATE',0x00000001)
		win_const_mgr.add_const('GETPROPS_NONE',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_DS_UNAVAILABLE',0x000025F5)
		win_const_mgr.add_const('D3DDEVCAPS_HWTRANSFORMANDLIGHT',0x00010000)
		win_const_mgr.add_const('ICERR_GOTOKEYFRAME',0x00000003)
		win_const_mgr.add_const('TRUST_AUTH_TYPE_VERSION',0x00000003)
		win_const_mgr.add_const('SQL_QU_PROCEDURE_INVOCATION',0x00000002)
		win_const_mgr.add_const('DSS_MONO',0x00000080)
		win_const_mgr.add_const('GCS_RESULTREADSTR',0x00000200)
		win_const_mgr.add_const('FILE_FLAG_POSIX_SEMANTICS',0x01000000)
		win_const_mgr.add_const('MAX_SUBTITLE_LEN',0x00000100)
		win_const_mgr.add_const('CRLF_CRLNUMBER_CRITICAL',0x00000004)
		win_const_mgr.add_const('MQ_LOOKUP_PEEK_FIRST',0x40000014)
		win_const_mgr.add_const('ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED',0x00000314)
		win_const_mgr.add_const('IDM_TRIED_SELECTALL',0x00000036)
		win_const_mgr.add_const('ES_AUTOHSCROLL',0x00000080)
		win_const_mgr.add_const('LL_RUNNING',0x00000002)
		win_const_mgr.add_const('IMC_CLOSESTATUSWINDOW',0x00000021)
		win_const_mgr.add_const('HTTP_STATUS_NO_CONTENT',0x000000CC)
		win_const_mgr.add_const('GT_BURGERMASTER',0x0000000A)
		win_const_mgr.add_const('WTPF_VERIFY_V1_OFF',0x00010000)
		win_const_mgr.add_const('NDIS_802_11_LENGTH_RATES_EX',0x00000010)
		win_const_mgr.add_const('WEBPOST_ERROR_PROV_NOT_IN_POSTINFO',0x80042114)
		win_const_mgr.add_const('FLAGS_ERROR_UI_SERIALIZE_DIALOGS',0x00000010)
		win_const_mgr.add_const('DIIDFLAG_SHOWSEARCHUI',0x00000001)
		win_const_mgr.add_const('IDM_TRIED_BRING_TO_FRONT',0x00000007)
		win_const_mgr.add_const('MUI_QUERY_LANGUAGE_NAME',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_BASED_MIPS_JMPADDR',0x00000005)
		win_const_mgr.add_const('FILE_DEVICE_KS',0x00000002)
		win_const_mgr.add_const('SSPROP_CURSORAUTOFETCH',0x0000000C)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_NETWORK',0x00000010)
		win_const_mgr.add_const('PIDSI_REVNUMBER',0x00000009)
		win_const_mgr.add_const('THREAD_SET_LIMITED_INFORMATION',0x00000400)
		win_const_mgr.add_const('NETPROPERTY_PERSISTENT',0x00000001)
		win_const_mgr.add_const('METADATA_SECURE',0x00000004)
		win_const_mgr.add_const('RTL_ENCRYPT_OPTION_CROSS_PROCESS',0x00000001)
		win_const_mgr.add_const('SYMOPT_DEBUG',0x80000000)
		win_const_mgr.add_const('UINT_ERROR',0x00000000)
		win_const_mgr.add_const('SUBLANG_LATVIAN_LATVIA',0x00000001)
		win_const_mgr.add_const('TF_US_HIDETIPUI',0x00000001)
		win_const_mgr.add_const('ERROR_LIBRARY_OFFLINE',0x000010D1)
		win_const_mgr.add_const('GETPAIRKERNTABLE',0x00000102)
		win_const_mgr.add_const('KSDSOUND_BUFFER_LOCSOFTWARE',0x00000008)
		win_const_mgr.add_const('ACCESS_ALLOWED_CALLBACK_OBJECT_ACE_TYPE',0x0000000B)
		win_const_mgr.add_const('GESTURE_TRIPLE_RIGHT',0x00000000)
		win_const_mgr.add_const('ATTR_CONVERTED',0x00000002)
		win_const_mgr.add_const('TOOLSBAND',0x00000001)
		win_const_mgr.add_const('PRINTER_ACCESS_USE',0x00000008)
		win_const_mgr.add_const('MAX_SCOPE_ID_LEN',0x00000100)
		win_const_mgr.add_const('WM_NCLBUTTONDBLCLK',0x000000A3)
		win_const_mgr.add_const('ABM_NEW',0x00000000)
		win_const_mgr.add_const('DSSSF_DONTSIGNSEAL',0x00000002)
		win_const_mgr.add_const('WIA_IPA_COLOR_PROFILE',0x00001015)
		win_const_mgr.add_const('PRINTER_STATUS_NO_TONER',0x00040000)
		win_const_mgr.add_const('VFT2_DRV_DISPLAY',0x00000004)
		win_const_mgr.add_const('LOCALE_INEGSYMPRECEDES',0x00000056)
		win_const_mgr.add_const('SNMP_BERAPI_INVALID_TAG',0x0000000B)
		win_const_mgr.add_const('GETSETSCREENPARAMS',0x00000C00)
		win_const_mgr.add_const('SYSTEM_ALARM_CALLBACK_OBJECT_ACE_TYPE',0x00000010)
		win_const_mgr.add_const('PIR_STATUS_ENABLED',0x00000001)
		win_const_mgr.add_const('FILE_ATTRIBUTE_READONLY',0x00000001)
		win_const_mgr.add_const('AM_GETDECODERCAP_QUERY_VMR9_SUPPORT',0x00000006)
		win_const_mgr.add_const('DS_REPSYNC_ABANDONED',0x00008000)
		win_const_mgr.add_const('VDMADDR_PM16',0x00000004)
		win_const_mgr.add_const('HTTP_STATUS_RETRY_WITH',0x000001C1)
		win_const_mgr.add_const('SFVM_UPDATEOBJECT',0x00000007)
		win_const_mgr.add_const('DATA_SOURCE_REGISTRY',0x00000001)
		win_const_mgr.add_const('WT_EXECUTEDEFAULT',0x00000000)
		win_const_mgr.add_const('KSAUDIO_CPU_RESOURCES_NOT_HOST_CPU',0x00000000)
		win_const_mgr.add_const('ERROR_DS_OBJ_CLASS_NOT_DEFINED',0x000020B3)
		win_const_mgr.add_const('MCI_DGV_STATUS_AUDIO_SOURCE',0x00004009)
		win_const_mgr.add_const('MDMEASURE_AGGR_SUM',0x00000001)
		win_const_mgr.add_const('PROCESS_SET_INFORMATION',0x00000200)
		win_const_mgr.add_const('EM_SETWORDBREAKPROC',0x000000D0)
		win_const_mgr.add_const('IMAGE_REL_CEE_ADDR32',0x00000001)
		win_const_mgr.add_const('SHARE_PASSWD_PARMNUM',0x00000009)
		win_const_mgr.add_const('IPV6_DONTFRAG',0x0000000E)
		win_const_mgr.add_const('CFS_RECT',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_RESNAME_NOT_FOUND',0x000013D8)
		win_const_mgr.add_const('DEBUG_CES_EVENT_FILTERS',0x00000100)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_SERVER_NAME',0x00000000)
		win_const_mgr.add_const('ERROR_SYSTEM_DEVICE_NOT_FOUND',0x00003BC3)
		win_const_mgr.add_const('ERROR_EFS_ALG_BLOB_TOO_BIG',0x0000177D)
		win_const_mgr.add_const('HHWIN_PROP_TRI_PANE',0x00000001)
		win_const_mgr.add_const('MIXER_GETCONTROLDETAILSF_VALUE',0x00000000)
		win_const_mgr.add_const('DDOVER_DDFX',0x00080000)
		win_const_mgr.add_const('FACILITY_SSPI',0x00000009)
		win_const_mgr.add_const('PORT_NETSTAT',0x0000000F)
		win_const_mgr.add_const('LOGON_SERVER_TRUST_ACCOUNT',0x00000080)
		win_const_mgr.add_const('DDOSDCAPS_OPTREORDERED',0x00000002)
		win_const_mgr.add_const('EMARCH_ENC_I17_IC_SIZE_X',0x00000001)
		win_const_mgr.add_const('WMDM_RIGHTS_GROUPID',0x00000004)
		win_const_mgr.add_const('KSAC3_ALTERNATE_AUDIO_BOTH',0x00000003)
		win_const_mgr.add_const('DDSCL_MULTITHREADED',0x00000400)
		win_const_mgr.add_const('OPTION_VENDOR_SPEC_INFO',0x0000002B)
		win_const_mgr.add_const('QDI_GETDIBITS',0x00000002)
		win_const_mgr.add_const('SHGNLI_PREFIXNAME',0x00000002)
		win_const_mgr.add_const('BTH_MAX_PIN_SIZE',0x00000010)
		win_const_mgr.add_const('DISPID_IMULTISESSION_NEXTWRITABLEADDRESS',0x00000203)
		win_const_mgr.add_const('LINETRANSLATEOPTION_CANCELCALLWAITING',0x00000002)
		win_const_mgr.add_const('LINEAGENTSESSIONSTATE_BUSYWRAPUP',0x00000008)
		win_const_mgr.add_const('ESB_DISABLE_DOWN',0x00000002)
		win_const_mgr.add_const('SV_VERSION_MAJOR_PARMNUM',0x00000067)
		win_const_mgr.add_const('DEBUG_PROC_DESC_NO_COMMAND_LINE',0x00000008)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_REPDIAL',0x00000027)
		win_const_mgr.add_const('PHONESTATE_HEADSETVOLUME',0x00010000)
		win_const_mgr.add_const('ERROR_DS_CANT_RETRIEVE_INSTANCE',0x000020D7)
		win_const_mgr.add_const('WNDT_NETWORK',0x00000001)
		win_const_mgr.add_const('APPCTR_MD_ID_END_RESERVED',0x00000000)
		win_const_mgr.add_const('L2_NOTIFICATION_SOURCE_SECURITY',0x00000000)
		win_const_mgr.add_const('SUBLANG_FRENCH_LUXEMBOURG',0x00000005)
		win_const_mgr.add_const('TM_OK',0x00000000)
		win_const_mgr.add_const('KP_ADMIN_PIN',0x0000001F)
		win_const_mgr.add_const('LNH_12_CPU',0x00000030)
		win_const_mgr.add_const('X3_IMM20_SIZE_X',0x00000014)
		win_const_mgr.add_const('WKSTA_KEEPSEARCH_PARMNUM',0x0000000E)
		win_const_mgr.add_const('PF_FLOATING_POINT_EMULATED',0x00000001)
		win_const_mgr.add_const('ERROR_SIGNAL_PENDING',0x000000A2)
		win_const_mgr.add_const('SQL_AM_STATEMENT',0x00000002)
		win_const_mgr.add_const('SPEAKER_TOP_FRONT_LEFT',0x00001000)
		win_const_mgr.add_const('SUBLANG_SAMI_NORTHERN_FINLAND',0x00000003)
		win_const_mgr.add_const('LM20_PWLEN',0x0000000E)
		win_const_mgr.add_const('ERROR_NO_MATCH',0x00000491)
		win_const_mgr.add_const('EMR_SELECTOBJECT',0x00000025)
		win_const_mgr.add_const('SQL_ODBC_SQL_CONFORMANCE',0x0000000F)
		win_const_mgr.add_const('ENABLE_AUTO_POSITION',0x00000100)
		win_const_mgr.add_const('PGF_CALCWIDTH',0x00000001)
		win_const_mgr.add_const('D3DGETDATA_FLUSH',0x00000001)
		win_const_mgr.add_const('DNS_RCODE_BADKEY',0x00000011)
		win_const_mgr.add_const('AM_LOADSTATUS_OPEN',0x00000006)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_MINIPORT_INTERRUPT',0x00000084)
		win_const_mgr.add_const('XECI_XENROLL',0x00000001)
		win_const_mgr.add_const('DBIM_INTEGRAL',0x00000004)
		win_const_mgr.add_const('ICDRAW_CONTINUE',0x00000010)
		win_const_mgr.add_const('KF_UP',0x00008000)
		win_const_mgr.add_const('SBS_SIZEBOX',0x00000008)
		win_const_mgr.add_const('SQL_CONVERT_TIMESTAMP',0x00000043)
		win_const_mgr.add_const('INTERNET_OPTION_IDENTITY',0x0000004E)
		win_const_mgr.add_const('DMDITHER_LINEART',0x00000004)
		win_const_mgr.add_const('VK_PLAY',0x000000FA)
		win_const_mgr.add_const('DST_TEXT',0x00000001)
		win_const_mgr.add_const('PDCAP_S2_SUPPORTED',0x00040000)
		win_const_mgr.add_const('SERVICE_NOTIFY_CONTINUE_PENDING',0x00000010)
		win_const_mgr.add_const('ABN_FULLSCREENAPP',0x00000002)
		win_const_mgr.add_const('TRUSTERROR_STEP_FINAL_WVTINIT',0x0000001E)
		win_const_mgr.add_const('ICEE_CREATE_MACHINE_MASK',0x0000FF00)
		win_const_mgr.add_const('DBPROPVAL_CS_INITIALIZED',0x00000001)
		win_const_mgr.add_const('OID_IRDA_RECEIVING',0x0A010100)
		win_const_mgr.add_const('IDM_TRIED_REDO',0x00000034)
		win_const_mgr.add_const('IDM_SHOWSPECIALCHAR',0x000008C9)
		win_const_mgr.add_const('DISPID_GETERRORMSG',0x00000011)
		win_const_mgr.add_const('WINWATCHNOTIFY_STOP',0x00000001)
		win_const_mgr.add_const('CMIC_MASK_PTINVOKE',0x20000000)
		win_const_mgr.add_const('OID_CO_ADDRESS_CHANGE',0xFE000007)
		win_const_mgr.add_const('CERT_HASH_LENGTH',0x00000014)
		win_const_mgr.add_const('HEAP_FREE_CHECKING_ENABLED',0x00000040)
		win_const_mgr.add_const('FC_DONT_FREE',0x00000002)
		win_const_mgr.add_const('RS_COMPLETED',0x80000000)
		win_const_mgr.add_const('IMAGE_SCN_MEM_SHARED',0x10000000)
		win_const_mgr.add_const('SPI_GETSCREENSAVERRUNNING',0x00000072)
		win_const_mgr.add_const('LINEGATHERTERM_BUFFERFULL',0x00000001)
		win_const_mgr.add_const('NTMS_OMIDLABELTYPE_LENGTH',0x00000040)
		win_const_mgr.add_const('FILE_SHARE_READ',0x00000001)
		win_const_mgr.add_const('IF_TYPE_ATM_VCI_ENDPT',0x000000C2)
		win_const_mgr.add_const('ERROR_DS_SINGLE_USER_MODE_FAILED',0x0000218E)
		win_const_mgr.add_const('BTH_ERROR_MAX_NUMBER_OF_SCO_CONNECTIONS',0x00000000)
		win_const_mgr.add_const('WLX_SAS_TYPE_SWITCHUSER',0x0000000A)
		win_const_mgr.add_const('NDIS_PROTOCOL_ID_MASK',0x0000000F)
		win_const_mgr.add_const('RPC_C_AUTHN_DEFAULT',0xFFFFFFFF)
		win_const_mgr.add_const('TBCDRF_NOBACKGROUND',0x00400000)
		win_const_mgr.add_const('SEARCH_ALTERNATE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER',0x00002147)
		win_const_mgr.add_const('BCRYPT_ECDSA_PRIVATE_P256_MAGIC',0x32534345)
		win_const_mgr.add_const('MAPMIME_DISABLE',0x00000002)
		win_const_mgr.add_const('MDPROPVAL_MSF_DRILLDOWNLEVELBOTTOM',0x00008000)
		win_const_mgr.add_const('OID_FDDI_PORT_MAC_LOOP_TIME',0x03030264)
		win_const_mgr.add_const('TAPE_DRIVE_WRITE_FILEMARKS',0x82000000)
		win_const_mgr.add_const('CERT_CHAIN_POLICY_IGNORE_WRONG_USAGE_FLAG',0x00000020)
		win_const_mgr.add_const('LB_SRC_ADDR_USE_SRCADDR_FLAG',0x00000001)
		win_const_mgr.add_const('PIFSTARTLOCSIZE',0x0000003F)
		win_const_mgr.add_const('CERT_VALIDITY_BEFORE_START',0x00000001)
		win_const_mgr.add_const('META_LINETO',0x00000213)
		win_const_mgr.add_const('DEBUG_OUTCTL_THIS_CLIENT',0x00000000)
		win_const_mgr.add_const('CRYPT_ENHKEY_USAGE_OID_GROUP_ID',0x00000007)
		win_const_mgr.add_const('VER_DRM_VIDEO_OUTPUT_PROTECTION',0x00000002)
		win_const_mgr.add_const('ERROR_ACTIVE_CONNECTIONS',0x00000962)
		win_const_mgr.add_const('OID_FDDI_IF_IN_NUCAST_PKTS',0x03030283)
		win_const_mgr.add_const('ERROR_KM_DRIVER_BLOCKED',0x0000078A)
		win_const_mgr.add_const('AE_SRVPAUSED',0x00000001)
		win_const_mgr.add_const('IDM_BOOKMARK',0x0000084B)
		win_const_mgr.add_const('DLCTL_URL_ENCODING_ENABLE_UTF8',0x00040000)
		win_const_mgr.add_const('DWORD_ERROR',0x00000000)
		win_const_mgr.add_const('SQL_FETCH_NEXT',0x00000001)
		win_const_mgr.add_const('AUDIT_SET_SYSTEM_POLICY',0x00000001)
		win_const_mgr.add_const('MSIMHOSTEVENTS_DISPID_ONDOUBLECLICK',0x0000000D)
		win_const_mgr.add_const('DYNAWIZ_FLAG_ANALYZE_HANDLECONFLICT',0x00000008)
		win_const_mgr.add_const('DISPID_FILTERSRCCODE',0x0000001F)
		win_const_mgr.add_const('DV_AUDIOQU',0x07000000)
		win_const_mgr.add_const('GESTURE_RIGHT_ARROW_DOWN',0x00000000)
		win_const_mgr.add_const('ERROR_BAD_COMPRESSION_BUFFER',0x0000025D)
		win_const_mgr.add_const('LB_GETITEMDATA',0x00000199)
		win_const_mgr.add_const('IMAGE_REL_ARM_BRANCH24',0x00000003)
		win_const_mgr.add_const('PIDDSI_PARCOUNT',0x00000006)
		win_const_mgr.add_const('LSA_SID_DISABLED_CONFLICT',0x00000002)
		win_const_mgr.add_const('PRINT_WAITFORCOMPLETION',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_NP_DIDEVENT',0x00000010)
		win_const_mgr.add_const('CRYPTLIMIT_USING_PCT',0x00000001)
		win_const_mgr.add_const('TTN_LAST',0x00000000)
		win_const_mgr.add_const('ERROR_DS_MISSING_SUPREF',0x000020D6)
		win_const_mgr.add_const('DBPROPVAL_SQL_ANSI92_INTERMEDIATE',0x00000040)
		win_const_mgr.add_const('CTRY_UAE',0x000003CB)
		win_const_mgr.add_const('MSV1_0_VALIDATION_LOGON_DOMAIN',0x00000008)
		win_const_mgr.add_const('FCIDM_GLOBALLAST',0x00000009)
		win_const_mgr.add_const('CM_PROB_LIAR',0x0000000B)
		win_const_mgr.add_const('APPCOMMAND_CUT',0x00000025)
		win_const_mgr.add_const('ERROR_WOW_ASSERTION',0x0000029E)
		win_const_mgr.add_const('INTERNET_MAX_PASSWORD_LENGTH',0x00000080)
		win_const_mgr.add_const('SNMPAPI_V2_SUPPORT',0x00000002)
		win_const_mgr.add_const('CTRY_THAILAND',0x00000042)
		win_const_mgr.add_const('RPC_S_UNKNOWN_AUTHN_LEVEL',0x000006D4)
		win_const_mgr.add_const('DIRID_NULL',0x00000000)
		win_const_mgr.add_const('SYMOPT_FAIL_CRITICAL_ERRORS',0x00000200)
		win_const_mgr.add_const('MAX_PACKET_BUTTON_COUNT',0x00000020)
		win_const_mgr.add_const('WM_KEYFIRST',0x00000100)
		win_const_mgr.add_const('IP_MULTICAST_LOOP',0x0000000B)
		win_const_mgr.add_const('DS_INSTANCETYPE_NC_IS_WRITEABLE',0x00000004)
		win_const_mgr.add_const('DISPID_LOADDOCUMENT',0x00000001)
		win_const_mgr.add_const('ERROR_DS_LOOP_DETECT',0x00002036)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_REFLO',0x0000000B)
		win_const_mgr.add_const('IME_RS_ERROR',0x00000001)
		win_const_mgr.add_const('PDEVICESIZE',0x0000001A)
		win_const_mgr.add_const('D3DSI_INSTLENGTH_SHIFT',0x00000018)
		win_const_mgr.add_const('DS_REPUPD_ASYNCHRONOUS_OPERATION',0x00000001)
		win_const_mgr.add_const('MAXOBJIDSIZE',0x00000080)
		win_const_mgr.add_const('ILC_COLOR32',0x00000020)
		win_const_mgr.add_const('CERT_TRUST_IS_EXPLICIT_DISTRUST',0x04000000)
		win_const_mgr.add_const('LINGUISTIC_IGNOREDIACRITIC',0x00000020)
		win_const_mgr.add_const('DIF_REMOVE',0x00000005)
		win_const_mgr.add_const('MCI_VCR_STATUS_VIDEO_MONITOR',0x0000400C)
		win_const_mgr.add_const('MCI_OVLY_PUT_DESTINATION',0x00040000)
		win_const_mgr.add_const('VP_TV_STANDARD_SECAM_L',0x00004000)
		win_const_mgr.add_const('VP_TV_STANDARD_SECAM_K',0x00001000)
		win_const_mgr.add_const('VP_TV_STANDARD_SECAM_H',0x00000800)
		win_const_mgr.add_const('METHOD_RIP2_ROUTE_TIMESTAMP',0x00000008)
		win_const_mgr.add_const('SQL_DIAG_DROP_SCHEMA',0x0000001F)
		win_const_mgr.add_const('VP_TV_STANDARD_SECAM_G',0x00000400)
		win_const_mgr.add_const('VP_TV_STANDARD_SECAM_D',0x00000200)
		win_const_mgr.add_const('VP_TV_STANDARD_SECAM_B',0x00000100)
		win_const_mgr.add_const('PID_INTSITE_CODEPAGE',0x00000012)
		win_const_mgr.add_const('SHCNF_PATHA',0x00000001)
		win_const_mgr.add_const('WM_SYSCOLORCHANGE',0x00000015)
		win_const_mgr.add_const('CR_INVALID_FLAG',0x00000004)
		win_const_mgr.add_const('CDIS_HOT',0x00000040)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_PICKUP',0x0000000D)
		win_const_mgr.add_const('IME_RS_TOOLONG',0x00000005)
		win_const_mgr.add_const('REG_RESOURCE_REQUIREMENTS_LIST',0x0000000A)
		win_const_mgr.add_const('MAPI_E_TYPE_NOT_SUPPORTED',0x00000014)
		win_const_mgr.add_const('SQL_CONVERT_DECIMAL',0x0000003A)
		win_const_mgr.add_const('EM_LINEFROMCHAR',0x000000C9)
		win_const_mgr.add_const('MCI_AVI_STATUS_FRAMES_SKIPPED',0x00008001)
		win_const_mgr.add_const('OID_FDDI_SMT_STAT_RPT_POLICY',0x03030210)
		win_const_mgr.add_const('RTL_CRITICAL_SECTION_FLAG_DYNAMIC_SPIN',0x02000000)
		win_const_mgr.add_const('SHCNF_PATHW',0x00000005)
		win_const_mgr.add_const('DISPID_SORTDONE',0x000000D6)
		win_const_mgr.add_const('COLOR_3DDKSHADOW',0x00000015)
		win_const_mgr.add_const('ERROR_DS_NO_SUCH_OBJECT',0x00002030)
		win_const_mgr.add_const('SHI1005_FLAGS_ALLOW_NAMESPACE_CACHING',0x00000400)
		win_const_mgr.add_const('PHONEFEATURE_GETRING',0x00000400)
		win_const_mgr.add_const('ERROR_IPSEC_MM_POLICY_EXISTS',0x000032CB)
		win_const_mgr.add_const('DDOVER_KEYDESTOVERRIDE',0x00000800)
		win_const_mgr.add_const('HEAP_MAXIMUM_TAG',0x00000FFF)
		win_const_mgr.add_const('R2_MASKPENNOT',0x00000005)
		win_const_mgr.add_const('SNMP_ERROR_WRONGLENGTH',0x00000008)
		win_const_mgr.add_const('LOCALSTATE_ASSIGNED',0x00000001)
		win_const_mgr.add_const('EM_SETMARGINS',0x000000D3)
		win_const_mgr.add_const('SERVICE_ACTIVE',0x00000001)
		win_const_mgr.add_const('BG_E_UPNP_ERROR',0x80200045)
		win_const_mgr.add_const('CLONE_FLAG_BASICS',0x00000001)
		win_const_mgr.add_const('ERROR_MEDIA_OFFLINE',0x000010D0)
		win_const_mgr.add_const('ERROR_DS_NO_NTDSA_OBJECT',0x000021AF)
		win_const_mgr.add_const('D3DCS_FRONT',0x00000010)
		win_const_mgr.add_const('MAX_FEATURE_CHARS',0x00000026)
		win_const_mgr.add_const('STI_HW_CONFIG_PARALLEL',0x00000010)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_DOCUMENT',0x0000000D)
		win_const_mgr.add_const('ISR_FP_TRAP',0x00000000)
		win_const_mgr.add_const('DISPID_CURRENTDOCUMENTPATH',0x00000017)
		win_const_mgr.add_const('VOLUME_SESSION_OPEN',0x00000004)
		win_const_mgr.add_const('SQL_SQL_CONFORMANCE',0x00000076)
		win_const_mgr.add_const('NET_STRING_IPV4_SERVICE',0x00000002)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_STATUS_INDICATION',0x00000098)
		win_const_mgr.add_const('CUR_BLOB_VERSION',0x00000002)
		win_const_mgr.add_const('FILE_ATTRIBUTE_ARCHIVE',0x00000020)
		win_const_mgr.add_const('SP_COPY_NOBROWSE',0x00008000)
		win_const_mgr.add_const('REO_GETOBJ_POLEOBJ',0x00000001)
		win_const_mgr.add_const('LINECALLINFOSTATE_CALLDATA',0x40000000)
		win_const_mgr.add_const('HTTP_STATUS_WEBDAV_MULTI_STATUS',0x000000CF)
		win_const_mgr.add_const('MCI_SEQ_STATUS_DIVTYPE',0x0000400A)
		win_const_mgr.add_const('WMDM_RIGHTS_EXPIRATIONDATE',0x00000002)
		win_const_mgr.add_const('PAGE_EXECUTE_READWRITE',0x00000040)
		win_const_mgr.add_const('ERROR_DS_RESERVED_LINK_ID',0x00002180)
		win_const_mgr.add_const('MINIMUM_CACHE_SIZE',0x00000004)
		win_const_mgr.add_const('GESTURE_BRACE_UNDER',0x00000000)
		win_const_mgr.add_const('OCR_HAND',0x00007F89)
		win_const_mgr.add_const('DYNAWIZ_FLAG_INSTALLDET_NEXT',0x00000002)
		win_const_mgr.add_const('SV_ACCEPTDOWNLEVELAPIS_PARMNUM',0x00000205)
		win_const_mgr.add_const('LDAP_OPT_REFERRALS',0x00000008)
		win_const_mgr.add_const('PORT_NLOGIN',0x000002F6)
		win_const_mgr.add_const('BCRYPT_SUPPORTED_PAD_PKCS1_ENC',0x00000002)
		win_const_mgr.add_const('OID_802_11_INFRASTRUCTURE_MODE',0x0D010108)
		win_const_mgr.add_const('DBPROP_DEFERCATALOGVERIFICATION',0x00000008)
		win_const_mgr.add_const('PDH_LOG_OPT_MAX_IS_BYTES',0x04000000)
		win_const_mgr.add_const('DEBUG_KNOWN_STRUCT_GET_SINGLE_LINE_OUTPUT',0x00000002)
		win_const_mgr.add_const('WNODE_FLAG_PDO_INSTANCE_NAMES',0x00010000)
		win_const_mgr.add_const('ERROR_TRANSACTION_RECORD_TOO_LONG',0x00001A44)
		win_const_mgr.add_const('SUBLANG_GREENLANDIC_GREENLAND',0x00000001)
		win_const_mgr.add_const('SPINST_REGISTERCALLBACKAWARE',0x00080000)
		win_const_mgr.add_const('UF_USE_DES_KEY_ONLY',0x00200000)
		win_const_mgr.add_const('AD_APPLY_FORCE',0x00000008)
		win_const_mgr.add_const('DDBLTFX_MIRRORUPDOWN',0x00000004)
		win_const_mgr.add_const('ACMFORMATCHOOSE_STYLEF_ENABLETEMPLATE',0x00000010)
		win_const_mgr.add_const('SQL_MAX_COLUMNS_IN_ORDER_BY',0x00000063)
		win_const_mgr.add_const('LOCALE_SSCRIPTS',0x00000006)
		win_const_mgr.add_const('FALSE',0x00000000)
		win_const_mgr.add_const('KERB_SETPASS_USE_LOGONID',0x00000001)
		win_const_mgr.add_const('DISPID_IHTMLDLGSAFEHELPER_BLOCKFORMATS',0x00000004)
		win_const_mgr.add_const('RPC_C_OPT_MAX_OPTIONS',0x00000011)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_OTHER',0x00000000)
		win_const_mgr.add_const('DDOVER_ALPHASRCSURFACEOVERRIDE',0x00000100)
		win_const_mgr.add_const('NET_IF_OID_NETWORK_GUID',0x00000003)
		win_const_mgr.add_const('LM20_SERVICE_ACTIVE',0x00000000)
		win_const_mgr.add_const('ARW_TOPLEFT',0x00000002)
		win_const_mgr.add_const('LBS_NOSEL',0x00004000)
		win_const_mgr.add_const('ERROR_REPARSE_ATTRIBUTE_CONFLICT',0x00001127)
		win_const_mgr.add_const('WINHTTP_OPTION_SERVER_CERT_CONTEXT',0x0000004E)
		win_const_mgr.add_const('WH_JOURNALRECORD',0x00000000)
		win_const_mgr.add_const('ERROR_LABEL_UNREADABLE',0x00000001)
		win_const_mgr.add_const('TXFS_RM_FLAG_DO_NOT_RESET_RM_AT_NEXT_START',0x00008000)
		win_const_mgr.add_const('MAX_TABLE_CELLS',0x0000003F)
		win_const_mgr.add_const('IME_REGWORD_STYLE_USER_FIRST',0x80000000)
		win_const_mgr.add_const('CTLCOLOR_DLG',0x00000004)
		win_const_mgr.add_const('D3DFVF_LASTBETA_UBYTE4',0x00001000)
		win_const_mgr.add_const('ERROR_DEVICE_REINITIALIZATION_NEEDED',0x0000048C)
		win_const_mgr.add_const('EMO_EXIT',0x00000000)
		win_const_mgr.add_const('WMDRM_METER_RESPONSE_PARTIAL',0x00000001)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2EVENTARGS_FREESYSTEMBUFFER',0x00000108)
		win_const_mgr.add_const('NDIS_802_11_AUTH_REQUEST_KEYUPDATE',0x00000002)
		win_const_mgr.add_const('SQL_ISV_VIEWS',0x00400000)
		win_const_mgr.add_const('MD_ERROR_IISAO_INVALID_SCHEMA',0x800CC810)
		win_const_mgr.add_const('WSA_QOS_NO_SENDERS',0x00002AFF)
		win_const_mgr.add_const('IDM_FOLLOW_ANCHOR',0x000007D8)
		win_const_mgr.add_const('DBPROPVAL_TC_DDL_IGNORE',0x00000004)
		win_const_mgr.add_const('DUPLICATE_DEREG',0x00000007)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_DELAY_IMPORT',0x0000000D)
		win_const_mgr.add_const('DDPCAPS_ALPHA',0x00000400)
		win_const_mgr.add_const('DTR_UTBASE_INDEX',0x00000003)
		win_const_mgr.add_const('SB_HORZ',0x00000000)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_128BYTES',0x00800000)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNCLOSEDSTRING',0x000036EE)
		win_const_mgr.add_const('DDOVERZ_MOVEBACKWARD',0x00000003)
		win_const_mgr.add_const('IRTIR_TASK_RUNNING',0x00000001)
		win_const_mgr.add_const('ACCESS_MAX_LEVEL',0x00000004)
		win_const_mgr.add_const('USER_NOT_DELEGATED',0x00004000)
		win_const_mgr.add_const('WMS_CONTAINER_MAX_PACKET_SIZE',0x00000006)
		win_const_mgr.add_const('ERROR_PAGED_SYSTEM_RESOURCES',0x000005AC)
		win_const_mgr.add_const('ALG_SID_DH_SANDF',0x00000001)
		win_const_mgr.add_const('FORMAT_MESSAGE_ALLOCATE_BUFFER',0x00000100)
		win_const_mgr.add_const('HTTP_AUTH_ENABLE_NEGOTIATE',0x00000008)
		win_const_mgr.add_const('MSV1_0_VALIDATION_USER_ID',0x00000040)
		win_const_mgr.add_const('CMS_MONITOROVERFLOW',0x80000000)
		win_const_mgr.add_const('TAPE_DRIVE_SEQUENTIAL_FMKS',0x80080000)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_ARM',0x00000005)
		win_const_mgr.add_const('CM_DEVCAP_SURPRISEREMOVALOK',0x00000080)
		win_const_mgr.add_const('BTH_MFG_NEWLOGIC',0x00000017)
		win_const_mgr.add_const('ECM_FIRST',0x00001500)
		win_const_mgr.add_const('MCI_DGV_DELETE_AUDIO_STREAM',0x00020000)
		win_const_mgr.add_const('OID_GEN_CURRENT_LOOKAHEAD',0x0001010F)
		win_const_mgr.add_const('KRB_NT_PRINCIPAL',0x00000001)
		win_const_mgr.add_const('DNS_RTYPE_UNSPEC',0x00006700)
		win_const_mgr.add_const('ERROR_DS_CANT_MOD_PRIMARYGROUPID',0x0000213A)
		win_const_mgr.add_const('LINEERR_SERVICE_NOT_RUNNING',0x80000061)
		win_const_mgr.add_const('SPI_GETGRIDGRANULARITY',0x00000012)
		win_const_mgr.add_const('BG_S_PROXY_CHANGED',0x0020002A)
		win_const_mgr.add_const('NDR_CONTEXT_HANDLE_CANNOT_BE_NULL',0x00000001)
		win_const_mgr.add_const('REG_STANDARD_FORMAT',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_RECORD_DOES_NOT_EXIST',0x000025E5)
		win_const_mgr.add_const('SFF_PERSISTVIEWSCALE',0x00002000)
		win_const_mgr.add_const('DISPID_ADDFAVORITE',0x00000004)
		win_const_mgr.add_const('ENM_KEYEVENTS',0x00010000)
		win_const_mgr.add_const('COM_RIGHTS_EXECUTE_REMOTE',0x00000004)
		win_const_mgr.add_const('COMPRESSION_ENGINE_MAXIMUM',0x00000100)
		win_const_mgr.add_const('INTERNET_NO_CALLBACK',0x00000000)
		win_const_mgr.add_const('RTM_DEST_FLAG_NATURAL_NET',0x00000001)
		win_const_mgr.add_const('CBR_38400',0x00009600)
		win_const_mgr.add_const('WIA_DPC_TIMELAPSE_INTERVAL',0x00000819)
		win_const_mgr.add_const('MAPI_NOTRESERVED',0x00000008)
		win_const_mgr.add_const('SPINT_REMOVED',0x00000004)
		win_const_mgr.add_const('SV_NUMREQBUF_PARMNUM',0x000001A4)
		win_const_mgr.add_const('REG_NO_LAZY_FLUSH',0x00000004)
		win_const_mgr.add_const('SPI_SETMENUSHOWDELAY',0x0000006B)
		win_const_mgr.add_const('DEBUG_SYMENT_IS_SYNTHETIC',0x00000020)
		win_const_mgr.add_const('DISPID_CANRETREATERROR',0x0000000D)
		win_const_mgr.add_const('SECBUFFER_EMPTY',0x00000000)
		win_const_mgr.add_const('WM_CREATE',0x00000001)
		win_const_mgr.add_const('TIMERMODE_VISIBILITYAWARE',0x00000001)
		win_const_mgr.add_const('ALG_SID_TEK',0x0000000B)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME',0x00000004)
		win_const_mgr.add_const('MPEG2_FILTER_VERSION_1_SIZE',0x0000007C)
		win_const_mgr.add_const('TMT_FONT',0x000000D2)
		win_const_mgr.add_const('OID_TAPI_GET_ID',0x07030113)
		win_const_mgr.add_const('SB_RIGHT',0x00000007)
		win_const_mgr.add_const('WPC_SETTINGS_LOCATE',0x00000014)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_CAN_REVERSE',0x00004004)
		win_const_mgr.add_const('WMDM_SCP_EXAMINE_DATA',0x00000002)
		win_const_mgr.add_const('ES_SAVESEL',0x00008000)
		win_const_mgr.add_const('UINT_PTR_MAX',0x00000000)
		win_const_mgr.add_const('IDC_CV_CONVERTTO',0x0000009B)
		win_const_mgr.add_const('DVB_RST_TID',0x00000071)
		win_const_mgr.add_const('SQL_KEYSET_CURSOR_ATTRIBUTES1',0x00000096)
		win_const_mgr.add_const('SQL_KEYSET_CURSOR_ATTRIBUTES2',0x00000097)
		win_const_mgr.add_const('CERT_ID_ISSUER_SERIAL_NUMBER',0x00000001)
		win_const_mgr.add_const('AE_GENERIC_TYPE',0x00000015)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_MAX_CUSTOM',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_MIPS_SECREL',0x0000000B)
		win_const_mgr.add_const('CR_INVALID_NODELIST',0x00000009)
		win_const_mgr.add_const('PSINJECT_DOCNEEDEDRES',0x00000005)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_PROCESSOR',0x00000008)
		win_const_mgr.add_const('MAPI_SIMPLE_STORE_TEMPORARY',0x00000002)
		win_const_mgr.add_const('DOT11_STATUS_UNAVAILABLE_PRIORITY',0x00000010)
		win_const_mgr.add_const('PORT_RLOGIN',0x00000201)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_RESOLVED',0x00000002)
		win_const_mgr.add_const('LGRPID_CENTRAL_EUROPE',0x00000002)
		win_const_mgr.add_const('PXE_TRACE_VERBOSE',0x00010000)
		win_const_mgr.add_const('INTERNET_OPTION_VERSION',0x00000028)
		win_const_mgr.add_const('WTS_SESSION_REMOTE_CONTROL',0x00000009)
		win_const_mgr.add_const('DBT_CONFIGMGPRIVATE',0x00007FFF)
		win_const_mgr.add_const('LANG_MOHAWK',0x00000007)
		win_const_mgr.add_const('CACHE_HEADER_DATA_COOKIE_CHANGE_COUNT',0x00000002)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_CHECK_CONSTRAINTS',0x00000003)
		win_const_mgr.add_const('URLMON_OPTION_USERAGENT_REFRESH',0x10000002)
		win_const_mgr.add_const('WKSTA_SESSTIMEOUT_PARMNUM',0x00000012)
		win_const_mgr.add_const('FAPPCOMMAND_MASK',0x0000F000)
		win_const_mgr.add_const('OID_FDDI_MAC_DUP_ADDRESS_TEST',0x03030229)
		win_const_mgr.add_const('META_POLYPOLYGON',0x00000538)
		win_const_mgr.add_const('MAPIFORM_CPU_AXP',0x00000003)
		win_const_mgr.add_const('ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED',0x000020ED)
		win_const_mgr.add_const('CM_REMOVE_NO_RESTART',0x00000002)
		win_const_mgr.add_const('ERROR_SERVER_NOT_DISABLED',0x0000053E)
		win_const_mgr.add_const('APPCOMMAND_SPELL_CHECK',0x0000002A)
		win_const_mgr.add_const('SETUP_DENIED_FLAG',0x00000020)
		win_const_mgr.add_const('LINEQUEUESTATUS_QUEUEREMOVED',0x00000004)
		win_const_mgr.add_const('SS_SIMPLE',0x0000000B)
		win_const_mgr.add_const('IPV6_MULTICAST_IF',0x00000009)
		win_const_mgr.add_const('ERROR_DS_CROSS_REF_BUSY',0x0000219A)
		win_const_mgr.add_const('MD_CERT_CHECK_REVOCATION_FRESHNESS_TIME',0x00000004)
		win_const_mgr.add_const('SQL_SR_CASCADE',0x00000020)
		win_const_mgr.add_const('SYMOPT_NO_UNQUALIFIED_LOADS',0x00000100)
		win_const_mgr.add_const('CACHEGROUP_FLAG_GIDONLY',0x00000004)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_RAW_DATA',0x00010000)
		win_const_mgr.add_const('CERT_DISPWELL_TRUST_ADD_CA_CERT',0x00000004)
		win_const_mgr.add_const('ERROR_CLUSTER_POISONED',0x00001713)
		win_const_mgr.add_const('DXVA_USUAL_BLOCK_WIDTH',0x00000008)
		win_const_mgr.add_const('CS_IME',0x00010000)
		win_const_mgr.add_const('SE_OWNER_DEFAULTED',0x00000001)
		win_const_mgr.add_const('DNOBJECT_MAIL11',0x0000001B)
		win_const_mgr.add_const('TRANSACTION_ENLIST',0x00000004)
		win_const_mgr.add_const('BG_E_RECORD_DELETED',0x80200042)
		win_const_mgr.add_const('D3DSP_WRITEMASK_ALL',0x000F0000)
		win_const_mgr.add_const('IF_TYPE_ROUTER_WORKSTATION_DIALOUT',0x00000007)
		win_const_mgr.add_const('CLUSCTL_OBJECT_MASK',0x000000FF)
		win_const_mgr.add_const('CF_ENABLETEMPLATE',0x00000010)
		win_const_mgr.add_const('OBM_UPARROWI',0x00007FE1)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_FLAG_INVALID_CA',0x00000008)
		win_const_mgr.add_const('LINECALLREASON_UNKNOWN',0x00000400)
		win_const_mgr.add_const('PERF_TYPE_NUMBER',0x00000000)
		win_const_mgr.add_const('IME_GETOPEN',0x00000005)
		win_const_mgr.add_const('TPM_NOANIMATION',0x00004000)
		win_const_mgr.add_const('LINEREMOVEFROMCONF_LAST',0x00000002)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_CROSS_FADE',0x0000000D)
		win_const_mgr.add_const('SQL_ROW_ADDED',0x00000004)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_DISASSOCIATED_BY_OS',0x00000007)
		win_const_mgr.add_const('RTCEF_ROAMING',0x00010000)
		win_const_mgr.add_const('MCI_SET_VIDEO',0x00001000)
		win_const_mgr.add_const('NRB_INPUT_DATA_OVERRUN',0x00000003)
		win_const_mgr.add_const('DDCAPS2_NOPAGELOCKREQUIRED',0x00000800)
		win_const_mgr.add_const('SO_DISCOPT',0x00007003)
		win_const_mgr.add_const('ECO_SAVESEL',0x00008000)
		win_const_mgr.add_const('WINHTTP_FLAG_SECURE_PROTOCOL_TLS1',0x00000080)
		win_const_mgr.add_const('EC_STREAM_CONTROL_STARTED',0x0000001B)
		win_const_mgr.add_const('LAP_LIAC_VALUE',0x009E8B00)
		win_const_mgr.add_const('DICS_ENABLE',0x00000001)
		win_const_mgr.add_const('DS_FORCE_REDISCOVERY',0x00000001)
		win_const_mgr.add_const('PDH_INVALID_INSTANCE',0xC0000BC5)
		win_const_mgr.add_const('LOCALSTATE_POLICYREMOVE_UNINSTALL',0x00000010)
		win_const_mgr.add_const('SERVICE_STOP_PENDING',0x00000003)
		win_const_mgr.add_const('PS_JOIN_BEVEL',0x00001000)
		win_const_mgr.add_const('MFE_PRUNED_UPSTREAM',0x00000004)
		win_const_mgr.add_const('TMT_BTNTEXT',0x00000653)
		win_const_mgr.add_const('VK_F9',0x00000078)
		win_const_mgr.add_const('VK_F8',0x00000077)
		win_const_mgr.add_const('CDB2N_CONTEXTMENU_DONE',0x00000001)
		win_const_mgr.add_const('WIA_DIP_FIRST',0x00000002)
		win_const_mgr.add_const('EXECUTE_FLAG_NO_HEADERS',0x00000001)
		win_const_mgr.add_const('VK_F2',0x00000071)
		win_const_mgr.add_const('VK_F1',0x00000070)
		win_const_mgr.add_const('VK_F7',0x00000076)
		win_const_mgr.add_const('IT_STATUS_MASK',0x00000007)
		win_const_mgr.add_const('VK_F5',0x00000074)
		win_const_mgr.add_const('VK_F4',0x00000073)
		win_const_mgr.add_const('TBSTATE_WRAP',0x00000020)
		win_const_mgr.add_const('MAPI_SUBMITTED',0x80000000)
		win_const_mgr.add_const('PDH_FMT_NODATA',0x00004000)
		win_const_mgr.add_const('WPSTYLE_CENTER',0x00000000)
		win_const_mgr.add_const('QOS_OBJECT_TRAFFIC_CLASS',0x00000002)
		win_const_mgr.add_const('RPC_C_OPT_MQ_DELIVERY',0x00000001)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_INPUT',0x02000000)
		win_const_mgr.add_const('STI_TRACE_WARNING',0x00000002)
		win_const_mgr.add_const('LVFI_SUBSTRING',0x00000004)
		win_const_mgr.add_const('REG_MUI_STRING_TRUNCATE',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_OA_ATROWRELEASE',0x00000004)
		win_const_mgr.add_const('PCF_PARITY_CHECK',0x00000008)
		win_const_mgr.add_const('FD_OOB',0x00000001)
		win_const_mgr.add_const('CQPM_GETPARAMETERS',0x00000005)
		win_const_mgr.add_const('COLOR_BLUEACCEL',0x000002D8)
		win_const_mgr.add_const('DNS_ERROR_NO_CREATE_CACHE_DATA',0x000025F1)
		win_const_mgr.add_const('INTERNET_OPTION_LISTEN_TIMEOUT',0x0000000B)
		win_const_mgr.add_const('AA_A_OWNER',0x00000004)
		win_const_mgr.add_const('MAX_SITENAME_LEN',0x00000080)
		win_const_mgr.add_const('SQL_FN_STR_CHAR_LENGTH',0x00100000)
		win_const_mgr.add_const('CSURL_ADDTOIDP',0x00000080)
		win_const_mgr.add_const('FILE_NAMED_STREAMS',0x00040000)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_RESPONSE_HTTP',0x00000001)
		win_const_mgr.add_const('ERROR_PRINTER_DRIVER_WARNED',0x00000BC5)
		win_const_mgr.add_const('KSAC3_SERVICE_DIALOG_ONLY',0x00000004)
		win_const_mgr.add_const('VS_USER_DEFINED',0x00000064)
		win_const_mgr.add_const('BACKUP_RECOVERY',0x0000000E)
		win_const_mgr.add_const('RPC_C_QOS_CAPABILITIES_DEFAULT',0x00000000)
		win_const_mgr.add_const('SECBUFFER_STREAM_TRAILER',0x00000006)
		win_const_mgr.add_const('UOI_HEAPSIZE',0x00000005)
		win_const_mgr.add_const('WLAN_AVAILABLE_NETWORK_CONSOLE_USER_PROFILE',0x00000004)
		win_const_mgr.add_const('COD_COMPUTER_MINOR_HANDHELD',0x00000004)
		win_const_mgr.add_const('REG_CREATED_NEW_KEY',0x00000001)
		win_const_mgr.add_const('CHANNEL_NAME_LEN',0x00000007)
		win_const_mgr.add_const('DATA_S_LAST',0x0004013F)
		win_const_mgr.add_const('ERROR_EVT_FILTER_UNEXPECTEDTOKEN',0x00003AAD)
		win_const_mgr.add_const('SQL_DD_CASCADE',0x00000004)
		win_const_mgr.add_const('OFN_NOCHANGEDIR',0x00000008)
		win_const_mgr.add_const('OCR_SIZENESW',0x00007F83)
		win_const_mgr.add_const('KP_KEYLEN',0x00000009)
		win_const_mgr.add_const('FLAGS_ERROR_UI_FLAGS_GENERATE_DATA',0x00000004)
		win_const_mgr.add_const('WLAN_UI_API_VERSION',0x00000001)
		win_const_mgr.add_const('REPL_INTEGRITY_FILE',0x00000001)
		win_const_mgr.add_const('ACM_METRIC_MAX_SIZE_FILTER',0x00000033)
		win_const_mgr.add_const('LVS_EX_TRACKSELECT',0x00000008)
		win_const_mgr.add_const('MAPI_ERROR_VERSION',0x00000000)
		win_const_mgr.add_const('CERT_CASE_INSENSITIVE_IS_RDN_ATTRS_FLAG',0x00000002)
		win_const_mgr.add_const('OIC_SHIELD',0x00007F06)
		win_const_mgr.add_const('WIA_DIP_PORT_NAME',0x00000006)
		win_const_mgr.add_const('RPC_S_ALREADY_LISTENING',0x000006B1)
		win_const_mgr.add_const('PERF_TEXT_UNICODE',0x00000000)
		win_const_mgr.add_const('ERROR_FILENAME_EXCED_RANGE',0x000000CE)
		win_const_mgr.add_const('WIA_DPC_EXPOSURE_TIME',0x00000806)
		win_const_mgr.add_const('ODS_SELECTED',0x00000001)
		win_const_mgr.add_const('IDTB_HISTORY',0x000000D8)
		win_const_mgr.add_const('SQL_ISV_CHECK_CONSTRAINTS',0x00000004)
		win_const_mgr.add_const('FILE_SEQUENTIAL_WRITE_ONCE',0x00100000)
		win_const_mgr.add_const('CTRY_IRELAND',0x00000161)
		win_const_mgr.add_const('WIA_PROP_WRITE',0x00000002)
		win_const_mgr.add_const('ILR_SCALE_ASPECTRATIO',0x00000100)
		win_const_mgr.add_const('MMIOM_USER',0x00008000)
		win_const_mgr.add_const('DTBG_NOMIRROR',0x00000040)
		win_const_mgr.add_const('KS_NABTS_GROUPID_MICROSOFT_RESERVED_TEST_DATA_BASE',0x000008F0)
		win_const_mgr.add_const('PAN_WEIGHT_VERY_LIGHT',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_ENABLE_PASSPORT_AUTH',0x0000005A)
		win_const_mgr.add_const('DDLOCK_EVENT',0x00000002)
		win_const_mgr.add_const('ERROR_TRUST_FAILURE',0x000006FE)
		win_const_mgr.add_const('GETEXTENTTABLE',0x00000101)
		win_const_mgr.add_const('MCI_DGV_WINDOW_HWND',0x00010000)
		win_const_mgr.add_const('ERROR_LOG_READ_MODE_INVALID',0x000019D2)
		win_const_mgr.add_const('EM_CHARFROMPOS',0x000000D7)
		win_const_mgr.add_const('ERROR_SXS_CANT_GEN_ACTCTX',0x000036B1)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_REQUESTEDWRITESPEED',0x00000111)
		win_const_mgr.add_const('TIMECOLLECTION_RESERVED_OFFSET',0x00000700)
		win_const_mgr.add_const('PHONESTATE_HEADSETHOOKSWITCH',0x00008000)
		win_const_mgr.add_const('BTH_MFG_WIDCOMM',0x00000011)
		win_const_mgr.add_const('CM_DEVCAP_HARDWAREDISABLED',0x00000100)
		win_const_mgr.add_const('WM_SYSKEYDOWN',0x00000104)
		win_const_mgr.add_const('OID_PNP_QUERY_POWER',0xFD010102)
		win_const_mgr.add_const('OID_FDDI_PORT_LER_CUTOFF',0x03030270)
		win_const_mgr.add_const('BG_E_CLIENT_SERVER_PROTOCOL_MISMATCH',0x80200022)
		win_const_mgr.add_const('DISPID_HTTPREQUEST_BASE',0x00000001)
		win_const_mgr.add_const('FPST_VANILLA',0x00000000)
		win_const_mgr.add_const('DEBUG_ASMOPT_NO_CODE_BYTES',0x00000002)
		win_const_mgr.add_const('NETSCAPE_SSL_SERVER_AUTH_CERT_TYPE',0x00000040)
		win_const_mgr.add_const('IMAGE_ORDINAL_FLAG32',0x80000000)
		win_const_mgr.add_const('IDS_CAP_END',0x0000012D)
		win_const_mgr.add_const('PRODUCT_STANDARD_SERVER_CORE',0x0000000D)
		win_const_mgr.add_const('LDAP_DIRSYNC_OBJECT_SECURITY',0x00000001)
		win_const_mgr.add_const('PROP_ID_INVALID',0x0000FFFF)
		win_const_mgr.add_const('GESTURE_DOWN_ARROW_RIGHT',0x00000000)
		win_const_mgr.add_const('TVE_EXPAND',0x00000002)
		win_const_mgr.add_const('NTDSSETTINGS_OPT_W2K3_BRIDGES_REQUIRED',0x00000001)
		win_const_mgr.add_const('MCI_WAVE_INPUT',0x00400000)
		win_const_mgr.add_const('ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD',0x00002189)
		win_const_mgr.add_const('PROFILE_KERNEL',0x20000000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_AUTH_ALG',0x00003632)
		win_const_mgr.add_const('IDM_MENUEXT_PLACEHOLDER',0x0000179F)
		win_const_mgr.add_const('DBPROPVAL_CD_NOTNULL',0x00000001)
		win_const_mgr.add_const('DEBUG_DATA_SPACE_MSR',0x00000004)
		win_const_mgr.add_const('DIRID_COMMON_DESKTOPDIRECTORY',0x00004019)
		win_const_mgr.add_const('MD_APPPOOL_STATE_STOPPING',0x00000003)
		win_const_mgr.add_const('LVGA_HEADER_CENTER',0x00000002)
		win_const_mgr.add_const('REQDISP_PENDINGFIRST',0x00000100)
		win_const_mgr.add_const('CMSG_SIGNER_COUNT_PARAM',0x00000005)
		win_const_mgr.add_const('EMR_POLYLINE',0x00000004)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_CURRENTWRITESPEED',0x00000113)
		win_const_mgr.add_const('ENM_SCROLLEVENTS',0x00000008)
		win_const_mgr.add_const('OLEUI_ERR_STANDARDMAX',0x00000074)
		win_const_mgr.add_const('MOVEFILE_CREATE_HARDLINK',0x00000010)
		win_const_mgr.add_const('FILE_NOTIFY_CHANGE_CREATION',0x00000040)
		win_const_mgr.add_const('CREDP_FLAGS_USE_MIDL_HEAP',0x00000002)
		win_const_mgr.add_const('SO_CONNDATA',0x00007000)
		win_const_mgr.add_const('SQL_SC_FIPS127_2_TRANSITIONAL',0x00000002)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_TYPE_NAME',0x00000001)
		win_const_mgr.add_const('AM_LOADSTATUS_LOADINGMCAST',0x00000002)
		win_const_mgr.add_const('D3DSPD_IUNKNOWN',0x00000001)
		win_const_mgr.add_const('DI_FLAGSEX_SETFAILEDINSTALL',0x00000080)
		win_const_mgr.add_const('LVS_EX_AUTOSIZECOLUMNS',0x10000000)
		win_const_mgr.add_const('DEBUG_ENGOPT_DISALLOW_NETWORK_PATHS',0x00000008)
		win_const_mgr.add_const('SPI_SETFOCUSBORDERHEIGHT',0x00002011)
		win_const_mgr.add_const('ALG_SID_MD4',0x00000002)
		win_const_mgr.add_const('HHWIN_BUTTON_BROWSE_FWD',0x00000001)
		win_const_mgr.add_const('PERF_DETAIL_EXPERT',0x0000012C)
		win_const_mgr.add_const('SQL_ATTR_METADATA_ID',0x0000271E)
		win_const_mgr.add_const('RDW_NOCHILDREN',0x00000040)
		win_const_mgr.add_const('IF_TYPE_PROP_CNLS',0x00000059)
		win_const_mgr.add_const('LDAP_RES_SEARCH_ENTRY',0x00000064)
		win_const_mgr.add_const('IME_SET_MODE',0x00000012)
		win_const_mgr.add_const('SETUP_REQUEST_FLAG',0x00000008)
		win_const_mgr.add_const('OID_GEN_CURRENT_PACKET_FILTER',0x0001010E)
		win_const_mgr.add_const('USAGE_MATCH_TYPE_AND',0x00000000)
		win_const_mgr.add_const('PHOTO_PROGRAMMODE_ACTION',0x00000006)
		win_const_mgr.add_const('PWR_SUSPENDREQUEST',0x00000001)
		win_const_mgr.add_const('LINEDISCONNECTMODE_REJECT',0x00000004)
		win_const_mgr.add_const('MCI_VCR_SIGNAL_CANCEL',0x00080000)
		win_const_mgr.add_const('D3DPTEXTURECAPS_POW2',0x00000002)
		win_const_mgr.add_const('LINEADDRFEATURE_FORWARDDND',0x00002000)
		win_const_mgr.add_const('WINHTTP_OPTION_READ_BUFFER_SIZE',0x0000000C)
		win_const_mgr.add_const('ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS',0x000013BD)
		win_const_mgr.add_const('D3DSP_OPCODESPECIFICCONTROL_SHIFT',0x00000010)
		win_const_mgr.add_const('FLASHW_TRAY',0x00000002)
		win_const_mgr.add_const('SQL_SQL92_STRING_FUNCTIONS',0x000000A4)
		win_const_mgr.add_const('LDAP_OPT_FAST_CONCURRENT_BIND',0x00000041)
		win_const_mgr.add_const('SPDRP_UPPERFILTERS',0x00000011)
		win_const_mgr.add_const('D3D10_SHADER_PREFER_FLOW_CONTROL',0x00000001)
		win_const_mgr.add_const('WIA_DPC_COPYRIGHT_INFO',0x0000082C)
		win_const_mgr.add_const('IDM_APPLYHEADING1',0x000008CF)
		win_const_mgr.add_const('DC_PRINTRATEPPM',0x0000001F)
		win_const_mgr.add_const('ERROR_DS_REMOTE_CROSSREF_OP_FAILED',0x00002199)
		win_const_mgr.add_const('ERROR_EVT_FILTER_PARSEERR',0x00003AAB)
		win_const_mgr.add_const('CACHE_ENTRY_MODIFY_DATA_FC',0x80000000)
		win_const_mgr.add_const('MOUSEEVENTF_MIDDLEDOWN',0x00000020)
		win_const_mgr.add_const('STATE_SYSTEM_CHECKED',0x00000010)
		win_const_mgr.add_const('SQL_MAX_COLUMNS_IN_SELECT',0x00000064)
		win_const_mgr.add_const('IMAGE_FILE_LINE_NUMS_STRIPPED',0x00000004)
		win_const_mgr.add_const('TR_INFO_TABLE_SIZE',0x0000000A)
		win_const_mgr.add_const('DI_COMPAT',0x00000004)
		win_const_mgr.add_const('SM_MENUDROPALIGNMENT',0x00000028)
		win_const_mgr.add_const('DS_REPDEL_REF_OK',0x00000040)
		win_const_mgr.add_const('MM_HIENGLISH',0x00000005)
		win_const_mgr.add_const('API_WRITE_DATA',0x00000004)
		win_const_mgr.add_const('SQL_SFKU_SET_NULL',0x00000008)
		win_const_mgr.add_const('ADOMD_VERSION',0x00000006)
		win_const_mgr.add_const('DIRID_LOADER',0x00000036)
		win_const_mgr.add_const('SB_GRAD_TRI',0x00000020)
		win_const_mgr.add_const('MDM_MASK_V120_SPEED',0x00000007)
		win_const_mgr.add_const('TAPIMEDIATYPE_G3FAX',0x00000020)
		win_const_mgr.add_const('SCARD_E_COMM_DATA_LOST',0x8010002F)
		win_const_mgr.add_const('SECPKG_ATTR_EAP_KEY_BLOCK',0x00000005)
		win_const_mgr.add_const('PID_INTSITE_SUBSCRIPTION',0x0000000E)
		win_const_mgr.add_const('VK_OEM_FJ_TOUROKU',0x00000094)
		win_const_mgr.add_const('OPATH_TOK_EQ',0x00000068)
		win_const_mgr.add_const('OID_GEN_HARDWARE_STATUS',0x00010102)
		win_const_mgr.add_const('MSV1_0_SUBAUTH_LOCKOUT',0x00000080)
		win_const_mgr.add_const('LGRPID_BALTIC',0x00000003)
		win_const_mgr.add_const('DEBUG_KERNEL_EXDI_DRIVER',0x00000002)
		win_const_mgr.add_const('CONFIGFLAG_FINISHINSTALL_ACTION',0x00020000)
		win_const_mgr.add_const('GET_PS_FEATURESETTING',0x00001019)
		win_const_mgr.add_const('BSF_MERGEDMENUS',0x00040000)
		win_const_mgr.add_const('PIDSI_TRACK',0x00000007)
		win_const_mgr.add_const('XINPUT_GAMEPAD_DPAD_LEFT',0x00000004)
		win_const_mgr.add_const('MPEG_PAT_PID',0x00000000)
		win_const_mgr.add_const('MNC_IGNORE',0x00000000)
		win_const_mgr.add_const('STAMP_DESIGNVECTOR',0x08000000)
		win_const_mgr.add_const('AM_DVD_CGMS_NO_COPY',0x00000018)
		win_const_mgr.add_const('MD_GLOBAL_EDIT_WHILE_RUNNING_MAJOR_VERSION_NUMBER',0x0000270A)
		win_const_mgr.add_const('MCI_ANIM_RECT',0x00010000)
		win_const_mgr.add_const('SUBLANG_PUNJABI_INDIA',0x00000001)
		win_const_mgr.add_const('VPF_SELECTRELATIVE',0x00000001)
		win_const_mgr.add_const('URLPOLICY_JAVA_LOW',0x00030000)
		win_const_mgr.add_const('DBT_CONFIGCHANGED',0x00000018)
		win_const_mgr.add_const('SECPKG_ATTR_CIPHER_INFO',0x00000064)
		win_const_mgr.add_const('CERT_VALIDITY_ISSUER_INVALID',0x00000100)
		win_const_mgr.add_const('PHONESTATUSFLAGS_SUSPENDED',0x00000002)
		win_const_mgr.add_const('WMDRM_QUERY_DEVICE_ISREVOKED',0x00000004)
		win_const_mgr.add_const('DEBUG_ECREATE_PROCESS_USE_IMPLICIT_COMMAND_LINE',0x00000004)
		win_const_mgr.add_const('SQLNUMERICN',0x00000006)
		win_const_mgr.add_const('ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE',0x000002B2)
		win_const_mgr.add_const('TTS_NOFADE',0x00000020)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_16BYTES',0x00500000)
		win_const_mgr.add_const('BS_COMMANDLINK',0x0000000E)
		win_const_mgr.add_const('FR_PROP_STATUSSTRING',0x00000005)
		win_const_mgr.add_const('CERT_COMPARE_NAME_STR_A',0x00000007)
		win_const_mgr.add_const('TAPE_DRIVE_TENSION',0x80000002)
		win_const_mgr.add_const('DDBLT_ROP',0x00020000)
		win_const_mgr.add_const('SQL_API_SQLTABLES',0x00000036)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_COM_SERVER_REDIRECTION',0x00000004)
		win_const_mgr.add_const('WINHTTP_QUERY_ACCEPT_CHARSET',0x00000019)
		win_const_mgr.add_const('DISPID_SNAPTOGRIDY',0x00000014)
		win_const_mgr.add_const('DISPID_SNAPTOGRIDX',0x00000013)
		win_const_mgr.add_const('DFCS_MENUARROWRIGHT',0x00000004)
		win_const_mgr.add_const('MAX_FOREST_TRUST_BINARY_DATA_SIZE',0x00000080)
		win_const_mgr.add_const('SPQ_SCAN_USE_CALLBACK',0x00000004)
		win_const_mgr.add_const('SUBLANG_GALICIAN_GALICIAN',0x00000001)
		win_const_mgr.add_const('PHONELAMPMODE_WINK',0x00000008)
		win_const_mgr.add_const('DBPROPVAL_FU_COLUMN',0x00000002)
		win_const_mgr.add_const('CERT_COMPARE_NAME_STR_W',0x00000008)
		win_const_mgr.add_const('IMN_CLOSESTATUSWINDOW',0x00000001)
		win_const_mgr.add_const('CERT_V3',0x00000002)
		win_const_mgr.add_const('AMDDS_RGBOFF',0x00000010)
		win_const_mgr.add_const('WAB_LOCAL_CONTAINERS',0x00100000)
		win_const_mgr.add_const('SHCIDS_COLUMNMASK',0x0000FFFF)
		win_const_mgr.add_const('RTL_ENCRYPT_OPTION_SAME_LOGON',0x00000002)
		win_const_mgr.add_const('MD_ASP_SERVICE_USE_PARTITION',0x00000004)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_SH3E',0x00000001)
		win_const_mgr.add_const('SUBLANG_NORWEGIAN_BOKMAL',0x00000001)
		win_const_mgr.add_const('CF_NOSIMULATIONS',0x00001000)
		win_const_mgr.add_const('DESKTOP_SETTING',0x00000002)
		win_const_mgr.add_const('EVENT_SYSTEM_DRAGDROPEND',0x0000000F)
		win_const_mgr.add_const('FILE_FLAG_OPEN_NO_RECALL',0x00100000)
		win_const_mgr.add_const('SQL_AT_DROP_COLUMN_RESTRICT',0x00000800)
		win_const_mgr.add_const('SQL_BCP_ON',0x00000001)
		win_const_mgr.add_const('DNF_OLDDRIVER',0x00000002)
		win_const_mgr.add_const('TF_DISCONNECT',0x00000001)
		win_const_mgr.add_const('HHWIN_PARAM_STYLES',0x00000001)
		win_const_mgr.add_const('PKR_V',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_PT_GUID',0x00000008)
		win_const_mgr.add_const('SERVICE_RESRV_MASK',0x0001FFFF)
		win_const_mgr.add_const('NRC_INCOMP',0x00000006)
		win_const_mgr.add_const('ERROR_FAILED_SERVICE_CONTROLLER_CONNECT',0x00000427)
		win_const_mgr.add_const('SQL_CVT_VARCHAR',0x00000100)
		win_const_mgr.add_const('IDS_CAP_STAT_OVERLAY_MODE',0x000001F5)
		win_const_mgr.add_const('IDS_CAP_RECORDING_ERROR2',0x000001B0)
		win_const_mgr.add_const('MWMO_ALERTABLE',0x00000002)
		win_const_mgr.add_const('MCI_WAVE_OPEN_BUFFER',0x00010000)
		win_const_mgr.add_const('SHDID_NET_RESTOFNET',0x00000010)
		win_const_mgr.add_const('OID_802_11_BSSID_LIST_SCAN',0x0D01011A)
		win_const_mgr.add_const('SQL_FETCH_PRIOR',0x00000004)
		win_const_mgr.add_const('CF_LOCALE',0x00000010)
		win_const_mgr.add_const('WM_IME_SELECT',0x00000285)
		win_const_mgr.add_const('INTERNET_CUSTOMDIAL_UNATTENDED',0x00000001)
		win_const_mgr.add_const('_DPNH_FACILITY_CODE',0x00000015)
		win_const_mgr.add_const('CAL_SMONTHNAME1',0x00000015)
		win_const_mgr.add_const('IMAGE_REL_PPC_SECRELLO',0x00000013)
		win_const_mgr.add_const('TASKSTATUS_COMPLETE',0x00000002)
		win_const_mgr.add_const('PO_THROTTLE_NONE',0x00000000)
		win_const_mgr.add_const('MAX_STRING_LENGTH',0x00000100)
		win_const_mgr.add_const('GUI_INMENUMODE',0x00000004)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2EVENTARGS_SECTORCOUNT',0x00000101)
		win_const_mgr.add_const('IDNO',0x00000007)
		win_const_mgr.add_const('DT_TABSTOP',0x00000080)
		win_const_mgr.add_const('CHANGER_TO_IEPORT',0x00000004)
		win_const_mgr.add_const('CURRENT_TCI_VERSION',0x00000002)
		win_const_mgr.add_const('DISPLAYDIB_NOWAIT',0x00000040)
		win_const_mgr.add_const('WIA_COMPRESSION_JPEG',0x00000005)
		win_const_mgr.add_const('VK_LAUNCH_APP1',0x000000B6)
		win_const_mgr.add_const('PCF_SETXCHAR',0x00000020)
		win_const_mgr.add_const('VK_LAUNCH_APP2',0x000000B7)
		win_const_mgr.add_const('SQL_SR_USAGE_ON_DOMAIN',0x00000001)
		win_const_mgr.add_const('PROC_THREAD_ATTRIBUTE_NUMBER',0x0000FFFF)
		win_const_mgr.add_const('WAB_IGNORE_PROFILES',0x00800000)
		win_const_mgr.add_const('GIL_FORSHELL',0x00000002)
		win_const_mgr.add_const('RPC_S_PRF_ELT_NOT_ADDED',0x00000786)
		win_const_mgr.add_const('VER_DDK_PRODUCTVERSION',0x00000006)
		win_const_mgr.add_const('IDM_SIZETOFIT',0x00000026)
		win_const_mgr.add_const('ERROR_DS_NON_ASQ_SEARCH',0x000021B0)
		win_const_mgr.add_const('CRYPT_TXT_LEN',0x00000008)
		win_const_mgr.add_const('IMAGE_ENHMETAFILE',0x00000003)
		win_const_mgr.add_const('SI_VIEW_ONLY',0x00400000)
		win_const_mgr.add_const('BG_E_INVALID_AUTH_SCHEME',0x80200028)
		win_const_mgr.add_const('PFD_SUPPORT_OPENGL',0x00000020)
		win_const_mgr.add_const('REAL_EPSILON',0x00000001)
		win_const_mgr.add_const('PROP_VERSION',0x00000008)
		win_const_mgr.add_const('LINEREMOVEFROMCONF_ANY',0x00000003)
		win_const_mgr.add_const('DBT_DEVTYP_DEVICEINTERFACE',0x00000005)
		win_const_mgr.add_const('WINHTTP_OPTION_CONNECT_RETRIES',0x00000004)
		win_const_mgr.add_const('SVAUD_RESOURCE',0x00008000)
		win_const_mgr.add_const('PKCS12_IMPORT_RESERVED_MASK',0x00000000)
		win_const_mgr.add_const('HTMENU',0x00000005)
		win_const_mgr.add_const('LMEM_MOVEABLE',0x00000002)
		win_const_mgr.add_const('PANE_PROGRESS',0x00000006)
		win_const_mgr.add_const('IKEEXT_CERT_FLAG_ENABLE_ACCOUNT_MAPPING',0x00000001)
		win_const_mgr.add_const('MCI_ON',0x00000001)
		win_const_mgr.add_const('MAPI_BCC',0x00000003)
		win_const_mgr.add_const('SQL_AT_SET_COLUMN_DEFAULT',0x00000100)
		win_const_mgr.add_const('IF_TYPE_INTERNAL',0x00000005)
		win_const_mgr.add_const('IDM_INSINPUTHIDDEN',0x00000908)
		win_const_mgr.add_const('SQL_CONVERT_NUMERIC',0x0000003F)
		win_const_mgr.add_const('PST_PARALLELPORT',0x00000002)
		win_const_mgr.add_const('DISPID_RUNONCESHOWN',0x0000000F)
		win_const_mgr.add_const('DNS_ERROR_RCODE_FORMAT_ERROR',0x00002329)
		win_const_mgr.add_const('CMSG_TYPE_PARAM',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_RANGE',0x0000003E)
		win_const_mgr.add_const('ERROR_INVALID_ACL',0x00000538)
		win_const_mgr.add_const('DISPID_UNSELECTALL',0x0000001A)
		win_const_mgr.add_const('IME_RS_NEST',0x00000012)
		win_const_mgr.add_const('LINEERR_INVALADDRESS',0x80000010)
		win_const_mgr.add_const('DDCAPS2_STEREO',0x02000000)
		win_const_mgr.add_const('META_ELLIPSE',0x00000418)
		win_const_mgr.add_const('DEBUG_CMDEX_RESET_EVENT_STRINGS',0x00000002)
		win_const_mgr.add_const('SHGFI_EXETYPE',0x00002000)
		win_const_mgr.add_const('CONTEXT_IA64',0x00080000)
		win_const_mgr.add_const('KP_SIGNATURE_PIN',0x00000021)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_LSOV1_ENABLED',0x00000002)
		win_const_mgr.add_const('PD_RESULT_CANCEL',0x00000000)
		win_const_mgr.add_const('ERROR_CANNOT_MAKE',0x00000052)
		win_const_mgr.add_const('PNRP_MAX_EXTENDED_PAYLOAD_BYTES',0x00001000)
		win_const_mgr.add_const('DMPAPER_A5_EXTRA',0x00000040)
		win_const_mgr.add_const('PORT_WEBSTER',0x000002FD)
		win_const_mgr.add_const('DS_ONLY_LDAP_NEEDED',0x00008000)
		win_const_mgr.add_const('ISFB_STATE_CHANNELBAR',0x00000010)
		win_const_mgr.add_const('KP_ALGID',0x00000007)
		win_const_mgr.add_const('PHOTO_WHITEBALANCE_MANUAL',0x00000001)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_IS_WILDCARD_BIND',0x00000008)
		win_const_mgr.add_const('SQL_FN_STR_SUBSTRING',0x00000800)
		win_const_mgr.add_const('SO_COMPARTMENT_ID',0x00003004)
		win_const_mgr.add_const('RPC_C_AUTHN_GSS_KERBEROS',0x00000010)
		win_const_mgr.add_const('MSI_INVALID_HASH_IS_FATAL',0x00000001)
		win_const_mgr.add_const('ERROR_UNEXPECTED_MM_MAP_ERROR',0x0000022D)
		win_const_mgr.add_const('MD_EXTLOG_TIME_TAKEN',0x00004000)
		win_const_mgr.add_const('NIIF_WARNING',0x00000002)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_CURRENTPROFILES',0x0000020B)
		win_const_mgr.add_const('HC_SYSMODALON',0x00000004)
		win_const_mgr.add_const('PT8',0x00008000)
		win_const_mgr.add_const('PT7',0x00004000)
		win_const_mgr.add_const('PT6',0x00002000)
		win_const_mgr.add_const('DB_BINDFLAGS_DELAYFETCHSTREAM',0x00000002)
		win_const_mgr.add_const('PT4',0x00000800)
		win_const_mgr.add_const('PT3',0x00000400)
		win_const_mgr.add_const('PT2',0x00000200)
		win_const_mgr.add_const('PT1',0x00000100)
		win_const_mgr.add_const('PT0',0x00000040)
		win_const_mgr.add_const('POLICY_VIEW_LOCAL_INFORMATION',0x00000001)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_PAGES_PRINTED',0x00000015)
		win_const_mgr.add_const('MF_MOUSESELECT',0x00008000)
		win_const_mgr.add_const('SCARD_PROTOCOL_T0',0x00000001)
		win_const_mgr.add_const('FS_FATAL_ERROR',0x20000800)
		win_const_mgr.add_const('TXTLOG_ERROR',0x00000001)
		win_const_mgr.add_const('PS_STYLE_MASK',0x0000000F)
		win_const_mgr.add_const('MDM_ANALOG_V34',0x00000002)
		win_const_mgr.add_const('MAPI_SUPPRESS_ATTACH',0x00000800)
		win_const_mgr.add_const('SV_SESSCONNS_PARMNUM',0x000001FF)
		win_const_mgr.add_const('WKSTA_KEEPCONN_PARMNUM',0x0000000D)
		win_const_mgr.add_const('VOS__WINDOWS32',0x00000004)
		win_const_mgr.add_const('LVCF_DEFAULTWIDTH',0x00000080)
		win_const_mgr.add_const('VER_SUITE_SECURITY_APPLIANCE',0x00001000)
		win_const_mgr.add_const('RPC_C_AUTHN_LEVEL_NONE',0x00000001)
		win_const_mgr.add_const('CPL_GETCOUNT',0x00000002)
		win_const_mgr.add_const('IDM_PARSECOMPLETE',0x0000090B)
		win_const_mgr.add_const('EMR_CREATEDIBPATTERNBRUSHPT',0x0000005E)
		win_const_mgr.add_const('TCM_FIRST',0x00001300)
		win_const_mgr.add_const('QIF_CACHED',0x00000001)
		win_const_mgr.add_const('OID_GEN_BROADCAST_FRAMES_XMIT',0x00020206)
		win_const_mgr.add_const('SUBLANG_MALAY_MALAYSIA',0x00000001)
		win_const_mgr.add_const('CRYPTPROTECT_LAST_RESERVED_FLAGVAL',0xFFFFFFFF)
		win_const_mgr.add_const('IPX_DIALED_LINK',0x00000002)
		win_const_mgr.add_const('LDAP_SEARCH_CMD',0x00000063)
		win_const_mgr.add_const('DEBUG_GSEL_DEFAULT',0x00000000)
		win_const_mgr.add_const('SQL_IK_DESC',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_XML_E_COMMENTSYNTAX',0x000036CF)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_PATH',0x0000000C)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_PREPAREMEDIA',0x00000200)
		win_const_mgr.add_const('DEX_IDS_INTERFACE_ERROR',0x00000595)
		win_const_mgr.add_const('IPXWAN_INTERFACE_INFO_TYPE',0x00000008)
		win_const_mgr.add_const('SQL_AD_ADD_CONSTRAINT_DEFERRABLE',0x00000080)
		win_const_mgr.add_const('RTCEF_MEDIA_REQUEST',0x00004000)
		win_const_mgr.add_const('LB_RESETCONTENT',0x00000184)
		win_const_mgr.add_const('HDIS_FOCUSED',0x00000001)
		win_const_mgr.add_const('FDTF_LONGTIME',0x00000008)
		win_const_mgr.add_const('SOCK_RAW',0x00000003)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_SCROLLBY',0x0000048F)
		win_const_mgr.add_const('SO_UPDATE_CONNECT_CONTEXT',0x00007010)
		win_const_mgr.add_const('IP_ADAPTER_RECEIVE_ONLY',0x00000008)
		win_const_mgr.add_const('LINEFEATURE_DEVSPECIFIC',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2ERASEEVENTS_UPDATE',0x00000200)
		win_const_mgr.add_const('CTRY_ICELAND',0x00000162)
		win_const_mgr.add_const('WIA_PROP_FLAG',0x00000040)
		win_const_mgr.add_const('IME_RS_INVALID',0x00000011)
		win_const_mgr.add_const('SO_BSP_STATE',0x00001009)
		win_const_mgr.add_const('PROTO_IP_MSDP',0x00000009)
		win_const_mgr.add_const('PDH_NO_COUNTERS',0xC0000BDF)
		win_const_mgr.add_const('SDP_ERROR_INVALID_REQUEST_SYNTAX',0x00000003)
		win_const_mgr.add_const('TMT_FILLCOLOR',0x00000EDA)
		win_const_mgr.add_const('ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS',0x0000200D)
		win_const_mgr.add_const('JIFMK_00',0x0000FF00)
		win_const_mgr.add_const('CLFS_FLAG_FORCE_FLUSH',0x00000002)
		win_const_mgr.add_const('IME_CONFIG_SELECTDICTIONARY',0x00000003)
		win_const_mgr.add_const('THEMEMGR_VERSION',0x00000001)
		win_const_mgr.add_const('KS_VIDEOSTREAM_IS_VPE',0x00008000)
		win_const_mgr.add_const('CTRY_UZBEKISTAN',0x00000007)
		win_const_mgr.add_const('DS_REPSYNC_PARTIAL_ATTRIBUTE_SET',0x00020000)
		win_const_mgr.add_const('RPC_S_PRF_ELT_NOT_REMOVED',0x00000787)
		win_const_mgr.add_const('DEBUG_ENGOPT_FINAL_BREAK',0x00000080)
		win_const_mgr.add_const('DNS_RTYPE_EID',0x00000001)
		win_const_mgr.add_const('VP_FLAGS_OVERSCAN',0x00000008)
		win_const_mgr.add_const('SCH_CRED_V1',0x00000001)
		win_const_mgr.add_const('LCPRI_LASTBESTCONFIG',0x00003FFF)
		win_const_mgr.add_const('SPMODE_PERFTAGS',0x00000800)
		win_const_mgr.add_const('SCH_CRED_V2',0x00000002)
		win_const_mgr.add_const('SUBLANG_SAMI_INARI_FINLAND',0x00000009)
		win_const_mgr.add_const('COMP_ELEM_SUBSCRIBEDURL',0x00000800)
		win_const_mgr.add_const('IPSEC_CIPHER_CONFIG_CBC_AES_256',0x00000005)
		win_const_mgr.add_const('CMSG_ENVELOPED_RECIPIENT_V3',0x00000003)
		win_const_mgr.add_const('CMSG_ENVELOPED_RECIPIENT_V2',0x00000002)
		win_const_mgr.add_const('CMSG_ENVELOPED_RECIPIENT_V0',0x00000000)
		win_const_mgr.add_const('TASKSTATUS_INPROGRESS',0x00000001)
		win_const_mgr.add_const('MCI_VD_STATUS_SIDE',0x00004005)
		win_const_mgr.add_const('MM_MIM_MOREDATA',0x000003CC)
		win_const_mgr.add_const('NUMPRS_TRAILING_MINUS',0x00000020)
		win_const_mgr.add_const('DBPROPVAL_STGM_DELETEONRELEASE',0x00200000)
		win_const_mgr.add_const('WLX_CONSOLESWITCHCREDENTIAL_TYPE_V1_0',0x00000001)
		win_const_mgr.add_const('ERROR_LUIDS_EXHAUSTED',0x00000536)
		win_const_mgr.add_const('HHWIN_PARAM_TABORDER',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_DATAFILE_NAME',0x00000021)
		win_const_mgr.add_const('GESTURE_BULLET',0x00000000)
		win_const_mgr.add_const('DNS_RTYPE_UID',0x00006500)
		win_const_mgr.add_const('AE_GENERAL',0x00000000)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_RESERVED',0x000000AB)
		win_const_mgr.add_const('JOB_OBJECT_MSG_JOB_MEMORY_LIMIT',0x0000000A)
		win_const_mgr.add_const('CAUSE_MANDATORY_IE_MISSING',0x00000060)
		win_const_mgr.add_const('DICS_STOP',0x00000005)
		win_const_mgr.add_const('SW_SHOWNA',0x00000008)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_CPU',0x0000000A)
		win_const_mgr.add_const('RF_BOXED_INPUT',0x00000010)
		win_const_mgr.add_const('CRYPTPROTECT_VERIFY_PROTECTION',0x00000040)
		win_const_mgr.add_const('RQ_PRE_EXECUTE_REQUEST_HANDLER',0x00000040)
		win_const_mgr.add_const('ARW_STARTRIGHT',0x00000001)
		win_const_mgr.add_const('OID_FDDI_PORT_MY_TYPE',0x0303025C)
		win_const_mgr.add_const('OID_GEN_LINK_PARAMETERS',0x00010208)
		win_const_mgr.add_const('THREAD_MODE_BACKGROUND_END',0x00020000)
		win_const_mgr.add_const('PHONEBUTTONMODE_LOCAL',0x00000010)
		win_const_mgr.add_const('PFD_STEREO_DONTCARE',0x80000000)
		win_const_mgr.add_const('SNMP_ACCESS_NONE',0x00000000)
		win_const_mgr.add_const('DBG_SEGMOVE',0x00000001)
		win_const_mgr.add_const('EXTENSION_ORIGIN_POLICY',0x00020000)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_LOG_CONTAINER_COUNT_MIN',0x00000002)
		win_const_mgr.add_const('TTDT_RESHOW',0x00000001)
		win_const_mgr.add_const('IKEEXT_KERB_AUTH_DONT_ACCEPT_EXPLICIT_CREDENTIALS',0x00000002)
		win_const_mgr.add_const('ERROR_SXS_FILE_HASH_MISSING',0x0000371E)
		win_const_mgr.add_const('CM_DRP_SECURITY',0x00000018)
		win_const_mgr.add_const('D3DPMISCCAPS_BLENDOP',0x00000800)
		win_const_mgr.add_const('LINECALLPARAMFLAGS_ONESTEPTRANSFER',0x00000080)
		win_const_mgr.add_const('SERVICE_STOP_REASON_FLAG_MAX',0x80000000)
		win_const_mgr.add_const('DFS_STORAGE_STATE_OFFLINE',0x00000001)
		win_const_mgr.add_const('LINEPROXYREQUEST_SETAGENTACTIVITY',0x00000003)
		win_const_mgr.add_const('AUTHZ_NO_ALLOC_STRINGS',0x00000004)
		win_const_mgr.add_const('ERROR_DS_AUTH_METHOD_NOT_SUPPORTED',0x00002027)
		win_const_mgr.add_const('D3DPSHADECAPS_SPECULARGOURAUDRGB',0x00000200)
		win_const_mgr.add_const('CRYPT_INSTALL_OID_INFO_BEFORE_FLAG',0x00000001)
		win_const_mgr.add_const('WKSTA_USELOCKANDREADANDUNLOCK_PARMNUM',0x00000034)
		win_const_mgr.add_const('EMR_MAX',0x00000061)
		win_const_mgr.add_const('RESOURCE_REMEMBERED',0x00000003)
		win_const_mgr.add_const('FPSR_O2',0x0000002A)
		win_const_mgr.add_const('FPSR_O3',0x00000037)
		win_const_mgr.add_const('FPSR_O0',0x00000010)
		win_const_mgr.add_const('FPSR_O1',0x0000001D)
		win_const_mgr.add_const('CERT_SET_KEY_PROV_HANDLE_PROP_ID',0x00000001)
		win_const_mgr.add_const('URLACTION_SHELL_SECURE_DRAGSOURCE',0x0000180D)
		win_const_mgr.add_const('SCARD_READER_TYPE_SCSI',0x00000008)
		win_const_mgr.add_const('MD_ERROR_SUB403_PASSPORT_LOGIN_FAILURE',0x00000014)
		win_const_mgr.add_const('IP_IFLIST',0x0000001C)
		win_const_mgr.add_const('VCSTATUS_DELETE',0x00010000)
		win_const_mgr.add_const('STREAM_FORMAT_COMPLIB_MANIFEST',0x00000001)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_GRP_FLOW_COUNT',0x00000006)
		win_const_mgr.add_const('DCR_INITIAL',0x00000007)
		win_const_mgr.add_const('MD_LOGFILE_PERIOD_WEEKLY',0x00000002)
		win_const_mgr.add_const('TVS_NOHSCROLL',0x00008000)
		win_const_mgr.add_const('ERROR_PCW_BASE',0xC00E5101)
		win_const_mgr.add_const('CACHE_HEADER_DATA_GID_HIGH',0x00000007)
		win_const_mgr.add_const('ERROR_PROTOCOL_UNREACHABLE',0x000004D1)
		win_const_mgr.add_const('EVENT_OBJECT_VALUECHANGE',0x0000800E)
		win_const_mgr.add_const('BATTERY_DISCHARGING',0x00000002)
		win_const_mgr.add_const('BTH_SDP_VERSION',0x00000001)
		win_const_mgr.add_const('LDAP_COMPARE_CMD',0x00000006)
		win_const_mgr.add_const('SQL_CT_COMMIT_DELETE',0x00000004)
		win_const_mgr.add_const('TAPIERR_CONNECTED',0x00000000)
		win_const_mgr.add_const('CM_DRP_COMPATIBLEIDS',0x00000003)
		win_const_mgr.add_const('D3DVS_X_Y',0x00000001)
		win_const_mgr.add_const('D3DVS_X_X',0x00000000)
		win_const_mgr.add_const('D3DVS_X_Z',0x00000002)
		win_const_mgr.add_const('RAS_EAP_ROLE_EXCLUDE_IN_PEAP',0x00000008)
		win_const_mgr.add_const('IP_MIB_STATS_ID',0x00000001)
		win_const_mgr.add_const('D3DVS_X_W',0x00000003)
		win_const_mgr.add_const('MB_RETRYCANCEL',0x00000005)
		win_const_mgr.add_const('ERROR_INVALID_SEGDPL',0x000000C6)
		win_const_mgr.add_const('POLICY_SHOWREASONUI_NEVER',0x00000000)
		win_const_mgr.add_const('RI_KEY_BREAK',0x00000001)
		win_const_mgr.add_const('FPSR_OD',0x00000003)
		win_const_mgr.add_const('MAPI_FORCE_CREATE',0x00000001)
		win_const_mgr.add_const('OID_FDDI_MAC_RMT_STATE',0x03030249)
		win_const_mgr.add_const('BSIS_LEFTALIGN',0x00000004)
		win_const_mgr.add_const('TXTLOG_BACKUP',0x00000080)
		win_const_mgr.add_const('IDS_SENT',0x00011002)
		win_const_mgr.add_const('DCI_CAN_STRETCHYN',0x00008000)
		win_const_mgr.add_const('UINT16_ERROR',0x00000000)
		win_const_mgr.add_const('SQL_MAX_ROWS_DEFAULT',0x00000000)
		win_const_mgr.add_const('L2_NOTIFICATION_SOURCE_WLAN_SECURITY',0x00000000)
		win_const_mgr.add_const('PAN_WEIGHT_DEMI',0x00000007)
		win_const_mgr.add_const('CB_SETDROPPEDWIDTH',0x00000160)
		win_const_mgr.add_const('IDD_ACMFORMATCHOOSE_CMB_FORMATTAG',0x00000065)
		win_const_mgr.add_const('SPI_SETSCREENSAVESECURE',0x00000077)
		win_const_mgr.add_const('INDEX_GUID_UNCLASSIFIEDINK',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_MIPS_JMPADDR',0x00000003)
		win_const_mgr.add_const('HICF_ACCELERATOR',0x00000004)
		win_const_mgr.add_const('SSRVOPT_FLAT_DEFAULT_STORE',0x00020000)
		win_const_mgr.add_const('ES_NUMBER',0x00002000)
		win_const_mgr.add_const('D3DCS_PLANE0',0x00000040)
		win_const_mgr.add_const('D3DCS_PLANE1',0x00000080)
		win_const_mgr.add_const('IEIFLAG_ASPECT',0x00000004)
		win_const_mgr.add_const('D3DCS_PLANE3',0x00000200)
		win_const_mgr.add_const('D3DCS_PLANE4',0x00000400)
		win_const_mgr.add_const('OID_802_3_DELETE_MULTICAST_ADDRESS',0x01010209)
		win_const_mgr.add_const('SAFER_MAX_FRIENDLYNAME_SIZE',0x00000100)
		win_const_mgr.add_const('D3DDP_MAXTEXCOORD',0x00000008)
		win_const_mgr.add_const('LDAP_OPT_ROOTDSE_CACHE',0x00000009)
		win_const_mgr.add_const('EM_SETSEL',0x000000B1)
		win_const_mgr.add_const('DVB_ST_PID_17',0x00000011)
		win_const_mgr.add_const('DISPID_SELECTEDITEM',0x0000000F)
		win_const_mgr.add_const('DE_E_REDIRECT_TO_DIR',0x800C0015)
		win_const_mgr.add_const('KSAC3_ALTERNATE_AUDIO_2',0x00000002)
		win_const_mgr.add_const('KSAC3_ALTERNATE_AUDIO_1',0x00000001)
		win_const_mgr.add_const('SQL_AD_ADD_DOMAIN_DEFAULT',0x00000008)
		win_const_mgr.add_const('LINECALLORIGIN_UNAVAIL',0x00000020)
		win_const_mgr.add_const('WINHTTP_QUERY_PASSPORT_CONFIG',0x0000004E)
		win_const_mgr.add_const('IR_OPENCONVERT',0x00000120)
		win_const_mgr.add_const('IME_GETIMECAPS',0x00000003)
		win_const_mgr.add_const('FVSIF_CANVIEWIT',0x40000000)
		win_const_mgr.add_const('SN_SIGN_ALL_FILES',0x00000001)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_PROMISCUOUS',0x00000020)
		win_const_mgr.add_const('ERROR_SXS_THREAD_QUERIES_DISABLED',0x000036BA)
		win_const_mgr.add_const('NUMFONTS',0x00000016)
		win_const_mgr.add_const('SM_CXDLGFRAME',0x00000007)
		win_const_mgr.add_const('GCP_NUMERICSLATIN',0x04000000)
		win_const_mgr.add_const('CLUS_MODIFY',0x00000001)
		win_const_mgr.add_const('ERROR_REGISTRY_RECOVERED',0x000003F6)
		win_const_mgr.add_const('ERROR_CLUSTER_QUORUMLOG_NOT_FOUND',0x00001703)
		win_const_mgr.add_const('MF_APPEND',0x00000100)
		win_const_mgr.add_const('ERROR_ENVVAR_NOT_FOUND',0x000000CB)
		win_const_mgr.add_const('FWPM_NET_EVENT_FLAG_REMOTE_ADDR_SET',0x00000004)
		win_const_mgr.add_const('INTERNET_OPTION_EXEMPT_CONNECTION_LIMIT',0x00000059)
		win_const_mgr.add_const('OFN_ENABLESIZING',0x00800000)
		win_const_mgr.add_const('PERM_FILE_CREATE',0x00000004)
		win_const_mgr.add_const('STARTF_FORCEOFFFEEDBACK',0x00000080)
		win_const_mgr.add_const('CERT_STORE_NO_ISSUER_FLAG',0x00020000)
		win_const_mgr.add_const('GPO_SECTION_USER',0x00000001)
		win_const_mgr.add_const('DFS_STORAGE_STATE_ACTIVE',0x00000004)
		win_const_mgr.add_const('SV_TYPE_ALL',0xFFFFFFFF)
		win_const_mgr.add_const('OS_NT',0x00000001)
		win_const_mgr.add_const('MCI_VD_GETDEVCAPS_CAV',0x00020000)
		win_const_mgr.add_const('IF_TYPE_ATM',0x00000025)
		win_const_mgr.add_const('HHWIN_BUTTON_EXPAND',0x00000001)
		win_const_mgr.add_const('SV_ENABLEOPLOCKS_PARMNUM',0x00000218)
		win_const_mgr.add_const('PDH_CSTATUS_NO_INSTANCE',0x800007D1)
		win_const_mgr.add_const('MCI_AVI_STATUS_AUDIO_BREAKS',0x00008003)
		win_const_mgr.add_const('AM_AC3_SERVICE_VOICE_OVER',0x00000007)
		win_const_mgr.add_const('OQWF_HIDESEARCHUI',0x00000800)
		win_const_mgr.add_const('EWX_FORCEIFHUNG',0x00000010)
		win_const_mgr.add_const('ERROR_CALL_NOT_IMPLEMENTED',0x00000078)
		win_const_mgr.add_const('FIND_PREV',0x00000004)
		win_const_mgr.add_const('CACHEGROUP_ATTRIBUTE_GET_ALL',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_RT_APTMTTHREAD',0x00000002)
		win_const_mgr.add_const('MSIM_DISPID_ONLISTADDRESULT',0x00000E02)
		win_const_mgr.add_const('ADS_PRINTER_NOT_AVAILABLE',0x00001000)
		win_const_mgr.add_const('FCSM_CLSID',0x00000008)
		win_const_mgr.add_const('ERROR_DS_EXISTS_IN_POSS_SUP',0x000020CB)
		win_const_mgr.add_const('SNMPAPI_ENTITY_INVALID',0x00000005)
		win_const_mgr.add_const('SNMP_MGMTAPI_TRAP_ERRORS',0x0000002A)
		win_const_mgr.add_const('TIMEMEDIAELEMENT2_OFFSET',0x00001400)
		win_const_mgr.add_const('SQL_DIAG_SUBCLASS_ORIGIN',0x00000009)
		win_const_mgr.add_const('WTS_REMOTE_CONNECT',0x00000003)
		win_const_mgr.add_const('PROV_DSS_DH',0x0000000D)
		win_const_mgr.add_const('OID_TAPI_GET_EXTENSION_ID',0x07030112)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_FUNCTIONAL',0x00004000)
		win_const_mgr.add_const('INF_STYLE_CACHE_DISABLE',0x00000020)
		win_const_mgr.add_const('LBS_NODATA',0x00002000)
		win_const_mgr.add_const('COLOR_HOTLIGHT',0x0000001A)
		win_const_mgr.add_const('CERT_STORE_CTRL_COMMIT_CLEAR_FLAG',0x00000002)
		win_const_mgr.add_const('SERVICE_SERVICE',0x00000002)
		win_const_mgr.add_const('ERROR_MCA_INTERNAL_ERROR',0x00003B65)
		win_const_mgr.add_const('EVENT_CONSOLE_UPDATE_SIMPLE',0x00004003)
		win_const_mgr.add_const('_WIN32_IE_IE60SP2',0x00000603)
		win_const_mgr.add_const('STYPE_SPECIAL',0x80000000)
		win_const_mgr.add_const('_WIN32_IE_IE60SP1',0x00000601)
		win_const_mgr.add_const('D3DSHADER_ADDRESSMODE_SHIFT',0x0000000D)
		win_const_mgr.add_const('TVNRET_DEFAULT',0x00000000)
		win_const_mgr.add_const('ISR_ILLEGAL_HAZARD',0x00000008)
		win_const_mgr.add_const('SQL_CVT_DOUBLE',0x00000080)
		win_const_mgr.add_const('IITWBC_BREAKTYPE_TEXT',0x00000000)
		win_const_mgr.add_const('WMS_CONTAINER_PLAYLIST_ENTRY_NAME',0x00000007)
		win_const_mgr.add_const('APPCOMMAND_MICROPHONE_VOLUME_MUTE',0x00000018)
		win_const_mgr.add_const('SYSTEM_FIXED_FONT',0x00000010)
		win_const_mgr.add_const('VDMEVENT_PE',0x00002000)
		win_const_mgr.add_const('ERROR_PRODUCT_UNINSTALLED',0x0000064E)
		win_const_mgr.add_const('PBT_APMRESUMEAUTOMATIC',0x00000012)
		win_const_mgr.add_const('LP_VGACOLOR',0x00000002)
		win_const_mgr.add_const('ASC_RET_NULL_SESSION',0x00100000)
		win_const_mgr.add_const('DMO_E_INVALIDTYPE',0x80040202)
		win_const_mgr.add_const('NET_SITEID_MAXUSER',0x00000007)
		win_const_mgr.add_const('SPI_GETSCREENSAVESECURE',0x00000076)
		win_const_mgr.add_const('DISPID_WINDOWSTATECHANGED',0x0000011B)
		win_const_mgr.add_const('SUBLANG_BASQUE_BASQUE',0x00000001)
		win_const_mgr.add_const('LB_SETITEMDATA',0x0000019A)
		win_const_mgr.add_const('IPV6_HOPLIMIT',0x00000015)
		win_const_mgr.add_const('FC_OBJECT_PIPE',0x00000040)
		win_const_mgr.add_const('URLACTION_SHELL_INSTALL_DTITEMS',0x00001800)
		win_const_mgr.add_const('MFE_REACHED_CORE',0x00000001)
		win_const_mgr.add_const('FILE_FLAG_FIRST_PIPE_INSTANCE',0x00080000)
		win_const_mgr.add_const('VP_CP_TYPE_APS_TRIGGER',0x00000001)
		win_const_mgr.add_const('DNF_LEGACYINF',0x00000010)
		win_const_mgr.add_const('FPSR_FTZ2',0x00000020)
		win_const_mgr.add_const('SQL_OU_INDEX_DEFINITION',0x00000008)
		win_const_mgr.add_const('IDS_CAP_DEFAVIEXT',0x00000197)
		win_const_mgr.add_const('CRYPTUI_ENABLE_REVOCATION_CHECKING',0x00000800)
		win_const_mgr.add_const('CVIEWAGEMINUTESDEFAULT',0x00000010)
		win_const_mgr.add_const('PDCAP_D3_SUPPORTED',0x00000008)
		win_const_mgr.add_const('SQL_COLUMN_DRIVER_START',0x000003E8)
		win_const_mgr.add_const('ERROR_INVALID_COMBOBOX_MESSAGE',0x0000058E)
		win_const_mgr.add_const('BN_CLICKED',0x00000000)
		win_const_mgr.add_const('IP_MF_SHIFT',0x00000005)
		win_const_mgr.add_const('WKSTA_BUFFERREADONLYFILES_PARMNUM',0x0000003B)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGENUMERATEKEY',0x00000011)
		win_const_mgr.add_const('KSDEVICE_DESCRIPTOR_VERSION_2',0x00000110)
		win_const_mgr.add_const('PHONEERR_ALLOCATED',0x90000001)
		win_const_mgr.add_const('STREAM_FLAGS_DISALLOW_URL',0x00000001)
		win_const_mgr.add_const('MSIMWND_DISPID_ONRESIZE',0x000000E2)
		win_const_mgr.add_const('SSRVOPT_MESSAGE',0x00080000)
		win_const_mgr.add_const('JT_UNKNOWN',0x00000000)
		win_const_mgr.add_const('FIRSTRUN',0x0000000B)
		win_const_mgr.add_const('VK_MENU',0x00000012)
		win_const_mgr.add_const('TF_LBI_STYLE_HIDDENBYDEFAULT',0x00000010)
		win_const_mgr.add_const('ACM_METRIC_DRIVER_SUPPORT',0x00000064)
		win_const_mgr.add_const('ISR_FC',0x00000001)
		win_const_mgr.add_const('CRYPTUI_DISABLE_EDITPROPERTIES',0x00000004)
		win_const_mgr.add_const('IPPORT_DYNAMIC_MAX',0x00000000)
		win_const_mgr.add_const('ODBCVER',0x00000351)
		win_const_mgr.add_const('WLX_CREATE_USER',0x00000002)
		win_const_mgr.add_const('IDM_PASTESPECIAL',0x000007D6)
		win_const_mgr.add_const('DS_REPADD_CRITICAL',0x00000800)
		win_const_mgr.add_const('DCI_WRITEONLY',0x00000200)
		win_const_mgr.add_const('UI_CAP_2700',0x00000001)
		win_const_mgr.add_const('ERROR_EVT_QUERY_RESULT_STALE',0x00003AA3)
		win_const_mgr.add_const('TXTBIT_VERTICAL',0x00000100)
		win_const_mgr.add_const('LDAP_VERSION2',0x00000002)
		win_const_mgr.add_const('SQL_MULTIPLE_ACTIVE_TXN',0x00000025)
		win_const_mgr.add_const('FEI_FAXSVC_STARTED',0x00000001)
		win_const_mgr.add_const('SERVICE_INSTALL_PENDING',0x00000001)
		win_const_mgr.add_const('OBM_LFARROW',0x00007FEE)
		win_const_mgr.add_const('WMDM_MODE_THREAD',0x00000002)
		win_const_mgr.add_const('PHOTO_ORIENTATION_TRANSVERSE',0x00000007)
		win_const_mgr.add_const('IF_TYPE_IEEE80211',0x00000047)
		win_const_mgr.add_const('IF_TYPE_IEEE80212',0x00000037)
		win_const_mgr.add_const('WSAEUSERS',0x00002754)
		win_const_mgr.add_const('PRINTER_CHANGE_DELETE_PRINT_PROCESSOR',0x04000000)
		win_const_mgr.add_const('WM_ENABLE',0x0000000A)
		win_const_mgr.add_const('SQL_DESC_BIND_TYPE',0x00000019)
		win_const_mgr.add_const('SQL_DRIVER_NOPROMPT',0x00000000)
		win_const_mgr.add_const('WSAEREFUSED',0x00002780)
		win_const_mgr.add_const('DBT_VPOWERDAPI',0x00008100)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_DH_FAILURE',0x00003628)
		win_const_mgr.add_const('WNNC_NET_TYPE',0x00000002)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_MULTICAST_FRAMES_RCV',0x00000002)
		win_const_mgr.add_const('ED_LEFT',0x00000100)
		win_const_mgr.add_const('CTFMODEBIAS_CONVERSATION',0x00000005)
		win_const_mgr.add_const('OID_FDDI_SMT_REMOTE_DISCONNECT_FLAG',0x03030218)
		win_const_mgr.add_const('SUF_SBSCOPYOK',0x00000100)
		win_const_mgr.add_const('GETSETPAPERBINS',0x0000001D)
		win_const_mgr.add_const('GIL_OPENICON',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_DTYPE_FUNCTION',0x00000002)
		win_const_mgr.add_const('TABLET_ENABLE_FLICKSONCONTEXT',0x00020000)
		win_const_mgr.add_const('WTS_EVENT_FLUSH',0x80000000)
		win_const_mgr.add_const('MQ_MAX_PRIORITY',0x00000007)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PEER_CRL_FAILED',0x00003618)
		win_const_mgr.add_const('INTERNET_FLAG_FROM_CACHE',0x01000000)
		win_const_mgr.add_const('CGD_ARRAY_NODE',0x00000008)
		win_const_mgr.add_const('INTERNET_FLAG_READ_PREFETCH',0x00100000)
		win_const_mgr.add_const('SV_DISABLEDOS_PARMNUM',0x00000258)
		win_const_mgr.add_const('PRJOB_DELETED',0x00008000)
		win_const_mgr.add_const('CERT_VALIDITY_PERIOD_NESTING_FAILURE',0x00000400)
		win_const_mgr.add_const('CRED_TYPE_GENERIC',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_PROXY_USERNAME',0x0000002B)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2_MEDIAHEURISTICALLYBLANK',0x00000701)
		win_const_mgr.add_const('SCHEME_DISPLAY',0x00000001)
		win_const_mgr.add_const('IDM_ALIGNVERTICALCENTERS',0x00000007)
		win_const_mgr.add_const('WHITEBALANCE_AUTO',0x00000002)
		win_const_mgr.add_const('PERF_TYPE_ZERO',0x00000C00)
		win_const_mgr.add_const('WIZ_CXBMP',0x00000050)
		win_const_mgr.add_const('PAN_MIDLINE_HIGH_SERIFED',0x00000007)
		win_const_mgr.add_const('OID_802_11_CONFIGURATION',0x0D010211)
		win_const_mgr.add_const('ERROR_OUT_OF_STRUCTURES',0x00000054)
		win_const_mgr.add_const('CMSG_RECIPIENT_INDEX_PARAM',0x00000012)
		win_const_mgr.add_const('NETBIOS_UNIQUE_NAME',0x00000000)
		win_const_mgr.add_const('LDAP_FILTER_GE',0x00000000)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_MEDIA_SPECIFIC_MASK',0x00000000)
		win_const_mgr.add_const('PID_INTSITE_AUTHOR',0x00000003)
		win_const_mgr.add_const('VAR_LOCALBOOL',0x00000010)
		win_const_mgr.add_const('URLZONE_ESC_FLAG',0x00000100)
		win_const_mgr.add_const('IOCTL_ARP_SEND_REQUEST',0x00000067)
		win_const_mgr.add_const('EMBDHLP_DELAYCREATE',0x00010000)
		win_const_mgr.add_const('IPX_ROUTE_FILTER_DENY',0x00000002)
		win_const_mgr.add_const('SUBLANG_AZERI_CYRILLIC',0x00000002)
		win_const_mgr.add_const('DIF_INSTALLDEVICE',0x00000002)
		win_const_mgr.add_const('SYMFLAG_CLR_TOKEN',0x00040000)
		win_const_mgr.add_const('OID_ATM_SUPPORTED_VC_RATES',0x08010101)
		win_const_mgr.add_const('LINEAGENTSTATEEX_UNKNOWN',0x00000020)
		win_const_mgr.add_const('RF_WORKAROUND',0x20000000)
		win_const_mgr.add_const('TLS1_ALERT_BAD_CERTIFICATE',0x0000002A)
		win_const_mgr.add_const('STDPROP_USERDATA',0x00000003)
		win_const_mgr.add_const('RPC_C_HTTP_FLAG_USE_SSL',0x00000001)
		win_const_mgr.add_const('WKSTA_LOGGED_ON_USERS_PARMNUM',0x00000006)
		win_const_mgr.add_const('SE_ADT_PARAMETER_EXTENSIBLE_AUDIT',0x00000004)
		win_const_mgr.add_const('ERROR_EXTRANEOUS_INFORMATION',0x000002A5)
		win_const_mgr.add_const('XEPR_TEMPLATENAME',0x00000006)
		win_const_mgr.add_const('SECPKG_PACKAGE_CHANGE_UNLOAD',0x00000001)
		win_const_mgr.add_const('LVBKIF_SOURCE_HBITMAP',0x00000001)
		win_const_mgr.add_const('ERROR_DS_ATT_ALREADY_EXISTS',0x0000207E)
		win_const_mgr.add_const('PORT_CISCOTNA',0x00000083)
		win_const_mgr.add_const('ERROR_DBG_TERMINATE_THREAD',0x000002B3)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_POWERPCFP',0x00000001)
		win_const_mgr.add_const('RPC_X_PIPE_CLOSED',0x0000077C)
		win_const_mgr.add_const('MFOUTPUTATTRIBUTE_BUSIMPLEMENTATION',0x0000FF00)
		win_const_mgr.add_const('URLACTION_ACTIVEX_TREATASUNTRUSTED',0x00001205)
		win_const_mgr.add_const('VIDEO_CONFIGURE_NOMINAL',0x00000020)
		win_const_mgr.add_const('STI_ONLINESTATE_POWER_SAVE',0x00002000)
		win_const_mgr.add_const('KSSTREAM_PAGED_DATA',0x00000000)
		win_const_mgr.add_const('KAGPROP_DRIVERODBCVER',0x00000009)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_TIMEDISCONTINUITY',0x00000040)
		win_const_mgr.add_const('ACTCTX_FLAG_SET_PROCESS_DEFAULT',0x00000010)
		win_const_mgr.add_const('IDH_NO_HELP',0x00006F18)
		win_const_mgr.add_const('FILE_NOTIFY_CHANGE_FILE_NAME',0x00000001)
		win_const_mgr.add_const('HDF_BITMAP',0x00002000)
		win_const_mgr.add_const('EN_ERRSPACE',0x00000500)
		win_const_mgr.add_const('WLX_OPTION_DISPATCH_TABLE_SIZE',0x00010003)
		win_const_mgr.add_const('MQ_MAX_Q_LABEL_LEN',0x0000007C)
		win_const_mgr.add_const('KS_VBICAP_PROTECTION_MV_DETECTED',0x00000004)
		win_const_mgr.add_const('ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED',0x00001AB0)
		win_const_mgr.add_const('MCI_TO',0x00000008)
		win_const_mgr.add_const('PORT_GRAPHICS',0x00000029)
		win_const_mgr.add_const('DIBCI_NODISPLAYCLASS',0x00000002)
		win_const_mgr.add_const('LINEERR_COMPLETIONOVERRUN',0x80000006)
		win_const_mgr.add_const('HISTORY_NO_DUP_FLAG',0x00000001)
		win_const_mgr.add_const('WLAN_PROFILE_USER',0x00000002)
		win_const_mgr.add_const('MAPI_SENT',0x00000004)
		win_const_mgr.add_const('IPPORT_NETSTAT',0x0000000F)
		win_const_mgr.add_const('ERROR_REGISTRY_HIVE_RECOVERED',0x000002AD)
		win_const_mgr.add_const('DLGC_BUTTON',0x00002000)
		win_const_mgr.add_const('TB_BOTTOM',0x00000007)
		win_const_mgr.add_const('KAGPROP_PROCEDURES',0x00000006)
		win_const_mgr.add_const('GT_DEFAULT',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_DC_END',0x00000004)
		win_const_mgr.add_const('MCI_ANIM_STATUS_HPAL',0x00004004)
		win_const_mgr.add_const('WM_STYLECHANGED',0x0000007D)
		win_const_mgr.add_const('PDH_FMT_1000',0x00002000)
		win_const_mgr.add_const('CRED_TI_VALID_FLAGS',0x0000F07F)
		win_const_mgr.add_const('LCPRI_DESIRED',0x00002000)
		win_const_mgr.add_const('CHANNEL_OPTION_COMPRESS',0x00400000)
		win_const_mgr.add_const('DCX_CLIPCHILDREN',0x00000008)
		win_const_mgr.add_const('LINEAGENTSTATEEX_RELEASED',0x00000040)
		win_const_mgr.add_const('LMEM_MODIFY',0x00000080)
		win_const_mgr.add_const('WIA_IPA_PLANAR',0x0000100F)
		win_const_mgr.add_const('D3D10_EFFECT_COMPILE_ALLOW_SLOW_OPS',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID',0x0000363E)
		win_const_mgr.add_const('CAL_UMALQURA',0x00000017)
		win_const_mgr.add_const('DBPROMPT_COMPLETE',0x00000002)
		win_const_mgr.add_const('IDM_BASELINEFONT2',0x0000085E)
		win_const_mgr.add_const('IDM_BASELINEFONT3',0x0000085F)
		win_const_mgr.add_const('IDM_BASELINEFONT1',0x0000085D)
		win_const_mgr.add_const('NLS_ROMAN',0x00400000)
		win_const_mgr.add_const('IDM_BASELINEFONT4',0x00000860)
		win_const_mgr.add_const('IDM_BASELINEFONT5',0x00000861)
		win_const_mgr.add_const('DXVA_QUERYORREPLYFUNCFLAG_ACCEL_PROBE_OK_PLUS',0x00FFFFF9)
		win_const_mgr.add_const('IPX_ADDRESS',0x00004007)
		win_const_mgr.add_const('CREATEPROCESS_MANIFEST_RESOURCE_ID',0x00000001)
		win_const_mgr.add_const('SQL_ASYNC_MODE',0x00002725)
		win_const_mgr.add_const('CHANNEL_RC_ALREADY_OPEN',0x0000000E)
		win_const_mgr.add_const('CF_SYLK',0x00000004)
		win_const_mgr.add_const('WMDM_STORAGE_CONTAINS_DEFAULT',0x10000000)
		win_const_mgr.add_const('DEBUG_KNOWN_STRUCT_GET_NAMES',0x00000001)
		win_const_mgr.add_const('SET_REPAIR_DELETE_CROSSLINK',0x00000004)
		win_const_mgr.add_const('RPC_S_TYPE_ALREADY_REGISTERED',0x000006B0)
		win_const_mgr.add_const('SQL_AT_DROP_COLUMN_DEFAULT',0x00000200)
		win_const_mgr.add_const('DNS_ATMA_AESA_ADDR_LENGTH',0x00000014)
		win_const_mgr.add_const('LPD_SHARE_STENCIL',0x00000080)
		win_const_mgr.add_const('RDH_RECTANGLES',0x00000001)
		win_const_mgr.add_const('DDPF_PALETTEINDEXED1',0x00000800)
		win_const_mgr.add_const('META_INTERSECTCLIPRECT',0x00000416)
		win_const_mgr.add_const('DC_MODEL',0x00000018)
		win_const_mgr.add_const('BCP_FMT_TYPE',0x00000001)
		win_const_mgr.add_const('IF_CHECK_MCAST',0x00000001)
		win_const_mgr.add_const('XA_HEURRB',0x00000006)
		win_const_mgr.add_const('SVAUD_PERMISSIONS',0x00004000)
		win_const_mgr.add_const('SNMPAPI_OFF',0x00000000)
		win_const_mgr.add_const('SPI_SETBLOCKSENDINPUTRESETS',0x00001027)
		win_const_mgr.add_const('DI_SHOWALL',0x00000007)
		win_const_mgr.add_const('TMT_XMLNAME',0x0000057A)
		win_const_mgr.add_const('CRYPT_PRIORITY_BOTTOM',0xFFFFFFFF)
		win_const_mgr.add_const('MAXPERMENTRIES',0x00000040)
		win_const_mgr.add_const('ERROR_SXS_MULTIPLE_DEACTIVATION',0x00003706)
		win_const_mgr.add_const('SPI_SETMOUSECLICKLOCK',0x0000101F)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_COMPUTERS',0x00000203)
		win_const_mgr.add_const('KS_VBI_FLAG_FIELD1',0x00000001)
		win_const_mgr.add_const('KS_VBI_FLAG_FIELD2',0x00000002)
		win_const_mgr.add_const('LOCALE_SSHORTESTDAYNAME6',0x00000065)
		win_const_mgr.add_const('FLG_ADDREG_TYPE_BINARY',0x00000000)
		win_const_mgr.add_const('MCI_DGV_PLAY_REVERSE',0x00020000)
		win_const_mgr.add_const('DS_RETURN_DNS_NAME',0x40000000)
		win_const_mgr.add_const('MEDIASINK_CLOCK_REQUIRED',0x00000008)
		win_const_mgr.add_const('TMT_COLORSCHEMES',0x00000191)
		win_const_mgr.add_const('AF_INET6',0x00000017)
		win_const_mgr.add_const('DN_MAXACCL',0x00000027)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_APPLICATION',0x00050000)
		win_const_mgr.add_const('SIC_NEUTRAL',0x00000004)
		win_const_mgr.add_const('TBSTYLE_TRANSPARENT',0x00008000)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_20',0x00000014)
		win_const_mgr.add_const('SCRIPTTYPELIB_ISPERSISTENT',0x00000040)
		win_const_mgr.add_const('WINEVENT_KEYWORD_RESERVED_59',0x800000000000000)
		win_const_mgr.add_const('FACILITY_FVE_ERROR_CODE',0x00000021)
		win_const_mgr.add_const('FIND_ACTCTX_SECTION_KEY_RETURN_ASSEMBLY_METADATA',0x00000004)
		win_const_mgr.add_const('GL_ID_TOOMANYSTROKE',0x00000022)
		win_const_mgr.add_const('WIA_DEVINFO_ENUM_ALL',0x0000000F)
		win_const_mgr.add_const('SBSP_NOTRANSFERHIST',0x00000080)
		win_const_mgr.add_const('PD_ENABLEPRINTTEMPLATEHANDLE',0x00010000)
		win_const_mgr.add_const('LOCKFILE_FAIL_IMMEDIATELY',0x00000001)
		win_const_mgr.add_const('SHTDN_REASON_MAJOR_OTHER',0x00000000)
		win_const_mgr.add_const('ERROR_INVALID_ID_AUTHORITY',0x0000053F)
		win_const_mgr.add_const('UINT32_ERROR',0x00000000)
		win_const_mgr.add_const('KSDATARANGE_BIT_ATTRIBUTES',0x00000001)
		win_const_mgr.add_const('ERROR_WMI_GUID_DISCONNECTED',0x0000106F)
		win_const_mgr.add_const('EC_VARIANT_TYPE_ARRAY',0x00000080)
		win_const_mgr.add_const('ERROR_JOURNAL_ENTRY_DELETED',0x0000049D)
		win_const_mgr.add_const('DOT11_SERVICE_CLASS_REORDERABLE_MULTICAST',0x00000000)
		win_const_mgr.add_const('PORT_SMTP',0x00000019)
		win_const_mgr.add_const('USE_CHARDEV',0x00000002)
		win_const_mgr.add_const('DM_PRINTQUALITY',0x00000400)
		win_const_mgr.add_const('ERROR_MP_PROCESSOR_MISMATCH',0x000002D5)
		win_const_mgr.add_const('MODALS_LOCKOUT_DURATION_PARMNUM',0x0000000A)
		win_const_mgr.add_const('DN_APM_DRIVER',0x10000000)
		win_const_mgr.add_const('WIA_DEVICE_EVENTS',0x00000002)
		win_const_mgr.add_const('LONG_MAX',0x7FFFFFFF)
		win_const_mgr.add_const('USER_ENCRYPTED_TEXT_PASSWORD_ALLOWED',0x00000800)
		win_const_mgr.add_const('CR_INVALID_PROPERTY',0x00000035)
		win_const_mgr.add_const('STAT_ERROR',0x00000001)
		win_const_mgr.add_const('SUBLANG_HUNGARIAN_HUNGARY',0x00000001)
		win_const_mgr.add_const('LSP_PROXY',0x00000004)
		win_const_mgr.add_const('MM_ANISOTROPIC',0x00000008)
		win_const_mgr.add_const('D3DPV_DONOTCOPYDATA',0x00000001)
		win_const_mgr.add_const('DEBUG_ENGOPT_KD_QUIET_MODE',0x00002000)
		win_const_mgr.add_const('DDOSD_ALL',0x00000000)
		win_const_mgr.add_const('DEX_IDS_MISSING_SOURCE_NAME',0x0000057A)
		win_const_mgr.add_const('DMDO_180',0x00000002)
		win_const_mgr.add_const('ACTRL_RESERVED',0x00000000)
		win_const_mgr.add_const('ENLISTMENT_SET_INFORMATION',0x00000002)
		win_const_mgr.add_const('CACHE_HEADER_DATA_ROOT_GROUPLIST_OFFSET',0x0000001B)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_ROOT',0x00000007)
		win_const_mgr.add_const('DNS_ERROR_RCODE_NAME_ERROR',0x0000232B)
		win_const_mgr.add_const('IDI_RESOURCEOVERLAYFIRST',0x000000A1)
		win_const_mgr.add_const('RAS_EAP_FLAG_PEAP_UPFRONT',0x00000400)
		win_const_mgr.add_const('WMDM_LOG_SEV_ERROR',0x00000004)
		win_const_mgr.add_const('PID_IS_AUTHOR',0x0000000B)
		win_const_mgr.add_const('VIEW_PRIORITY_RESTRICTED',0x00000070)
		win_const_mgr.add_const('SQL_SO_FORWARD_ONLY',0x00000001)
		win_const_mgr.add_const('WMPCOREEVENT_PLAYLIST_BASE',0x000016A8)
		win_const_mgr.add_const('MOD_ON_KEYUP',0x00000800)
		win_const_mgr.add_const('FLAGS_ERROR_UI_FLAGS_CHANGE_OPTIONS',0x00000002)
		win_const_mgr.add_const('SERVICE_CCP_WAIT_TIME',0x0000FF00)
		win_const_mgr.add_const('SQL_ACCESSIBLE_PROCEDURES',0x00000014)
		win_const_mgr.add_const('ISDB_DCT_TID',0x000000C0)
		win_const_mgr.add_const('LVS_TYPESTYLEMASK',0x00000000)
		win_const_mgr.add_const('SCREEN_FONTTYPE',0x00002000)
		win_const_mgr.add_const('BS_GROUPBOX',0x00000007)
		win_const_mgr.add_const('LDAP_OPT_DESC',0x00000001)
		win_const_mgr.add_const('SV_MINFREEWORKITEMS_PARMNUM',0x00000212)
		win_const_mgr.add_const('TCI_SRCLOCALE',0x00001000)
		win_const_mgr.add_const('PHONEERR_INVALLAMPMODE',0x90000011)
		win_const_mgr.add_const('ERROR_UNEXPECTED_OMID',0x000010EE)
		win_const_mgr.add_const('SECURITY_NT_NON_UNIQUE',0x00000015)
		win_const_mgr.add_const('GESTURE_CHEVRON_DOWN',0x00000000)
		win_const_mgr.add_const('JIFMK_RES',0x0000FF02)
		win_const_mgr.add_const('STI_DEVICE_CREATE_MASK',0x0000FFFF)
		win_const_mgr.add_const('MCI_QUALITY',0x00000877)
		win_const_mgr.add_const('CONTROLLED_DELAY_SERV',0x00000004)
		win_const_mgr.add_const('ERROR_ENCRYPTION_FAILED',0x00001770)
		win_const_mgr.add_const('ERROR_SXS_XML_E_BADNAMECHAR',0x000036D1)
		win_const_mgr.add_const('CM_DRP_PHYSICAL_DEVICE_OBJECT_NAME',0x0000000F)
		win_const_mgr.add_const('SQL_CODE_YEAR_TO_MONTH',0x00000007)
		win_const_mgr.add_const('ASC_RET_IDENTIFY',0x00080000)
		win_const_mgr.add_const('CAUSE_NO_ROUTE_TO_DESTINATION',0x00000003)
		win_const_mgr.add_const('RAS_FLAGS_RAS_CONNECTION',0x00000004)
		win_const_mgr.add_const('KP_PADDING',0x00000003)
		win_const_mgr.add_const('IF_TYPE_BSC',0x00000053)
		win_const_mgr.add_const('SCS_POSIX_BINARY',0x00000004)
		win_const_mgr.add_const('CERT_STORE_DELETE_FLAG',0x00000010)
		win_const_mgr.add_const('FACILITY_USB_ERROR_CODE',0x00000010)
		win_const_mgr.add_const('SDP_ATTRIB_PROFILE_DESCRIPTOR_LIST',0x00000009)
		win_const_mgr.add_const('FLAGCOLOR_ORANGE',0x00000002)
		win_const_mgr.add_const('PAN_MIDLINE_STANDARD_SERIFED',0x00000004)
		win_const_mgr.add_const('WINHTTP_OPTION_USER_AGENT',0x00000029)
		win_const_mgr.add_const('PHONEHOOKSWITCHMODE_MICSPEAKER',0x00000008)
		win_const_mgr.add_const('ICDRAW_MEMORYDC',0x00000020)
		win_const_mgr.add_const('ERROR_HANDLES_CLOSED',0x000002A4)
		win_const_mgr.add_const('VER_OR',0x00000007)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_CONNECTION_OFFLOAD_ENABLED',0x00000002)
		win_const_mgr.add_const('SQL_API_SQLSETCURSORNAME',0x00000015)
		win_const_mgr.add_const('URLACTION_BEHAVIOR_RUN',0x00002000)
		win_const_mgr.add_const('FOREGROUND_GREEN',0x00000002)
		win_const_mgr.add_const('COOKIE_ALLOW',0x00000002)
		win_const_mgr.add_const('SQLDECIMAL',0x00000006)
		win_const_mgr.add_const('ERROR_TRANSACTION_NOT_ACTIVE',0x00001A2D)
		win_const_mgr.add_const('DCICREATEOVERLAYSURFACE',0x00000003)
		win_const_mgr.add_const('INTERNET_OPTION_OFFLINE_MODE',0x0000001A)
		win_const_mgr.add_const('HTTP_RECEIVE_REQUEST_FLAG_FLUSH_BODY',0x00000002)
		win_const_mgr.add_const('NDIS_802_11_AI_REQFI_LISTENINTERVAL',0x00000002)
		win_const_mgr.add_const('ECO_READONLY',0x00000800)
		win_const_mgr.add_const('CMS_FORWARD',0x00000000)
		win_const_mgr.add_const('CQPM_RELEASE',0x00000002)
		win_const_mgr.add_const('VK_APPS',0x0000005D)
		win_const_mgr.add_const('PKR_VALID',0x00000001)
		win_const_mgr.add_const('C3_KASHIDA',0x00000200)
		win_const_mgr.add_const('WM_VSCROLLCLIPBOARD',0x0000030A)
		win_const_mgr.add_const('DLLVER_MAJOR_MASK',0xFFFF000000000000)
		win_const_mgr.add_const('SPI_GETMOUSECLICKLOCKTIME',0x00002008)
		win_const_mgr.add_const('DFCS_CAPTIONMAX',0x00000002)
		win_const_mgr.add_const('IMAGE_DLLCHARACTERISTICS_NO_BIND',0x00000800)
		win_const_mgr.add_const('AVIFILEINFO_ISINTERLEAVED',0x00000100)
		win_const_mgr.add_const('HHWIN_PROP_POST_QUIT',0x00000001)
		win_const_mgr.add_const('TR_IGN0',0x00000035)
		win_const_mgr.add_const('OID_802_11_POWER_MODE',0x0D010216)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_GRP_SUM_PEAK_RATE',0x0000002A)
		win_const_mgr.add_const('TCN_LAST',0x00000000)
		win_const_mgr.add_const('TRACELOG_LOG_EVENT',0x00000200)
		win_const_mgr.add_const('ACTIVEOBJECT_STRONG',0x00000000)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_MCAST',0x00000100)
		win_const_mgr.add_const('CTRY_LIBYA',0x000000DA)
		win_const_mgr.add_const('SECPKG_ID_NONE',0x0000FFFF)
		win_const_mgr.add_const('DISPID_CTRLMOUSEWHEEL',0x000000D5)
		win_const_mgr.add_const('OID_FDDI_MAC_LATE_CT',0x03030243)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_FLAG5',0x00000020)
		win_const_mgr.add_const('IDM_IFRAME',0x0000086E)
		win_const_mgr.add_const('RPC_PROXY_CONNECTION_TYPE_IN_PROXY',0x00000000)
		win_const_mgr.add_const('VP_FLAGS_POSITION',0x00000020)
		win_const_mgr.add_const('LVCFMT_WRAP',0x00400000)
		win_const_mgr.add_const('INTERNET_CUSTOMDIAL_DISCONNECT',0x00000002)
		win_const_mgr.add_const('RPC_S_UNSUPPORTED_AUTHN_LEVEL',0x0000071D)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_PARK',0x0000000F)
		win_const_mgr.add_const('CM_INSTALL_STATE_INSTALLED',0x00000000)
		win_const_mgr.add_const('GESTURE_DIAGONAL_RIGHTUP',0x00000000)
		win_const_mgr.add_const('COD_COMPUTER_MINOR_DESKTOP',0x00000001)
		win_const_mgr.add_const('WIA_LAMP_ON',0x00000000)
		win_const_mgr.add_const('FACILITY_INK',0x00000028)
		win_const_mgr.add_const('CONTROLCALLBACK_CAPTURING',0x00000002)
		win_const_mgr.add_const('PAN_CONTRAST_MEDIUM',0x00000006)
		win_const_mgr.add_const('IF_TYPE_FRF16_MFR_BUNDLE',0x000000A3)
		win_const_mgr.add_const('SQL_COLUMN_LABEL',0x00000012)
		win_const_mgr.add_const('WLX_VERSION_1_4',0x00000000)
		win_const_mgr.add_const('SQL_UNION',0x00000060)
		win_const_mgr.add_const('IDC_PS_PASTELIST',0x000001F7)
		win_const_mgr.add_const('GS_HANDOBJ_ALLOC',0x00000003)
		win_const_mgr.add_const('ERROR_SERIAL_NO_DEVICE',0x0000045E)
		win_const_mgr.add_const('GET_FEATURE_FROM_THREAD_RESTRICTED',0x00000080)
		win_const_mgr.add_const('NCRYPT_REGISTER_NOTIFY_FLAG',0x00000001)
		win_const_mgr.add_const('MIXERCONTROL_CT_SC_TIME_MICROSECS',0x00000000)
		win_const_mgr.add_const('DISPID_TABLEPARAMS_NUMROWS',0x00000001)
		win_const_mgr.add_const('ABE_TOP',0x00000001)
		win_const_mgr.add_const('META_SETBKCOLOR',0x00000201)
		win_const_mgr.add_const('SO_LOOKUP_ZONES',0x0000A005)
		win_const_mgr.add_const('ERROR_RM_ALREADY_STARTED',0x00001AA6)
		win_const_mgr.add_const('DEBUG_GET_PROC_ONLY_MATCH',0x00000002)
		win_const_mgr.add_const('WMS_TOTAL_AVG_BITRATE',0x00000002)
		win_const_mgr.add_const('DEBUG_LEVEL_ASSEMBLY',0x00000001)
		win_const_mgr.add_const('MQMSG_AUTHENTICATION_REQUESTED',0x00000001)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_CLOSING_CONNECTION',0x00000100)
		win_const_mgr.add_const('LVTVIM_TILESIZE',0x00000001)
		win_const_mgr.add_const('MA_ACTIVATE',0x00000001)
		win_const_mgr.add_const('QUERYFORM_CHANGESFORMLIST',0x00000001)
		win_const_mgr.add_const('NIM_DELETE',0x00000002)
		win_const_mgr.add_const('MD_CHANGE_TYPE_DELETE_OBJECT',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_UP_CHANGE',0x00000001)
		win_const_mgr.add_const('AM_DVD_CGMS_COPY_ONCE',0x00000010)
		win_const_mgr.add_const('D3DDTCAPS_USHORT4N',0x00000020)
		win_const_mgr.add_const('DS_REPSYNC_ADD_REFERENCE',0x00000200)
		win_const_mgr.add_const('ISCSI_SECURITY_FLAG_MAIN_MODE_ENABLED',0x00000004)
		win_const_mgr.add_const('COLOR_SAVE',0x000002C7)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_TOTAL_BYTES',0x00000016)
		win_const_mgr.add_const('LIMITED_VALIDATION_MODE',0x00000001)
		win_const_mgr.add_const('SECPKG_ATTR_REMOTE_CERT_CONTEXT',0x00000053)
		win_const_mgr.add_const('EVENT_TRACE_ADD_HEADER_MODE',0x00001000)
		win_const_mgr.add_const('ERROR_INVALID_HOOK_FILTER',0x00000592)
		win_const_mgr.add_const('IDD_EDITLINKS',0x000003EC)
		win_const_mgr.add_const('BASE_VAL_WIA_SUCCESS',0x00000000)
		win_const_mgr.add_const('SV_SIZREQBUF_PARMNUM',0x000001F8)
		win_const_mgr.add_const('ERROR_BAD_DYNALINK',0x000000D5)
		win_const_mgr.add_const('RBNM_ID',0x00000001)
		win_const_mgr.add_const('KSCREATE_ITEM_WILDCARD',0x00000002)
		win_const_mgr.add_const('DT_SINGLELINE',0x00000020)
		win_const_mgr.add_const('PORT_RTELNET',0x0000006B)
		win_const_mgr.add_const('HTTP_RECEIVE_REQUEST_FLAG_COPY_BODY',0x00000001)
		win_const_mgr.add_const('DBFLAGS_CIRCULARLOGGING',0x00000004)
		win_const_mgr.add_const('OID_FDDI_MAC_REQUESTED_PATHS',0x0303022A)
		win_const_mgr.add_const('WMDM_STATUS_DEVICECONTROL_STREAM',0x00000080)
		win_const_mgr.add_const('INTERNET_MAX_PATH_LENGTH',0x00000800)
		win_const_mgr.add_const('LINEERR_RESOURCEUNAVAIL',0x8000004B)
		win_const_mgr.add_const('ERROR_DS_NONEXISTENT_MUST_HAVE',0x000020C4)
		win_const_mgr.add_const('SS_EDITCONTROL',0x00002000)
		win_const_mgr.add_const('WMDRM_DEVICE_REVOKED',0x00000004)
		win_const_mgr.add_const('CERT_TRUST_IS_UNTRUSTED_ROOT',0x00000020)
		win_const_mgr.add_const('AVISF_VIDEO_PALCHANGES',0x00010000)
		win_const_mgr.add_const('CERT_VALIDITY_OTHER_ERROR',0x00000800)
		win_const_mgr.add_const('AC_LINE_UNKNOWN',0x000000FF)
		win_const_mgr.add_const('BST_DROPDOWNPUSHED',0x00000400)
		win_const_mgr.add_const('WINDOW_BUFFER_SIZE_EVENT',0x00000004)
		win_const_mgr.add_const('JL_BOTH',0x00000004)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_IS_REAUTHORIZE',0x00000004)
		win_const_mgr.add_const('ELEMENT_STATUS_EXCEPT',0x00000004)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_DRIVER_NAME',0x00000008)
		win_const_mgr.add_const('IDS_CONVERSATION',0x00011007)
		win_const_mgr.add_const('IDM_PRESERVEUNDOALWAYS',0x000017A1)
		win_const_mgr.add_const('DEX_IDS_BROKEN_DXT',0x00000586)
		win_const_mgr.add_const('SV_LOWDISKSPACEMINIMUM_PARMNUM',0x00000259)
		win_const_mgr.add_const('INTERNET_CACHE_CONTAINER_MAP_ENABLED',0x00000010)
		win_const_mgr.add_const('IPSEC_AUTH_CONFIG_HMAC_SHA_1_96',0x00000001)
		win_const_mgr.add_const('DISPID_CHECKSTATECHANGED',0x000000D1)
		win_const_mgr.add_const('GCT_LFNCHAR',0x00000001)
		win_const_mgr.add_const('FF_MODERN',0x00000003)
		win_const_mgr.add_const('SPI_GETMOUSEKEYS',0x00000036)
		win_const_mgr.add_const('EVENT_CONSOLE_UPDATE_SCROLL',0x00004004)
		win_const_mgr.add_const('ERROR_COMMITMENT_LIMIT',0x000005AF)
		win_const_mgr.add_const('IDM_PAGE',0x000008DB)
		win_const_mgr.add_const('PRINTACTION_OPENNETPRN',0x00000005)
		win_const_mgr.add_const('ACM_FILTERTAGDETAILSF_LARGESTSIZE',0x00000002)
		win_const_mgr.add_const('MCI_OVLY_WINDOW_DEFAULT',0x00000000)
		win_const_mgr.add_const('NTDSDSA_OPT_DISABLE_NTDSCONN_XLATE',0x00000001)
		win_const_mgr.add_const('SQL_EN_OFF',0x00000000)
		win_const_mgr.add_const('TVIF_PARAM',0x00000004)
		win_const_mgr.add_const('SQL_ISV_TABLE_PRIVILEGES',0x00010000)
		win_const_mgr.add_const('DCI_DWORDALIGN',0x00000100)
		win_const_mgr.add_const('SE_ERR_PNF',0x00000003)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_KEYWORD_VALUE',0x00000008)
		win_const_mgr.add_const('S_NORMAL',0x00000000)
		win_const_mgr.add_const('HTTP_QUERY_SET_COOKIE',0x0000002B)
		win_const_mgr.add_const('META_SETLAYOUT',0x00000149)
		win_const_mgr.add_const('OCR_SIZEALL',0x00007F86)
		win_const_mgr.add_const('WMS_CONTAINER_CANSTRIDE',0x00000004)
		win_const_mgr.add_const('MDM_V120_SPEED_56K',0x00000002)
		win_const_mgr.add_const('LPV_DONT_CARE',0x0000FFFE)
		win_const_mgr.add_const('D3D10_EFFECT_VARIABLE_EXPLICIT_BIND_POINT',0x00000001)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGKCBRUNDOWNBEGIN',0x00000018)
		win_const_mgr.add_const('ESB_DISABLE_LEFT',0x00000001)
		win_const_mgr.add_const('PID_VOLUME_FREE',0x00000002)
		win_const_mgr.add_const('LINECAPS',0x0000001E)
		win_const_mgr.add_const('ERROR_SEM_IS_SET',0x00000066)
		win_const_mgr.add_const('ERROR_DEVICE_REQUIRES_CLEANING',0x0000048D)
		win_const_mgr.add_const('SQL_CA2_SENSITIVITY_UPDATES',0x00000040)
		win_const_mgr.add_const('IF_TYPE_RS232',0x00000021)
		win_const_mgr.add_const('FR_PROP_PENDINFOTIME',0x00000009)
		win_const_mgr.add_const('PSP_PREMATURE',0x00000400)
		win_const_mgr.add_const('KEY_EVENT',0x00000001)
		win_const_mgr.add_const('SHACF_DEFAULT',0x00000000)
		win_const_mgr.add_const('CSIDL_INTERNET',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_CO_CASESENSITIVE',0x00000004)
		win_const_mgr.add_const('MB_APPLMODAL',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_M32R_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('IME_SETOPEN',0x00000004)
		win_const_mgr.add_const('D3DPRASTERCAPS_ZTEST',0x00000010)
		win_const_mgr.add_const('ASC_REQ_EXTENDED_ERROR',0x00008000)
		win_const_mgr.add_const('VDMEVENT_NEEDS_INTERACTIVE',0x00008000)
		win_const_mgr.add_const('SI_RESET_OWNER',0x00100000)
		win_const_mgr.add_const('SDP_ATTRIB_PAN_WAP_STACK_TYPE',0x00000309)
		win_const_mgr.add_const('ICMODE_COMPRESS',0x00000001)
		win_const_mgr.add_const('TRACE_USE_FILE',0x00000001)
		win_const_mgr.add_const('ADN_DEL_IF_EMPTY',0x00000001)
		win_const_mgr.add_const('RTCRMF_PROFILE_ROAMING',0x00000008)
		win_const_mgr.add_const('SBM_GETPOS',0x000000E1)
		win_const_mgr.add_const('CMSG_KEY_AGREE_ORIGINATOR_CERT',0x00000001)
		win_const_mgr.add_const('LINEDEVSTATE_DEVSPECIFIC',0x00020000)
		win_const_mgr.add_const('SSRVOPT_RESETTOU',0x00008000)
		win_const_mgr.add_const('TMT_MARGINS',0x000000CD)
		win_const_mgr.add_const('NETBIOS_NAME_LENGTH',0x00000010)
		win_const_mgr.add_const('BST_PUSHED',0x00000004)
		win_const_mgr.add_const('OBJ_COLORSPACE',0x0000000E)
		win_const_mgr.add_const('SPEAKER_BACK_CENTER',0x00000100)
		win_const_mgr.add_const('DFCS_TRANSPARENT',0x00000800)
		win_const_mgr.add_const('STICKY_CACHE_ENTRY',0x00000004)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_GRP_PEAK_RATE',0x0000001E)
		win_const_mgr.add_const('HHWIN_PROP_TAB_AUTOHIDESHOW',0x00000001)
		win_const_mgr.add_const('TMT_MIRRORIMAGE',0x000008A1)
		win_const_mgr.add_const('DIF_FIRSTTIMESETUP',0x00000006)
		win_const_mgr.add_const('INTERNET_OPTION_CERT_ERROR_FLAGS',0x00000062)
		win_const_mgr.add_const('CACHE_NOTIFY_ADD_URL',0x00000001)
		win_const_mgr.add_const('MD_SERVER_STATE_STARTED',0x00000002)
		win_const_mgr.add_const('IDSI_FLAG_TUNNEL',0x00000008)
		win_const_mgr.add_const('ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE',0x000013C8)
		win_const_mgr.add_const('ERROR_SHUTDOWN_USERS_LOGGED_ON',0x000004A7)
		win_const_mgr.add_const('DOT11_RATE_SET_MAX_LENGTH',0x0000007E)
		win_const_mgr.add_const('DS_IS_FLAT_NAME',0x00010000)
		win_const_mgr.add_const('SUBLANG_CROATIAN_BOSNIA_HERZEGOVINA_LATIN',0x00000004)
		win_const_mgr.add_const('PIDDRSI_PLAYSTARTS',0x00000005)
		win_const_mgr.add_const('DEBUG_VSOURCE_DEBUGGEE',0x00000001)
		win_const_mgr.add_const('CBS_LOWERCASE',0x00004000)
		win_const_mgr.add_const('DIF_UPDATEDRIVER_UI',0x00000029)
		win_const_mgr.add_const('CRYPT_DESTROYKEY',0x00000004)
		win_const_mgr.add_const('ERROR_NESTING_NOT_ALLOWED',0x000000D7)
		win_const_mgr.add_const('DRM_ADD_LICENSE_NOPERSIST',0x00000000)
		win_const_mgr.add_const('RF_FREE_INPUT',0x00000004)
		win_const_mgr.add_const('OID_GEN_TRANSPORT_HEADER_OFFSET',0x00010119)
		win_const_mgr.add_const('KS_VIDEOSTREAM_CAPTURE',0x00000002)
		win_const_mgr.add_const('PLATFORM_BROWSERONLY',0x00000001)
		win_const_mgr.add_const('OFN_SHAREFALLTHROUGH',0x00000002)
		win_const_mgr.add_const('CREATE_UNICODE_ENVIRONMENT',0x00000400)
		win_const_mgr.add_const('DISPID_PICT_WIDTH',0x00000004)
		win_const_mgr.add_const('CMSG_ENCRYPTED_DIGEST',0x0000001B)
		win_const_mgr.add_const('LDAP_OPT_RESTART',0x00000009)
		win_const_mgr.add_const('ALIGN_SIZE',0x00000008)
		win_const_mgr.add_const('FPSR_FTZ1',0x00000013)
		win_const_mgr.add_const('FPSR_FTZ0',0x00000006)
		win_const_mgr.add_const('FPSR_FTZ3',0x0000002D)
		win_const_mgr.add_const('DB_MODE_READ',0x00000001)
		win_const_mgr.add_const('SIF_POS',0x00000004)
		win_const_mgr.add_const('SPDRP_MFG',0x0000000B)
		win_const_mgr.add_const('IMAGE_SCN_MEM_PRELOAD',0x00080000)
		win_const_mgr.add_const('IDM_SHOWAREATAGS',0x00000915)
		win_const_mgr.add_const('SPFILENOTIFY_ENDREGISTRATION',0x00000020)
		win_const_mgr.add_const('ERROR_RXACT_INVALID_STATE',0x00000559)
		win_const_mgr.add_const('DXVA_ALPHA_BLEND_COMBINATION_FUNCTION',0x00000003)
		win_const_mgr.add_const('ERROR_BEGINNING_OF_MEDIA',0x0000044E)
		win_const_mgr.add_const('ERROR_DS_NOT_ON_BACKLINK',0x000020AA)
		win_const_mgr.add_const('SQL_TRANSLATE_DLL',0x0000006A)
		win_const_mgr.add_const('CERT_CHAIN_FIND_BY_ISSUER',0x00000001)
		win_const_mgr.add_const('DCI_VERSION',0x00000100)
		win_const_mgr.add_const('DDSDM_STANDARDVGAMODE',0x00000001)
		win_const_mgr.add_const('MCAST_LEAVE_GROUP',0x0000002A)
		win_const_mgr.add_const('CO_E_FIRST',0x800401F0)
		win_const_mgr.add_const('PSTF_COMPRESSABLE_ENCRYPTION',0x40000000)
		win_const_mgr.add_const('ASC_RET_USED_DCE_STYLE',0x00000200)
		win_const_mgr.add_const('DEBUG_NOTIFY_SESSION_INACTIVE',0x00000001)
		win_const_mgr.add_const('SMC_REFRESH',0x00000010)
		win_const_mgr.add_const('SDP_ATTRIB_HID_SUPERVISION_TIMEOUT',0x0000020C)
		win_const_mgr.add_const('ISC_RET_USED_SUPPLIED_CREDS',0x00000080)
		win_const_mgr.add_const('GESTURE_TRIPLE_TAP',0x00000000)
		win_const_mgr.add_const('SUCCEED_ASYNC',0x00000003)
		win_const_mgr.add_const('POLICY_IGNORE_NON_CRITICAL_BC',0x00000001)
		win_const_mgr.add_const('TMT_FROMHUE5',0x0000070D)
		win_const_mgr.add_const('APPCOMMAND_NEW',0x0000001D)
		win_const_mgr.add_const('SQL_QL_END',0x00000002)
		win_const_mgr.add_const('EM_GETWORDBREAKPROC',0x000000D1)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_CAN_TEST',0x00004006)
		win_const_mgr.add_const('MD_ACCESS_SOURCE',0x00000010)
		win_const_mgr.add_const('JRO_MINOR',0x00000006)
		win_const_mgr.add_const('TMT_GLYPHDIBDATA',0x00000008)
		win_const_mgr.add_const('OID_1394_LOCAL_NODE_INFO',0x0C010101)
		win_const_mgr.add_const('SQL_CUR_USE_DRIVER',0x00000002)
		win_const_mgr.add_const('IF_TYPE_ATM_FUNI',0x0000006A)
		win_const_mgr.add_const('SCARD_E_NOT_TRANSACTED',0x80100016)
		win_const_mgr.add_const('CM_SET_HW_PROF_FLAGS_UI_NOT_OK',0x00000001)
		win_const_mgr.add_const('IOC_PROTOCOL',0x10000000)
		win_const_mgr.add_const('HHWIN_PROP_NAV_ONLY_WIN',0x00000001)
		win_const_mgr.add_const('ERROR_GROUP_NOT_ONLINE',0x00001396)
		win_const_mgr.add_const('LINEERR_OPERATIONUNAVAIL',0x80000049)
		win_const_mgr.add_const('SQL_INFO_SS_FIRST',0x000004AF)
		win_const_mgr.add_const('CM_SETUP_DEVNODE_RESET',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_SH3_DIRECT4',0x00000006)
		win_const_mgr.add_const('REG_OPTION_BACKUP_RESTORE',0x00000004)
		win_const_mgr.add_const('ERROR_LOG_ARCHIVE_IN_PROGRESS',0x000019E9)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_PREPARE',0x00000002)
		win_const_mgr.add_const('DMDITHER_RESERVED6',0x00000006)
		win_const_mgr.add_const('IDM_TRIED_JUSTIFYCENTER',0x0000002C)
		win_const_mgr.add_const('DDOVERFX_MIRRORLEFTRIGHT',0x00000002)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_FLUORESCENT',0x00000002)
		win_const_mgr.add_const('LOCALE_IDEFAULTLANGUAGE',0x00000009)
		win_const_mgr.add_const('FD_CLOSE',0x00000001)
		win_const_mgr.add_const('SPSVCINST_STOPSERVICE',0x00000200)
		win_const_mgr.add_const('IMAGE_REL_EBC_ADDR32NB',0x00000001)
		win_const_mgr.add_const('CERT_STORE_PROV_GP_SYSTEM_STORE_FLAG',0x00000020)
		win_const_mgr.add_const('IRF_NO_WAIT',0x00000008)
		win_const_mgr.add_const('PORT_QUOTE',0x00000011)
		win_const_mgr.add_const('GCS_RESULTREADCLAUSE',0x00000400)
		win_const_mgr.add_const('D3DCAPS3_LINEAR_TO_SRGB_PRESENTATION',0x00000080)
		win_const_mgr.add_const('XP1_INTERRUPT',0x00004000)
		win_const_mgr.add_const('DISPLAY_DEVICE_ATTACHED',0x00000002)
		win_const_mgr.add_const('VK_BROWSER_SEARCH',0x000000AA)
		win_const_mgr.add_const('NUMPRS_TRAILING_WHITE',0x00000002)
		win_const_mgr.add_const('SQL_HANDLE_DESC',0x00000004)
		win_const_mgr.add_const('FPS_RECEIVING',0x20000004)
		win_const_mgr.add_const('INTERNET_REQFLAG_NET_TIMEOUT',0x00000080)
		win_const_mgr.add_const('JOB_OBJECT_RESERVED_LIMIT_VALID_FLAGS',0x00000007)
		win_const_mgr.add_const('NDR_CONTEXT_HANDLE_SERIALIZE',0x00000002)
		win_const_mgr.add_const('ASC_REQ_ALLOW_NULL_SESSION',0x00100000)
		win_const_mgr.add_const('CM_DRP_BUSTYPEGUID',0x00000014)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_FULL_MEMORY_INFO',0x00000400)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_IS_IPSEC_SECURED',0x00000002)
		win_const_mgr.add_const('OFFLINEAVAILABILITY_ALWAYS_AVAILABLE',0x00000002)
		win_const_mgr.add_const('CM_PROB_NOT_CONFIGURED',0x00000001)
		win_const_mgr.add_const('CM_DRP_LOCATION_INFORMATION',0x0000000E)
		win_const_mgr.add_const('PFD_NEED_PALETTE',0x00000080)
		win_const_mgr.add_const('ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC',0x00002127)
		win_const_mgr.add_const('DI_MULTMFGS',0x00000400)
		win_const_mgr.add_const('ASC_RET_ALLOCATED_MEMORY',0x00000100)
		win_const_mgr.add_const('URLACTION_DOWNLOAD_UNSIGNED_ACTIVEX',0x00001004)
		win_const_mgr.add_const('FROM_LEFT_1ST_BUTTON_PRESSED',0x00000001)
		win_const_mgr.add_const('VK_DBE_NOROMAN',0x00000000)
		win_const_mgr.add_const('DNS_TYPE_CNAME',0x00000005)
		win_const_mgr.add_const('PID_IS_WORKINGDIR',0x00000005)
		win_const_mgr.add_const('SC_MANAGER_QUERY_LOCK_STATUS',0x00000010)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_PLAY_PAUSE',0x0000000E)
		win_const_mgr.add_const('MCI_ANIM_PLAY_SCAN',0x00100000)
		win_const_mgr.add_const('NOTIFY_CLASS_REGISTRY_CHANGE',0x00000004)
		win_const_mgr.add_const('ILD_MASK',0x00000010)
		win_const_mgr.add_const('LINECALLSELECT_CALLID',0x00000010)
		win_const_mgr.add_const('SQLINTN',0x00000026)
		win_const_mgr.add_const('PROFILE_READWRITE',0x00000002)
		win_const_mgr.add_const('PID_VOLUME_FILESYSTEM',0x00000004)
		win_const_mgr.add_const('OID_TCP4_OFFLOAD_STATS',0xFC010207)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_RESOURCEUNAVAILABLE',0x0000000D)
		win_const_mgr.add_const('UINT32_MAX',0x00000000)
		win_const_mgr.add_const('HTTP_SERVICE_CONFIG_SSL_FLAG_NO_RAW_FILTER',0x00000004)
		win_const_mgr.add_const('SNMP_ACCESS_READ_CREATE',0x00000004)
		win_const_mgr.add_const('ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED',0x0000078D)
		win_const_mgr.add_const('VK_ZOOM',0x000000FB)
		win_const_mgr.add_const('DSQPF_SAVELOCATION',0x00000002)
		win_const_mgr.add_const('GESTURE_CURLICUE',0x00000000)
		win_const_mgr.add_const('SFVM_DEFITEMCOUNT',0x0000001A)
		win_const_mgr.add_const('DDOVER_KEYDEST',0x00000400)
		win_const_mgr.add_const('WMDM_CONTENT_FILE',0x00000004)
		win_const_mgr.add_const('ERROR_DS_AUDIT_FAILURE',0x000021B1)
		win_const_mgr.add_const('ERROR_DELETE_PENDING',0x0000012F)
		win_const_mgr.add_const('IDM_COMPOSESETTINGS',0x0000090E)
		win_const_mgr.add_const('STRM_RUNNING',0x00000004)
		win_const_mgr.add_const('SCESTATUS_OBJECT_EXIST',0x00000004)
		win_const_mgr.add_const('AAL5_SSCS_NULL',0x00000000)
		win_const_mgr.add_const('SERVICE_CONTROL_PARAMCHANGE',0x00000006)
		win_const_mgr.add_const('TMT_CAPTIONFONT',0x00000321)
		win_const_mgr.add_const('WINHTTP_QUERY_CACHE_CONTROL',0x00000031)
		win_const_mgr.add_const('SHUTDOWN_FORCE_OTHERS',0x00000001)
		win_const_mgr.add_const('AF_OP_PRINT',0x00000001)
		win_const_mgr.add_const('SPFILENOTIFY_NEEDNEWCABINET',0x00000012)
		win_const_mgr.add_const('BCRYPT_ECDSA_PUBLIC_P521_MAGIC',0x35534345)
		win_const_mgr.add_const('DS_IP_REQUIRED',0x00000200)
		win_const_mgr.add_const('FEI_DELETED',0x00000017)
		win_const_mgr.add_const('FLI_MASK',0x0000103B)
		win_const_mgr.add_const('LDAP_ADD_CMD',0x00000068)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_USER_SUM_PEAK_RATE',0x0000002F)
		win_const_mgr.add_const('TMT_BODYTEXTCOLOR',0x00000EF3)
		win_const_mgr.add_const('BG_E_DISCOVERY_IN_PROGRESS',0x80200044)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_LASTSECTOROFPREVIOUSSESSION',0x0000010C)
		win_const_mgr.add_const('DBPROPVAL_PERSIST_XML',0x00000001)
		win_const_mgr.add_const('GIL_ASYNC',0x00000020)
		win_const_mgr.add_const('IDM_RADIOBUTTON',0x00000874)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCDEVENTARGS_CURRENTACTION',0x00000301)
		win_const_mgr.add_const('XA_HEURMIX',0x00000005)
		win_const_mgr.add_const('MDM_V120_ML_NONE',0x00000001)
		win_const_mgr.add_const('IP_RECVDSTADDR',0x00000019)
		win_const_mgr.add_const('IDM_BLINK',0x0000088E)
		win_const_mgr.add_const('ERROR_HOOK_TYPE_NOT_ALLOWED',0x000005B2)
		win_const_mgr.add_const('FLG_ADDREG_TYPE_MASK',0xFFFF0000)
		win_const_mgr.add_const('APMMENUSUSPEND_DISABLED',0x00000000)
		win_const_mgr.add_const('SCOPE_TYPE_WINPATH',0x00000100)
		win_const_mgr.add_const('SQL_CODE_HOUR_TO_SECOND',0x0000000C)
		win_const_mgr.add_const('LINECALLINFOSTATE_TERMINAL',0x02000000)
		win_const_mgr.add_const('EVENT_OBJECT_DESTROY',0x00008001)
		win_const_mgr.add_const('MODALS_DOMAIN_NAME_PARMNUM',0x00000008)
		win_const_mgr.add_const('REG_FORCE_UNLOAD',0x00000001)
		win_const_mgr.add_const('DDCAPS_BLTQUEUE',0x00000080)
		win_const_mgr.add_const('FACILITY_NT_BIT',0x10000000)
		win_const_mgr.add_const('URL_MK_UNIFORM',0x00000001)
		win_const_mgr.add_const('LINEPROXYSTATUS_ALLOPENFORACD',0x00000004)
		win_const_mgr.add_const('EM_SETTABSTOPS',0x000000CB)
		win_const_mgr.add_const('EWX_QUICKRESOLVE',0x00000020)
		win_const_mgr.add_const('DBPROPVAL_BMK_NUMERIC',0x00000001)
		win_const_mgr.add_const('DDFXCAPS_BLTSTRETCHYN',0x00020000)
		win_const_mgr.add_const('STGM_WRITE',0x00000001)
		win_const_mgr.add_const('SAFER_POLICY_JOBID_CONSTRAINED',0x04000000)
		win_const_mgr.add_const('META_SETWINDOWEXT',0x0000020C)
		win_const_mgr.add_const('DVB_SDT_ACTUAL_TID',0x00000042)
		win_const_mgr.add_const('SQL_FN_TSI_YEAR',0x00000100)
		win_const_mgr.add_const('WINHTTP_OPTION_GLOBAL_PROXY_CREDS',0x00000061)
		win_const_mgr.add_const('BG_E_MISSING_FILE_SIZE',0x80200011)
		win_const_mgr.add_const('CONNECT_RESERVED',0xFF000000)
		win_const_mgr.add_const('SAMPLE_SEQ_CONTENT_I_FRAME',0x00000001)
		win_const_mgr.add_const('SSPROP_INIT_APPNAME',0x0000000A)
		win_const_mgr.add_const('DDBLT_EXTENDED_LINEAR_CONTENT',0x00000004)
		win_const_mgr.add_const('DDCAPS2_CANBOBHARDWARE',0x00004000)
		win_const_mgr.add_const('MCI_BREAK_KEY',0x00000100)
		win_const_mgr.add_const('DBPROPVAL_BD_ROWSET',0x00000000)
		win_const_mgr.add_const('PPP_LCP_CHAP_MS',0x00000080)
		win_const_mgr.add_const('IDD_SERVERNOTREGW',0x000003FD)
		win_const_mgr.add_const('WIA_IPA_RAW_BITS_PER_CHANNEL',0x00001020)
		win_const_mgr.add_const('OID_FDDI_SMT_AVAILABLE_PATHS',0x0303020B)
		win_const_mgr.add_const('NETLOGON_CONTROL_QUERY',0x00000001)
		win_const_mgr.add_const('MSGF_COMMCTRL_SIZEHEADER',0x00004201)
		win_const_mgr.add_const('REO_RESIZABLE',0x00000001)
		win_const_mgr.add_const('RRF_RT_REG_BINARY',0x00000008)
		win_const_mgr.add_const('DMPAPER_P16K',0x0000005D)
		win_const_mgr.add_const('IF_TYPE_DLSW',0x0000004A)
		win_const_mgr.add_const('IDD_SERVERNOTREGA',0x00000401)
		win_const_mgr.add_const('GREEN_SHIFT',0x00000008)
		win_const_mgr.add_const('_WIN32_IE_IE302',0x00000302)
		win_const_mgr.add_const('SC_SIZE',0x0000F000)
		win_const_mgr.add_const('ERROR_NETWORK_UNREACHABLE',0x000004CF)
		win_const_mgr.add_const('L2_REASON_CODE_GEN_BASE',0x00010000)
		win_const_mgr.add_const('PP_SIGNATURE_KEYSIZE',0x0000000D)
		win_const_mgr.add_const('WM_DEVICECHANGE',0x00000219)
		win_const_mgr.add_const('MPR_INTERFACE_OUT_OF_RESOURCES',0x00000001)
		win_const_mgr.add_const('OID_802_5_CURRENT_RING_STATE',0x02010107)
		win_const_mgr.add_const('RIM_TYPEKEYBOARD',0x00000001)
		win_const_mgr.add_const('OFFLINESTATUS_ONLINE',0x00000000)
		win_const_mgr.add_const('PHONESTATE_HANDSETGAIN',0x00000800)
		win_const_mgr.add_const('PER_USER_AUDIT_FAILURE_INCLUDE',0x00000004)
		win_const_mgr.add_const('SKF_LCTLLATCHED',0x04000000)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SOURCE_AVERAGE',0x00004000)
		win_const_mgr.add_const('SQLAOPCNT',0x00000004)
		win_const_mgr.add_const('RECOFLAG_WORDMODE',0x00000001)
		win_const_mgr.add_const('EAP_FLAG_SUPRESS_UI',0x00010000)
		win_const_mgr.add_const('DISPID_IHTMLMIMETYPESCOLLECTION_LENGTH',0x00000001)
		win_const_mgr.add_const('ERROR_ALREADY_THREAD',0x00000501)
		win_const_mgr.add_const('WLX_CREATE_INSTANCE_ONLY',0x00000001)
		win_const_mgr.add_const('ERROR_DISK_OPERATION_FAILED',0x00000467)
		win_const_mgr.add_const('CM_HWPI_UNDOCKED',0x00000001)
		win_const_mgr.add_const('DI_USECI_SELECTSTRINGS',0x08000000)
		win_const_mgr.add_const('LINECALLINFOSTATE_NUMMONITORS',0x00002000)
		win_const_mgr.add_const('RTM_MATCH_FULL',0x0000FFFF)
		win_const_mgr.add_const('MTXDM_E_ENLISTRESOURCEFAILED',0x8004E100)
		win_const_mgr.add_const('ARW_TOPRIGHT',0x00000003)
		win_const_mgr.add_const('ODT_MENU',0x00000001)
		win_const_mgr.add_const('LINETERMMODE_MEDIAFROMLINE',0x00000040)
		win_const_mgr.add_const('RAS_EAP_ROLE_EXCLUDE_IN_VPN',0x00000010)
		win_const_mgr.add_const('JOB_OBJECT_SECURITY_NO_ADMIN',0x00000001)
		win_const_mgr.add_const('CERT_RDN_DISABLE_CHECK_TYPE_FLAG',0x40000000)
		win_const_mgr.add_const('ERROR_MEMBER_IN_GROUP',0x00000528)
		win_const_mgr.add_const('ACM_FILTERTAGDETAILSF_INDEX',0x00000000)
		win_const_mgr.add_const('IDM_PAGEINFO',0x000008B7)
		win_const_mgr.add_const('EISAFLAG_SLOT_IO_FIRST',0x00000002)
		win_const_mgr.add_const('LINEERR_NOTREGISTERED',0x80000047)
		win_const_mgr.add_const('IMAGE_REL_M32R_GPREL16',0x00000004)
		win_const_mgr.add_const('PAPS_PRESAVE',0x00000000)
		win_const_mgr.add_const('SAP_BASE_ENTRY',0x00000000)
		win_const_mgr.add_const('ERROR_PATCH_TARGET_NOT_FOUND',0x0000066A)
		win_const_mgr.add_const('APPCOMMAND_DELETE',0x00000035)
		win_const_mgr.add_const('WMDM_E_PROCESSFAILED',0x80045003)
		win_const_mgr.add_const('TVIS_CUT',0x00000004)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_26',0x0000001A)
		win_const_mgr.add_const('PSCB_PRECREATE',0x00000002)
		win_const_mgr.add_const('IF_TYPE_X25_HUNTGROUP',0x0000007A)
		win_const_mgr.add_const('PDERR_INITFAILURE',0x00001006)
		win_const_mgr.add_const('CRED_PACK_GENERIC_CREDENTIALS',0x00000004)
		win_const_mgr.add_const('FILE_DEVICE_SERIAL_PORT',0x00000001)
		win_const_mgr.add_const('CMSG_KEY_TRANS_ENCRYPT_FREE_OBJID_FLAG',0x00000002)
		win_const_mgr.add_const('LINEREMOVEFROMCONF_NONE',0x00000001)
		win_const_mgr.add_const('OPTION_KEEP_ALIVE_INTERVAL',0x00000026)
		win_const_mgr.add_const('SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION_3',0x00000003)
		win_const_mgr.add_const('HDF_SORTDOWN',0x00000200)
		win_const_mgr.add_const('ERROR_MEDIA_UNAVAILABLE',0x000010D4)
		win_const_mgr.add_const('SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION_4',0x00000004)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_POLICY_CHANGE',0x00003619)
		win_const_mgr.add_const('SV_ERRORTHRESHOLD_PARMNUM',0x00000224)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_CLIENTNAME',0x00000110)
		win_const_mgr.add_const('EAP_E_USER_CERT_REVOKED',0x80420103)
		win_const_mgr.add_const('ERROR_SHARING_BUFFER_EXCEEDED',0x00000024)
		win_const_mgr.add_const('DI_NEEDREBOOT',0x00000100)
		win_const_mgr.add_const('ES_SELFIME',0x00040000)
		win_const_mgr.add_const('PFS_PPL',0x0000003E)
		win_const_mgr.add_const('SQL_TIMEDATE_FUNCTIONS',0x00000034)
		win_const_mgr.add_const('MC_CAPS_DEGAUSS',0x00000040)
		win_const_mgr.add_const('DT_WORD_ELLIPSIS',0x00040000)
		win_const_mgr.add_const('IME_SMODE_RESERVED',0x0000F000)
		win_const_mgr.add_const('IMAGE_REL_SHM_PCRELPT',0x00000013)
		win_const_mgr.add_const('CREATE_PROTECTED_PROCESS',0x00040000)
		win_const_mgr.add_const('ERROR_THREAD_1_INACTIVE',0x000000D2)
		win_const_mgr.add_const('EWX_SHUTDOWN',0x00000001)
		win_const_mgr.add_const('TF_LBI_STYLE_SHOWNINTRAYONLY',0x00000008)
		win_const_mgr.add_const('WMDM_E_TOO_MANY_SESSIONS',0x80045013)
		win_const_mgr.add_const('PHONEBUTTONMODE_KEYPAD',0x00000008)
		win_const_mgr.add_const('SES_ALLOWBEEPS',0x00000100)
		win_const_mgr.add_const('TXFS_RM_FLAG_ENFORCE_MINIMUM_SIZE',0x00001000)
		win_const_mgr.add_const('DS_TIMESERV_REQUIRED',0x00000800)
		win_const_mgr.add_const('PI_NOUI',0x00000001)
		win_const_mgr.add_const('SQL_FN_STR_CHAR',0x00004000)
		win_const_mgr.add_const('CAUSE_INVALID_NUMBER_FORMAT',0x0000001C)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_TOOBIG',0x00000001)
		win_const_mgr.add_const('CCH_MAX_PROPSTG_NAME',0x0000001F)
		win_const_mgr.add_const('MDMEASURE_AGGR_MAX',0x00000004)
		win_const_mgr.add_const('VER_LESS_EQUAL',0x00000005)
		win_const_mgr.add_const('ERROR_I24_CHAR_CALL_INTERRUPTED',0x00000011)
		win_const_mgr.add_const('EXTENDED_STARTUPINFO_PRESENT',0x00080000)
		win_const_mgr.add_const('LINEERR_INVALAGENTSTATE',0x8000005A)
		win_const_mgr.add_const('DISPID_CONTENTSCHANGED',0x000000CF)
		win_const_mgr.add_const('SERVICE_DELETE_TYPE',0x00000005)
		win_const_mgr.add_const('SQL_DESC_LENGTH',0x000003EB)
		win_const_mgr.add_const('TLS1_ALERT_UNEXPECTED_MESSAGE',0x0000000A)
		win_const_mgr.add_const('PORT_OCSERVER',0x000000B8)
		win_const_mgr.add_const('VIEW_E_LAST',0x8004014F)
		win_const_mgr.add_const('WLX_SAS_ACTION_LOCK_WKSTA',0x00000003)
		win_const_mgr.add_const('FILEOP_RENAME',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_M32R_PCREL8',0x00000007)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2_SUPPORTEDMEDIATYPES',0x00000702)
		win_const_mgr.add_const('ENABLE_WINDOW_INPUT',0x00000008)
		win_const_mgr.add_const('FACILITY_WINDOWSUPDATE',0x00000024)
		win_const_mgr.add_const('WIA_TRANSFER_MSG_DEVICE_STATUS',0x00000005)
		win_const_mgr.add_const('NOTE_COLOR_BLUE',0x00000000)
		win_const_mgr.add_const('MDM_FLOWCONTROL_SOFT',0x00000020)
		win_const_mgr.add_const('DDPF_LUMINANCE',0x00020000)
		win_const_mgr.add_const('TXFS_LOGGING_MODE_SIMPLE',0x00000001)
		win_const_mgr.add_const('FEI_CALL_DELAYED',0x00000000)
		win_const_mgr.add_const('NRC_OSRESNOTAV',0x00000035)
		win_const_mgr.add_const('SERIAL_NUMBER_LENGTH',0x00000020)
		win_const_mgr.add_const('ERROR_INVALID_EA_HANDLE',0x00000116)
		win_const_mgr.add_const('PROPID_M_CORRELATIONID_SIZE',0x00000014)
		win_const_mgr.add_const('IDH_OK',0x00006F1B)
		win_const_mgr.add_const('LINEADDRESSSTATE_INUSEMANY',0x00000010)
		win_const_mgr.add_const('IDD_CANNOTUPDATELINK',0x000003F0)
		win_const_mgr.add_const('PTE_CACHE_LEN',0x00000003)
		win_const_mgr.add_const('CSCONTROL_RESTART',0x00000003)
		win_const_mgr.add_const('ERROR_ACCOUNT_EXPIRED',0x00000701)
		win_const_mgr.add_const('SP_COPY_SOURCE_ABSOLUTE',0x00000040)
		win_const_mgr.add_const('TMT_INACTIVEBORDER',0x0000064C)
		win_const_mgr.add_const('DDSD_CKSRCOVERLAY',0x00008000)
		win_const_mgr.add_const('MDPROPVAL_MSF_TOPPERCENT',0x00000001)
		win_const_mgr.add_const('SUBLANG_SERBIAN_LATIN',0x00000002)
		win_const_mgr.add_const('SHACF_VIRTUAL_NAMESPACE',0x00000040)
		win_const_mgr.add_const('CM_REMOVAL_POLICY_EXPECT_ORDERLY_REMOVAL',0x00000002)
		win_const_mgr.add_const('LDAP_FILTER_EQUALITY',0x00000000)
		win_const_mgr.add_const('ETW_INT64_TYPE_VALUE',0x00000009)
		win_const_mgr.add_const('LANG_ALBANIAN',0x00000001)
		win_const_mgr.add_const('URL_PARTFLAG_KEEPSCHEME',0x00000001)
		win_const_mgr.add_const('PORT_QFT',0x000000BD)
		win_const_mgr.add_const('IDM_SELECTALL',0x0000001F)
		win_const_mgr.add_const('MQ_LOOKUP_PEEK_NEXT',0x40000011)
		win_const_mgr.add_const('WKSTA_NUMDGRAMBUF_PARMNUM',0x0000001F)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_LOAD_FAILED',0x00003634)
		win_const_mgr.add_const('CREDUI_FLAGS_SERVER_CREDENTIAL',0x00004000)
		win_const_mgr.add_const('MOUSE_MOVE_ABSOLUTE',0x00000001)
		win_const_mgr.add_const('LINECALLORIGIN_INTERNAL',0x00000002)
		win_const_mgr.add_const('ACM_DRIVERENUMF_DISABLED',0x80000000)
		win_const_mgr.add_const('DIREG_BOTH',0x00000004)
		win_const_mgr.add_const('SERVICE_CONTROLLEDLOAD',0x80020000)
		win_const_mgr.add_const('FILE_TYPE_DISK',0x00000001)
		win_const_mgr.add_const('MD_LOGCUSTOM_DATATYPE_LONG',0x00000002)
		win_const_mgr.add_const('AE_ACLMOD',0x0000000C)
		win_const_mgr.add_const('SMART_WRITE_LOG',0x00000000)
		win_const_mgr.add_const('TAPE_QUERY_IO_ERROR_DATA',0x00000003)
		win_const_mgr.add_const('CERT_UNICODE_VALUE_ERR_INDEX_MASK',0x0000FFFF)
		win_const_mgr.add_const('DI_FLAGSEX_RESTART_DEVICE_ONLY',0x20000000)
		win_const_mgr.add_const('ENUM_ALL_CALENDARS',0x00000000)
		win_const_mgr.add_const('LM20_SERVICE_CONTINUE_PENDING',0x00000004)
		win_const_mgr.add_const('DS_REPL_NBR_SYNC_ON_STARTUP',0x00000020)
		win_const_mgr.add_const('DISPID_EVENTHOOK_INSENSITIVE_MAX',0x004C4B3F)
		win_const_mgr.add_const('_SIZE_T_ERROR',0x00000000)
		win_const_mgr.add_const('CSIDL_PRINTHOOD',0x00000001)
		win_const_mgr.add_const('DWM_EC_ENABLECOMPOSITION',0x00000001)
		win_const_mgr.add_const('DSLFLAG_MISMATCHED_PDB',0x00000001)
		win_const_mgr.add_const('DISPLAYDIB_MODE_DEFAULT',0x00000000)
		win_const_mgr.add_const('IF_CONNECTION_DEMAND',0x00000003)
		win_const_mgr.add_const('SS_WORDELLIPSIS',0x0000C000)
		win_const_mgr.add_const('ERROR_SET_POWER_STATE_VETOED',0x00000474)
		win_const_mgr.add_const('DISPID_UNLOAD',0x00000002)
		win_const_mgr.add_const('WINSTA_ENUMDESKTOPS',0x00000001)
		win_const_mgr.add_const('ERROR_CTX_CDM_DISCONNECT',0x00001B9B)
		win_const_mgr.add_const('SB_PREMULT_ALPHA',0x00000004)
		win_const_mgr.add_const('MSIMHOSTEVENTS_DISPID_ONSHUTDOWN',0x0000000E)
		win_const_mgr.add_const('IMAGE_REL_SHM_REFLO',0x00000014)
		win_const_mgr.add_const('SQLINT1',0x00000030)
		win_const_mgr.add_const('PROCESS_SET_QUOTA',0x00000100)
		win_const_mgr.add_const('MFCLOCK_JITTER_ISR',0x000003E8)
		win_const_mgr.add_const('DATABITS_16',0x00000010)
		win_const_mgr.add_const('OID_ATM_MAX_ACTIVE_VCS',0x08010105)
		win_const_mgr.add_const('SCH_CRED_DISABLE_RECONNECTS',0x00000080)
		win_const_mgr.add_const('DEBUG_OUTTYPE_ADDRESS_AT_END',0x00020000)
		win_const_mgr.add_const('SE_DACL_AUTO_INHERITED',0x00000400)
		win_const_mgr.add_const('COLORMATCHTOTARGET_EMBEDED',0x00000001)
		win_const_mgr.add_const('MD_ERROR_SUB403_CERT_REVOKED',0x0000000D)
		win_const_mgr.add_const('IDD_ACMFILTERCHOOSE_BTN_SETNAME',0x00000067)
		win_const_mgr.add_const('ACTRL_STD_RIGHTS_ALL',0x00000000)
		win_const_mgr.add_const('COLOR_MENUHILIGHT',0x0000001D)
		win_const_mgr.add_const('SNMP_ERROR_UNDOFAILED',0x0000000F)
		win_const_mgr.add_const('SVSI_POSITIONITEM',0x00000080)
		win_const_mgr.add_const('NCRYPTBUFFER_PKCS_ALG_PARAM',0x0000002A)
		win_const_mgr.add_const('SQL_CN_ANY',0x00000002)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_NONE',0x00000017)
		win_const_mgr.add_const('DTS_TIMEFORMAT',0x00000009)
		win_const_mgr.add_const('LOCALE_IINTLCURRDIGITS',0x0000001A)
		win_const_mgr.add_const('HTCAPTION',0x00000002)
		win_const_mgr.add_const('OS_WIN2000TERMINAL',0x0000000C)
		win_const_mgr.add_const('USN_REASON_REPARSE_POINT_CHANGE',0x00100000)
		win_const_mgr.add_const('STATUS_SEVERITY_INFORMATIONAL',0x00000001)
		win_const_mgr.add_const('TYPE1_FONTTYPE',0x00040000)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_FILTER_PARTIAL_CHARACTERISTICS',0x0000008C)
		win_const_mgr.add_const('CMSG_CONTENT_ENCRYPT_RELEASE_CONTEXT_FLAG',0x00008000)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_CALLAPP',0x0000001E)
		win_const_mgr.add_const('D3DTEXOPCAPS_MODULATE2X',0x00000010)
		win_const_mgr.add_const('DEBUG_ATTACH_NONINVASIVE',0x00000001)
		win_const_mgr.add_const('ERROR_FAIL_I24',0x00000053)
		win_const_mgr.add_const('LOCALE_SNATIVEDIGITS',0x00000013)
		win_const_mgr.add_const('LOGON32_PROVIDER_WINNT40',0x00000002)
		win_const_mgr.add_const('VER_PLATFORM_WIN32_NT',0x00000002)
		win_const_mgr.add_const('MCI_SEQ_STATUS_OFFSET',0x00004009)
		win_const_mgr.add_const('CR_PROP_BASECRLPUBLISHSTATUS',0x0000001E)
		win_const_mgr.add_const('WMDRM_LICENSE_TYPE_XMR',0x00000002)
		win_const_mgr.add_const('SM_CYMAXIMIZED',0x0000003E)
		win_const_mgr.add_const('EVENT_TRACE_USE_PAGED_MEMORY',0x01000000)
		win_const_mgr.add_const('SQL_SMALLINT',0x00000005)
		win_const_mgr.add_const('IO_REPARSE_TAG_DFS',0x8000000A)
		win_const_mgr.add_const('SHDID_COMPUTER_AUDIO',0x00000013)
		win_const_mgr.add_const('ACTRL_ACCESS_DENIED',0x00000002)
		win_const_mgr.add_const('PIPE_NOWAIT',0x00000001)
		win_const_mgr.add_const('RPC_C_NS_SYNTAX_DEFAULT',0x00000000)
		win_const_mgr.add_const('OID_QOS_RESERVED14',0xFB01010D)
		win_const_mgr.add_const('OID_QOS_RESERVED15',0xFB01010E)
		win_const_mgr.add_const('OID_QOS_RESERVED16',0xFB01010F)
		win_const_mgr.add_const('OID_QOS_RESERVED17',0xFB010110)
		win_const_mgr.add_const('OID_QOS_RESERVED10',0xFB010109)
		win_const_mgr.add_const('OID_QOS_RESERVED11',0xFB01010A)
		win_const_mgr.add_const('OID_QOS_RESERVED12',0xFB01010B)
		win_const_mgr.add_const('DVD_TITLE_MENU',0x00000000)
		win_const_mgr.add_const('ERROR_OPERATION_ABORTED',0x000003E3)
		win_const_mgr.add_const('OID_QOS_RESERVED18',0xFB010111)
		win_const_mgr.add_const('OID_QOS_RESERVED19',0xFB010112)
		win_const_mgr.add_const('HTTP_QUERY_TITLE',0x00000026)
		win_const_mgr.add_const('LINEERR_INVALLOCATION',0x8000002D)
		win_const_mgr.add_const('ERROR_EMPTY',0x000010D2)
		win_const_mgr.add_const('ERROR_INC_BACKUP',0x00000FA3)
		win_const_mgr.add_const('IITWBC_BREAKTYPE_TIME',0x00000003)
		win_const_mgr.add_const('LOCALGROUP_NAME_PARMNUM',0x00000001)
		win_const_mgr.add_const('ALG_SID_SHA_256',0x0000000C)
		win_const_mgr.add_const('DDL_HIDDEN',0x00000002)
		win_const_mgr.add_const('ERROR_PRINTER_DELETED',0x00000771)
		win_const_mgr.add_const('BCRYPT_RNG_USE_ENTROPY_IN_BUFFER',0x00000001)
		win_const_mgr.add_const('FC_BIG_PIPE',0x00000080)
		win_const_mgr.add_const('CF_OWNERDISPLAY',0x00000080)
		win_const_mgr.add_const('BTH_ERROR_LMP_PDU_NOT_ALLOWED',0x00000024)
		win_const_mgr.add_const('DEBUG_ATTACH_NONINVASIVE_ALLOW_PARTIAL',0x00000020)
		win_const_mgr.add_const('CRYPTNET_URL_CACHE_PRE_FETCH_BLOB',0x00000001)
		win_const_mgr.add_const('NO_PERMISSION_REQUIRED',0x00000001)
		win_const_mgr.add_const('MK_S_FIRST',0x000401E0)
		win_const_mgr.add_const('LAST_LINEMEDIAMODE',0x00008000)
		win_const_mgr.add_const('MSG_INTERRUPT',0x00000010)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_NOCREATION',0x0000000B)
		win_const_mgr.add_const('SPFILENOTIFY_STARTQUEUE',0x00000001)
		win_const_mgr.add_const('ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY',0x00002009)
		win_const_mgr.add_const('USE_OK',0x00000000)
		win_const_mgr.add_const('TMT_TRANSPARENT',0x00000899)
		win_const_mgr.add_const('FILE_DEVICE_MODEM',0x00000002)
		win_const_mgr.add_const('SQL_TIMESTAMP_LEN',0x00000013)
		win_const_mgr.add_const('ERROR_WMI_SET_FAILURE',0x00001076)
		win_const_mgr.add_const('WLAN_API_VERSION_1_0',0x00000001)
		win_const_mgr.add_const('DNS_TYPE_WKS',0x00000000)
		win_const_mgr.add_const('HHWIN_BUTTON_PRINT',0x00000001)
		win_const_mgr.add_const('OID_GEN_NETCARD_LOAD',0x00020211)
		win_const_mgr.add_const('GD_MENU',0x00000004)
		win_const_mgr.add_const('LANG_LAO',0x00000054)
		win_const_mgr.add_const('DC_PAPERNAMES',0x00000010)
		win_const_mgr.add_const('SETCOPYCOUNT',0x00000011)
		win_const_mgr.add_const('CRLF_REVCHECK_IGNORE_NOREVCHECK',0x00020000)
		win_const_mgr.add_const('SQL_NOSCAN_OFF',0x00000000)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_DISCARD',0x00000004)
		win_const_mgr.add_const('CLIP_TO_PATH',0x00001001)
		win_const_mgr.add_const('CERT_RDN_IA5_STRING',0x00000007)
		win_const_mgr.add_const('IDC_GP_OBJECTNAME',0x000003F1)
		win_const_mgr.add_const('URLACTION_HTML_USERDATA_SAVE',0x00001606)
		win_const_mgr.add_const('GOPHER_TYPE_MOVIE',0x00008000)
		win_const_mgr.add_const('DBG_TASKSTART',0x0000000A)
		win_const_mgr.add_const('DMPAPER_FOLIO',0x0000000E)
		win_const_mgr.add_const('ALG_SID_SSL3_MASTER',0x00000001)
		win_const_mgr.add_const('DIOCR_INTERFACE',0x00000002)
		win_const_mgr.add_const('WM_IMEKEYDOWN',0x00000290)
		win_const_mgr.add_const('MCI_SEQ_SET_TEMPO',0x00010000)
		win_const_mgr.add_const('ICW_MAX_PASSWORD',0x00000100)
		win_const_mgr.add_const('IMAGE_REL_AMD64_REL32_2',0x00000006)
		win_const_mgr.add_const('EMR_GLSRECORD',0x00000066)
		win_const_mgr.add_const('MD_ERROR_SUB404_FILE_ATTRIBUTE_HIDDEN',0x00000009)
		win_const_mgr.add_const('IMAGE_REL_AMD64_REL32_5',0x00000009)
		win_const_mgr.add_const('IMAGE_REL_AMD64_REL32_4',0x00000008)
		win_const_mgr.add_const('FACILITY_NULL',0x00000000)
		win_const_mgr.add_const('LINEAGENTSESSIONSTATE_NOTREADY',0x00000001)
		win_const_mgr.add_const('HHT_TORIGHT',0x00000400)
		win_const_mgr.add_const('SNMPAPI_TL_NOT_SUPPORTED',0x00000065)
		win_const_mgr.add_const('IP_CHKSUM_OFF',0x0000000A)
		win_const_mgr.add_const('CDO_E_SELF_BINDING',0x80040234)
		win_const_mgr.add_const('HTTP_QUERY_CACHE_CONTROL',0x00000031)
		win_const_mgr.add_const('IPP_E_SERVERTYPE_NOT_SUPPORTED',0xC004800A)
		win_const_mgr.add_const('FRS_ERR_PARENT_AUTHENTICATION',0x00001F4A)
		win_const_mgr.add_const('SSPROP_STREAM_MAPPINGSCHEMA',0x0000000F)
		win_const_mgr.add_const('DS_USEPIXELS',0x00008000)
		win_const_mgr.add_const('SFGAO_READONLY',0x00040000)
		win_const_mgr.add_const('CAUSE_BEARER_CAPABILITY_UNIMPLEMENTED',0x00000041)
		win_const_mgr.add_const('LDAP_DEREF_ALWAYS',0x00000003)
		win_const_mgr.add_const('SHARD_PATHW',0x00000003)
		win_const_mgr.add_const('SF_NOTIFY_NONSECURE_PORT',0x00000002)
		win_const_mgr.add_const('RTCEF_REINVITE',0x00400000)
		win_const_mgr.add_const('MAX_MODULE_NAME',0x00000008)
		win_const_mgr.add_const('TPM_LEFTALIGN',0x00000000)
		win_const_mgr.add_const('ERROR_WX86_ERROR',0x0000021C)
		win_const_mgr.add_const('BAUD_56K',0x00008000)
		win_const_mgr.add_const('INSUFFICIENT_PRIVILEGES',0x00000003)
		win_const_mgr.add_const('SHARD_PATHA',0x00000002)
		win_const_mgr.add_const('BTH_MFG_CONEXANT',0x0000001C)
		win_const_mgr.add_const('DEBUG_EVENT_CHANGE_ENGINE_STATE',0x00000800)
		win_const_mgr.add_const('ERROR_DS_HIERARCHY_TABLE_TOO_DEEP',0x000021B4)
		win_const_mgr.add_const('CRYPT_KEYID_MACHINE_FLAG',0x00000020)
		win_const_mgr.add_const('WMDM_E_NOTSUPPORTED',0x80045004)
		win_const_mgr.add_const('CMSG_RECIPIENT_INFO_PARAM',0x00000013)
		win_const_mgr.add_const('HTTP_STATUS_DENIED',0x00000191)
		win_const_mgr.add_const('XECR_CMC',0x00000003)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGQUERY',0x0000000D)
		win_const_mgr.add_const('POSTSCRIPT_IGNORE',0x00000026)
		win_const_mgr.add_const('IT_COMPACT',0x00000000)
		win_const_mgr.add_const('GCP_MAXEXTENT',0x00100000)
		win_const_mgr.add_const('GCPCLASS_HEBREW',0x00000002)
		win_const_mgr.add_const('CTL_MODIFY_REQUEST_REMOVE',0x00000002)
		win_const_mgr.add_const('DDEDM_REFRESHRATES',0x00000001)
		win_const_mgr.add_const('VP_FLAGS_MAX_UNSCALED',0x00000010)
		win_const_mgr.add_const('LOCALE_SLANGDISPLAYNAME',0x00000006)
		win_const_mgr.add_const('DNS_RCODE_YXRRSET',0x00000007)
		win_const_mgr.add_const('MONITOR_DEFAULTTONEAREST',0x00000002)
		win_const_mgr.add_const('SQL_DV_CASCADE',0x00000004)
		win_const_mgr.add_const('SECURITY_PRINCIPAL_SELF_RID',0x0000000A)
		win_const_mgr.add_const('IDS_ORIGINAL_MESSAGE',0x00011000)
		win_const_mgr.add_const('PCI_OPTIONS_USE_IRQ_STEERING',0x00000002)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW4_CREATEPOPUP',0x0000049C)
		win_const_mgr.add_const('SQL_SSF_TRANSLATE',0x00000010)
		win_const_mgr.add_const('ADN_DEL_UNC_PATHS',0x00000008)
		win_const_mgr.add_const('START_SEQUENCE',0x00000001)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_RESERVED5',0x00020000)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_RESERVED2',0x00004000)
		win_const_mgr.add_const('LINEADDRESSSTATE_INUSEZERO',0x00000004)
		win_const_mgr.add_const('TVS_LINESATROOT',0x00000004)
		win_const_mgr.add_const('PCF_TOTALTIMEOUTS',0x00000040)
		win_const_mgr.add_const('SERVER_SEARCH_FLAG_DOMAIN_SCOPE',0x00000001)
		win_const_mgr.add_const('F_REFERENCED',0x0000000E)
		win_const_mgr.add_const('CREDUI_FLAGS_GENERIC_CREDENTIALS',0x00040000)
		win_const_mgr.add_const('SCF_ASSOCIATEFONT',0x00000010)
		win_const_mgr.add_const('KSPROPERTY_MEMBER_VALUES',0x00000003)
		win_const_mgr.add_const('SFGAO_FILESYSTEM',0x40000000)
		win_const_mgr.add_const('SSF_HIDEICONS',0x00004000)
		win_const_mgr.add_const('BG_COPY_FILE_OWNER',0x00000001)
		win_const_mgr.add_const('WIA_PAGE_JIS_B7',0x0000002E)
		win_const_mgr.add_const('WM_CODEC_TWOPASS_VBR_UNCONSTRAINED',0x00000008)
		win_const_mgr.add_const('DEBUG_TBINFO_ALL',0x00000003)
		win_const_mgr.add_const('COLOR_BTNSHADOW',0x00000010)
		win_const_mgr.add_const('CSIDL_PROGRAM_FILES_COMMON',0x00000002)
		win_const_mgr.add_const('CHECKJPEGFORMAT',0x00001017)
		win_const_mgr.add_const('PT_MOVETO',0x00000006)
		win_const_mgr.add_const('IDTB_BACK',0x000000CC)
		win_const_mgr.add_const('APPCOMMAND_BASS_DOWN',0x00000013)
		win_const_mgr.add_const('LINEPROXYREQUEST_SETAGENTSTATEEX',0x00000014)
		win_const_mgr.add_const('KSPIN_FLAG_ASYNCHRONOUS_PROCESSING',0x00000008)
		win_const_mgr.add_const('PC_TRAPEZOID',0x00000004)
		win_const_mgr.add_const('VK_DOWN',0x00000028)
		win_const_mgr.add_const('OPTION_NETBIOS_DATAGRAM_SERVER',0x0000002D)
		win_const_mgr.add_const('DSOP_FILTER_GLOBAL_GROUPS_DL',0x00000040)
		win_const_mgr.add_const('GESTURE_DOLLAR',0x00000000)
		win_const_mgr.add_const('DEBUG_GSEL_ALLOW_LOWER',0x00000002)
		win_const_mgr.add_const('DTR_DRIVER0_INDEX',0x00000002)
		win_const_mgr.add_const('PRINTER_ENUM_CONNECTIONS',0x00000004)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_PROCESS_THREAD_DATA',0x00000080)
		win_const_mgr.add_const('DBIM_BKCOLOR',0x00000040)
		win_const_mgr.add_const('ERROR_SUBST_TO_JOIN',0x0000008D)
		win_const_mgr.add_const('DIRID_VIEWERS',0x00000015)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_TABLE_CONSTRAINTS',0x00000007)
		win_const_mgr.add_const('PORT_USERS',0x0000000B)
		win_const_mgr.add_const('WMDRM_PROTECTION_TYPE_RC4',0x00000001)
		win_const_mgr.add_const('PT_MANDATORY',0x00000004)
		win_const_mgr.add_const('CACHE_ENTRY_HITRATE_FC',0x00000010)
		win_const_mgr.add_const('XEPR_VERSION',0x00000007)
		win_const_mgr.add_const('DEBUG_MODULE_UNLOADED',0x00000001)
		win_const_mgr.add_const('SPI_GETDESKWALLPAPER',0x00000073)
		win_const_mgr.add_const('PORT_CRONUS',0x00000094)
		win_const_mgr.add_const('DSCCIF_HASWIZARDPRIMARYPAGE',0x00000002)
		win_const_mgr.add_const('MCI_VCR_STATUS_PAUSE_TIMEOUT',0x00004022)
		win_const_mgr.add_const('PORT_NS',0x000002F8)
		win_const_mgr.add_const('CM_PROB_NOT_VERIFIED',0x0000000D)
		win_const_mgr.add_const('DBPROPVAL_IT_HASH',0x00000002)
		win_const_mgr.add_const('CERT_ACCESS_STATE_WRITE_PERSIST_FLAG',0x00000001)
		win_const_mgr.add_const('MCI_VCR_STATUS_TIMECODE_RECORD',0x00004016)
		win_const_mgr.add_const('CMSG_SIGNER_INFO_V1',0x00000001)
		win_const_mgr.add_const('AM_DVD_COPYRIGHTED',0x00000040)
		win_const_mgr.add_const('CMSG_SIGNER_INFO_V3',0x00000003)
		win_const_mgr.add_const('GPO_BROWSE_NODSGPOS',0x00000004)
		win_const_mgr.add_const('WMDM_DEVICE_TYPE_NONSDMI',0x00000080)
		win_const_mgr.add_const('SERVICE_NOTIFY_START_PENDING',0x00000002)
		win_const_mgr.add_const('SMART_INVALID_BUFFER',0x00000004)
		win_const_mgr.add_const('S_PERIOD2048',0x00000002)
		win_const_mgr.add_const('ICM_QUERYPROFILE',0x00000003)
		win_const_mgr.add_const('CREDUIWIN_ENUMERATE_ADMINS',0x00000100)
		win_const_mgr.add_const('CTFMODEBIAS_FILENAME',0x00000001)
		win_const_mgr.add_const('NRB_OUTPUT_DATA_OVERRUN',0x00000005)
		win_const_mgr.add_const('COLOR_SOLID_LEFT',0x000002DA)
		win_const_mgr.add_const('CCS_NOMOVEY',0x00000002)
		win_const_mgr.add_const('NFS_USEFONTASSOC',0x00000020)
		win_const_mgr.add_const('ICEE_CREATE_FILE_EMIT_FIXUPS',0x00000010)
		win_const_mgr.add_const('CPF_BADURL_ERROR',0x00000020)
		win_const_mgr.add_const('PATCH_OPTION_NO_LOCKFIX',0x00020000)
		win_const_mgr.add_const('DDOVER_KEYSRC',0x00001000)
		win_const_mgr.add_const('COOKIEACTION_READ',0x00000020)
		win_const_mgr.add_const('DTBG_MIRRORDC',0x00000020)
		win_const_mgr.add_const('CERT_TRUST_REVOCATION_STATUS_UNKNOWN',0x00000040)
		win_const_mgr.add_const('WM_CLIPBOARDUPDATE',0x0000031D)
		win_const_mgr.add_const('PAN_LETTERFORM_INDEX',0x00000007)
		win_const_mgr.add_const('CONNECTION_AOL',0x00000004)
		win_const_mgr.add_const('S_SURFACE_DISCARDED',0x0000C003)
		win_const_mgr.add_const('ERROR_UNKNOWN_PRINTER_DRIVER',0x00000705)
		win_const_mgr.add_const('WIA_TRANSFER_ACQUIRE_CHILDREN',0x00000001)
		win_const_mgr.add_const('RDW_NOINTERNALPAINT',0x00000010)
		win_const_mgr.add_const('PRINTER_CHANGE_JOB',0x0000FF00)
		win_const_mgr.add_const('MDPROPVAL_MOQ_DIMHIER_LEVEL',0x00000020)
		win_const_mgr.add_const('TT_AVAILABLE',0x00000001)
		win_const_mgr.add_const('SV_CHDEVJOBS_PARMNUM',0x0000019B)
		win_const_mgr.add_const('OID_FDDI_MAC_T_REQ',0x03030230)
		win_const_mgr.add_const('IS_NORMAL',0x00000001)
		win_const_mgr.add_const('IME_CAND_READ',0x00000001)
		win_const_mgr.add_const('JOB_OBJECT_SECURITY_ONLY_TOKEN',0x00000004)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MINFGAUSSIANQUAD',0x00001000)
		win_const_mgr.add_const('MNID_STRING',0x00000001)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_USER_FLOW_RATE',0x00000013)
		win_const_mgr.add_const('MF_COMPONENT_HS_CERT_REVOKED',0x00020000)
		win_const_mgr.add_const('DSBM_QUERYINSERTW',0x00000064)
		win_const_mgr.add_const('WNPERMC_OWNER',0x00000004)
		win_const_mgr.add_const('KERB_ETYPE_DSA_SHA1_CMS',0x00000009)
		win_const_mgr.add_const('CTRY_SINGAPORE',0x00000041)
		win_const_mgr.add_const('ISO_EXP_DATA_NUSE',0x00000001)
		win_const_mgr.add_const('TMT_SMCAPTIONBARWIDTH',0x000004B6)
		win_const_mgr.add_const('WINHTTP_ADDREQ_FLAG_ADD_IF_NEW',0x10000000)
		win_const_mgr.add_const('MS_CLIPAROUNDCURSOR',0x00000002)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_TABLE_STATISTICS',0x00000007)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_NETWORK_CONNECTIVITY',0x00000011)
		win_const_mgr.add_const('ERROR_DS_MAX_OBJ_SIZE_EXCEEDED',0x00002070)
		win_const_mgr.add_const('DSBM_QUERYINSERTA',0x00000065)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_DEVMODE',0x00000007)
		win_const_mgr.add_const('MCI_DGV_RESTORE_AT',0x00020000)
		win_const_mgr.add_const('SQL_SVE_CASE',0x00000001)
		win_const_mgr.add_const('IPSEC_POLICY_FLAG_DONT_NEGOTIATE_BYTE_LIFETIME',0x00000080)
		win_const_mgr.add_const('ERROR_DRIVER_BLOCKED',0x000004FB)
		win_const_mgr.add_const('SCF_NOKBUPDATE',0x00000020)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INVALIDATROOTLEVEL',0x000036E7)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM5C_INST_WORD_POS_X',0x0000000D)
		win_const_mgr.add_const('WS_MAXIMIZE',0x01000000)
		win_const_mgr.add_const('JIFMK_JPG1',0x0000FFF1)
		win_const_mgr.add_const('PO_THROTTLE_CONSTANT',0x00000001)
		win_const_mgr.add_const('MIXER_LONG_NAME_CHARS',0x00000040)
		win_const_mgr.add_const('SP_COPY_REPLACE_BOOT_FILE',0x00080000)
		win_const_mgr.add_const('OID_IRDA_TURNAROUND_TIME',0x0A010101)
		win_const_mgr.add_const('GESTURE_SHARP',0x00000000)
		win_const_mgr.add_const('SQL_LIKE_ONLY',0x00000001)
		win_const_mgr.add_const('ERROR_TXF_ATTRIBUTE_CORRUPT',0x00001AAE)
		win_const_mgr.add_const('DNS_STATUS_CONTINUE_NEEDED',0x00002649)
		win_const_mgr.add_const('LINEERR_INVALAGENTSESSIONSTATE',0x8000005F)
		win_const_mgr.add_const('ERROR_PROC_NOT_FOUND',0x0000007F)
		win_const_mgr.add_const('MAX_GUID_CHARS',0x00000026)
		win_const_mgr.add_const('DOT11_FLAGS_80211G_NON_ERP_PRESENT',0x00000040)
		win_const_mgr.add_const('CAL_SMONTHNAME4',0x00000018)
		win_const_mgr.add_const('ERROR_RECOVERY_FAILURE',0x000004FF)
		win_const_mgr.add_const('STAT_TIME_LIMIT_EXCEEDED',0x00000100)
		win_const_mgr.add_const('RSVP_RESV',0x00000002)
		win_const_mgr.add_const('SETLINECAP',0x00000015)
		win_const_mgr.add_const('IDM_GETZOOMDENOMINATOR',0x0000092A)
		win_const_mgr.add_const('CAL_SMONTHNAME3',0x00000017)
		win_const_mgr.add_const('SECPKG_FLAG_CONNECTION',0x00000010)
		win_const_mgr.add_const('DEBUG_WAIT_DEFAULT',0x00000000)
		win_const_mgr.add_const('CAL_SMONTHNAME8',0x00000001)
		win_const_mgr.add_const('CAL_SMONTHNAME9',0x00000001)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_IDECHANNEL',0x00000017)
		win_const_mgr.add_const('SYMF_LOCAL',0x00000080)
		win_const_mgr.add_const('WIA_IPA_NUMBER_OF_LINES',0x00001012)
		win_const_mgr.add_const('FW_LIGHT',0x0000012C)
		win_const_mgr.add_const('DBPROPVAL_SU_TABLE_DEFINITION',0x00000002)
		win_const_mgr.add_const('EXITPUB_REMOVEOLDCERTS',0x00000010)
		win_const_mgr.add_const('IP_ADAPTER_IPV6_ENABLED',0x00000100)
		win_const_mgr.add_const('HTTP_QUERY_IF_MATCH',0x00000038)
		win_const_mgr.add_const('OPTION_PMTU_AGING_TIMEOUT',0x00000018)
		win_const_mgr.add_const('MSV1_0_RETURN_PROFILE_PATH',0x00000200)
		win_const_mgr.add_const('TMT_WINDOWTEXT',0x00000649)
		win_const_mgr.add_const('MSIM_LIST_SAVE',0x00000020)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_RM_DISCONNECTED',0x01000000)
		win_const_mgr.add_const('MAXGETHOSTSTRUCT',0x00000400)
		win_const_mgr.add_const('ICMODE_FASTDECOMPRESS',0x00000003)
		win_const_mgr.add_const('MDM_HDLCPPP_SPEED_DEFAULT',0x00000000)
		win_const_mgr.add_const('EC_SCRUB_TIME',0x00000023)
		win_const_mgr.add_const('AUTHZ_FLAG_ALLOW_MULTIPLE_SOURCE_INSTANCES',0x00000001)
		win_const_mgr.add_const('MEDIA_READ_ONLY',0x00000004)
		win_const_mgr.add_const('CLFS_FLAG_NON_REENTRANT_FILTER',0x00000010)
		win_const_mgr.add_const('ERROR_INVALID_CLUSTER_IPV6_ADDRESS',0x00001717)
		win_const_mgr.add_const('READ_ATTRIBUTES',0x000000D0)
		win_const_mgr.add_const('KRB_NT_UNKNOWN',0x00000000)
		win_const_mgr.add_const('IF_TYPE_ISO88025_FIBER',0x00000073)
		win_const_mgr.add_const('IDTB_REFRESH',0x000000CB)
		win_const_mgr.add_const('IDI_RESOURCEOVERLAYLAST',0x000000A1)
		win_const_mgr.add_const('WAN_PROTOCOL_KEEPS_STATS',0x00000001)
		win_const_mgr.add_const('KSAUDIO_STEREO_SPEAKER_GEOMETRY_MIN',0x00000005)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_SELECTRING',0x0000000A)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_DURATIONVALID',0x00000100)
		win_const_mgr.add_const('ERROR_DS_DRA_SOURCE_REINSTALLED',0x0000210B)
		win_const_mgr.add_const('LVHT_EX_GROUP_FOOTER',0x20000000)
		win_const_mgr.add_const('ERROR_PATCH_SAME_FILE',0xC00E3103)
		win_const_mgr.add_const('OID_FDDI_MAC_T_MAX_CAPABILITY',0x03030221)
		win_const_mgr.add_const('MDLEVEL_TYPE_RESERVED1',0x00000008)
		win_const_mgr.add_const('PTE_ATTR_LEN',0x00000005)
		win_const_mgr.add_const('VK_SUBTRACT',0x0000006D)
		win_const_mgr.add_const('LINEERR_TARGETSELF',0x8000004F)
		win_const_mgr.add_const('LOGPIXELSY',0x0000005A)
		win_const_mgr.add_const('DNS_CLASS_ANY',0x00000000)
		win_const_mgr.add_const('HTTP_QUERY_CUSTOM',0x0000FFFF)
		win_const_mgr.add_const('SPDRP_BUSNUMBER',0x00000015)
		win_const_mgr.add_const('DNS_RCODE_REFUSED',0x00000005)
		win_const_mgr.add_const('TA_BOTTOM',0x00000008)
		win_const_mgr.add_const('ERROR_DS_SORT_CONTROL_MISSING',0x00002045)
		win_const_mgr.add_const('TIMEEVENTELEMENT_OFFSET',0x00000A00)
		win_const_mgr.add_const('CR_ACCESS_DENIED',0x00000033)
		win_const_mgr.add_const('DS_SCHEMA_GUID_CONTROL_RIGHT',0x00000004)
		win_const_mgr.add_const('SERIAL_IOC_FCR_RES2',0x00000020)
		win_const_mgr.add_const('ERROR_DS_GOVERNSID_MISSING',0x000020DA)
		win_const_mgr.add_const('MDM_COMPRESSION',0x00000001)
		win_const_mgr.add_const('SSRVOPT_SECURE',0x00000200)
		win_const_mgr.add_const('SI_READONLY',0x00000008)
		win_const_mgr.add_const('OLEOBJ_S_FIRST',0x00040180)
		win_const_mgr.add_const('DIRID_COLOR',0x00000017)
		win_const_mgr.add_const('WMDM_E_INCORRECT_APPSEC',0x80045010)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_NUMBEROFEXISTINGTRACKS',0x00000103)
		win_const_mgr.add_const('IDC_IO_FILEDISPLAY',0x0000083B)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_MULTICAST_BYTES_RCV',0x00020000)
		win_const_mgr.add_const('CHANGER_TRUE_EXCHANGE_CAPABLE',0x80000008)
		win_const_mgr.add_const('MCI_PUT',0x00000842)
		win_const_mgr.add_const('DMPAPER_ENV_9',0x00000013)
		win_const_mgr.add_const('ATTRIB_MATTE',0x00000002)
		win_const_mgr.add_const('BCRYPT_BLOCK_PADDING',0x00000001)
		win_const_mgr.add_const('ERROR_WAS_LOCKED',0x000002CD)
		win_const_mgr.add_const('XA_RDONLY',0x00000003)
		win_const_mgr.add_const('SUBLANG_LAO_LAO',0x00000001)
		win_const_mgr.add_const('URL_DONT_SIMPLIFY',0x08000000)
		win_const_mgr.add_const('ERROR_SPOOL_FILE_NOT_FOUND',0x00000BBA)
		win_const_mgr.add_const('DDSD_CKDESTOVERLAY',0x00002000)
		win_const_mgr.add_const('MCI_NOTIFY_FAILURE',0x00000008)
		win_const_mgr.add_const('SQL_IC_MIXED',0x00000004)
		win_const_mgr.add_const('SI_ACCESS_SPECIFIC',0x00010000)
		win_const_mgr.add_const('USER_NUM_LOGONS_PARMNUM',0x00000016)
		win_const_mgr.add_const('BACKUP_EA_DATA',0x00000002)
		win_const_mgr.add_const('SPFEI_ALL_EVENTS',0xEFFFFFFFFFFFFFFF)
		win_const_mgr.add_const('DS_REPMOD_UPDATE_SCHEDULE',0x00000004)
		win_const_mgr.add_const('SM_STARTER',0x00000058)
		win_const_mgr.add_const('USE_RECONN',0x00000005)
		win_const_mgr.add_const('MCSC_TEXT',0x00000001)
		win_const_mgr.add_const('LR_SHARED',0x00008000)
		win_const_mgr.add_const('EVENT_SYSTEM_MOVESIZEEND',0x0000000B)
		win_const_mgr.add_const('IMR_DOCUMENTFEED',0x00000007)
		win_const_mgr.add_const('SMSET_TOP',0x10000000)
		win_const_mgr.add_const('NF_REQUERY',0x00000004)
		win_const_mgr.add_const('PDH_CANNOT_SET_DEFAULT_REALTIME_DATASOURCE',0x800007DC)
		win_const_mgr.add_const('SPI_ICONVERTICALSPACING',0x00000018)
		win_const_mgr.add_const('TMT_PROGRESSSPACESIZE',0x0000096C)
		win_const_mgr.add_const('DISPID_IMPORTEXPORTFAVORITES',0x00000009)
		win_const_mgr.add_const('CONTEXT_MENU_HSCROLL',0x0000000B)
		win_const_mgr.add_const('PP_SIGNATURE_ALG',0x0000000F)
		win_const_mgr.add_const('UDN_FIRST',0x00000000)
		win_const_mgr.add_const('TF_SFT_NOEXTRAICONSONMINIMIZED',0x00000400)
		win_const_mgr.add_const('META_SETSTRETCHBLTMODE',0x00000107)
		win_const_mgr.add_const('WNPERMC_PERM',0x00000001)
		win_const_mgr.add_const('LINEAGENTSTATUS_NEXTSTATE',0x00000004)
		win_const_mgr.add_const('VDMEVENT_ALLFLAGS',0x00000000)
		win_const_mgr.add_const('CDO_E_HTTP_FAILED',0x8004021A)
		win_const_mgr.add_const('ACCESS_OBJECT_GUID',0x00000000)
		win_const_mgr.add_const('MAX_INTERFACE_NAME_LEN',0x00000100)
		win_const_mgr.add_const('WINHTTP_QUERY_PUBLIC',0x00000008)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_SUPPORTEDWRITESPEEDDESCRIPTORS',0x00000110)
		win_const_mgr.add_const('ASYNC_RECO_INTERRUPTED',0x00000001)
		win_const_mgr.add_const('SUBLANG_SPANISH_COSTA_RICA',0x00000005)
		win_const_mgr.add_const('MFASFINDEXER_PER_ENTRY_BYTES_DYNAMIC',0x00000000)
		win_const_mgr.add_const('PAGE_GUARD',0x00000100)
		win_const_mgr.add_const('PRJOB_ERROR',0x00000010)
		win_const_mgr.add_const('OBM_SIZE',0x00007FFE)
		win_const_mgr.add_const('UDS_NOTHOUSANDS',0x00000080)
		win_const_mgr.add_const('STAP_ALLOW_WEBCONTENT',0x00000001)
		win_const_mgr.add_const('HANGEUL_CHARSET',0x00000081)
		win_const_mgr.add_const('RTM_ROUTE_STATE_CREATED',0x00000000)
		win_const_mgr.add_const('ERROR_INVALID_LABEL',0x00000513)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_REDIRECT',0x00000011)
		win_const_mgr.add_const('DISPID_IMPORT',0x00000006)
		win_const_mgr.add_const('SPI_SETDOUBLECLKHEIGHT',0x0000001E)
		win_const_mgr.add_const('CMSG_CONTENT_ENCRYPT_FREE_PARA_FLAG',0x00000001)
		win_const_mgr.add_const('OS_TABLETPC',0x00000021)
		win_const_mgr.add_const('STGM_NOSCRATCH',0x00100000)
		win_const_mgr.add_const('EC_PROCESSING_LATENCY',0x00000021)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_RECOVER_BEST_EFFORT',0x00000200)
		win_const_mgr.add_const('BS_DEFCOMMANDLINK',0x0000000F)
		win_const_mgr.add_const('DV_STYPE',0x00000001)
		win_const_mgr.add_const('MCI_DGV_STATUS_OUTPUT',0x00800000)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_BROADCAST_CTRL',0x01000000)
		win_const_mgr.add_const('TCP_KEEPALIVE',0x00000003)
		win_const_mgr.add_const('RTCRF_REGISTER_MESSAGE_SESSIONS',0x00000002)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_CURRENTROTATIONTYPEISPURECAV',0x00000114)
		win_const_mgr.add_const('ERROR_DEVICE_ALREADY_REMEMBERED',0x000004B2)
		win_const_mgr.add_const('PIPE_REJECT_REMOTE_CLIENTS',0x00000008)
		win_const_mgr.add_const('SNMP_BERAPI_OVERFLOW',0x0000000C)
		win_const_mgr.add_const('SPMODE_EVENT',0x00000020)
		win_const_mgr.add_const('ADS_PRINTER_DOOR_OPEN',0x00400000)
		win_const_mgr.add_const('PCF_16BITMODE',0x00000200)
		win_const_mgr.add_const('CFU_UNDERLINEWAVE',0x00000008)
		win_const_mgr.add_const('CB_DIR',0x00000145)
		win_const_mgr.add_const('ACDD_VISIBLE',0x00000001)
		win_const_mgr.add_const('SSA_FIT',0x00000008)
		win_const_mgr.add_const('HDN_LAST',0x00000000)
		win_const_mgr.add_const('IPV6_PKTINFO',0x00000013)
		win_const_mgr.add_const('OSVERSION_MASK',0xFFFF0000)
		win_const_mgr.add_const('MP_STATUS_SUBMITTED',0x00000004)
		win_const_mgr.add_const('LINEAGENTSTATUSEX_NEWAGENT',0x00000001)
		win_const_mgr.add_const('IP_OPT_NOP',0x00000001)
		win_const_mgr.add_const('EAP_FLAG_GUEST_ACCESS',0x00000040)
		win_const_mgr.add_const('DRM_SERVICE_TYPE_CERTIFICATION',0x00000002)
		win_const_mgr.add_const('MAP_FOLDCZONE',0x00000010)
		win_const_mgr.add_const('MF_CHANGE',0x00000080)
		win_const_mgr.add_const('ERROR_NO_SYSTEM_MENU',0x0000059D)
		win_const_mgr.add_const('HICF_DUPACCEL',0x00000008)
		win_const_mgr.add_const('IMF_SMODE_PLAURALCLAUSE',0x00000001)
		win_const_mgr.add_const('XEPR_HASH',0x00000008)
		win_const_mgr.add_const('IMAGE_FILE_SYSTEM',0x00001000)
		win_const_mgr.add_const('SPI_SETMENUDROPALIGNMENT',0x0000001C)
		win_const_mgr.add_const('OBM_DNARROWI',0x00007FE0)
		win_const_mgr.add_const('PCMCIA_OPT_HAVE_SOCKET',0x00000001)
		win_const_mgr.add_const('DI_FLAGSEX_NOUIONQUERYREMOVE',0x00001000)
		win_const_mgr.add_const('DPNHQUERYADDRESS_CHECKFORPRIVATEBUTUNMAPPED',0x00000008)
		win_const_mgr.add_const('MD_ERROR_SUB403_INVALID_CNFG',0x0000000A)
		win_const_mgr.add_const('INDEX_GUID_NODEDATA',0x00000004)
		win_const_mgr.add_const('TBCDRF_NOETCHEDEFFECT',0x00100000)
		win_const_mgr.add_const('SV_SHARESECURITY',0x00000000)
		win_const_mgr.add_const('FEATURESETTING_CUSTPAPER',0x00000003)
		win_const_mgr.add_const('IOF_SELECTCREATEFROMFILE',0x00000004)
		win_const_mgr.add_const('DCI_PRIMARY',0x00000000)
		win_const_mgr.add_const('ERROR_DS_DUP_LINK_ID',0x00002114)
		win_const_mgr.add_const('LINE_CREATE',0x00000013)
		win_const_mgr.add_const('VS_FF_PRERELEASE',0x00000002)
		win_const_mgr.add_const('KSALLOCATOR_OPTIONF_SYSTEM_MEMORY',0x00000002)
		win_const_mgr.add_const('DMPAPER_A3_ROTATED',0x0000004C)
		win_const_mgr.add_const('PFS_SIZE_SHIFT',0x00000007)
		win_const_mgr.add_const('INTERNET_ERROR_MASK_LOGIN_FAILURE_DISPLAY_ENTITY_BODY',0x00000008)
		win_const_mgr.add_const('ERROR_OBJECT_IN_LIST',0x00001393)
		win_const_mgr.add_const('SQL_SNVF_BIT_LENGTH',0x00000001)
		win_const_mgr.add_const('IMGDECODE_HINT_BOTTOMUP',0x00000002)
		win_const_mgr.add_const('OID_TCP_OFFLOAD_HARDWARE_CAPABILITIES',0xFC01020D)
		win_const_mgr.add_const('VDS_REBUILD_PRIORITY_MIN',0x00000000)
		win_const_mgr.add_const('IC_E_CAPS_INSTANTIATION_FAILURE',0x83010001)
		win_const_mgr.add_const('DDCAPS_COLORKEY',0x00400000)
		win_const_mgr.add_const('LONG64_MAX',0x7FFFFFFFFFFFFFFF)
		win_const_mgr.add_const('SCARD_E_NO_READERS_AVAILABLE',0x8010002E)
		win_const_mgr.add_const('FILE_PREFETCH_TYPE_FOR_CREATE_EX',0x00000003)
		win_const_mgr.add_const('HTTP_QUERY_REFERER',0x00000023)
		win_const_mgr.add_const('DMDFO_STRETCH',0x00000001)
		win_const_mgr.add_const('TCIS_BUTTONPRESSED',0x00000001)
		win_const_mgr.add_const('EMR_SETCOLORADJUSTMENT',0x00000017)
		win_const_mgr.add_const('SAP_FIELD_ANY_AESA_SEL',0xFFFFFFFA)
		win_const_mgr.add_const('AVICOMPRESSF_INTERLEAVE',0x00000001)
		win_const_mgr.add_const('HTTP_STATUS_FORBIDDEN',0x00000193)
		win_const_mgr.add_const('ERROR_CTX_LOGON_DISABLED',0x00001B7D)
		win_const_mgr.add_const('SI_OWNER_READONLY',0x00000040)
		win_const_mgr.add_const('EFSRPC_SECURE_ONLY',0x00000008)
		win_const_mgr.add_const('DDSCAPS_LOCALVIDMEM',0x10000000)
		win_const_mgr.add_const('LMEM_NODISCARD',0x00000020)
		win_const_mgr.add_const('CACHEGROUP_ATTRIBUTE_QUOTA',0x00000008)
		win_const_mgr.add_const('SQL_PS_POSITIONED_UPDATE',0x00000002)
		win_const_mgr.add_const('TTI_WARNING_LARGE',0x00000005)
		win_const_mgr.add_const('RS_UPDATING',0x00000004)
		win_const_mgr.add_const('FLASHMODE_OFF',0x00000002)
		win_const_mgr.add_const('FORMPROPSET_INTERSECTION',0x00000001)
		win_const_mgr.add_const('RPC_C_SECURITY_QOS_VERSION_1',0x00000001)
		win_const_mgr.add_const('SS_TYPEMASK',0x0000001F)
		win_const_mgr.add_const('ERROR_DS_NAME_ERROR_RESOLVING',0x00002115)
		win_const_mgr.add_const('SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION_2',0x00000002)
		win_const_mgr.add_const('WKSTA_VER_MINOR_PARMNUM',0x00000005)
		win_const_mgr.add_const('D3DUSAGE_QUERY_POSTPIXELSHADER_BLENDING',0x00080000)
		win_const_mgr.add_const('IDC_PU_ICON',0x0000038C)
		win_const_mgr.add_const('UDP_CHECKSUM_COVERAGE',0x00000014)
		win_const_mgr.add_const('ADOX_VERSION',0x00000006)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_MM_DZF',0x0000000B)
		win_const_mgr.add_const('DISPID_ACTIVATEAPPLETS',0x00000007)
		win_const_mgr.add_const('MDSP_SEEK_CUR',0x00000002)
		win_const_mgr.add_const('MNS_NOTIFYBYPOS',0x08000000)
		win_const_mgr.add_const('CERT_ISSUER_SERIAL_NUMBER_MD5_HASH_PROP_ID',0x0000001C)
		win_const_mgr.add_const('ERROR_ACCESS_AUDIT_BY_POLICY',0x00000311)
		win_const_mgr.add_const('DMI_USERECT',0x00000004)
		win_const_mgr.add_const('NTMS_SEQUENCE_LENGTH',0x00000020)
		win_const_mgr.add_const('SPI_SETMENUANIMATION',0x00001003)
		win_const_mgr.add_const('ERROR_BAD_COMMAND',0x00000016)
		win_const_mgr.add_const('DRM_COMMIT_PLAYLIST_BURN',0x00000002)
		win_const_mgr.add_const('DMPAPER_JENV_CHOU4',0x0000004A)
		win_const_mgr.add_const('SAVE_CTM',0x00001005)
		win_const_mgr.add_const('SQL_MAX_OWNER_NAME_LEN',0x00000020)
		win_const_mgr.add_const('LVGF_SUBSETITEMS',0x00010000)
		win_const_mgr.add_const('IMGDECODE_HINT_TOPDOWN',0x00000001)
		win_const_mgr.add_const('OID_FDDI_SMT_STATION_STATUS',0x03030219)
		win_const_mgr.add_const('KERB_PURGE_ALL_TICKETS',0x00000001)
		win_const_mgr.add_const('IF_TYPE_IPOVER_ATM',0x00000072)
		win_const_mgr.add_const('IDC_IO_CREATEFROMFILE',0x00000835)
		win_const_mgr.add_const('SORTED_CTL_EXT_HASH_BUCKET_OFFSET',0x00000003)
		win_const_mgr.add_const('IOC_VENDOR',0x18000000)
		win_const_mgr.add_const('D3DFMT_X1R5G5B5',0x00000018)
		win_const_mgr.add_const('WEBPOST_ERROR_POSTINFO_REQUIRED',0xC0042111)
		win_const_mgr.add_const('CHANGER_STORAGE_TRANSPORT',0x00008000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_UNSUPPORTED_ID',0x0000362D)
		win_const_mgr.add_const('CTRY_ARMENIA',0x00000176)
		win_const_mgr.add_const('CERT_CA_SUBJECT_FLAG',0x00000080)
		win_const_mgr.add_const('CLUS_NODE_MAJORITY_QUORUM',0x00000000)
		win_const_mgr.add_const('EVENT_HEADER_EXT_TYPE_INSTANCE_INFO',0x00000004)
		win_const_mgr.add_const('TLS1_ALERT_PROTOCOL_VERSION',0x00000046)
		win_const_mgr.add_const('WM_DRAWCLIPBOARD',0x00000308)
		win_const_mgr.add_const('EC_NOTIFY_WINDOW',0x00000019)
		win_const_mgr.add_const('WIA_MAJOR_EVENT_DEVICE_CONNECT',0x00000001)
		win_const_mgr.add_const('TMT_STRING',0x000000C9)
		win_const_mgr.add_const('CDB2GVF_ISFOLDERPICKER',0x00000020)
		win_const_mgr.add_const('CERT_PHYSICAL_STORE_INSERT_COMPUTER_NAME_ENABLE_FLAG',0x00000008)
		win_const_mgr.add_const('XP1_GRACEFUL_CLOSE',0x00000020)
		win_const_mgr.add_const('IDC_VP_SCALETXT',0x0000040A)
		win_const_mgr.add_const('PFM_NOWIDOWCONTROL',0x00200000)
		win_const_mgr.add_const('AI_NUMERICHOST',0x00000004)
		win_const_mgr.add_const('IP_ADAPTER_NETBIOS_OVER_TCPIP_ENABLED',0x00000040)
		win_const_mgr.add_const('ADS_PRINTER_TONER_LOW',0x00020000)
		win_const_mgr.add_const('HDM_FIRST',0x00001200)
		win_const_mgr.add_const('DEBUG_SYMENT_IS_MANAGED',0x00000010)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_HIGHLEVCOMP',0x00000002)
		win_const_mgr.add_const('JOY_USEDEADZONE',0x00000800)
		win_const_mgr.add_const('PORT_SWIFTRVF',0x00000061)
		win_const_mgr.add_const('IMAGE_REL_CEF_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_INVALID_IP_ADDRESS',0x00002550)
		win_const_mgr.add_const('SPI_SETFOCUSBORDERWIDTH',0x0000200F)
		win_const_mgr.add_const('RESUTIL_PROPITEM_REQUIRED',0x00000002)
		win_const_mgr.add_const('SUBLANG_SWEDISH_FINLAND',0x00000002)
		win_const_mgr.add_const('MAPI_NO_MAIL',0x00008000)
		win_const_mgr.add_const('EXITEVENT_CERTDENIED',0x00000004)
		win_const_mgr.add_const('SUBLANG_BULGARIAN_BULGARIA',0x00000001)
		win_const_mgr.add_const('SSGF_NONE',0x00000000)
		win_const_mgr.add_const('RQ_AUTHENTICATE_REQUEST',0x00000002)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_RAW_MGMT',0x00400000)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_FIELD1_MASK',0x000000F0)
		win_const_mgr.add_const('FACILITY_RTC_INTERFACE',0x000000EE)
		win_const_mgr.add_const('DEBUG_FIND_SOURCE_BEST_MATCH',0x00000002)
		win_const_mgr.add_const('PC_SCANLINE',0x00000008)
		win_const_mgr.add_const('LINEERR_INVALTERMINALID',0x80000039)
		win_const_mgr.add_const('CDBOSC_SELCHANGE',0x00000002)
		win_const_mgr.add_const('WIA_IPC_FIRST',0x00001402)
		win_const_mgr.add_const('PFA_FULL_INTERLETTER',0x00000005)
		win_const_mgr.add_const('LINEADDRESSTYPE_PHONENUMBER',0x00000001)
		win_const_mgr.add_const('WPWIZ_ERROR_UNKNOWN',0xC0042001)
		win_const_mgr.add_const('LIS_QUIET',0x00000001)
		win_const_mgr.add_const('OID_TAPI_SET_DEFAULT_MEDIA_DETECTION',0x0703011F)
		win_const_mgr.add_const('ERROR_APP_INIT_FAILURE',0x0000023F)
		win_const_mgr.add_const('ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE',0x0000371B)
		win_const_mgr.add_const('WM_CTLCOLORSCROLLBAR',0x00000137)
		win_const_mgr.add_const('DMPAPER_ENV_C6',0x0000001F)
		win_const_mgr.add_const('MD_ACCESS_SCRIPT',0x00000200)
		win_const_mgr.add_const('CHANGER_CLEANER_ACCESS_NOT_VALID',0x00040000)
		win_const_mgr.add_const('ERRACT_ABORT',0x00000004)
		win_const_mgr.add_const('IDS_CAP_NODISKSPACE',0x0000019F)
		win_const_mgr.add_const('EDITF_ENABLEAKIKEYID',0x00000100)
		win_const_mgr.add_const('ALG_SID_RIPEMD160',0x00000007)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_GLOBAL_GROUPS',0x80000004)
		win_const_mgr.add_const('F_OK',0x00000000)
		win_const_mgr.add_const('KSRATE_NOPRESENTATIONSTART',0x00000001)
		win_const_mgr.add_const('CERT_CHAIN_ENABLE_PEER_TRUST',0x00000400)
		win_const_mgr.add_const('DM_BITSPERPEL',0x00040000)
		win_const_mgr.add_const('SIGNERSCORE_UNCLASSIFIED',0x0D000004)
		win_const_mgr.add_const('PSPROTOCOL_TBCP',0x00000002)
		win_const_mgr.add_const('WTS_PROTOCOL_TYPE_ICA',0x00000001)
		win_const_mgr.add_const('DISABLE_INTERRUPTION_LOG',0x0000000D)
		win_const_mgr.add_const('CIF_SELECTDEFAULT',0x00000004)
		win_const_mgr.add_const('FACILITY_MONITOR',0x0000001D)
		win_const_mgr.add_const('TTS_NOANIMATE',0x00000010)
		win_const_mgr.add_const('FACILITY_USERMODE_COMMONLOG',0x0000001A)
		win_const_mgr.add_const('DISPID_IADCCTL_FORCEX86',0x00000103)
		win_const_mgr.add_const('SQL_SG_UPDATE_TABLE',0x00000800)
		win_const_mgr.add_const('DDD_EXACT_MATCH_ON_REMOVE',0x00000004)
		win_const_mgr.add_const('FINDDLGORDMOTIF',0x00002715)
		win_const_mgr.add_const('SYMOPT_UNDNAME',0x00000002)
		win_const_mgr.add_const('FILE_CLEAR_ENCRYPTION',0x00000002)
		win_const_mgr.add_const('D3DVS_SWIZZLE_SHIFT',0x00000010)
		win_const_mgr.add_const('FRS_ERR_STOPPING_SERVICE',0x00001F43)
		win_const_mgr.add_const('IDM_COPYCONTENT',0x000008F3)
		win_const_mgr.add_const('ERROR_INVALID_EVENT_COUNT',0x00000097)
		win_const_mgr.add_const('EMR_LINETO',0x00000036)
		win_const_mgr.add_const('POLICY_ERRV_GLOBAL_GRP_FLOW_RATE',0x00000012)
		win_const_mgr.add_const('WM_NCXBUTTONUP',0x000000AC)
		win_const_mgr.add_const('ERROR_CRC',0x00000017)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_IO_WRITE',0x0000000B)
		win_const_mgr.add_const('SM_MOUSEPRESENT',0x00000013)
		win_const_mgr.add_const('SL_CLIENTAPI_ZONE',0x0000F000)
		win_const_mgr.add_const('ERROR_NO_SECURITY_ON_OBJECT',0x00000546)
		win_const_mgr.add_const('WM_XBUTTONUP',0x0000020C)
		win_const_mgr.add_const('PERF_ATTRIB_NO_DISPLAYABLE',0x00000002)
		win_const_mgr.add_const('SUBLANG_SAMI_SKOLT_FINLAND',0x00000008)
		win_const_mgr.add_const('FLG_ADDREG_DELREG_BIT',0x00008000)
		win_const_mgr.add_const('MKF_RIGHTBUTTONSEL',0x20000000)
		win_const_mgr.add_const('LDAP_SERVER_COPY_CONTROL_USE_COPY',0x00000000)
		win_const_mgr.add_const('LDAP_DEREF_NEVER',0x00000000)
		win_const_mgr.add_const('LGRPID_INSTALLED',0x00000001)
		win_const_mgr.add_const('OID_802_5_AC_ERRORS',0x02020202)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_TX_RX_ENABLED',0x00000004)
		win_const_mgr.add_const('LANG_AZERI',0x00000002)
		win_const_mgr.add_const('PID_INTSITE_LASTVISIT',0x00000004)
		win_const_mgr.add_const('SV_ENABLEFORCEDLOGOFF_PARMNUM',0x00000203)
		win_const_mgr.add_const('LCMAP_HALFWIDTH',0x00400000)
		win_const_mgr.add_const('EC_CODECAPI_EVENT',0x00000057)
		win_const_mgr.add_const('TF_LBI_BALLOON',0x00000010)
		win_const_mgr.add_const('NABTS_BUFFER_PICTURENUMBER_SUPPORT',0x00000001)
		win_const_mgr.add_const('MD_EXTLOG_USER_AGENT',0x00010000)
		win_const_mgr.add_const('MCI_OVLY_WHERE_FRAME',0x00080000)
		win_const_mgr.add_const('WSAENOBUFS',0x00002747)
		win_const_mgr.add_const('RI_MOUSE_LEFT_BUTTON_DOWN',0x00000001)
		win_const_mgr.add_const('DISPID_GETERRORCHAR',0x0000000F)
		win_const_mgr.add_const('CP_ACP',0x00000000)
		win_const_mgr.add_const('SQL_DBMS_VER',0x00000012)
		win_const_mgr.add_const('WM_NCHITTEST',0x00000084)
		win_const_mgr.add_const('NOTIFY_CLASS_DOMAIN_CHANGE',0x00000003)
		win_const_mgr.add_const('IDM_TRIED_UNDERLINE',0x00000039)
		win_const_mgr.add_const('SKF_RALTLOCKED',0x00200000)
		win_const_mgr.add_const('PORT_LOGIN',0x00000031)
		win_const_mgr.add_const('RPC_C_AUTHN_MQ',0x00000064)
		win_const_mgr.add_const('DNS_TYPE_X25',0x00000013)
		win_const_mgr.add_const('GL_ID_READINGCONFLICT',0x00000023)
		win_const_mgr.add_const('SHPPFW_DIRCREATE',0x00000001)
		win_const_mgr.add_const('WNODE_FLAG_SEND_DATA_BLOCK',0x00400000)
		win_const_mgr.add_const('TXTLOG_VERBOSE',0x00000006)
		win_const_mgr.add_const('PHONE_DEVSPECIFIC',0x00000010)
		win_const_mgr.add_const('ERROR_LOG_RECORD_NONEXISTENT',0x000019E0)
		win_const_mgr.add_const('IMAGE_REL_SH3_PCREL8_WORD',0x00000009)
		win_const_mgr.add_const('R2_COPYPEN',0x0000000D)
		win_const_mgr.add_const('FR_PROP_ISSUEDCERTIFICATEHASH',0x0000000A)
		win_const_mgr.add_const('ODT_BUTTON',0x00000004)
		win_const_mgr.add_const('GGO_BEZIER',0x00000003)
		win_const_mgr.add_const('PRINTER_CHANGE_PRINTER_DRIVER',0x70000000)
		win_const_mgr.add_const('DNS_ERROR_RCODE_NOTZONE',0x00002332)
		win_const_mgr.add_const('ERROR_DS_DOMAIN_VERSION_TOO_LOW',0x00002176)
		win_const_mgr.add_const('WINHTTP_QUERY_EXPIRES',0x0000000A)
		win_const_mgr.add_const('MD_APP_POOL_RECYCLE_ISAPI_UNHEALTHY',0x00000010)
		win_const_mgr.add_const('DDENUMSURFACES_NOMATCH',0x00000004)
		win_const_mgr.add_const('MCI_VD_ESCAPE_STRING',0x00000100)
		win_const_mgr.add_const('SQL_FN_NUM_ROUND',0x00400000)
		win_const_mgr.add_const('JIFMK_SOF0',0x0000FFC0)
		win_const_mgr.add_const('JIFMK_SOF1',0x0000FFC1)
		win_const_mgr.add_const('JIFMK_SOF2',0x0000FFC2)
		win_const_mgr.add_const('JIFMK_SOF3',0x0000FFC3)
		win_const_mgr.add_const('IDS_SUBJECT',0x00011008)
		win_const_mgr.add_const('JIFMK_SOF5',0x0000FFC5)
		win_const_mgr.add_const('JIFMK_SOF6',0x0000FFC6)
		win_const_mgr.add_const('JIFMK_SOF7',0x0000FFC7)
		win_const_mgr.add_const('JIFMK_SOF9',0x0000FFC9)
		win_const_mgr.add_const('__REQUIRED_RPCNDR_H_VERSION__',0x000001DB)
		win_const_mgr.add_const('OPTION_NETBIOS_SCOPE_OPTION',0x0000002F)
		win_const_mgr.add_const('IMAGE_SCN_LNK_INFO',0x00000200)
		win_const_mgr.add_const('SQL_API_SQLGETFUNCTIONS',0x0000002C)
		win_const_mgr.add_const('SUBLANG_CHINESE_HONGKONG',0x00000003)
		win_const_mgr.add_const('DT_RASDISPLAY',0x00000001)
		win_const_mgr.add_const('MSG_BCAST',0x00000400)
		win_const_mgr.add_const('ERROR_PORT_MESSAGE_TOO_LONG',0x00000222)
		win_const_mgr.add_const('TF_IPP_CAPS_DISABLEONTRANSITORY',0x00000001)
		win_const_mgr.add_const('WIA_DPC_THUMB_WIDTH',0x00000812)
		win_const_mgr.add_const('DXVA_IA44_SURFACE_BUFFER',0x00000009)
		win_const_mgr.add_const('SM_FOCUS_TYPE_LM_SERVER',0x00000005)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_SECOND',0x00000100)
		win_const_mgr.add_const('PORT_CYCLESERV2',0x00000304)
		win_const_mgr.add_const('DNSSEC_ALGORITHM_PRIVATE',0x000000FE)
		win_const_mgr.add_const('BT_PORT_MIN',0x00000001)
		win_const_mgr.add_const('LOGON_RESOURCE_GROUPS',0x00000200)
		win_const_mgr.add_const('MGMCTL_SETAGENTPORT',0x00000001)
		win_const_mgr.add_const('REO_LINKAVAILABLE',0x00800000)
		win_const_mgr.add_const('LINEGATHERTERM_INTERTIMEOUT',0x00000008)
		win_const_mgr.add_const('WMS_CONTAINER_RECORDABLE',0x00000010)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_DISASSOCIATED_BY_ROAMING',0x00000008)
		win_const_mgr.add_const('LOWER_HINT_MASK',0x000000FF)
		win_const_mgr.add_const('MMIO_UNICODEPROC',0x01000000)
		win_const_mgr.add_const('AVSTREAMMASTER_NONE',0x00000001)
		win_const_mgr.add_const('SECPKG_FLAG_READONLY_WITH_CHECKSUM',0x00040000)
		win_const_mgr.add_const('FPS_HANDLED',0x20000010)
		win_const_mgr.add_const('IDC_UL_PERCENT',0x00000407)
		win_const_mgr.add_const('ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS',0x0000171E)
		win_const_mgr.add_const('TLS_OUT_OF_INDEXES',0xFFFFFFFF)
		win_const_mgr.add_const('DM_DISPLAYFIXEDOUTPUT',0x20000000)
		win_const_mgr.add_const('WINHTTP_OPTION_MAX_RESPONSE_HEADER_SIZE',0x0000005B)
		win_const_mgr.add_const('NET_SITEID_UNSPECIFIED',0x00000000)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_512BYTES',0x00A00000)
		win_const_mgr.add_const('RPC_S_NO_ENTRY_NAME',0x000006C7)
		win_const_mgr.add_const('VFT2_DRV_NETWORK',0x00000006)
		win_const_mgr.add_const('SQL_IDENTIFIER_QUOTE_CHAR',0x0000001D)
		win_const_mgr.add_const('D3DDTCAPS_SHORT2N',0x00000004)
		win_const_mgr.add_const('PDH_CSTATUS_ITEM_NOT_VALIDATED',0x800007D3)
		win_const_mgr.add_const('IDM_BROWSEMODE',0x0000084E)
		win_const_mgr.add_const('LINEERR_INVALCALLSELECT',0x8000001B)
		win_const_mgr.add_const('SW_SCROLLCHILDREN',0x00000001)
		win_const_mgr.add_const('WS_EX_RTLREADING',0x00002000)
		win_const_mgr.add_const('KDF_TLS_PRF_SEED',0x00000005)
		win_const_mgr.add_const('RP_DSN_SENT_NDR',0x00000450)
		win_const_mgr.add_const('FLS_OUT_OF_INDEXES',0xFFFFFFFF)
		win_const_mgr.add_const('VAR_FORMAT_NOSUBSTITUTE',0x00000020)
		win_const_mgr.add_const('IMAGE_DOS_SIGNATURE',0x00004D5A)
		win_const_mgr.add_const('ATSC_ETM_LOCATION_RESERVED',0x00000003)
		win_const_mgr.add_const('OPTION_MAX_REASSEMBLY_SIZE',0x00000016)
		win_const_mgr.add_const('V86FLAGS_ZERO',0x00000040)
		win_const_mgr.add_const('MIB_IPADDR_PRIMARY',0x00000001)
		win_const_mgr.add_const('CRYPT_MODE_CBCI',0x00000006)
		win_const_mgr.add_const('INTERNET_AUTODIAL_FAILIFSECURITYCHECK',0x00000004)
		win_const_mgr.add_const('OID_GEN_MEDIA_CONNECT_STATUS_EX',0x0001028A)
		win_const_mgr.add_const('DEVICEPOWER_SET_WAKEENABLED',0x00000001)
		win_const_mgr.add_const('ERROR_LOCAL_USER_SESSION_KEY',0x00000517)
		win_const_mgr.add_const('IF_TYPE_EON',0x00000019)
		win_const_mgr.add_const('TAPE_DRIVE_FILEMARKS',0x80040000)
		win_const_mgr.add_const('NETSETUP_DOMAIN_JOIN_IF_JOINED',0x00000020)
		win_const_mgr.add_const('WINHTTP_OPTION_HTTP_VERSION',0x0000003B)
		win_const_mgr.add_const('KERB_RETRIEVE_TICKET_DEFAULT',0x00000000)
		win_const_mgr.add_const('MD_CPU_ENABLE_APP_LOGGING',0x00000004)
		win_const_mgr.add_const('COMP_ELEM_SIZE_HEIGHT',0x00000080)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_VIEW_TABLE_USAGE',0x00000003)
		win_const_mgr.add_const('PAN_CONTRAST_MEDIUM_HIGH',0x00000007)
		win_const_mgr.add_const('SC_VSCROLL',0x0000F070)
		win_const_mgr.add_const('EAP_E_SERVER_ROOT_CERT_INVALID',0x80420401)
		win_const_mgr.add_const('NUMPRS_THOUSANDS',0x00000200)
		win_const_mgr.add_const('ERROR_NOT_EXPORT_FORMAT',0x00001778)
		win_const_mgr.add_const('MMIOM_WRITEFLUSH',0x00000005)
		win_const_mgr.add_const('URLACTION_DOWNLOAD_MAX',0x000011FF)
		win_const_mgr.add_const('EXCEPTION_READ_FAULT',0x00000000)
		win_const_mgr.add_const('HTTP_SEND_RESPONSE_FLAG_MORE_DATA',0x00000002)
		win_const_mgr.add_const('SAFER_POLICY_ONLY_EXES',0x00010000)
		win_const_mgr.add_const('ALINF_NGCONV',0x00000008)
		win_const_mgr.add_const('MCI_PASTE',0x00000853)
		win_const_mgr.add_const('SECPKG_ATTR_NEGOTIATION_PACKAGE',0x80000081)
		win_const_mgr.add_const('SUBLANG_NORWEGIAN_NYNORSK',0x00000002)
		win_const_mgr.add_const('SUCCESS',0x00000000)
		win_const_mgr.add_const('HHWIN_PROP_NOTITLEBAR',0x00000001)
		win_const_mgr.add_const('IDM_BUTTON',0x00000877)
		win_const_mgr.add_const('CTRY_FINLAND',0x00000166)
		win_const_mgr.add_const('IGIMII_OTHER',0x00000020)
		win_const_mgr.add_const('SQL_ROWSET_SIZE',0x00000009)
		win_const_mgr.add_const('CRYPT_OID_USE_PUBKEY_PARA_FOR_PKCS7_FLAG',0x00000002)
		win_const_mgr.add_const('CTRY_TURKEY',0x0000005A)
		win_const_mgr.add_const('MD_APP_POOL_RECYCLE_SCHEDULE',0x00000004)
		win_const_mgr.add_const('MAX_LANMAN_MESSAGE_ID',0x0000170B)
		win_const_mgr.add_const('DMNUP_SYSTEM',0x00000001)
		win_const_mgr.add_const('PSD_MINMARGINS',0x00000001)
		win_const_mgr.add_const('PSP_USEICONID',0x00000004)
		win_const_mgr.add_const('SQL_DIAG_GRANT',0x00000030)
		win_const_mgr.add_const('IDC_PS_SOURCETEXT',0x000001F6)
		win_const_mgr.add_const('ERROR_ALREADY_WIN32',0x000002CF)
		win_const_mgr.add_const('GESTURE_CROSS',0x00000000)
		win_const_mgr.add_const('ERROR_NO_MORE_SEARCH_HANDLES',0x00000071)
		win_const_mgr.add_const('TMT_SHADOWCOLOR',0x00000EE7)
		win_const_mgr.add_const('DRM_WM_GET_LIC_DATA_DEFINED',0x00000001)
		win_const_mgr.add_const('SOUND_SYSTEM_APPEND',0x0000000E)
		win_const_mgr.add_const('VP_TV_STANDARD_WIN_VGA',0x00008000)
		win_const_mgr.add_const('CTRY_VENEZUELA',0x0000003A)
		win_const_mgr.add_const('TASK_FLAG_SYSTEM_REQUIRED',0x00001000)
		win_const_mgr.add_const('MRINFO_DOWN_FLAG',0x00000010)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_DONOTDISTURB',0x0000001A)
		win_const_mgr.add_const('NET_NOT_AVAIL',0x00000002)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_OUTPUT',0x04000000)
		win_const_mgr.add_const('CAL_THAI',0x00000007)
		win_const_mgr.add_const('FS_LINE_UNAVAILABLE',0x20000020)
		win_const_mgr.add_const('ERROR_EC_CIRCULAR_FORWARDING',0x00003AEA)
		win_const_mgr.add_const('PERF_PROVIDER_DRIVER',0x00000002)
		win_const_mgr.add_const('ERROR_VOLUME_NOT_SIS_ENABLED',0x00001194)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_RECEIVED',0x00000080)
		win_const_mgr.add_const('IDM_FONTSIZE',0x00000013)
		win_const_mgr.add_const('DBPROPVAL_NT_SINGLEROW',0x00000001)
		win_const_mgr.add_const('WS_VSCROLL',0x00200000)
		win_const_mgr.add_const('BLKHOLE_FUNCTION',0x00000002)
		win_const_mgr.add_const('DMPAPER_RESERVED_48',0x00000030)
		win_const_mgr.add_const('DMPAPER_RESERVED_49',0x00000031)
		win_const_mgr.add_const('TMT_GRAYTEXT',0x00000652)
		win_const_mgr.add_const('AF_ICLFXBM',0x0000001F)
		win_const_mgr.add_const('RECOVERED_READS_VALID',0x00000004)
		win_const_mgr.add_const('SQL_DIAG_ROW_COUNT',0x00000003)
		win_const_mgr.add_const('CTRY_BOLIVIA',0x0000024F)
		win_const_mgr.add_const('DDSCAPS_MIPMAP',0x00400000)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_SUBJECT_BLOB',0x00000002)
		win_const_mgr.add_const('KEY_NOTIFY',0x00000010)
		win_const_mgr.add_const('COD_SERVICE_BIT_OFFSET',0x00000008)
		win_const_mgr.add_const('PIDISM_GLOBAL',0x00000000)
		win_const_mgr.add_const('DPNHREGISTERPORTS_FIXEDPORTS',0x00000002)
		win_const_mgr.add_const('LINETRANSLATEOPTION_FORCELD',0x00000008)
		win_const_mgr.add_const('SECPKG_ATTR_PACKAGE_INFO',0x0000000A)
		win_const_mgr.add_const('ERROR_PROCESS_MODE_ALREADY_BACKGROUND',0x00000192)
		win_const_mgr.add_const('PHONE_CLOSE',0x0000000F)
		win_const_mgr.add_const('OID_802_11_SSID',0x0D010102)
		win_const_mgr.add_const('VER_ERR_TOKEN',0x00000008)
		win_const_mgr.add_const('DMPAPER_JENV_YOU4',0x0000005B)
		win_const_mgr.add_const('MCI_DGV_INFO_AUDIO_QUALITY',0x00004001)
		win_const_mgr.add_const('IDD_CONVERT',0x000003EA)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_DEFAULTSTATUS',0x0000044D)
		win_const_mgr.add_const('CERT_TRUST_HAS_NOT_PERMITTED_NAME_CONSTRAINT',0x00004000)
		win_const_mgr.add_const('HCBT_SYSCOMMAND',0x00000008)
		win_const_mgr.add_const('DISPID_DHTMLEDITAPPEARANCE',0x0000000D)
		win_const_mgr.add_const('DEBUG_FIND_SOURCE_FULL_PATH',0x00000001)
		win_const_mgr.add_const('C2_BLOCKSEPARATOR',0x00000008)
		win_const_mgr.add_const('DMBIN_UPPER',0x00000001)
		win_const_mgr.add_const('CM_DRP_LEGACYBUSTYPE',0x00000015)
		win_const_mgr.add_const('SQL_API_SQLTRANSACT',0x00000017)
		win_const_mgr.add_const('WINHTTP_OPTION_CODEPAGE',0x00000044)
		win_const_mgr.add_const('DBPROPVAL_ASYNCH_INITIALIZE',0x00000001)
		win_const_mgr.add_const('RPC_C_MGMT_INQ_IF_IDS',0x00000000)
		win_const_mgr.add_const('SELECTDIB',0x00000029)
		win_const_mgr.add_const('SUBLANG_GERMAN_LUXEMBOURG',0x00000004)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_DISK',0x00000007)
		win_const_mgr.add_const('PST_RS423',0x00000004)
		win_const_mgr.add_const('VK_OEM_COPY',0x000000F2)
		win_const_mgr.add_const('OLEUI_SUCCESS',0x00000001)
		win_const_mgr.add_const('NTMS_MESSAGE_LENGTH',0x00000100)
		win_const_mgr.add_const('PIDSI_LASTSAVE_DTM',0x00000000)
		win_const_mgr.add_const('ERROR_CTX_MODEM_RESPONSE_BUSY',0x00001B67)
		win_const_mgr.add_const('LVBKIF_STYLE_MASK',0x00000010)
		win_const_mgr.add_const('CF_DSPTEXT',0x00000081)
		win_const_mgr.add_const('FOFX_NOSKIPJUNCTIONS',0x00010000)
		win_const_mgr.add_const('LINE_CALLSTATE',0x00000002)
		win_const_mgr.add_const('SCRIPTSTAT_INTSTRUCTION_TIME',0x00000003)
		win_const_mgr.add_const('ERROR_DS_DUP_SCHEMA_ID_GUID',0x000020BD)
		win_const_mgr.add_const('GOPHER_TYPE_PDF',0x00040000)
		win_const_mgr.add_const('CLOSEPROPS_DISCARD',0x00000001)
		win_const_mgr.add_const('CERT_ID_SHA1_HASH',0x00000003)
		win_const_mgr.add_const('VIF_TEMPFILE',0x00000001)
		win_const_mgr.add_const('CF_DSPBITMAP',0x00000082)
		win_const_mgr.add_const('EVENT_TRACE_SECURE_MODE',0x00000080)
		win_const_mgr.add_const('ERROR_INVALID_STACKSEG',0x000000BD)
		win_const_mgr.add_const('PORT_LPD731',0x000002DB)
		win_const_mgr.add_const('WAB_CONTEXT_ADRLIST',0x00000002)
		win_const_mgr.add_const('MCW_HIDDEN',0x00000010)
		win_const_mgr.add_const('ACCESS_PROPERTY_GUID',0x00000002)
		win_const_mgr.add_const('ASP_MD_ID_BEGIN_RESERVED',0x00007000)
		win_const_mgr.add_const('SPI_ICONHORIZONTALSPACING',0x0000000D)
		win_const_mgr.add_const('C2_SEGMENTSEPARATOR',0x00000009)
		win_const_mgr.add_const('D3DTEXOPCAPS_ADDSMOOTH',0x00000400)
		win_const_mgr.add_const('SCARD_E_NO_ACCESS',0x80100027)
		win_const_mgr.add_const('DC_MAXEXTENT',0x00000005)
		win_const_mgr.add_const('PGF_CALCHEIGHT',0x00000002)
		win_const_mgr.add_const('OID_IRDA_MAX_SEND_WINDOW_SIZE',0x0A010205)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_COMPLETION_HANDLE',0x00004000)
		win_const_mgr.add_const('RPC_C_AUTHZ_DEFAULT',0x00000000)
		win_const_mgr.add_const('DDBLTFX_ROTATE270',0x00000020)
		win_const_mgr.add_const('TMT_ROUNDCORNERWIDTH',0x00000964)
		win_const_mgr.add_const('SOFTDIST_FLAG_DELETE_SUBSCRIPTION',0x00000008)
		win_const_mgr.add_const('NTMS_OBJECTNAME_LENGTH',0x00000040)
		win_const_mgr.add_const('MCI_WAVE_STATUS_CHANNELS',0x00004002)
		win_const_mgr.add_const('SQL_MODE_READ_WRITE',0x00000000)
		win_const_mgr.add_const('ISDB_LIT_PID',0x00000020)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_RAW_ONLY',0x00001000)
		win_const_mgr.add_const('ERROR_INVALID_FORM_NAME',0x0000076E)
		win_const_mgr.add_const('IDM_DROPDOWNBOX',0x00000875)
		win_const_mgr.add_const('CERT_STORE_CTRL_NOTIFY_CHANGE',0x00000002)
		win_const_mgr.add_const('DUP_RESULTS',0x00000004)
		win_const_mgr.add_const('PFD_DOUBLEBUFFER',0x00000001)
		win_const_mgr.add_const('ERROR_PATCH_WRONG_FILE',0xC00E4104)
		win_const_mgr.add_const('DEBUG_DATA_KPCR_OFFSET',0x00000000)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_LSOV2_DISABLED',0x00000001)
		win_const_mgr.add_const('BCRYPT_SIGNATURE_INTERFACE',0x00000005)
		win_const_mgr.add_const('INTERNET_FLAG_RESTRICTED_ZONE',0x00020000)
		win_const_mgr.add_const('WINHTTP_FLAG_SECURE_PROTOCOL_SSL2',0x00000008)
		win_const_mgr.add_const('SECPKG_ATTR_SIZES',0x00000000)
		win_const_mgr.add_const('GT_DGROUP',0x00000001)
		win_const_mgr.add_const('TF_MOD_RSHIFT',0x00000020)
		win_const_mgr.add_const('LINEFORWARDMODE_BUSYNA',0x00001000)
		win_const_mgr.add_const('MOUSEEVENTF_MIDDLEUP',0x00000040)
		win_const_mgr.add_const('WINSTA_WRITEATTRIBUTES',0x00000010)
		win_const_mgr.add_const('XA_FMTID_DTC',0x00445443)
		win_const_mgr.add_const('STM_ONLY_THIS_INTERFACE',0x00000001)
		win_const_mgr.add_const('MD_ACCESS_MAP_CERT',0x00000080)
		win_const_mgr.add_const('DIIDFLAG_INSTALLNULLDRIVER',0x00000004)
		win_const_mgr.add_const('CM_DRP_DRIVER',0x0000000A)
		win_const_mgr.add_const('VCSTATUS_INTERACTIVE',0x00000008)
		win_const_mgr.add_const('SUBSINFO_ALLFLAGS',0x0000EF7F)
		win_const_mgr.add_const('IMAGEHLP_GET_TYPE_INFO_UNCACHED',0x00000001)
		win_const_mgr.add_const('DDSCAPS2_RESERVED4',0x00000002)
		win_const_mgr.add_const('DDSCAPS2_RESERVED1',0x00000020)
		win_const_mgr.add_const('ICC_LINK_CLASS',0x00008000)
		win_const_mgr.add_const('DDSCAPS2_RESERVED3',0x04000000)
		win_const_mgr.add_const('DDSCAPS2_RESERVED2',0x00000040)
		win_const_mgr.add_const('MCW_RECT',0x00000001)
		win_const_mgr.add_const('IMC_GETCANDIDATEPOS',0x00000007)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_NETWORK_CONNECTIVITY',0x00000014)
		win_const_mgr.add_const('SPEAKER_TOP_CENTER',0x00000800)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_CEE',0x0000C0EE)
		win_const_mgr.add_const('MAXGTRIDSIZE',0x00000040)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_CEF',0x00000CEF)
		win_const_mgr.add_const('FLG_ADDREG_TYPE_SZ',0x00000000)
		win_const_mgr.add_const('KERB_ETYPE_RC2_CBC_ENV',0x0000000C)
		win_const_mgr.add_const('DNS_ERROR_DATABASE_BASE',0x000025E4)
		win_const_mgr.add_const('CERT_COMPARE_SHA1_HASH',0x00000001)
		win_const_mgr.add_const('MEVT_F_SHORT',0x00000000)
		win_const_mgr.add_const('ERROR_UNKNOWN_PATCH',0x0000066F)
		win_const_mgr.add_const('NDR_MINOR_VERSION',0x00000004)
		win_const_mgr.add_const('PROXIMITY_UNIT_PARAGRAPH',0x00000002)
		win_const_mgr.add_const('TAPIMAXCOMMENTSIZE',0x00000050)
		win_const_mgr.add_const('DMDITHER_RESERVED9',0x00000009)
		win_const_mgr.add_const('CAUSE_REASON_IE_INSUFFICIENT',0x00000008)
		win_const_mgr.add_const('URLACTION_AUTHENTICATE_CLIENT',0x00001A01)
		win_const_mgr.add_const('ETW_BOOL_TYPE_VALUE',0x0000006C)
		win_const_mgr.add_const('PIR_STATUS_DISABLED',0x00000002)
		win_const_mgr.add_const('NRB_FUNCTION_FLUSH_NVCACHE',0x00000014)
		win_const_mgr.add_const('IDM_REGISTRYREFRESH',0x0000090D)
		win_const_mgr.add_const('DELFLG_IN_USE1',0x00010000)
		win_const_mgr.add_const('GPT_BASIC_DATA_ATTRIBUTE_READ_ONLY',0x1000000000000000)
		win_const_mgr.add_const('NOTIFY_CLASS_ROLE_CHANGE',0x00000002)
		win_const_mgr.add_const('PID_INTSITE_TITLE',0x00000010)
		win_const_mgr.add_const('IDM_SETWALLPAPER',0x000008D8)
		win_const_mgr.add_const('DNS_TYPE_KEY',0x00000019)
		win_const_mgr.add_const('ERROR_DS_DRA_REF_ALREADY_EXISTS',0x00002100)
		win_const_mgr.add_const('SNMP_GENERICTRAP_COLDSTART',0x00000000)
		win_const_mgr.add_const('ES_USER_PRESENT',0x00000004)
		win_const_mgr.add_const('MSV1_0_NTLM3_RESPONSE_LENGTH',0x00000010)
		win_const_mgr.add_const('ERROR_DS_CANT_REMOVE_CLASS_CACHE',0x000020D4)
		win_const_mgr.add_const('CC_CIRCLES',0x00000001)
		win_const_mgr.add_const('SP_COPY_ALREADYDECOMP',0x00400000)
		win_const_mgr.add_const('OID_FDDI_IF_PHYS_ADDRESS',0x0303027D)
		win_const_mgr.add_const('MF_POPUP',0x00000010)
		win_const_mgr.add_const('DDCAPS_ZOVERLAYS',0x00200000)
		win_const_mgr.add_const('PDCAP_WARM_EJECT_SUPPORTED',0x00000100)
		win_const_mgr.add_const('LVGS_SUBSETED',0x00000040)
		win_const_mgr.add_const('CHANNEL_FLAG_SHOW_PROTOCOL',0x00000010)
		win_const_mgr.add_const('FILE_DEVICE_SCSI',0x00000001)
		win_const_mgr.add_const('USER_PASSWORD_AGE_PARMNUM',0x00000004)
		win_const_mgr.add_const('SQL_RD_OFF',0x00000000)
		win_const_mgr.add_const('CMC_FAIL_MUST_ARCHIVE_KEYS',0x00000006)
		win_const_mgr.add_const('DEMAND_UPDATE_SERVICES',0x00000008)
		win_const_mgr.add_const('INTERNET_FLAG_NO_AUTO_REDIRECT',0x00200000)
		win_const_mgr.add_const('MFCLOCK_JITTER_PASSIVE',0x00002710)
		win_const_mgr.add_const('ACMDRIVERDETAILS_SUPPORTF_CODEC',0x00000001)
		win_const_mgr.add_const('ALG_SID_CYLINK_MEK',0x0000000C)
		win_const_mgr.add_const('MFSESSIONCAP_SEEK',0x00000002)
		win_const_mgr.add_const('DBPROMPT_PROMPT',0x00000001)
		win_const_mgr.add_const('RS_SUSPENDED',0x00000002)
		win_const_mgr.add_const('RRF_RT_REG_NONE',0x00000001)
		win_const_mgr.add_const('DEBUG_EVENT_EXCEPTION',0x00000002)
		win_const_mgr.add_const('ERROR_CANT_RECOVER_WITH_HANDLE_OPEN',0x00001AA2)
		win_const_mgr.add_const('SOFTDIST_ADSTATE_DOWNLOADED',0x00000002)
		win_const_mgr.add_const('WMDM_SEEK_BEGIN',0x00000001)
		win_const_mgr.add_const('D3DVTXPCAPS_POSITIONALLIGHTS',0x00000010)
		win_const_mgr.add_const('CB_GETEXTENDEDUI',0x00000156)
		win_const_mgr.add_const('FRS_ERR_INSUFFICIENT_PRIV',0x00001F47)
		win_const_mgr.add_const('FD_READ_BIT',0x00000000)
		win_const_mgr.add_const('GDIPLUS_TS_QUERYVER',0x0000101A)
		win_const_mgr.add_const('WDIAG_IHV_WLAN_ID_FLAG_SECURITY_ENABLED',0x00000001)
		win_const_mgr.add_const('IFF_POINTTOPOINT',0x00000008)
		win_const_mgr.add_const('OBM_CLOSE',0x00007FF2)
		win_const_mgr.add_const('CRYPT_DECODE_NOCOPY_FLAG',0x00000001)
		win_const_mgr.add_const('SE_DACL_PROTECTED',0x00001000)
		win_const_mgr.add_const('KERB_CERTIFICATE_S4U_LOGON_FLAG_CHECK_LOGONHOURS',0x00000002)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_DEF_SUM_FLOW_RATE',0x00000025)
		win_const_mgr.add_const('IITWBC_EXTDATA_STOPWORDLIST',0x00000001)
		win_const_mgr.add_const('TVIF_TEXT',0x00000001)
		win_const_mgr.add_const('AUDIT_TYPE_LEGACY',0x00000001)
		win_const_mgr.add_const('IF_TYPE_FASTETHER_FX',0x00000045)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_WINDOWS_CUI',0x00000003)
		win_const_mgr.add_const('IDM_SPELL',0x000007D5)
		win_const_mgr.add_const('PM_NOREMOVE',0x00000000)
		win_const_mgr.add_const('D3DCS_PLANE2',0x00000100)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYDEINTERLACE',0x20000000)
		win_const_mgr.add_const('TB_LINEDOWN',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLGETCONNECTOPTION',0x0000002A)
		win_const_mgr.add_const('BG_E_NEW_OWNER_DIFF_MAPPING',0x80200015)
		win_const_mgr.add_const('DISPID_NEWWINDOW3',0x00000111)
		win_const_mgr.add_const('DISPID_NEWWINDOW2',0x000000FB)
		win_const_mgr.add_const('COD_AUDIO_MINOR_HIFI_AUDIO',0x0000000A)
		win_const_mgr.add_const('OID_ATM_ALIGNMENT_REQUIRED',0x08010208)
		win_const_mgr.add_const('IDM_SCROLL_BOTTOM',0x0000094E)
		win_const_mgr.add_const('CM_QUERY_ARBITRATOR_RAW',0x00000000)
		win_const_mgr.add_const('FACILITY_IMAPI2',0x000000AA)
		win_const_mgr.add_const('SO_LINKINFO',0x00000007)
		win_const_mgr.add_const('CTF_UNUSED',0x00000080)
		win_const_mgr.add_const('ARCONTENT_AUTOPLAYVIDEO',0x00000200)
		win_const_mgr.add_const('CC_ENABLETEMPLATE',0x00000020)
		win_const_mgr.add_const('SQL_SSF_LOWER',0x00000002)
		win_const_mgr.add_const('MCIWNDF_NOTIFYMEDIAA',0x00000880)
		win_const_mgr.add_const('KAGPROP_MAXCOLUMNSINORDERBY',0x0000000E)
		win_const_mgr.add_const('ERROR_FLOAT_MULTIPLE_FAULTS',0x00000276)
		win_const_mgr.add_const('SYSFXUI_DONOTSHOW_HEADPHONEVIRTUALIZATION',0x00000010)
		win_const_mgr.add_const('SYMOPT_ALLOW_ZERO_ADDRESS',0x01000000)
		win_const_mgr.add_const('BTH_ERROR_HOST_REJECTED_PERSONAL_DEVICE',0x00000000)
		win_const_mgr.add_const('SDP_ATTRIB_CLIENT_EXECUTABLE_URL',0x0000000B)
		win_const_mgr.add_const('WMPCOREEVENT_CONTENT_BASE',0x000014B4)
		win_const_mgr.add_const('PSM_TCS_BIN_CORDLESS',0x00000007)
		win_const_mgr.add_const('LVCFMT_IMAGE',0x00000800)
		win_const_mgr.add_const('RPC_C_MGMT_STOP_SERVER_LISTEN',0x00000004)
		win_const_mgr.add_const('CR_PROP_KRACERTUSEDCOUNT',0x00000018)
		win_const_mgr.add_const('LINECONNECTEDMODE_INACTIVEHELD',0x00000008)
		win_const_mgr.add_const('DISKQUOTA_STATE_TRACK',0x00000001)
		win_const_mgr.add_const('PSINJECT_ENDPROLOG',0x0000000F)
		win_const_mgr.add_const('VTBIT_I4',0x00000001)
		win_const_mgr.add_const('MF_GRL_ABSENT',0x00001000)
		win_const_mgr.add_const('WINHTTP_OPTION_REDIRECT_POLICY_ALWAYS',0x00000002)
		win_const_mgr.add_const('VTBIT_I1',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_DATAFILE_OPEN_FAILURE',0x000025B5)
		win_const_mgr.add_const('DDE_FNOTPROCESSED',0x00000000)
		win_const_mgr.add_const('VTBIT_I2',0x00000001)
		win_const_mgr.add_const('SERVICE_ADD_TYPE',0x00000004)
		win_const_mgr.add_const('SERVICE_NOT_UNINSTALLABLE',0x00000000)
		win_const_mgr.add_const('FMFOCUS_DIR',0x00000001)
		win_const_mgr.add_const('FWPM_LAYER_FLAG_BUILTIN',0x00000002)
		win_const_mgr.add_const('VTBIT_I8',0x00000001)
		win_const_mgr.add_const('SQL_WARN_YES',0x00000001)
		win_const_mgr.add_const('ATSC_STT_PID',0x00001FFB)
		win_const_mgr.add_const('POLICY_NOTIFICATION',0x00001000)
		win_const_mgr.add_const('PST_PC_HARDWARE',0x00000002)
		win_const_mgr.add_const('ERROR_BUS_RESET',0x00000457)
		win_const_mgr.add_const('SQL_CA1_BULK_UPDATE_BY_BOOKMARK',0x00020000)
		win_const_mgr.add_const('POLICY_ERRV_PRE_EMPTED',0x00000035)
		win_const_mgr.add_const('WIA_DPC_WHITE_BALANCE',0x00000829)
		win_const_mgr.add_const('ERROR_IPSEC_MM_AUTH_EXISTS',0x000032D2)
		win_const_mgr.add_const('ERROR_DISCARDED',0x0000009D)
		win_const_mgr.add_const('OLE_VERS_LOWORD',0x0000000A)
		win_const_mgr.add_const('SPDRP_HARDWAREID',0x00000001)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_FILTER_DRIVER_CHARACTERISTICS',0x0000008B)
		win_const_mgr.add_const('SCARD_F_UNKNOWN_ERROR',0x80100014)
		win_const_mgr.add_const('MD_DIMTYPE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('SEE_MASK_NOZONECHECKS',0x00800000)
		win_const_mgr.add_const('PIDDSI_MANAGER',0x0000000E)
		win_const_mgr.add_const('STGM_RECURSIVE',0x01000000)
		win_const_mgr.add_const('SB_PAGERIGHT',0x00000003)
		win_const_mgr.add_const('SQL_DROP_DOMAIN',0x0000008B)
		win_const_mgr.add_const('PHYSICALOFFSETX',0x00000070)
		win_const_mgr.add_const('CTRY_PHILIPPINES',0x0000003F)
		win_const_mgr.add_const('IDS_CAP_VIDEDITERR',0x0000019C)
		win_const_mgr.add_const('ERROR_SYSTEM_PROCESS_TERMINATED',0x0000024F)
		win_const_mgr.add_const('SPI_GETMOUSECLICKLOCK',0x0000101E)
		win_const_mgr.add_const('DEBUG_DUMP_FULL',0x00000402)
		win_const_mgr.add_const('WMDRM_IMPORT_INIT_STRUCT_DEFINED',0x00000001)
		win_const_mgr.add_const('CDO_E_ARGUMENT4',0x80044003)
		win_const_mgr.add_const('MC_CAPS_COLOR_TEMPERATURE',0x00000008)
		win_const_mgr.add_const('LOCALE_SABBREVLANGNAME',0x00000003)
		win_const_mgr.add_const('PDH_MEMORY_ALLOCATION_FAILURE',0xC0000BBB)
		win_const_mgr.add_const('OID_OFFLOAD_ENCAPSULATION',0x0101010A)
		win_const_mgr.add_const('SCHEME_REFRESH',0x00000010)
		win_const_mgr.add_const('DDPF_FOURCC',0x00000004)
		win_const_mgr.add_const('DOCKINFO_USER_SUPPLIED',0x00000004)
		win_const_mgr.add_const('ARW_DOWN',0x00000004)
		win_const_mgr.add_const('ERROR_PATCH_ENCODE_FAILURE',0xC00E3101)
		win_const_mgr.add_const('LDAP_EXTENDED_CMD',0x00000077)
		win_const_mgr.add_const('SQLBIT',0x00000032)
		win_const_mgr.add_const('WIA_DPS_HORIZONTAL_BED_SIZE',0x00000C02)
		win_const_mgr.add_const('DBPROPVAL_TR_ABORT_NO',0x00000020)
		win_const_mgr.add_const('PROCESSOR_ARCHITECTURE_IA64',0x00000006)
		win_const_mgr.add_const('ENM_LOWFIRTF',0x08000000)
		win_const_mgr.add_const('PRINTER_STATUS_NOT_AVAILABLE',0x00001000)
		win_const_mgr.add_const('D3D10_SHADER_FORCE_VS_SOFTWARE_NO_OPT',0x00000001)
		win_const_mgr.add_const('SQL_ISV_KEY_COLUMN_USAGE',0x00000800)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW3_SETTIMEOUT',0x0000044F)
		win_const_mgr.add_const('ABM_REMOVE',0x00000001)
		win_const_mgr.add_const('ISFBVIEWMODE_LOGOS',0x00000003)
		win_const_mgr.add_const('RDW_NOERASE',0x00000020)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_29',0x0000001D)
		win_const_mgr.add_const('EVENT_TRACE_RELOG_MODE',0x00010000)
		win_const_mgr.add_const('PSIDENT_PSCENTRIC',0x00000001)
		win_const_mgr.add_const('IDS_CAP_BEGIN',0x0000012C)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_REQUIRES_ALE_CLASSIFY',0x00000100)
		win_const_mgr.add_const('TRACE_LEVEL_RESERVED6',0x00000006)
		win_const_mgr.add_const('TRACE_LEVEL_RESERVED7',0x00000007)
		win_const_mgr.add_const('TRACE_LEVEL_RESERVED8',0x00000008)
		win_const_mgr.add_const('TRACE_LEVEL_RESERVED9',0x00000009)
		win_const_mgr.add_const('PBS_VERTICAL',0x00000004)
		win_const_mgr.add_const('USN_REASON_BASIC_INFO_CHANGE',0x00008000)
		win_const_mgr.add_const('PRINTER_CHANGE_SET_PRINTER_DRIVER',0x20000000)
		win_const_mgr.add_const('DDL_READONLY',0x00000001)
		win_const_mgr.add_const('LINECALLPRIVILEGE_OWNER',0x00000004)
		win_const_mgr.add_const('MB_NOFOCUS',0x00008000)
		win_const_mgr.add_const('EVENT_CONSOLE_LAYOUT',0x00004005)
		win_const_mgr.add_const('CFS_CANDIDATEPOS',0x00000040)
		win_const_mgr.add_const('FOFX_NOMINIMIZEBOX',0x01000000)
		win_const_mgr.add_const('DEBUG_BREAK_READ',0x00000001)
		win_const_mgr.add_const('ARCONTENT_PHASE_PRESNIFF',0x10000000)
		win_const_mgr.add_const('WIA_IPA_COMPRESSION',0x0000100B)
		win_const_mgr.add_const('NCRYPT_MACHINE_KEY_FLAG',0x00000020)
		win_const_mgr.add_const('UME_MENU_TEXT_LEN',0x00000032)
		win_const_mgr.add_const('DNS_OPCODE_IQUERY',0x00000001)
		win_const_mgr.add_const('KS_VIDEOSTREAM_EDS',0x00000200)
		win_const_mgr.add_const('OID_FDDI_SMT_LO_VERSION_ID',0x03030204)
		win_const_mgr.add_const('UF_NOT_DELEGATED',0x00100000)
		win_const_mgr.add_const('MCIWNDF_NOTIFYMODE',0x00000100)
		win_const_mgr.add_const('BPPF_NOCLIP',0x00000002)
		win_const_mgr.add_const('PDH_LOG_READ_ACCESS',0x00010000)
		win_const_mgr.add_const('WMIREG_FLAG_REMOVE_GUID',0x00010000)
		win_const_mgr.add_const('IDS_CAP_VIDEO_SIZE_ERROR',0x000001AC)
		win_const_mgr.add_const('HSE_URL_FLAGS_MASK',0x00000003)
		win_const_mgr.add_const('PKR_XD',0x00000003)
		win_const_mgr.add_const('MF_DEFAULT',0x00001000)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY5',0x00000020)
		win_const_mgr.add_const('CRYPT_DONT_CHECK_TIME_VALIDITY',0x00000200)
		win_const_mgr.add_const('SSA_CLIP',0x00000004)
		win_const_mgr.add_const('CERT_SOURCE_LOCATION_PROP_ID',0x00000048)
		win_const_mgr.add_const('SOMAXCONN',0x00000007)
		win_const_mgr.add_const('DBPROPVAL_SS_ISEQUENTIALSTREAM',0x00000001)
		win_const_mgr.add_const('XECR_PKCS10_V1_5',0x00000004)
		win_const_mgr.add_const('ERROR_FUNCTION_NOT_CALLED',0x0000065A)
		win_const_mgr.add_const('SEF_MACL_NO_READ_UP',0x00000200)
		win_const_mgr.add_const('ICINSTALL_HDRV',0x00000004)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_KERBEROS_ERROR',0x00003603)
		win_const_mgr.add_const('CDIS_DEFAULT',0x00000020)
		win_const_mgr.add_const('SCS_PIF_BINARY',0x00000003)
		win_const_mgr.add_const('CRYPT_ENCODE_ALLOC_FLAG',0x00008000)
		win_const_mgr.add_const('LVTVIF_FIXEDHEIGHT',0x00000002)
		win_const_mgr.add_const('GBF_COPY',0x00000002)
		win_const_mgr.add_const('DOT11_RECV_FLAG_RAW_PACKET_TIMESTAMP',0x00000004)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_SETUPCONFNULL',0x00000200)
		win_const_mgr.add_const('BCSIF_STYLE',0x00000004)
		win_const_mgr.add_const('DISPID_DOCUMENT',0x00000006)
		win_const_mgr.add_const('ERROR_INVALID_STATE',0x0000139F)
		win_const_mgr.add_const('DB_IMP_LEVEL_IMPERSONATE',0x00000002)
		win_const_mgr.add_const('WMPGC_FLAGS_DISABLE_PLUGINS',0x00000008)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_HARDWARE_DRIVER',0x00000000)
		win_const_mgr.add_const('AC_SRC_ALPHA',0x00000001)
		win_const_mgr.add_const('ERROR_OBJECT_ALREADY_EXISTS',0x00001392)
		win_const_mgr.add_const('LINECONNECTEDMODE_INACTIVE',0x00000002)
		win_const_mgr.add_const('CONFIGFLAG_MANUAL_INSTALL',0x00000004)
		win_const_mgr.add_const('SBSP_NEWBROWSER',0x00000002)
		win_const_mgr.add_const('OID_TCP_TASK_IPSEC_DELETE_UDPESP_SA',0xFC010206)
		win_const_mgr.add_const('ASC_RET_THIRD_LEG_FAILED',0x00004000)
		win_const_mgr.add_const('MF_128_BYTE_ALIGNMENT',0x00000007)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_INSET',0x00000013)
		win_const_mgr.add_const('DNS_QUERY_MULTICAST_ONLY',0x00000400)
		win_const_mgr.add_const('DISKQUOTA_USERNAME_RESOLVE_NONE',0x00000000)
		win_const_mgr.add_const('INTERNET_IDENTITY_FLAG_CLEAR_CONTENT',0x00000020)
		win_const_mgr.add_const('ERROR_NETWORK_NOT_AVAILABLE',0x000013AB)
		win_const_mgr.add_const('PST_FAX',0x00000021)
		win_const_mgr.add_const('CBR_4800',0x000012C0)
		win_const_mgr.add_const('SUBLANG_SWEDISH',0x00000001)
		win_const_mgr.add_const('ACTRL_PERM_20',0x00080000)
		win_const_mgr.add_const('DBPROPVAL_AO_SEQUENTIAL',0x00000000)
		win_const_mgr.add_const('CP_UTF7',0x0000FDE8)
		win_const_mgr.add_const('OID_CO_DELETE_PVC',0xFE000002)
		win_const_mgr.add_const('KERB_RETRIEVE_TICKET_CACHE_TICKET',0x00000020)
		win_const_mgr.add_const('LSA_SID_DISABLED_ADMIN',0x00000001)
		win_const_mgr.add_const('CREDUI_FLAGS_REQUIRE_SMARTCARD',0x00000100)
		win_const_mgr.add_const('KERB_REQUEST_REPLACE_CREDENTIAL',0x00000002)
		win_const_mgr.add_const('FORMAT_MESSAGE_MAX_WIDTH_MASK',0x000000FF)
		win_const_mgr.add_const('ERROR_BAD_LOGON_SESSION_STATE',0x00000555)
		win_const_mgr.add_const('IDM_IMGARTSTOP',0x000008E3)
		win_const_mgr.add_const('LANG_MAPUDUNGUN',0x00000007)
		win_const_mgr.add_const('SV_NUMBIGBUF_PARMNUM',0x000001A6)
		win_const_mgr.add_const('CMC_FAIL_BAD_ALG',0x00000000)
		win_const_mgr.add_const('LINECALLINFOSTATE_DIALPARAMS',0x04000000)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_NSI_INTERFACE_PERSIST_RW_STRUCT',0x000000AE)
		win_const_mgr.add_const('SCS_DOS_BINARY',0x00000001)
		win_const_mgr.add_const('SF_DENIED_LOGON',0x00000001)
		win_const_mgr.add_const('NWF_STATISTICS_OID',0x00000002)
		win_const_mgr.add_const('MCMV_DECADE',0x00000002)
		win_const_mgr.add_const('CDRF_DODEFAULT',0x00000000)
		win_const_mgr.add_const('PFA_RIGHT',0x00000002)
		win_const_mgr.add_const('CAUSE_USER_CELL_RATE_UNAVAILABLE',0x00000033)
		win_const_mgr.add_const('LDAP_OPT_SASL_METHOD',0x00000097)
		win_const_mgr.add_const('DOSOPTF_DEFAULT',0x00000001)
		win_const_mgr.add_const('SUB_CONTAINERS_ONLY_INHERIT',0x00000002)
		win_const_mgr.add_const('EMR_INVERTRGN',0x00000049)
		win_const_mgr.add_const('FLASHMODE_FILL',0x00000003)
		win_const_mgr.add_const('TVIS_EX_FLAT',0x00000001)
		win_const_mgr.add_const('CT_CTYPE3',0x00000004)
		win_const_mgr.add_const('ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE',0x0000172D)
		win_const_mgr.add_const('INTERNET_FLAG_EXISTING_CONNECT',0x20000000)
		win_const_mgr.add_const('ERROR_BUSY',0x000000AA)
		win_const_mgr.add_const('MB_ICONQUESTION',0x00000020)
		win_const_mgr.add_const('FE_FONTSMOOTHINGSTANDARD',0x00000001)
		win_const_mgr.add_const('TMT_ACTIVEBORDER',0x0000064B)
		win_const_mgr.add_const('SMC_SFSELECTITEM',0x0000000A)
		win_const_mgr.add_const('DISPID_WINDOWCLOSING',0x00000107)
		win_const_mgr.add_const('SE_GROUP_LOGON_ID',0xC0000000)
		win_const_mgr.add_const('SECURITY_FLAG_STRENGTH_MEDIUM',0x40000000)
		win_const_mgr.add_const('MCI_DGV_STATUS_SEEK_EXACTLY',0x00004011)
		win_const_mgr.add_const('DNS_INFO_AXFR_COMPLETE',0x00002617)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_ODD',0x00000001)
		win_const_mgr.add_const('CTLCOLOR_MAX',0x00000007)
		win_const_mgr.add_const('SYSPAL_ERROR',0x00000000)
		win_const_mgr.add_const('CM_DELETE_CLASS_INTERFACE',0x00000002)
		win_const_mgr.add_const('SSPROP_UNICODECOMPARISONSTYLE',0x00000003)
		win_const_mgr.add_const('OID_TAPI_CONFIG_DIALOG',0x07030106)
		win_const_mgr.add_const('ERRLOG2_BASE',0x00001644)
		win_const_mgr.add_const('DDLOCK_NOOVERWRITE',0x00001000)
		win_const_mgr.add_const('PERF_FILTER',0x00000009)
		win_const_mgr.add_const('SFF_PLAINRTF',0x00004000)
		win_const_mgr.add_const('CERT_EFS_PROP_ID',0x00000011)
		win_const_mgr.add_const('FRAME_NONFPO',0x00000003)
		win_const_mgr.add_const('RPC_C_OPT_MQ_AUTHN_SERVICE',0x00000005)
		win_const_mgr.add_const('STI_MAX_INTERNAL_NAME_LENGTH',0x00000080)
		win_const_mgr.add_const('PD_STRETCHDIB_1_N_OK',0x00000010)
		win_const_mgr.add_const('PRODUCT_BUSINESS_N',0x00000010)
		win_const_mgr.add_const('WMDRM_OPL_COPY',0x00000002)
		win_const_mgr.add_const('NOTIFIER_FLAG_SECONDS',0x80000000)
		win_const_mgr.add_const('DRM_PLAYLIST_DATA_OTHER_VALID',0x00000004)
		win_const_mgr.add_const('FORM_PRINTER',0x00000002)
		win_const_mgr.add_const('EAP_E_USER_CERT_EXPIRED',0x80420102)
		win_const_mgr.add_const('DISPID_LOAD',0x00000001)
		win_const_mgr.add_const('PTE_ATTR_SHIFT',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_FLAG_REQUEST_HEADERS',0x80000000)
		win_const_mgr.add_const('OID_IRDA_RATE_SNIFF',0x0A010201)
		win_const_mgr.add_const('CRYPT_ECC_CMS_SHARED_INFO_SUPPPUBINFO_BYTE_LENGTH',0x00000004)
		win_const_mgr.add_const('SCARD_E_READER_UNSUPPORTED',0x8010001A)
		win_const_mgr.add_const('IDD_CONVERTONLY',0x000003F4)
		win_const_mgr.add_const('CONNECT_NEED_DRIVE',0x00000020)
		win_const_mgr.add_const('ERRCLASS_LOCKED',0x0000000A)
		win_const_mgr.add_const('MDMSPKRFLAG_CALLSETUP',0x00000008)
		win_const_mgr.add_const('EN_SELCHANGE',0x00000702)
		win_const_mgr.add_const('MCI_VCR_CUE_REVERSE',0x00080000)
		win_const_mgr.add_const('ETW_HIDDEN_TYPE_VALUE',0x0000006B)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM5C_SIZE_X',0x00000005)
		win_const_mgr.add_const('MUI_FILETYPE_NOT_LANGUAGE_NEUTRAL',0x00000001)
		win_const_mgr.add_const('SPSVCINST_ASSOCSERVICE',0x00000002)
		win_const_mgr.add_const('EXPIRED_CREDENTIAL',0x00000004)
		win_const_mgr.add_const('RPC_C_HTTP_FLAG_IGNORE_CERT_CN_INVALID',0x00000008)
		win_const_mgr.add_const('INTERNET_OPTION_RESET_URLCACHE_SESSION',0x0000003C)
		win_const_mgr.add_const('SSRVOPT_UNATTENDED',0x00000020)
		win_const_mgr.add_const('PROV_SSL',0x00000006)
		win_const_mgr.add_const('CRED_TI_CREATE_EXPLICIT_CRED',0x00000010)
		win_const_mgr.add_const('PDH_FMT_RAW',0x00000010)
		win_const_mgr.add_const('ADS_PRINTER_PRINTING',0x00000400)
		win_const_mgr.add_const('INTERNET_FLAG_IGNORE_CERT_CN_INVALID',0x00001000)
		win_const_mgr.add_const('CACHE_NOTIFY_SET_ONLINE',0x00000100)
		win_const_mgr.add_const('CLFS_FLAG_FORCE_APPEND',0x00000001)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_ORIGOFFHOOK',0x00000040)
		win_const_mgr.add_const('SQL_SO_MIXED',0x00000008)
		win_const_mgr.add_const('PRINTER_ATTRIBUTE_QUEUED',0x00000001)
		win_const_mgr.add_const('KAGPROP_FORCENOPREPARE',0x0000000C)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_DAY_TO_MINUTE',0x00000800)
		win_const_mgr.add_const('OID_FDDI_SMT_BYPASS_PRESENT',0x03030214)
		win_const_mgr.add_const('MCI_VCR_STATUS_AUDIO_RECORD',0x00004018)
		win_const_mgr.add_const('BITS_MC_FAILED_TO_START',0x80194008)
		win_const_mgr.add_const('CI_STATE_MASTER_MERGE_PAUSED',0x00000200)
		win_const_mgr.add_const('PDH_LOG_OPT_MASK',0x0F000000)
		win_const_mgr.add_const('CTRY_JAMAICA',0x00000001)
		win_const_mgr.add_const('ML_CROSSCODEPAGE_NT',0x00000001)
		win_const_mgr.add_const('TMT_FILLTYPE',0x00000FA3)
		win_const_mgr.add_const('NDR64_FC_CALLBACK_HANDLE',0x00000004)
		win_const_mgr.add_const('PERF_PROVIDER_USER_MODE',0x00000000)
		win_const_mgr.add_const('SETICMPROFILE_EMBEDED',0x00000001)
		win_const_mgr.add_const('DDBLT_DDROPS',0x00001000)
		win_const_mgr.add_const('SQL_SFKD_SET_NULL',0x00000008)
		win_const_mgr.add_const('DXVA_EXECUTE_RETURN_OK',0x00000000)
		win_const_mgr.add_const('INDEX_GUID_WRITINGREGION',0x00000002)
		win_const_mgr.add_const('CF_LIMITSIZE',0x00002000)
		win_const_mgr.add_const('WSA_QOS_BAD_OBJECT',0x00002B05)
		win_const_mgr.add_const('SQL_CS_AUTHORIZATION',0x00000002)
		win_const_mgr.add_const('TMT_RECT',0x000000D1)
		win_const_mgr.add_const('LANG_UIGHUR',0x00000080)
		win_const_mgr.add_const('DEBUG_BREAKPOINT_CODE',0x00000000)
		win_const_mgr.add_const('MCI_CUE',0x00000830)
		win_const_mgr.add_const('META_CREATEPATTERNBRUSH',0x000001F9)
		win_const_mgr.add_const('ASC_RET_STREAM',0x00010000)
		win_const_mgr.add_const('DS_REPSYNC_NEVER_NOTIFY',0x00001000)
		win_const_mgr.add_const('QUERYESCSUPPORT',0x00000008)
		win_const_mgr.add_const('SQL_FN_NUM_CEILING',0x00000020)
		win_const_mgr.add_const('TF_PROFILETYPE_INPUTPROCESSOR',0x00000001)
		win_const_mgr.add_const('PSBTN_BACK',0x00000000)
		win_const_mgr.add_const('CSIDL_CONNECTIONS',0x00000031)
		win_const_mgr.add_const('IOCTL_IP_UNIDIRECTIONAL_ADAPTER_ADDRESS',0x0000006A)
		win_const_mgr.add_const('SETPROPS_NONE',0x00000000)
		win_const_mgr.add_const('LDAP_OPT_SEND_TIMEOUT',0x00000042)
		win_const_mgr.add_const('CSIDL_PROGRAM_FILES_COMMONX86',0x00000002)
		win_const_mgr.add_const('MCI_CUT',0x00000851)
		win_const_mgr.add_const('DEBUG_ONLY_THIS_PROCESS',0x00000002)
		win_const_mgr.add_const('SSWF_CUSTOM',0x00000004)
		win_const_mgr.add_const('IT_MSG_NEW_PAGE',0x00000005)
		win_const_mgr.add_const('IDM_SCRIPT',0x0000087E)
		win_const_mgr.add_const('ERROR_PLUGPLAY_QUERY_VETOED',0x000002AB)
		win_const_mgr.add_const('TF_LBI_STYLE_BTN_MENU',0x00020000)
		win_const_mgr.add_const('D3D10_DEFAULT_BLEND_FACTOR_RED',0x00000001)
		win_const_mgr.add_const('SECBUFFER_PADDING',0x00000009)
		win_const_mgr.add_const('MCI_DGV_PUT_DESTINATION',0x00040000)
		win_const_mgr.add_const('SUBLANG_INDONESIAN_INDONESIA',0x00000001)
		win_const_mgr.add_const('ACCESS_FAIL_DELETE',0x00000400)
		win_const_mgr.add_const('ERROR_VOLUME_DIRTY',0x00001AC3)
		win_const_mgr.add_const('SAC_SESSION_KEYLEN',0x00000008)
		win_const_mgr.add_const('SPI_SETGRIDGRANULARITY',0x00000013)
		win_const_mgr.add_const('RIDEV_PAGEONLY',0x00000020)
		win_const_mgr.add_const('PD_NOPAGENUMS',0x00000008)
		win_const_mgr.add_const('SQL_SC_NON_UNIQUE',0x00000000)
		win_const_mgr.add_const('PPP_LCP_3_DES',0x00000020)
		win_const_mgr.add_const('PBST_PAUSED',0x00000003)
		win_const_mgr.add_const('LOCALSTATE_POLICYREMOVE_ORPHAN',0x00000008)
		win_const_mgr.add_const('SUBLANG_LITHUANIAN',0x00000001)
		win_const_mgr.add_const('CRYPTUI_SELECT_EXPIRATION_COLUMN',0x00000020)
		win_const_mgr.add_const('IF_TYPE_ADSL',0x0000005E)
		win_const_mgr.add_const('CTRY_LITHUANIA',0x00000172)
		win_const_mgr.add_const('ERROR_WAIT_FOR_OPLOCK',0x000002FD)
		win_const_mgr.add_const('MSV1_0_PASSTHRU',0x00000001)
		win_const_mgr.add_const('D3DPMISCCAPS_MRTPOSTPIXELSHADERBLENDING',0x00080000)
		win_const_mgr.add_const('KS_TVAUDIO_PRESET_LANG_C',0x00004000)
		win_const_mgr.add_const('KS_TVAUDIO_PRESET_LANG_B',0x00002000)
		win_const_mgr.add_const('KS_TVAUDIO_PRESET_LANG_A',0x00001000)
		win_const_mgr.add_const('SE_ERR_DDEBUSY',0x0000001E)
		win_const_mgr.add_const('COMMON_LVB_TRAILING_BYTE',0x00000200)
		win_const_mgr.add_const('DDSCAPS2_NPATCHES',0x02000000)
		win_const_mgr.add_const('C3_DIACRITIC',0x00000002)
		win_const_mgr.add_const('ADDRESSBAND',0x00000002)
		win_const_mgr.add_const('CONFIGFLAG_NOREMOVEEXIT',0x00000200)
		win_const_mgr.add_const('OCSP_UNAUTHORIZED_RESPONSE',0x00000006)
		win_const_mgr.add_const('BASIC_CONSTRAINTS_CERT_CHAIN_POLICY_END_ENTITY_FLAG',0x40000000)
		win_const_mgr.add_const('RASBASE',0x00000258)
		win_const_mgr.add_const('_WIN32_IE_IE50',0x00000500)
		win_const_mgr.add_const('DIRID_SPOOL',0x00000033)
		win_const_mgr.add_const('_WIN32_IE_IE55',0x00000550)
		win_const_mgr.add_const('DDGFS_CANFLIP',0x00000001)
		win_const_mgr.add_const('MB_DEFAULT_DESKTOP_ONLY',0x00020000)
		win_const_mgr.add_const('WIA_DEVICE_DIALOG_USE_COMMON_UI',0x00000004)
		win_const_mgr.add_const('IMGDECODE_EVENT_PROGRESS',0x00000001)
		win_const_mgr.add_const('WMDM_STATUS_DEVICECONTROL_RECORDING',0x00000010)
		win_const_mgr.add_const('DEBUG_STATUS_STEP_INTO',0x00000005)
		win_const_mgr.add_const('BCPMAXERRS',0x00000001)
		win_const_mgr.add_const('PIR_STATUS_TABLE_REALMODE',0x00000002)
		win_const_mgr.add_const('PRINTER_ERROR_OUTOFTONER',0x00000004)
		win_const_mgr.add_const('ISC_REQ_CALL_LEVEL',0x00001000)
		win_const_mgr.add_const('SG_UNCONSTRAINED_GROUP',0x00000001)
		win_const_mgr.add_const('WM_PENWINFIRST',0x00000380)
		win_const_mgr.add_const('CERT_TRUST_PUB_CHECK_TIMESTAMP_REV_FLAG',0x00000200)
		win_const_mgr.add_const('OID_802_5_LAST_OPEN_STATUS',0x02010105)
		win_const_mgr.add_const('ERR_FORWARD_OK',0x00008000)
		win_const_mgr.add_const('PROP_LOCALE',0x00000002)
		win_const_mgr.add_const('CB_GETCURSEL',0x00000147)
		win_const_mgr.add_const('FLUSHOUTPUT',0x00000006)
		win_const_mgr.add_const('OID_FDDI_SHORT_MULTICAST_LIST',0x03010107)
		win_const_mgr.add_const('RPC_BUFFER_ASYNC',0x00008000)
		win_const_mgr.add_const('SQL_BEST_ROWID',0x00000001)
		win_const_mgr.add_const('D3D10_FLOAT_TO_SRGB_OFFSET',0x00000000)
		win_const_mgr.add_const('ERROR_EVT_UNRESOLVED_PARAMETER_INSERT',0x00003AB6)
		win_const_mgr.add_const('LINEOPENOPTION_PROXY',0x40000000)
		win_const_mgr.add_const('NDIS_PNP_WAKE_UP_PATTERN_MATCH',0x00000002)
		win_const_mgr.add_const('AW_VER_POSITIVE',0x00000004)
		win_const_mgr.add_const('WVR_ALIGNLEFT',0x00000020)
		win_const_mgr.add_const('DDFXCAPS_BLTSHRINKX',0x00000400)
		win_const_mgr.add_const('NETE_SERVERNOTFOUND',0x00000006)
		win_const_mgr.add_const('DBPROPVAL_NP_SYNCHAFTER',0x00000004)
		win_const_mgr.add_const('LANG_INVARIANT',0x00000007)
		win_const_mgr.add_const('DS_3DLOOK',0x00000004)
		win_const_mgr.add_const('CAUSE_BEARER_CAPABILITY_UNAUTHORIZED',0x00000039)
		win_const_mgr.add_const('PORT_MITMLDEV1',0x00000053)
		win_const_mgr.add_const('PORT_MITMLDEV2',0x00000055)
		win_const_mgr.add_const('DDPCAPS_4BIT',0x00000001)
		win_const_mgr.add_const('ERROR_DS_NONEXISTENT_MAY_HAVE',0x000020C3)
		win_const_mgr.add_const('WM_SIZECLIPBOARD',0x0000030B)
		win_const_mgr.add_const('BLLI_L3_PACKET_32',0x00000005)
		win_const_mgr.add_const('LINEFEATURE_SETDEVSTATUS',0x00000040)
		win_const_mgr.add_const('SQL_CDO_CONSTRAINT_NAME_DEFINITION',0x00000010)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_DAYS',0x00000204)
		win_const_mgr.add_const('VK_OEM_AX',0x000000E1)
		win_const_mgr.add_const('STI_ONLINESTATE_TRANSFERRING',0x00000200)
		win_const_mgr.add_const('DR_MASK',0x00000000)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_IA64',0x00000200)
		win_const_mgr.add_const('CERT_CA_DISABLE_CRL_PROP_ID',0x00000052)
		win_const_mgr.add_const('WMS_NUM_STREAMHEADERLIST_ATTRIBUTES',0x00000012)
		win_const_mgr.add_const('RBIM_IMAGELIST',0x00000001)
		win_const_mgr.add_const('BSF_FORCEIFHUNG',0x00000020)
		win_const_mgr.add_const('GIL_FORSHORTCUT',0x00000080)
		win_const_mgr.add_const('KLF_REORDER',0x00000008)
		win_const_mgr.add_const('IDM_SCROLL_LEFT',0x00000957)
		win_const_mgr.add_const('ERROR_PROCESS_NOT_IN_JOB',0x000002F7)
		win_const_mgr.add_const('SQL_DRIVER_HDBC',0x00000003)
		win_const_mgr.add_const('TXFS_RM_FLAG_LOG_AUTO_SHRINK_PERCENTAGE',0x00000040)
		win_const_mgr.add_const('SO_MAX_MSG_SIZE',0x00002003)
		win_const_mgr.add_const('MAX_ADAPTER_DESCRIPTION_LENGTH',0x00000080)
		win_const_mgr.add_const('ERROR_CACHE_PAGE_LOCKED',0x000002F0)
		win_const_mgr.add_const('CRYPT_PROCESS_ISOLATE',0x00010000)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SAMPLESPERSEC',0x00004005)
		win_const_mgr.add_const('CERT_COMPARE_KEY_IDENTIFIER',0x0000000F)
		win_const_mgr.add_const('WMDM_DEVICECAP_CANSTREAMPLAY',0x00000002)
		win_const_mgr.add_const('RTCSI_MULTIPARTY_IM',0x00000010)
		win_const_mgr.add_const('WS_EX_CLIENTEDGE',0x00000200)
		win_const_mgr.add_const('FPS_RINGING',0x20020000)
		win_const_mgr.add_const('DEX_IDS_DIBSEQ_NOTALLSAME',0x00000581)
		win_const_mgr.add_const('WMDM_DEVICECAP_CANRESUME',0x00000020)
		win_const_mgr.add_const('COD_SERVICE_NETWORKING',0x00000010)
		win_const_mgr.add_const('SCRIPTPROP_MINORVERSION',0x00000002)
		win_const_mgr.add_const('RPC_S_UNSUPPORTED_TYPE',0x000006C4)
		win_const_mgr.add_const('DMPAPER_PENV_3_ROTATED',0x0000006F)
		win_const_mgr.add_const('CTFMODEBIAS_NUMERIC',0x00000006)
		win_const_mgr.add_const('C2_EUROPESEPARATOR',0x00000004)
		win_const_mgr.add_const('ERROR_UNKNOWN_PROPERTY',0x00000648)
		win_const_mgr.add_const('RPC_C_AUTHN_DCE_PRIVATE',0x00000001)
		win_const_mgr.add_const('ERROR_RM_NOT_ACTIVE',0x00001A91)
		win_const_mgr.add_const('CRYPT_VERIFY_CERT_SIGN_SUBJECT_CERT',0x00000002)
		win_const_mgr.add_const('ERROR_APPHELP_BLOCK',0x000004EB)
		win_const_mgr.add_const('IDC_CI_FROMFILEEDIT',0x0000007E)
		win_const_mgr.add_const('OLEMISC_ACTSLIKEBUTTON',0x00001000)
		win_const_mgr.add_const('PRINTACTION_OPEN',0x00000000)
		win_const_mgr.add_const('IMN_SETCONVERSIONMODE',0x00000006)
		win_const_mgr.add_const('ODBC_VS_FLAG_UNICODE_COR',0x00000002)
		win_const_mgr.add_const('OBM_OLD_LFARROW',0x00007FFA)
		win_const_mgr.add_const('DXVA_RESTRICTED_MODE_MPEG1_A',0x00000009)
		win_const_mgr.add_const('CB_GETLBTEXTLEN',0x00000149)
		win_const_mgr.add_const('VK_PAUSE',0x00000013)
		win_const_mgr.add_const('LDAP_OPT_SSPI_FLAGS',0x00000092)
		win_const_mgr.add_const('BS_TOP',0x00000400)
		win_const_mgr.add_const('OBM_OLD_RGARROW',0x00007FFB)
		win_const_mgr.add_const('VK_OEM_CUSEL',0x000000EF)
		win_const_mgr.add_const('OID_802_3_MAC_OPTIONS',0x01010105)
		win_const_mgr.add_const('SETCOLORTABLE',0x00000004)
		win_const_mgr.add_const('PROGDLG_NOTIME',0x00000004)
		win_const_mgr.add_const('SHHLNF_NOAUTOSELECT',0x04000000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_IO_READ_INIT',0x0000000C)
		win_const_mgr.add_const('CRYPT_STRING_HEXASCII',0x00000005)
		win_const_mgr.add_const('INTERNET_OPTION_SUPPRESS_BEHAVIOR',0x00000051)
		win_const_mgr.add_const('PROP_MACHINE',0x00000020)
		win_const_mgr.add_const('XEKL_KEYSIZE_MIN',0x00000001)
		win_const_mgr.add_const('CDERR_LOCKRESFAILURE',0x00000008)
		win_const_mgr.add_const('RESTORE_TYPE_CATCHUP',0x00000004)
		win_const_mgr.add_const('POWER_ACTION_LIGHTEST_FIRST',0x10000000)
		win_const_mgr.add_const('ELF_VERSION',0x00000000)
		win_const_mgr.add_const('MCI_SYSINFO_OPEN',0x00000200)
		win_const_mgr.add_const('SF_MAX_AUTH_TYPE',0x00000020)
		win_const_mgr.add_const('LBN_KILLFOCUS',0x00000005)
		win_const_mgr.add_const('MANUAL_CHECKPOINT',0x00000010)
		win_const_mgr.add_const('MODALS_LOCKOUT_THRESHOLD_PARMNUM',0x0000000C)
		win_const_mgr.add_const('WIA_IPA_BUFFER_SIZE',0x00001016)
		win_const_mgr.add_const('LB_SETCURSEL',0x00000186)
		win_const_mgr.add_const('STI_ONLINESTATE_USER_INTERVENTION',0x00001000)
		win_const_mgr.add_const('IF_TYPE_HIPPIINTERFACE',0x00000039)
		win_const_mgr.add_const('LINECALLFEATURE_PREPAREADDCONF',0x00010000)
		win_const_mgr.add_const('EN_IMECHANGE',0x00000707)
		win_const_mgr.add_const('DMPAPER_NOTE',0x00000012)
		win_const_mgr.add_const('DISPID_IHTMLOPSPROFILE_DOREQUEST',0x00000003)
		win_const_mgr.add_const('TVHT_ABOVE',0x00000100)
		win_const_mgr.add_const('LANG_PASHTO',0x00000063)
		win_const_mgr.add_const('MQMSG_AUTH_LEVEL_SIG30',0x00000008)
		win_const_mgr.add_const('ACTRL_DS_DELETE_CHILD',0x00000002)
		win_const_mgr.add_const('CFS_DEFAULT',0x00000000)
		win_const_mgr.add_const('SQL_PARAM_TYPE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('RPC_S_SEC_PKG_ERROR',0x00000721)
		win_const_mgr.add_const('IPPORT_ECHO',0x00000007)
		win_const_mgr.add_const('APPSTATUS_STOPPED',0x00000000)
		win_const_mgr.add_const('SERVICE_QUERY_STATUS',0x00000004)
		win_const_mgr.add_const('WMDM_DEVICECAP_CANPAUSE',0x00000010)
		win_const_mgr.add_const('PSP_USEFUSIONCONTEXT',0x00004000)
		win_const_mgr.add_const('SUBSCRIPTION_CAP_IS_CONTENTPARTNER',0x00000040)
		win_const_mgr.add_const('AMDDS_YUVFLP',0x00000080)
		win_const_mgr.add_const('FW_HEAVY',0x00000384)
		win_const_mgr.add_const('ODBC_ERROR_WRITING_SYSINFO_FAILED',0x00000013)
		win_const_mgr.add_const('SUBLANG_ENGLISH_BELIZE',0x00000000)
		win_const_mgr.add_const('LVCFMT_LINE_BREAK',0x00100000)
		win_const_mgr.add_const('VER_GREATER',0x00000002)
		win_const_mgr.add_const('ERROR_TIMER_RESOLUTION_NOT_SET',0x0000025F)
		win_const_mgr.add_const('SFVM_GETSORTDEFAULTS',0x00000035)
		win_const_mgr.add_const('WKSTA_PIPEMAXIMUM_PARMNUM',0x0000002D)
		win_const_mgr.add_const('OID_802_11_MEDIA_STREAM_MODE',0x0D010121)
		win_const_mgr.add_const('ULW_COLORKEY',0x00000001)
		win_const_mgr.add_const('ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED',0x0000216D)
		win_const_mgr.add_const('SQL_API_SQLALLOCHANDLE',0x000003E9)
		win_const_mgr.add_const('IMAGE_REL_M32R_PCREL16',0x00000006)
		win_const_mgr.add_const('SNMP_ERROR_COMMITFAILED',0x0000000E)
		win_const_mgr.add_const('UF_PASSWD_CANT_CHANGE',0x00000040)
		win_const_mgr.add_const('RTM_DEST_FLAG_DONT_FORWARD',0x00000004)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_UNAUTH_USER_FLOW_DURATION',0x00000010)
		win_const_mgr.add_const('DBPROPVAL_DF_NOT_DEFERRABLE',0x00000003)
		win_const_mgr.add_const('COMP_ELEM_POS_ZINDEX',0x00000100)
		win_const_mgr.add_const('DEBUG_PROCESS_DETACH_ON_EXIT',0x00000001)
		win_const_mgr.add_const('MSV1_0_CRED_VERSION',0x00000000)
		win_const_mgr.add_const('IME_RS_NOIME',0x00000002)
		win_const_mgr.add_const('DSGIF_ISOPEN',0x00000001)
		win_const_mgr.add_const('PROXY_TYPE_AUTO_DETECT',0x00000008)
		win_const_mgr.add_const('DTRESULTPART',0x00000003)
		win_const_mgr.add_const('COD_COMPUTER_MINOR_LAPTOP',0x00000003)
		win_const_mgr.add_const('CM_INSTALL_STATE_FINISH_INSTALL',0x00000003)
		win_const_mgr.add_const('WM_MOVING',0x00000216)
		win_const_mgr.add_const('TYPE_ENUMFONTFAMILIES',0x00000002)
		win_const_mgr.add_const('CSS_ALLOWMULTISELECT',0x00000004)
		win_const_mgr.add_const('KERB_ETYPE_DES_CBC_CRC',0x00000001)
		win_const_mgr.add_const('IF_ADMIN_STATUS_TESTING',0x00000003)
		win_const_mgr.add_const('FC_SIMPLE_POINTER',0x00000008)
		win_const_mgr.add_const('SQL_DELETE_BY_BOOKMARK',0x00000006)
		win_const_mgr.add_const('D3DPCMPCAPS_ALWAYS',0x00000080)
		win_const_mgr.add_const('SECBUFFER_UNMAPPED',0x40000000)
		win_const_mgr.add_const('PIPE_READMODE_BYTE',0x00000000)
		win_const_mgr.add_const('FOF_NOCONFIRMMKDIR',0x00000200)
		win_const_mgr.add_const('OID_QOS_RESERVED13',0xFB01010C)
		win_const_mgr.add_const('TXFS_TRANSACTION_STATE_NONE',0x00000000)
		win_const_mgr.add_const('FILE_DEVICE_FULLSCREEN_VIDEO',0x00000034)
		win_const_mgr.add_const('WINHTTP_FLAG_ESCAPE_DISABLE_QUERY',0x00000080)
		win_const_mgr.add_const('DEVICEPOWER_HARDWAREID',0x80000000)
		win_const_mgr.add_const('VTBIT_R4',0x00000001)
		win_const_mgr.add_const('LANG_TSWANA',0x00000032)
		win_const_mgr.add_const('EIMES_CANCELCOMPSTRINFOCUS',0x00000002)
		win_const_mgr.add_const('OQWF_REMOVEFORMS',0x00000020)
		win_const_mgr.add_const('DB_INVALID_HCHAPTER',0x00000000)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_UNTIL_TIME',0x00000012)
		win_const_mgr.add_const('VTBIT_R8',0x00000001)
		win_const_mgr.add_const('DBPROP_MACHINE',0x00000002)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_DEFAULT_FILTER_GROUPS',0x00000080)
		win_const_mgr.add_const('GL_CONFIGURATION_CHANGE',0x00000040)
		win_const_mgr.add_const('JOB_STATUS_OFFLINE',0x00000020)
		win_const_mgr.add_const('PAGE_NOACCESS',0x00000001)
		win_const_mgr.add_const('INTERNET_CACHE_FLAG_ENTRY_OR_MAPPING',0x00000400)
		win_const_mgr.add_const('MD_CPU_ENABLE_PAGE_FAULTS',0x00000010)
		win_const_mgr.add_const('MF_INVALID_GRL_SIGNATURE',0x00000020)
		win_const_mgr.add_const('WAVE_FORMAT_96M08',0x00010000)
		win_const_mgr.add_const('DS_REPSYNC_ASYNCHRONOUS_REPLICA',0x00100000)
		win_const_mgr.add_const('ERROR_LOG_STATE_INVALID',0x000019F3)
		win_const_mgr.add_const('SSWF_DISPLAY',0x00000003)
		win_const_mgr.add_const('LINE_AGENTSPECIFIC',0x00000015)
		win_const_mgr.add_const('MSG_DONTROUTE',0x00000004)
		win_const_mgr.add_const('CRYPT_MODE_OFB',0x00000003)
		win_const_mgr.add_const('ERROR_LOG_RECORDS_RESERVED_INVALID',0x000019E1)
		win_const_mgr.add_const('URLACTION_DOWNLOAD_CURR_MAX',0x00001004)
		win_const_mgr.add_const('HH_ENUM_CATEGORY_IT',0x00000016)
		win_const_mgr.add_const('GESTURE_DOUBLE_ARROW_DOWN',0x00000000)
		win_const_mgr.add_const('LANG_TAJIK',0x00000028)
		win_const_mgr.add_const('DTT_FONTPROP',0x00000001)
		win_const_mgr.add_const('USN_DELETE_FLAG_NOTIFY',0x00000002)
		win_const_mgr.add_const('ICON_SMALL',0x00000000)
		win_const_mgr.add_const('VK_DBE_ALPHANUMERIC',0x00000000)
		win_const_mgr.add_const('REG_FORCE_RESTORE',0x00000008)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_SHARE_NAME',0x00000002)
		win_const_mgr.add_const('CACHE_HEADER_DATA_CACHE_RESERVED_28',0x0000001C)
		win_const_mgr.add_const('MCI_OPEN_ELEMENT',0x00000200)
		win_const_mgr.add_const('TMT_INT',0x000000CA)
		win_const_mgr.add_const('OID_FDDI_IF_OUT_DISCARDS',0x0303028A)
		win_const_mgr.add_const('RIP_BASE_ENTRY',0x00000000)
		win_const_mgr.add_const('DTRESULTFIX',0x00000001)
		win_const_mgr.add_const('RPC_X_WRONG_PIPE_ORDER',0x00000727)
		win_const_mgr.add_const('SCESTATUS_ACCESS_DENIED',0x00000009)
		win_const_mgr.add_const('SMILANIMATIONFRAGMENT_OFFSET',0x00000F00)
		win_const_mgr.add_const('DIRID_COMMON_STARTMENU',0x00004016)
		win_const_mgr.add_const('CACHE_HEADER_DATA_GID_LOW',0x00000006)
		win_const_mgr.add_const('RTCAU_NTLM',0x00000004)
		win_const_mgr.add_const('SYMSTOREOPT_POINTER',0x00000008)
		win_const_mgr.add_const('SN_INFLAG_USER_ACCESS',0x00000008)
		win_const_mgr.add_const('PP_KEYSET_TYPE',0x0000001B)
		win_const_mgr.add_const('ERROR_DS_REFERRAL',0x0000202B)
		win_const_mgr.add_const('CSIDL_COMMON_PICTURES',0x00000036)
		win_const_mgr.add_const('IME_RS_NOTFOUND',0x00000007)
		win_const_mgr.add_const('LNH_8_CPU',0x0000002F)
		win_const_mgr.add_const('DTR_STBASE_INDEX',0x00000004)
		win_const_mgr.add_const('WM_QUERYDRAGICON',0x00000037)
		win_const_mgr.add_const('SQL_CODE_DAY_TO_HOUR',0x00000008)
		win_const_mgr.add_const('FWPM_CONTEXT_TCP_CHIMNEY_OFFLOAD_DISABLE',0x00000002)
		win_const_mgr.add_const('SP_COPY_DELETESOURCE',0x00000001)
		win_const_mgr.add_const('SNMP_TRAP_LINKDOWN',0x00000002)
		win_const_mgr.add_const('CMF_EXTENDEDVERBS',0x00000100)
		win_const_mgr.add_const('HTTP_STATUS_AMBIGUOUS',0x0000012C)
		win_const_mgr.add_const('LOGON_WINLOGON',0x00008000)
		win_const_mgr.add_const('EMR_SETMAPMODE',0x00000011)
		win_const_mgr.add_const('ALLOC_LOG_CONF',0x00000002)
		win_const_mgr.add_const('HTTP_LOG_FIELD_CLIENT_IP',0x00000004)
		win_const_mgr.add_const('KAGPROP_INCLUDENONEXACT',0x00000009)
		win_const_mgr.add_const('LOAD_LIBRARY_AS_IMAGE_RESOURCE',0x00000020)
		win_const_mgr.add_const('OID_GEN_NETWORK_LAYER_ADDRESSES',0x00010118)
		win_const_mgr.add_const('EAP_PEER_FLAG_HEALTH_STATE_CHANGE',0x00008000)
		win_const_mgr.add_const('CRYPT_MESSAGE_KEYID_SIGNER_FLAG',0x00000004)
		win_const_mgr.add_const('SELECT_CAP_CONVERSION',0x00000001)
		win_const_mgr.add_const('SYSTEM_EVENT_TYPE',0x00000001)
		win_const_mgr.add_const('KERB_ETYPE_PKCS7_PUB',0x0000000D)
		win_const_mgr.add_const('PAN_LETT_OBLIQUE_BOXED',0x0000000B)
		win_const_mgr.add_const('OID_WAN_CO_SET_COMP_INFO',0x04010281)
		win_const_mgr.add_const('WINHTTP_QUERY_TRANSFER_ENCODING',0x0000003F)
		win_const_mgr.add_const('SUBLANG_NEPALI_INDIA',0x00000002)
		win_const_mgr.add_const('WINHTTP_OPTION_PASSPORT_RETURN_URL',0x00000057)
		win_const_mgr.add_const('LINEDEVSTATE_MSGWAITOFF',0x00000020)
		win_const_mgr.add_const('SECURITY_BATCH_RID',0x00000003)
		win_const_mgr.add_const('SP_COPY_OEMINF_CATALOG_ONLY',0x00040000)
		win_const_mgr.add_const('SIGNERSCORE_LOGO_STANDARD',0x0D000002)
		win_const_mgr.add_const('IDM_DOCPROPERTIES',0x000008D4)
		win_const_mgr.add_const('RESTORE_CTM',0x00001004)
		win_const_mgr.add_const('LINEROAMMODE_UNKNOWN',0x00000001)
		win_const_mgr.add_const('MK_SHIFT',0x00000004)
		win_const_mgr.add_const('JOB_STATUS_RESTART',0x00000800)
		win_const_mgr.add_const('DISPLAYDIB_INVALIDFORMAT',0x00000003)
		win_const_mgr.add_const('LBS_NOREDRAW',0x00000004)
		win_const_mgr.add_const('CLUS_LEGACY_QUORUM',0x00000004)
		win_const_mgr.add_const('D3DDEVCAPS2_ADAPTIVETESSRTPATCH',0x00000004)
		win_const_mgr.add_const('BOLD_FONTTYPE',0x00000100)
		win_const_mgr.add_const('DBDTF_RETURNMIXEDDOMAINS',0x00000002)
		win_const_mgr.add_const('WEBPOST_ERROR_SITE_CORRUPT',0xC0042103)
		win_const_mgr.add_const('SCARD_PROTOCOL_RAW',0x00010000)
		win_const_mgr.add_const('PIPE_UNLIMITED_INSTANCES',0x000000FF)
		win_const_mgr.add_const('X3_I_INST_WORD_POS_X',0x0000001B)
		win_const_mgr.add_const('CROSS_CERT_DIST_POINT_ERR_INDEX_MASK',0x000000FF)
		win_const_mgr.add_const('LINEDISCONNECTMODE_NORMAL',0x00000001)
		win_const_mgr.add_const('SPEAKER_ALL',0x80000000)
		win_const_mgr.add_const('SECURITY_NETWORK_SERVICE_RID',0x00000014)
		win_const_mgr.add_const('PHONEERR_INCOMPATIBLEEXTVERSION',0x90000004)
		win_const_mgr.add_const('DDCKEY_DESTBLT',0x00000002)
		win_const_mgr.add_const('SQL_CA_CONSTRAINT_INITIALLY_IMMEDIATE',0x00000020)
		win_const_mgr.add_const('KAGPROP_FORCENOPARAMETERREBIND',0x0000000B)
		win_const_mgr.add_const('EXTENSION_ORIGIN_RENEWALCERT',0x00050000)
		win_const_mgr.add_const('ERROR_HANDLE_NO_LONGER_VALID',0x00001A9F)
		win_const_mgr.add_const('ERROR_PATCH_BIGGER_THAN_COMPRESSED',0xC00E3105)
		win_const_mgr.add_const('PKCS_RSA_SSA_PSS_TRAILER_FIELD_BC',0x00000001)
		win_const_mgr.add_const('SQL_SSF_TRIM_LEADING',0x00000040)
		win_const_mgr.add_const('NTM_TT_OPENTYPE',0x00040000)
		win_const_mgr.add_const('OFFLINESTATUS_OFFLINE_ERROR',0x00000004)
		win_const_mgr.add_const('FACILITY_USERMODE_HYPERVISOR',0x00000035)
		win_const_mgr.add_const('FMEVENT_INITMENU',0x00000066)
		win_const_mgr.add_const('IPV6_HOPOPTS',0x00000001)
		win_const_mgr.add_const('GLEX_NOT',0x00000008)
		win_const_mgr.add_const('DNS_ERROR_AXFR',0x00002618)
		win_const_mgr.add_const('SPI_GETMINIMIZEDMETRICS',0x0000002B)
		win_const_mgr.add_const('FILE_DEVICE_STREAMS',0x00000001)
		win_const_mgr.add_const('CMF_NORMAL',0x00000000)
		win_const_mgr.add_const('SUBLANG_ARABIC_KUWAIT',0x00000000)
		win_const_mgr.add_const('SV_MAXFREECONNECTIONS_PARMNUM',0x0000021E)
		win_const_mgr.add_const('PHONEFEATURE_GETGAINHEADSET',0x00000020)
		win_const_mgr.add_const('WNODE_FLAG_USE_GUID_PTR',0x00080000)
		win_const_mgr.add_const('ERROR_IPSEC_QM_POLICY_NOT_FOUND',0x000032C9)
		win_const_mgr.add_const('PATCH_OPTION_NO_RESTIMEFIX',0x00400000)
		win_const_mgr.add_const('HDI_STATE',0x00000200)
		win_const_mgr.add_const('ERROR_FLOPPY_WRONG_CYLINDER',0x00000463)
		win_const_mgr.add_const('ERRCLASS_SYSFAIL',0x00000006)
		win_const_mgr.add_const('SAM_HOURS_PER_WEEK',0x00000018)
		win_const_mgr.add_const('TT_OPENTYPE_FONTTYPE',0x00020000)
		win_const_mgr.add_const('SDP_ATTRIB_PAN_HOME_PAGE_URL',0x00000308)
		win_const_mgr.add_const('ERROR_DS_CANT_FIND_DSA_OBJ',0x000020E3)
		win_const_mgr.add_const('PFM_ALIGNMENT',0x00000008)
		win_const_mgr.add_const('DEBUG_SERVERS_ALL',0x00000003)
		win_const_mgr.add_const('IDC_VP_PERCENT',0x000003E8)
		win_const_mgr.add_const('TBS_TOOLTIPS',0x00000100)
		win_const_mgr.add_const('SDP_ATTRIB_SERVICE_ID',0x00000003)
		win_const_mgr.add_const('WB_MOVEWORDNEXT',0x00000005)
		win_const_mgr.add_const('HTTP_QUERY_PROXY_AUTHORIZATION',0x0000003D)
		win_const_mgr.add_const('LINEREQUESTMODE_MEDIACALL',0x00000002)
		win_const_mgr.add_const('GCL_REVERSE_LENGTH',0x00000003)
		win_const_mgr.add_const('DOMAIN_USER_RID_GUEST',0x000001F5)
		win_const_mgr.add_const('MCI_OVLY_RECT',0x00010000)
		win_const_mgr.add_const('CMC_FAIL_BAD_MESSAGE_CHECK',0x00000001)
		win_const_mgr.add_const('HTTP_LOG_FIELD_SITE_ID',0x01000000)
		win_const_mgr.add_const('ENM_IMECHANGE',0x00800000)
		win_const_mgr.add_const('ERROR_FORMS_AUTH_REQUIRED',0x000000E0)
		win_const_mgr.add_const('SCHANNEL_SHUTDOWN',0x00000001)
		win_const_mgr.add_const('EMR_SETVIEWPORTORGEX',0x0000000C)
		win_const_mgr.add_const('HTTP_QUERY_STATUS_TEXT',0x00000014)
		win_const_mgr.add_const('PP_ROOT_CERTSTORE',0x0000002E)
		win_const_mgr.add_const('OID_802_5_LINE_ERRORS',0x02020101)
		win_const_mgr.add_const('DRMQUERYHANDLE_INVALID',0x00000000)
		win_const_mgr.add_const('DIRID_INF',0x00000011)
		win_const_mgr.add_const('LDAP_FILTER_EXTENSIBLE',0x00000000)
		win_const_mgr.add_const('IDM_TRIED_BRING_ABOVE_TEXT',0x0000000B)
		win_const_mgr.add_const('SSPROP_STREAM_FLAGS',0x00000014)
		win_const_mgr.add_const('FEI_CALL_BLACKLISTED',0x00000000)
		win_const_mgr.add_const('ERROR_I24_NO_MONITOR_SUPPORT',0x00000012)
		win_const_mgr.add_const('CSIDL_COMMON_MUSIC',0x00000035)
		win_const_mgr.add_const('DLGC_WANTARROWS',0x00000001)
		win_const_mgr.add_const('PROV_STT_ISS',0x0000000B)
		win_const_mgr.add_const('SIF_TRACKPOS',0x00000010)
		win_const_mgr.add_const('EXTENSION_DISABLE_FLAG',0x00000002)
		win_const_mgr.add_const('DNS_WARNING_PTR_CREATE_FAILED',0x000025F3)
		win_const_mgr.add_const('IOF_DISABLELINK',0x00000100)
		win_const_mgr.add_const('ERROR_NOT_LOCKED',0x0000009E)
		win_const_mgr.add_const('MSIDXSPROP_ROWSETQUERYSTATUS',0x00000002)
		win_const_mgr.add_const('DBPROPVAL_OS_CLIENTCURSOR',0x00000004)
		win_const_mgr.add_const('SQL_DESC_NAME',0x000003F3)
		win_const_mgr.add_const('RPC_C_PROFILE_MATCH_BY_IF',0x00000002)
		win_const_mgr.add_const('STAMP_AXESLIST',0x08000000)
		win_const_mgr.add_const('OPENPROPS_NONE',0x00000000)
		win_const_mgr.add_const('MAX_PROTOCOL_CHAIN',0x00000007)
		win_const_mgr.add_const('CTRY_BELIZE',0x000001F5)
		win_const_mgr.add_const('WC_COMPOSITECHECK',0x00000200)
		win_const_mgr.add_const('DT_MODIFYSTRING',0x00010000)
		win_const_mgr.add_const('TABLET_DISABLE_PENBARRELFEEDBACK',0x00000010)
		win_const_mgr.add_const('LBS_OWNERDRAWFIXED',0x00000010)
		win_const_mgr.add_const('MCI_VCR_LIST_AUDIO_SOURCE',0x00020000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_STARTSECTOROFPREVIOUSSESSION',0x0000010B)
		win_const_mgr.add_const('DSBI_IGNORETREATASLEAF',0x00400000)
		win_const_mgr.add_const('ISR_CODE_LEN',0x00000010)
		win_const_mgr.add_const('OID_FDDI_MAC_HARDWARE_PRESENT',0x0303024F)
		win_const_mgr.add_const('DRM_OWNER_LICENSE_NOPERSIST',0x00000020)
		win_const_mgr.add_const('CMC_FAIL_BAD_REQUEST',0x00000002)
		win_const_mgr.add_const('MF_STRING',0x00000000)
		win_const_mgr.add_const('TF_LBI_STYLE_HIDDENSTATUSCONTROL',0x00000001)
		win_const_mgr.add_const('ICU_ESCAPE_AUTHORITY',0x00002000)
		win_const_mgr.add_const('SNMP_ERROR_NOACCESS',0x00000006)
		win_const_mgr.add_const('DSA_NEWOBJ_CTX_COMMIT',0x00000002)
		win_const_mgr.add_const('PRINTDLGORD',0x00000602)
		win_const_mgr.add_const('KEY_SET_VALUE',0x00000002)
		win_const_mgr.add_const('LLKHF_INJECTED',0x00000010)
		win_const_mgr.add_const('CC_ANYCOLOR',0x00000100)
		win_const_mgr.add_const('SQL_CONVERT_DOUBLE',0x0000003B)
		win_const_mgr.add_const('DSOP_FILTER_USERS',0x00000002)
		win_const_mgr.add_const('AE_ADD',0x00000002)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_GROUP',0x00001000)
		win_const_mgr.add_const('CTRY_ROMANIA',0x00000028)
		win_const_mgr.add_const('DDCOLOR_CONTRAST',0x00000002)
		win_const_mgr.add_const('D3DFVF_PSIZE',0x00000020)
		win_const_mgr.add_const('SFGAO_CANRENAME',0x00000010)
		win_const_mgr.add_const('IME_ESC_GETHELPFILENAME',0x00000100)
		win_const_mgr.add_const('WMDM_STORAGECAP_NOT_INITIALIZABLE',0x00000040)
		win_const_mgr.add_const('HSE_EXEC_URL_IGNORE_VALIDATION_AND_RANGE',0x00000010)
		win_const_mgr.add_const('ENDSESSION_LOGOFF',0x80000000)
		win_const_mgr.add_const('POLICY_CREATE_PRIVILEGE',0x00000040)
		win_const_mgr.add_const('SHDID_COMPUTER_FIXED',0x00000008)
		win_const_mgr.add_const('ASP_MD_SERVER_BASE',0x00001B58)
		win_const_mgr.add_const('D3DCREATE_SOFTWARE_VERTEXPROCESSING',0x00000020)
		win_const_mgr.add_const('CMS_PRINTEROVERFLOW',0x40000000)
		win_const_mgr.add_const('DS_REPSYNC_FULL',0x00000020)
		win_const_mgr.add_const('OID_TAPI_NEGOTIATE_EXT_VERSION',0x07030116)
		win_const_mgr.add_const('SCH_CRED_CERT_CONTEXT',0x00000003)
		win_const_mgr.add_const('TAPE_DRIVE_LOAD_UNLOAD',0x80000001)
		win_const_mgr.add_const('SECPKG_FLAG_EXTENDED_ERROR',0x00000080)
		win_const_mgr.add_const('SM_SWAPBUTTON',0x00000017)
		win_const_mgr.add_const('SCARD_E_NO_SMARTCARD',0x8010000C)
		win_const_mgr.add_const('EMR_EXTSELECTCLIPRGN',0x0000004B)
		win_const_mgr.add_const('SFVM_SETCLIPBOARD',0x00000010)
		win_const_mgr.add_const('MSV1_0_DONT_TRY_GUEST_ACCOUNT',0x00000010)
		win_const_mgr.add_const('COMP_TYPE_WEBSITE',0x00000002)
		win_const_mgr.add_const('TMT_MINSIZE',0x00000D4B)
		win_const_mgr.add_const('COD_SERVICE_OBJECT_XFER',0x00000080)
		win_const_mgr.add_const('TVE_EXPANDPARTIAL',0x00004000)
		win_const_mgr.add_const('ERROR_LOG_CANT_DELETE',0x000019D8)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_MINIPORT_DRIVER_CHARACTERISTICS',0x0000008A)
		win_const_mgr.add_const('SPI_SETWORKAREA',0x0000002F)
		win_const_mgr.add_const('DISPLAYDIB_BADSIZE',0x00000007)
		win_const_mgr.add_const('LOGON32_LOGON_BATCH',0x00000004)
		win_const_mgr.add_const('DISPID_ISSEARCHMIGRATED',0x00000019)
		win_const_mgr.add_const('DRM_ACTIVATE_GROUPIDENTITY',0x00000002)
		win_const_mgr.add_const('FILEOP_COPY',0x00000000)
		win_const_mgr.add_const('GT_SENTINEL',0x00000009)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_OFFLOAD',0x000000A7)
		win_const_mgr.add_const('CM_REENUMERATE_SYNCHRONOUS',0x00000001)
		win_const_mgr.add_const('WMS_STREAM_DISTRIBUTION_BROADCAST_GENERATION_ID',0x00000011)
		win_const_mgr.add_const('IDD_ACMFORMATCHOOSE_BTN_HELP',0x00000009)
		win_const_mgr.add_const('SQL_PAS_NO_SELECT',0x00000003)
		win_const_mgr.add_const('MSIDXSPROP_MAX_RANK',0x00000006)
		win_const_mgr.add_const('MQMSG_AUTHENTICATION_REQUESTED_EX',0x00000003)
		win_const_mgr.add_const('EC_STATUS',0x00000041)
		win_const_mgr.add_const('SQL_DATE_LEN',0x0000000A)
		win_const_mgr.add_const('NIIF_LARGE_ICON',0x00000020)
		win_const_mgr.add_const('ETW_SID_TYPE_VALUE',0x00000073)
		win_const_mgr.add_const('CO_E_LAST',0x800401FF)
		win_const_mgr.add_const('KS_DVD_CGMS_RESERVED_MASK',0x00000078)
		win_const_mgr.add_const('PIDVSI_COMPRESSION',0x0000000A)
		win_const_mgr.add_const('ERROR_BAD_NET_NAME',0x00000043)
		win_const_mgr.add_const('RECOCONF_HIGHCONFIDENCE',0x00000001)
		win_const_mgr.add_const('DS_REPSYNCALL_SYNC_ADJACENT_SERVERS_ONLY',0x00000002)
		win_const_mgr.add_const('CHANNEL_OPTION_PRI_MED',0x04000000)
		win_const_mgr.add_const('GDT_VALID',0x00000000)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_FAILURE',0x00000001)
		win_const_mgr.add_const('MD_APPPOOL_STATE_STOPPED',0x00000004)
		win_const_mgr.add_const('ERROR_INVALID_SID',0x00000539)
		win_const_mgr.add_const('SUBLANG_ARABIC_ALGERIA',0x00000005)
		win_const_mgr.add_const('SNMP_ACCESS_NOTIFY',0x00000001)
		win_const_mgr.add_const('DSOP_FILTER_DOMAIN_LOCAL_GROUPS_SE',0x00000200)
		win_const_mgr.add_const('PORT_BUSBOY',0x000003E6)
		win_const_mgr.add_const('ILC_COLOR16',0x00000010)
		win_const_mgr.add_const('DDCKEYCAPS_DESTBLTYUV',0x00000008)
		win_const_mgr.add_const('INTENT_RELATIVE_COLORIMETRIC',0x00000001)
		win_const_mgr.add_const('SCARD_E_SERVER_TOO_BUSY',0x80100031)
		win_const_mgr.add_const('NOTIFY_CLASS_PACKAGE_CHANGE',0x00000001)
		win_const_mgr.add_const('IDS_CAP_DRIVER_ERROR',0x000001A2)
		win_const_mgr.add_const('SQL_FN_STR_POSITION',0x00800000)
		win_const_mgr.add_const('ISR_W',0x00000021)
		win_const_mgr.add_const('ETW_INT16_TYPE_VALUE',0x00000005)
		win_const_mgr.add_const('PRINTER_CHANGE_ADD_PRINTER_DRIVER',0x10000000)
		win_const_mgr.add_const('ISR_R',0x00000022)
		win_const_mgr.add_const('IF_TYPE_ARAP',0x00000058)
		win_const_mgr.add_const('CB_MSGMAX',0x0000015B)
		win_const_mgr.add_const('CHANGER_RTN_MEDIA_TO_ORIGINAL_ADDR',0x80000020)
		win_const_mgr.add_const('USN_REASON_DATA_TRUNCATION',0x00000004)
		win_const_mgr.add_const('LINELOCATIONOPTION_PULSEDIAL',0x00000001)
		win_const_mgr.add_const('SV_NUMBLOCKTHREADS_PARMNUM',0x0000020F)
		win_const_mgr.add_const('DOMAIN_LOCKOUT_ADMINS',0x00000008)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_ZEROS_NETBC',0x00001000)
		win_const_mgr.add_const('NTDSCONN_OPT_OVERRIDE_NOTIFY_DEFAULT',0x00000001)
		win_const_mgr.add_const('MANAGED_APPTYPE_WINDOWSINSTALLER',0x00000001)
		win_const_mgr.add_const('WEBPOST_ERROR_NO_EXT_ERR_INFO',0xC0042117)
		win_const_mgr.add_const('MFSESSIONCAP_PAUSE',0x00000004)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_EFI_RUNTIME_DRIVER',0x0000000C)
		win_const_mgr.add_const('UNDNAME_NO_FUNCTION_RETURNS',0x00000004)
		win_const_mgr.add_const('SNMP_GENERICTRAP_LINKUP',0x00000003)
		win_const_mgr.add_const('GESTURE_CIRCLE',0x00000000)
		win_const_mgr.add_const('WINDOWS_VERSION_WIN32C',0x00000002)
		win_const_mgr.add_const('SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION',0x00000001)
		win_const_mgr.add_const('DDCAPS2_NONLOCALVIDMEM',0x00000200)
		win_const_mgr.add_const('NINF_KEY',0x00000001)
		win_const_mgr.add_const('TXTLOG_WARNING',0x00000002)
		win_const_mgr.add_const('WINDOWS_VERSION_WIN32S',0x00000001)
		win_const_mgr.add_const('ERROR_PATCH_NOT_NECESSARY',0xC00E4105)
		win_const_mgr.add_const('ERROR_DS_MISSING_EXPECTED_ATT',0x000020DB)
		win_const_mgr.add_const('ALINF_BKINSTALL',0x00000020)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_COFF',0x00000001)
		win_const_mgr.add_const('_WIN32_WINNT',0x00000500)
		win_const_mgr.add_const('DFM_MERGECONTEXTMENU_TOP',0x0000000A)
		win_const_mgr.add_const('SES_CUSTOMLOOK',0x00080000)
		win_const_mgr.add_const('EMR_FILLPATH',0x0000003E)
		win_const_mgr.add_const('ITR_HAL_INDEX',0x00000004)
		win_const_mgr.add_const('ID_BROWSE_INSERTFILE',0x00000002)
		win_const_mgr.add_const('KS_VIDEOSTREAM_TELETEXT',0x00000400)
		win_const_mgr.add_const('WMIGUID_QUERY',0x00000001)
		win_const_mgr.add_const('CACHE_CONFIG_FORCE_CLEANUP_FC',0x00000020)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_DIRECTED_FRAMES_XMIT',0x00000040)
		win_const_mgr.add_const('IMAGE_FILE_EXECUTABLE_IMAGE',0x00000002)
		win_const_mgr.add_const('SV_USERS_PARMNUM',0x0000006B)
		win_const_mgr.add_const('CLIENTSITE_E_LAST',0x8004019F)
		win_const_mgr.add_const('SPI_GETFASTTASKSWITCH',0x00000023)
		win_const_mgr.add_const('USE_PASSWORD_PARMNUM',0x00000003)
		win_const_mgr.add_const('PHONEERR_INVALPARAM',0x90000012)
		win_const_mgr.add_const('GT_NOHIDDENTEXT',0x00000008)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_CONNECTED',0x00000008)
		win_const_mgr.add_const('ERROR_ALREADY_EXISTS',0x000000B7)
		win_const_mgr.add_const('DEBUG_REQUEST_GET_EXTENSION_SEARCH_PATH_WIDE',0x0000000D)
		win_const_mgr.add_const('ERROR_CONTINUE',0x000004DE)
		win_const_mgr.add_const('SETUP_ONLINE_FLAG',0x00000010)
		win_const_mgr.add_const('D3DPBLENDCAPS_SRCCOLOR',0x00000004)
		win_const_mgr.add_const('CERT_BIOMETRIC_PREDEFINED_DATA_CHOICE',0x00000001)
		win_const_mgr.add_const('PRINTER_CHANGE_FORM',0x00070000)
		win_const_mgr.add_const('FPSR_FOR_KERNEL',0x9804C0270033F)
		win_const_mgr.add_const('IMAGE_REL_AMD64_REL32_3',0x00000007)
		win_const_mgr.add_const('ATF_TIMEOUTON',0x00000001)
		win_const_mgr.add_const('ERROR_I24_INVALID_PARAMETER',0x00000013)
		win_const_mgr.add_const('FD_READ',0x00000001)
		win_const_mgr.add_const('SNMP_LOG_SILENT',0x00000000)
		win_const_mgr.add_const('LUP_RETURN_TYPE',0x00000020)
		win_const_mgr.add_const('TMT_ANIMATIONDELAY',0x0000097C)
		win_const_mgr.add_const('IMAGE_REL_AMD64_REL32_1',0x00000005)
		win_const_mgr.add_const('MCI_PAUSE',0x00000809)
		win_const_mgr.add_const('MRINFO_PIM_FLAG',0x00000004)
		win_const_mgr.add_const('SM_CXMAXIMIZED',0x0000003D)
		win_const_mgr.add_const('LB_DST_ADDR_USE_SRCADDR_FLAG',0x00000004)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY11',0x00000800)
		win_const_mgr.add_const('SQL_SG_WITH_GRANT_OPTION',0x00000010)
		win_const_mgr.add_const('MIXERCONTROL_CT_CLASS_METER',0x10000000)
		win_const_mgr.add_const('LCPRI_BOOTCONFIG',0x00000001)
		win_const_mgr.add_const('IF_TYPE_L2_VLAN',0x00000087)
		win_const_mgr.add_const('ERROR_EA_LIST_INCONSISTENT',0x000000FF)
		win_const_mgr.add_const('CDO_E_INACTIVE',0x80040206)
		win_const_mgr.add_const('OF_SHARE_DENY_WRITE',0x00000020)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY3',0x00040000)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY2',0x00020000)
		win_const_mgr.add_const('CRYPT_OID_INHIBIT_SIGNATURE_FORMAT_FLAG',0x00000001)
		win_const_mgr.add_const('WIA_DPC_TIMER_MODE',0x0000080E)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY7',0x00400000)
		win_const_mgr.add_const('FR_PROP_FULLRESPONSE',0x00000001)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY5',0x00100000)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY4',0x00080000)
		win_const_mgr.add_const('TF_SFT_DESKBAND',0x00000800)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY9',0x01000000)
		win_const_mgr.add_const('PORT_NETBIOSNS',0x00000089)
		win_const_mgr.add_const('EMR_GRADIENTFILL',0x00000076)
		win_const_mgr.add_const('WMS_CONTAINER_BROADCAST',0x00000001)
		win_const_mgr.add_const('FR_WHOLEWORD',0x00000002)
		win_const_mgr.add_const('DI_NOFILECOPY',0x01000000)
		win_const_mgr.add_const('HHWIN_PROP_TRACKING',0x00000001)
		win_const_mgr.add_const('ENLISTMENT_QUERY_INFORMATION',0x00000001)
		win_const_mgr.add_const('AF_OP_SERVER',0x00000004)
		win_const_mgr.add_const('HTTP_QUERY_ACCEPT',0x00000018)
		win_const_mgr.add_const('RTCEF_MESSAGING',0x00000080)
		win_const_mgr.add_const('MDM_SHIFT_HDLCPPP_AUTH',0x00000003)
		win_const_mgr.add_const('BS_PUSHBOX',0x0000000A)
		win_const_mgr.add_const('SECURITY_CREATOR_GROUP_SERVER_RID',0x00000003)
		win_const_mgr.add_const('KERB_RETRIEVE_TICKET_USE_CACHE_ONLY',0x00000002)
		win_const_mgr.add_const('WLAN_SET_EAPHOST_DATA_ALL_USERS',0x00000001)
		win_const_mgr.add_const('COD_AUDIO_MINOR_PORTABLE_AUDIO',0x00000007)
		win_const_mgr.add_const('PPP_LCP_CHAP_MD5',0x00000005)
		win_const_mgr.add_const('CFM_UNDERLINE',0x00000004)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_TRANSITION_PAGE_ROLL',0x00000015)
		win_const_mgr.add_const('SV_PLATFORM_ID_NT',0x000001F4)
		win_const_mgr.add_const('PROP_MED_CYDLG',0x000000D7)
		win_const_mgr.add_const('CS_NOMOVECARET',0x00004000)
		win_const_mgr.add_const('SESSION_MODIFY_ACCESS',0x00000002)
		win_const_mgr.add_const('COPYFLG_NO_OVERWRITE',0x00000010)
		win_const_mgr.add_const('VK_OEM_6',0x000000DD)
		win_const_mgr.add_const('WTS_EVENT_ALL',0x00000007)
		win_const_mgr.add_const('GETTECHNOLOGY',0x00000014)
		win_const_mgr.add_const('PST_MODEM',0x00000006)
		win_const_mgr.add_const('STGFMT_NATIVE',0x00000001)
		win_const_mgr.add_const('LANG_LOWER_SORBIAN',0x00000002)
		win_const_mgr.add_const('IF_TYPE_ETHERNET_CSMACD',0x00000006)
		win_const_mgr.add_const('SAFER_CRITERIA_AUTHENTICODE',0x00000008)
		win_const_mgr.add_const('IC_E_NO_FORMATS',0x83010003)
		win_const_mgr.add_const('BTH_ERROR_INSTANT_PASSED',0x00000028)
		win_const_mgr.add_const('DOF_DOCUMENT',0x00008002)
		win_const_mgr.add_const('MCI_DGV_STATUS_FORWARD',0x00000402)
		win_const_mgr.add_const('CRYPT_KEYID_DELETE_FLAG',0x00000010)
		win_const_mgr.add_const('TCS_EX_REGISTERDROP',0x00000002)
		win_const_mgr.add_const('INSTALLFLAG_READONLY',0x00000002)
		win_const_mgr.add_const('SCRIPT_DIGITSUBSTITUTE_NATIONAL',0x00000002)
		win_const_mgr.add_const('IDD_DYNAWIZ_INSTALLDETECTED_NODEVS',0x00002718)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_RETRANSMIT',0x0000000E)
		win_const_mgr.add_const('EV_RXFLAG',0x00000002)
		win_const_mgr.add_const('INTERNET_FLAG_BGUPDATE',0x00000008)
		win_const_mgr.add_const('ERROR_UNEXP_NET_ERR',0x0000003B)
		win_const_mgr.add_const('SUBLANG_ARABIC_SAUDI_ARABIA',0x00000001)
		win_const_mgr.add_const('MAPVK_VSC_TO_VK',0x00000001)
		win_const_mgr.add_const('PIDSI_PAGECOUNT',0x00000000)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY15',0x00008000)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_PREPREPARE_COMPLETE',0x00000010)
		win_const_mgr.add_const('MCI_GETDEVCAPS_ITEM',0x00000100)
		win_const_mgr.add_const('NIF_STATE',0x00000008)
		win_const_mgr.add_const('ALERT_SYSTEM_CRITICAL',0x00000005)
		win_const_mgr.add_const('DNS_UPDATE_SECURITY_ON',0x00000020)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_EXTERNAL',0x00000491)
		win_const_mgr.add_const('PRODUCT_DATACENTER_SERVER',0x00000008)
		win_const_mgr.add_const('CGD_BINARY_PROPERTY',0x00000004)
		win_const_mgr.add_const('KLF_RESET',0x40000000)
		win_const_mgr.add_const('MCI_VD_GETDEVCAPS_SLOW_RATE',0x00004004)
		win_const_mgr.add_const('WINHTTP_AUTOPROXY_CONFIG_URL',0x00000002)
		win_const_mgr.add_const('CORDLESS_EXTERNAL_NETWORK_PACKET_SWITCHED',0x00000006)
		win_const_mgr.add_const('E_PRINTTICKET_FORMAT',0x80040003)
		win_const_mgr.add_const('ACM_STREAMCONVERTF_START',0x00000010)
		win_const_mgr.add_const('WIA_DPC_PICTURES_REMAINING',0x00000803)
		win_const_mgr.add_const('CRYPTPROTECT_FIRST_RESERVED_FLAGVAL',0x0FFFFFFF)
		win_const_mgr.add_const('PHONEFEATURE_GETGAINSPEAKER',0x00000010)
		win_const_mgr.add_const('RIDEV_NOHOTKEYS',0x00000200)
		win_const_mgr.add_const('FILTERCHOOSE_MESSAGE',0x00000000)
		win_const_mgr.add_const('AAL5_MODE_STREAMING',0x00000002)
		win_const_mgr.add_const('DDCAPS2_NO2DDURING3DSCENE',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('INHERITED_PARENT',0x10000000)
		win_const_mgr.add_const('ISR_NA',0x00000023)
		win_const_mgr.add_const('FLAGS_ERROR_UI_SHOW_IDN_HOSTNAME',0x00000020)
		win_const_mgr.add_const('ERROR_CANNOT_ACCEPT_TRANSACTED_WORK',0x00001ABF)
		win_const_mgr.add_const('DS_REPL_NBR_NEVER_SYNCED',0x00200000)
		win_const_mgr.add_const('D3DCOLORWRITEENABLE_RED',0x00000001)
		win_const_mgr.add_const('MAX_INF_STRING_LENGTH',0x00001000)
		win_const_mgr.add_const('HDF_IMAGE',0x00000800)
		win_const_mgr.add_const('ERROR_SXS_XML_E_BADSTARTNAMECHAR',0x000036D0)
		win_const_mgr.add_const('SYMFLAG_VIRTUAL',0x00001000)
		win_const_mgr.add_const('MIXERCONTROL_CT_CLASS_CUSTOM',0x00000000)
		win_const_mgr.add_const('PSD_SHOWHELP',0x00000800)
		win_const_mgr.add_const('OID_FDDI_SMT_PORT_INDEXES',0x03030212)
		win_const_mgr.add_const('SECURITY_CREATOR_OWNER_RIGHTS_RID',0x00000004)
		win_const_mgr.add_const('PROPID_QUERY_LASTSEENTIME',0x0000000A)
		win_const_mgr.add_const('DSS_HIDEPREFIX',0x00000200)
		win_const_mgr.add_const('HTTP_STATUS_GATEWAY_TIMEOUT',0x000001F8)
		win_const_mgr.add_const('WIA_IPS_LAMP',0x00000C21)
		win_const_mgr.add_const('AE_ACCLIMITEXCD',0x00000011)
		win_const_mgr.add_const('ERROR_MEMORY_HARDWARE',0x0000030B)
		win_const_mgr.add_const('FILESYSTEM_STATISTICS_TYPE_FAT',0x00000002)
		win_const_mgr.add_const('ERROR_NO_SUCH_DOMAIN',0x0000054B)
		win_const_mgr.add_const('ERROR_STACK_OVERFLOW_READ',0x00000257)
		win_const_mgr.add_const('LVGA_FOOTER_CENTER',0x00000010)
		win_const_mgr.add_const('VK_LCONTROL',0x000000A2)
		win_const_mgr.add_const('ALG_CLASS_HASH',0x00000004)
		win_const_mgr.add_const('DISPID_UPDATEPAGESTATUS',0x000000E3)
		win_const_mgr.add_const('SQL_AM_NONE',0x00000000)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_LOCATION',0x00000033)
		win_const_mgr.add_const('ERROR_SXS_MANIFEST_PARSE_ERROR',0x000036B5)
		win_const_mgr.add_const('D3DTEXOPCAPS_SELECTARG1',0x00000002)
		win_const_mgr.add_const('GOPHER_TYPE_UNIX_UUENCODED',0x00000040)
		win_const_mgr.add_const('WSA_QOS_EOBJLENGTH',0x00002B0E)
		win_const_mgr.add_const('SECPKG_STATE_ENCRYPTION_PERMITTED',0x00000001)
		win_const_mgr.add_const('PERF_COUNTER_RATE',0x00010000)
		win_const_mgr.add_const('SCRIPTITEM_CODEONLY',0x00000200)
		win_const_mgr.add_const('SECPKG_ATTR_FLAGS',0x0000000E)
		win_const_mgr.add_const('LSP_OUTBOUND_MODIFY',0x00000020)
		win_const_mgr.add_const('RPC_S_BINDING_INCOMPLETE',0x0000071B)
		win_const_mgr.add_const('DNS_RTYPE_TKEY',0x00000000)
		win_const_mgr.add_const('DS_LIST_DNS_HOST_NAME_FOR_SERVER',0x00000001)
		win_const_mgr.add_const('D3DTEXOPCAPS_DOTPRODUCT3',0x00800000)
		win_const_mgr.add_const('SQL_CURSOR_FORWARD_ONLY',0x00000000)
		win_const_mgr.add_const('WMT_VIDEOIMAGE_INTEGER_DENOMINATOR',0x00010000)
		win_const_mgr.add_const('CR_PROP_KRACERT',0x0000001A)
		win_const_mgr.add_const('HTTP_LOG_FIELD_COMPUTER_NAME',0x00000020)
		win_const_mgr.add_const('REVEXT_CDPHTTPURL_OLD',0x00000002)
		win_const_mgr.add_const('TMNOWAIT',0x10000000)
		win_const_mgr.add_const('TMT_PADDEDBORDERWIDTH',0x000004BA)
		win_const_mgr.add_const('MQMSG_AUTH_LEVEL_ALWAYS',0x00000001)
		win_const_mgr.add_const('SOUND_SYSTEM_MENUCOMMAND',0x0000000F)
		win_const_mgr.add_const('CRYPTPROTECT_AUDIT',0x00000010)
		win_const_mgr.add_const('ASC_RET_LICENSING',0x00040000)
		win_const_mgr.add_const('ESB_DISABLE_UP',0x00000001)
		win_const_mgr.add_const('DISPID_IMULTISESSION_SUPPORTEDONCURRENTMEDIA',0x00000100)
		win_const_mgr.add_const('D3D10_DEFAULT_BORDER_COLOR_COMPONENT',0x00000000)
		win_const_mgr.add_const('LINECALLSTATE_PROCEEDING',0x00000200)
		win_const_mgr.add_const('GDIP_EMFPLUS_RECORD_BASE',0x00004000)
		win_const_mgr.add_const('PROTECTION_LEVEL_EDGERESTRICTED',0x00000014)
		win_const_mgr.add_const('PORT_REXEC',0x00000200)
		win_const_mgr.add_const('WPP_ERROR_LAST',0x400423FF)
		win_const_mgr.add_const('FD_EVENTID',0x000003E8)
		win_const_mgr.add_const('SQL_CVT_TINYINT',0x00002000)
		win_const_mgr.add_const('LOCALE_SLIST',0x0000000C)
		win_const_mgr.add_const('D3DDEVCAPS_DRAWPRIMITIVES2EX',0x00008000)
		win_const_mgr.add_const('EDITF_DISABLELDAPPACKAGELIST',0x00800000)
		win_const_mgr.add_const('MCI_DGV_WHERE_MAX',0x00400000)
		win_const_mgr.add_const('DB_UNSEARCHABLE',0x00000001)
		win_const_mgr.add_const('AVIIF_LIST',0x00000001)
		win_const_mgr.add_const('MD_AUTH_ADVNOTIFY_DISABLE',0x00000004)
		win_const_mgr.add_const('ODS_FOCUS',0x00000010)
		win_const_mgr.add_const('SQL_DIAG_ALTER_DOMAIN',0x00000003)
		win_const_mgr.add_const('SQL_SFKD_CASCADE',0x00000001)
		win_const_mgr.add_const('LDAP_OPT_DNS',0x00000001)
		win_const_mgr.add_const('TMT_TEXTBORDERSIZE',0x0000096E)
		win_const_mgr.add_const('SSA_FULLMEASURE',0x04000000)
		win_const_mgr.add_const('GT_SELECTION',0x00000002)
		win_const_mgr.add_const('HTBOTTOMRIGHT',0x00000011)
		win_const_mgr.add_const('IF_TYPE_MVL',0x000000BF)
		win_const_mgr.add_const('CB_MAX_CHUNK',0x00008000)
		win_const_mgr.add_const('BCRYPT_ECDSA_PRIVATE_P521_MAGIC',0x36534345)
		win_const_mgr.add_const('MCI_GETDEVCAPS_USES_FILES',0x00000005)
		win_const_mgr.add_const('FILE_USER_DISALLOWED',0x00000007)
		win_const_mgr.add_const('NDR_DEFAULT_ALLOCATOR',0x20000000)
		win_const_mgr.add_const('LDAP_FEATURE_INFO_VERSION',0x00000001)
		win_const_mgr.add_const('IDN_USE_STD3_ASCII_RULES',0x00000002)
		win_const_mgr.add_const('CLONE_FLAG_NO_DAV',0x00000010)
		win_const_mgr.add_const('HTTP_STATUS_PROXY_AUTH_REQ',0x00000197)
		win_const_mgr.add_const('OPERATION_MESSAGE',0x00000020)
		win_const_mgr.add_const('NCBLANSTALERT',0x00000073)
		win_const_mgr.add_const('ENLISTMENT_SUPERIOR_RIGHTS',0x00000010)
		win_const_mgr.add_const('WIA_IPS_PAGE_HEIGHT',0x00000C1B)
		win_const_mgr.add_const('D3D10_FTOU_INSTRUCTION_MAX_INPUT',0xFFFFFFFF)
		win_const_mgr.add_const('SSL_SESSION_ENABLE_RECONNECTS',0x00000001)
		win_const_mgr.add_const('BATTERY_SET_CHARGE_SUPPORTED',0x00000001)
		win_const_mgr.add_const('PD_ALLPAGES',0x00000000)
		win_const_mgr.add_const('POLICY_ERRV_CRAZY_FLOWSPEC',0x00000039)
		win_const_mgr.add_const('EC_ENABLEALL',0x00000000)
		win_const_mgr.add_const('DBT_VXDINITCOMPLETE',0x00000023)
		win_const_mgr.add_const('D3DPTEXTURECAPS_CUBEMAP',0x00000800)
		win_const_mgr.add_const('RESOURCEDISPLAYTYPE_GENERIC',0x00000000)
		win_const_mgr.add_const('LASTGOOD_OPERATION_DELETE',0x00000001)
		win_const_mgr.add_const('ERROR_NOT_FROZEN',0x0000005A)
		win_const_mgr.add_const('BM_SETSTYLE',0x000000F4)
		win_const_mgr.add_const('MDPROPVAL_RR_UPDATE',0x00000004)
		win_const_mgr.add_const('DATA_E_LAST',0x8004013F)
		win_const_mgr.add_const('CM_PROB_SYSTEM_SHUTDOWN',0x0000002E)
		win_const_mgr.add_const('NDIS_RING_LOBE_WIRE_FAULT',0x00000800)
		win_const_mgr.add_const('MUI_LANGUAGE_ID',0x00000004)
		win_const_mgr.add_const('SPI_SETMOUSEHOVERTIME',0x00000067)
		win_const_mgr.add_const('FMFOCUS_DRIVES',0x00000003)
		win_const_mgr.add_const('MCI_SEQ_SET_SLAVE',0x00040000)
		win_const_mgr.add_const('FF_SWISS',0x00000002)
		win_const_mgr.add_const('CACHEGROUP_FLAG_FLUSHURL_ONDELETE',0x00000002)
		win_const_mgr.add_const('WAB_DISPLAY_ISNTDS',0x00000004)
		win_const_mgr.add_const('MIDICAPS_CACHE',0x00000004)
		win_const_mgr.add_const('EMARCH_ENC_I17_IC_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('OID_FDDI_ATTACHMENT_TYPE',0x03020101)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_UNLOADED_MODULES',0x00000004)
		win_const_mgr.add_const('WVR_ALIGNBOTTOM',0x00000040)
		win_const_mgr.add_const('DS_SYSMODAL',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_SA',0x00003606)
		win_const_mgr.add_const('SP_COPY_SOURCEPATH_ABSOLUTE',0x00000080)
		win_const_mgr.add_const('ASSERT_PRIMARY',0x00000008)
		win_const_mgr.add_const('SIGNERSCORE_UNSIGNED',0x80000000)
		win_const_mgr.add_const('CONSOLE_FULLSCREEN',0x00000001)
		win_const_mgr.add_const('KS_NABTS_GROUPID_PRODUCTION_COMPANY_CONTENT_BASE',0x00000820)
		win_const_mgr.add_const('DFS_VOLUME_FLAVORS',0x00000300)
		win_const_mgr.add_const('IMAGE_FILE_RELOCS_STRIPPED',0x00000001)
		win_const_mgr.add_const('DI_FLAGSEX_APPENDDRIVERLIST',0x00040000)
		win_const_mgr.add_const('IP_ADAPTER_REGISTER_ADAPTER_SUFFIX',0x00000002)
		win_const_mgr.add_const('VER_ERR_TYPE_F',0x00002000)
		win_const_mgr.add_const('OLEUI_ERR_LOADSTRING',0x00000073)
		win_const_mgr.add_const('MUI_CONSOLE_FILTER',0x00000100)
		win_const_mgr.add_const('CF_SELECTACTIVATEAS',0x00000010)
		win_const_mgr.add_const('SPI_GETMINIMUMHITRADIUS',0x00002014)
		win_const_mgr.add_const('IMAGE_REL_AMD64_REL32',0x00000004)
		win_const_mgr.add_const('PDH_CSTATUS_NO_MACHINE',0x800007D0)
		win_const_mgr.add_const('MCI_DGV_FILE_MODE_SAVING',0x00000001)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_WITHIN_FOREST',0x00000020)
		win_const_mgr.add_const('FLOW_DURATION',0x00000005)
		win_const_mgr.add_const('MILBITMAPEFFECT_SDK_VERSION',0x01000000)
		win_const_mgr.add_const('WKSTA_USEOPPORTUNISTICLOCKING_PARMNUM',0x00000030)
		win_const_mgr.add_const('WSA_QOS_NO_RECEIVERS',0x00002B00)
		win_const_mgr.add_const('MD_STOP_LISTENING',0x00002703)
		win_const_mgr.add_const('EVENT_TRACE_FILE_MODE_SEQUENTIAL',0x00000001)
		win_const_mgr.add_const('CHANNEL_RC_ALREADY_CONNECTED',0x00000003)
		win_const_mgr.add_const('DNS_TYPE_KX',0x00000024)
		win_const_mgr.add_const('ERROR_EVENTLOG_FILE_CHANGED',0x000005DF)
		win_const_mgr.add_const('SEL_EMPTY',0x00000000)
		win_const_mgr.add_const('OFFLINESTATUS_OFFLINE_ITEM_VERSION_CONFLICT',0x00000005)
		win_const_mgr.add_const('SQL_CN_NONE',0x00000000)
		win_const_mgr.add_const('PFM_SIDEBYSIDE',0x00800000)
		win_const_mgr.add_const('CERT_STORE_MAXIMUM_ALLOWED_FLAG',0x00001000)
		win_const_mgr.add_const('MD_SERVER_CONFIG_AUTO_PW_SYNC',0x00000008)
		win_const_mgr.add_const('IMAGE_DEBUG_TYPE_CLSID',0x0000000B)
		win_const_mgr.add_const('QUERY_SHALLOW',0x00000000)
		win_const_mgr.add_const('DFS_RESTORE_VOLUME',0x00000002)
		win_const_mgr.add_const('LVHT_ONITEMLABEL',0x00000004)
		win_const_mgr.add_const('NS_TCPIP_LOCAL',0x0000000A)
		win_const_mgr.add_const('DDSCAPS_FRONTBUFFER',0x00000020)
		win_const_mgr.add_const('SYSFXUI_DONOTSHOW_VIRTUALSURROUND',0x00000020)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_PREPAREMEDIA',0x00000200)
		win_const_mgr.add_const('SUBLANG_TURKMEN_TURKMENISTAN',0x00000001)
		win_const_mgr.add_const('WKSTA_MAXTHREADS_PARMNUM',0x00000021)
		win_const_mgr.add_const('ACM_FILTERDETAILSF_QUERYMASK',0x0000000F)
		win_const_mgr.add_const('SPFILENOTIFY_DELETEERROR',0x00000007)
		win_const_mgr.add_const('IFS_MBZ0_V',0x00000001)
		win_const_mgr.add_const('RPC_X_ENUM_VALUE_OUT_OF_RANGE',0x000006F5)
		win_const_mgr.add_const('PRODUCT_UNLICENSED',0xABCDABCD)
		win_const_mgr.add_const('LOCKP_FAIL_MEM_MAPPING',0x00000002)
		win_const_mgr.add_const('IEIFLAG_QUALITY',0x00000200)
		win_const_mgr.add_const('SQL_DIAG_ALTER_TABLE',0x00000004)
		win_const_mgr.add_const('IMAGE_REL_AMD64_SSPAN32',0x00000010)
		win_const_mgr.add_const('IO_REPARSE_TAG_RESERVED_ONE',0x00000001)
		win_const_mgr.add_const('OID_LTALK_DEFERS',0x05020203)
		win_const_mgr.add_const('AE_CONNREJ',0x00000006)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_DEBUG',0x00000006)
		win_const_mgr.add_const('WPWIZ_ERROR_NO_PROVIDERS',0xC0042005)
		win_const_mgr.add_const('JOB_CONTROL_CANCEL',0x00000003)
		win_const_mgr.add_const('EAP_FLAG_PREVIEW',0x00000008)
		win_const_mgr.add_const('SQLNTEXT',0x00000063)
		win_const_mgr.add_const('INTERNET_FLAG_IGNORE_REDIRECT_TO_HTTPS',0x00004000)
		win_const_mgr.add_const('CREATE_NO_WINDOW',0x08000000)
		win_const_mgr.add_const('FILE_DEVICE_MIDI_IN',0x00000000)
		win_const_mgr.add_const('CERT_TRUST_IS_PARTIAL_CHAIN',0x00010000)
		win_const_mgr.add_const('SPRDI_FIND_DUPS',0x00000001)
		win_const_mgr.add_const('PID_CHARCOUNT',0x00000010)
		win_const_mgr.add_const('CERT_INFO_SUBJECT_PUBLIC_KEY_INFO_FLAG',0x00000008)
		win_const_mgr.add_const('SE_ERR_OOM',0x00000008)
		win_const_mgr.add_const('ERROR_DS_WRONG_LINKED_ATT_SYNTAX',0x00002150)
		win_const_mgr.add_const('WNPERM_DLG_AUDIT',0x00000001)
		win_const_mgr.add_const('AUDIT_SET_USER_POLICY',0x00000004)
		win_const_mgr.add_const('ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX',0x000020B9)
		win_const_mgr.add_const('SERVICE_CONTROL_HARDWAREPROFILECHANGE',0x0000000C)
		win_const_mgr.add_const('DCR_DA',0x0000000D)
		win_const_mgr.add_const('TREE_SEC_INFO_RESET',0x00000002)
		win_const_mgr.add_const('DCR_DD',0x0000000E)
		win_const_mgr.add_const('OID_FDDI_SMT_MAC_CT',0x03030208)
		win_const_mgr.add_const('DFCS_ADJUSTRECT',0x00002000)
		win_const_mgr.add_const('LANG_TATAR',0x00000044)
		win_const_mgr.add_const('DCR_DK',0x0000000A)
		win_const_mgr.add_const('DCR_DM',0x00000008)
		win_const_mgr.add_const('DCR_DP',0x00000009)
		win_const_mgr.add_const('DCR_DR',0x0000000C)
		win_const_mgr.add_const('PATCH_OPTION_INTERLEAVE_FILES',0x40000000)
		win_const_mgr.add_const('LINEDEVSTATE_DISCONNECTED',0x00000008)
		win_const_mgr.add_const('DBPROPVAL_CL_END',0x00000002)
		win_const_mgr.add_const('DCR_DX',0x0000000B)
		win_const_mgr.add_const('GC_WCH_FREVERSEDIR',0x08000000)
		win_const_mgr.add_const('MAXIMUM_RESERVED_MANIFEST_RESOURCE_ID',0x00000010)
		win_const_mgr.add_const('LINECALLPARTYID_PARTIAL',0x00000010)
		win_const_mgr.add_const('CRYPT_STRING_HEX',0x00000004)
		win_const_mgr.add_const('ECO_VERTICAL',0x00400000)
		win_const_mgr.add_const('MQCERT_REGISTER_IF_NOT_EXIST',0x00000002)
		win_const_mgr.add_const('OID_PNP_WAKE_UP_OK',0xFD020200)
		win_const_mgr.add_const('ERROR_SCOPE_NOT_FOUND',0x0000013E)
		win_const_mgr.add_const('SPI_SETSERIALKEYS',0x0000003F)
		win_const_mgr.add_const('SQL_SCCO_OPT_ROWVER',0x00000004)
		win_const_mgr.add_const('PANE_SSL',0x00000004)
		win_const_mgr.add_const('PSH_RESIZABLE',0x04000000)
		win_const_mgr.add_const('LINECALLFEATURE2_NOHOLDCONFERENCE',0x00000001)
		win_const_mgr.add_const('MCI_DGV_METHOD_POST',0x00000000)
		win_const_mgr.add_const('WKSTA_CACHEFILETIMEOUT_PARMNUM',0x0000002F)
		win_const_mgr.add_const('ERROR_INVALID_DEVICE_OBJECT_PARAMETER',0x0000028A)
		win_const_mgr.add_const('SQL_CA1_POS_DELETE',0x00000800)
		win_const_mgr.add_const('IDS_CAP_FILE_OPEN_ERROR',0x000001AD)
		win_const_mgr.add_const('SQL_DEFAULT',0x00000063)
		win_const_mgr.add_const('PIR_OPTION_ENABLED',0x00000001)
		win_const_mgr.add_const('APPCOMMAND_PRINT',0x00000021)
		win_const_mgr.add_const('SQL_CT_CONSTRAINT_INITIALLY_IMMEDIATE',0x00000040)
		win_const_mgr.add_const('UF_SCRIPT',0x00000001)
		win_const_mgr.add_const('ISFB_MASK_SHELLFOLDER',0x00000008)
		win_const_mgr.add_const('SHIFTJIS_CHARSET',0x00000080)
		win_const_mgr.add_const('DNS_TYPE_MAILA',0x00000000)
		win_const_mgr.add_const('GOPHER_TYPE_REDUNDANT',0x00000400)
		win_const_mgr.add_const('ERROR_SXS_XML_E_INTERNALERROR',0x000036D9)
		win_const_mgr.add_const('CACHE_HEADER_DATA_ROOTGROUP_OFFSET',0x00000005)
		win_const_mgr.add_const('ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME',0x00001711)
		win_const_mgr.add_const('ISFB_STATE_DEBOSSED',0x00000001)
		win_const_mgr.add_const('DISPID_IMULTISESSION_LASTSECTOROFPREVIOUSSESSION',0x00000202)
		win_const_mgr.add_const('CMSG_INNER_CONTENT_TYPE_PARAM',0x00000004)
		win_const_mgr.add_const('WMDM_STATUS_STORAGE_INITIALIZING',0x00000200)
		win_const_mgr.add_const('CF_INITTOLOGFONTSTRUCT',0x00000040)
		win_const_mgr.add_const('ERROR_IMAGE_MACHINE_TYPE_MISMATCH',0x000002C2)
		win_const_mgr.add_const('IMAGE_REL_BASED_LOW',0x00000002)
		win_const_mgr.add_const('D3DCAPS3_RESERVED',0x08000001)
		win_const_mgr.add_const('EC_TIME',0x00000004)
		win_const_mgr.add_const('EMR_FLATTENPATH',0x00000041)
		win_const_mgr.add_const('ERROR_INVALID_EA_NAME',0x000000FE)
		win_const_mgr.add_const('NTDSDSA_OPT_DISABLE_OUTBOUND_REPL_SECRET',0x00000001)
		win_const_mgr.add_const('SPI_SETPOWEROFFACTIVE',0x00000056)
		win_const_mgr.add_const('SQL_MAX_SQLSERVERNAME',0x00000080)
		win_const_mgr.add_const('SQL_API_SQLDATASOURCES',0x00000039)
		win_const_mgr.add_const('CMSG_USE_SIGNER_INDEX_FLAG',0x00000004)
		win_const_mgr.add_const('DEBUG_PROC_DESC_NO_USER_NAME',0x00000020)
		win_const_mgr.add_const('WSAETIMEDOUT',0x0000274C)
		win_const_mgr.add_const('RPC_C_MQ_AUTHN_LEVEL_PKT_INTEGRITY',0x00000008)
		win_const_mgr.add_const('DDCAPS2_AUTOFLIPOVERLAY',0x00000008)
		win_const_mgr.add_const('EVENTLOG_AUDIT_FAILURE',0x00000010)
		win_const_mgr.add_const('CSIDL_MYVIDEO',0x00000000)
		win_const_mgr.add_const('ISC_REQ_IDENTIFY',0x00020000)
		win_const_mgr.add_const('MCI_VCR_SETTUNER_NUMBER',0x00200000)
		win_const_mgr.add_const('LANG_GERMAN',0x00000007)
		win_const_mgr.add_const('CHANGER_TO_SLOT',0x00000002)
		win_const_mgr.add_const('WMDM_WMDM_REVOKED',0x00000001)
		win_const_mgr.add_const('CONVERT10_S_LAST',0x000401CF)
		win_const_mgr.add_const('MD_ERROR_SUB503_CPU_LIMIT',0x00000001)
		win_const_mgr.add_const('OID_TAPI_SELECT_EXT_VERSION',0x0703011B)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_RESERVED6',0x00040000)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SOURCE_RIGHT',0x00000002)
		win_const_mgr.add_const('CFERR_MAXLESSTHANMIN',0x00002002)
		win_const_mgr.add_const('MCI_VD_GETDEVCAPS_NORMAL_RATE',0x00004005)
		win_const_mgr.add_const('SYMOPT_EXACT_SYMBOLS',0x00000400)
		win_const_mgr.add_const('FWPM_FILTER_FLAG_PERMIT_IF_CALLOUT_UNREGISTERED',0x00000010)
		win_const_mgr.add_const('SECPKG_STATE_STANDALONE',0x00000010)
		win_const_mgr.add_const('STRM_TERMINALSELECTED',0x00000001)
		win_const_mgr.add_const('INV_RESULTS',0x00000005)
		win_const_mgr.add_const('RPC_C_OPT_SECURITY_CALLBACK',0x0000000A)
		win_const_mgr.add_const('IP_OPT_RR',0x00000007)
		win_const_mgr.add_const('ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE',0x00002136)
		win_const_mgr.add_const('CACHEGROUP_ATTRIBUTE_TYPE',0x00000004)
		win_const_mgr.add_const('DS_LIST_DSA_OBJECT_FOR_SERVER',0x00000000)
		win_const_mgr.add_const('SHACF_USETAB',0x00000008)
		win_const_mgr.add_const('CRYPT_ENUM_ALL_PROVIDERS',0x00000001)
		win_const_mgr.add_const('SQL_GET_BOOKMARK',0x0000000D)
		win_const_mgr.add_const('CDERR_NOHOOK',0x0000000B)
		win_const_mgr.add_const('WIA_INTENT_MINIMIZE_SIZE',0x00010000)
		win_const_mgr.add_const('NFR_UNICODE',0x00000002)
		win_const_mgr.add_const('ODBC_ERROR_REQUEST_FAILED',0x0000000B)
		win_const_mgr.add_const('PORT_HEMS',0x00000097)
		win_const_mgr.add_const('DISPLAYDIB_NOTSUPPORTED',0x00000001)
		win_const_mgr.add_const('MCI_ANIM_PLAY_SPEED',0x00010000)
		win_const_mgr.add_const('CERT_SMART_CARD_ROOT_INFO_PROP_ID',0x0000004C)
		win_const_mgr.add_const('MSV1_0_ALLOW_MSVCHAPV2',0x00010000)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_DIALUP',0x80000400)
		win_const_mgr.add_const('TABLE_SETCOL_DONE',0x00000008)
		win_const_mgr.add_const('IDS_CAP_COMPRESSOR_ERROR',0x000001B8)
		win_const_mgr.add_const('ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER',0x00001782)
		win_const_mgr.add_const('HOTKEYF_ALT',0x00000004)
		win_const_mgr.add_const('SQL_DESC_MINIMUM_SCALE',0x0000001F)
		win_const_mgr.add_const('DEBUG_OUTPUT_ERROR',0x00000002)
		win_const_mgr.add_const('SCARD_READER_TYPE_KEYBOARD',0x00000004)
		win_const_mgr.add_const('NDW_INSTALLFLAG_USERCANCEL',0x00040000)
		win_const_mgr.add_const('_WIN32_WINNT_WINXP',0x00000501)
		win_const_mgr.add_const('SQL_DT_RESTRICT',0x00000002)
		win_const_mgr.add_const('ERROR_OLD_WIN_VERSION',0x0000047E)
		win_const_mgr.add_const('WIZ_CYDLG',0x0000008C)
		win_const_mgr.add_const('IDTB_ZOOM',0x000000DE)
		win_const_mgr.add_const('ERROR_CHECKING_FILE_SYSTEM',0x000002C8)
		win_const_mgr.add_const('RTCRF_REGISTER_PRESENCE',0x00000004)
		win_const_mgr.add_const('SES_HIDEGRIDLINES',0x00020000)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_ROUTEPOINT',0x02000000)
		win_const_mgr.add_const('DCX_PARENTCLIP',0x00000020)
		win_const_mgr.add_const('SQL_FN_TD_DAYOFYEAR',0x00000010)
		win_const_mgr.add_const('INTERNET_FLAG_PASSIVE',0x08000000)
		win_const_mgr.add_const('PRJOB_COMPLETE',0x00000004)
		win_const_mgr.add_const('START_PAGE_GENERAL',0x00000000)
		win_const_mgr.add_const('DDCAPS_OVERLAYCANTCLIP',0x00001000)
		win_const_mgr.add_const('SNMP_OUTPUT_TO_LOGFILE',0x00000002)
		win_const_mgr.add_const('WSB_PROP_WINSTYLE',0x00000400)
		win_const_mgr.add_const('DISPID_IHTMLOPSPROFILE_GETATTRIBUTE',0x00000004)
		win_const_mgr.add_const('DNS_RTYPE_TEXT',0x00001000)
		win_const_mgr.add_const('CICAT_WRITABLE',0x00000004)
		win_const_mgr.add_const('TF_SENTENCEMODE_PLAURALCLAUSE',0x00000001)
		win_const_mgr.add_const('WIA_MAJOR_EVENT_PICTURE_DELETED',0x00000004)
		win_const_mgr.add_const('DR_X',0x0000003F)
		win_const_mgr.add_const('CERT_ACCESS_STATE_LM_SYSTEM_STORE_FLAG',0x00000004)
		win_const_mgr.add_const('ETW_UINT64_TYPE_VALUE',0x0000000A)
		win_const_mgr.add_const('VER_MAJORVERSION',0x00000002)
		win_const_mgr.add_const('IMF_DUALFONT',0x00000080)
		win_const_mgr.add_const('CONTEXT_MENU_IMGART',0x00000008)
		win_const_mgr.add_const('ERROR_FILE_CORRUPT',0x00000570)
		win_const_mgr.add_const('ICDECOMPRESS_UPDATE',0x40000000)
		win_const_mgr.add_const('RPC_S_DUPLICATE_ENDPOINT',0x000006CC)
		win_const_mgr.add_const('OS_WIN98ORGREATER',0x00000005)
		win_const_mgr.add_const('IDM_TRIED_UNORDERLIST',0x0000003C)
		win_const_mgr.add_const('SV_SHARINGVIOLATIONDELAY_PARMNUM',0x00000234)
		win_const_mgr.add_const('HTTP_LOG_FIELD_TIME',0x00000002)
		win_const_mgr.add_const('SFGAO_CONTENTSMASK',0x80000000)
		win_const_mgr.add_const('DPAS_INSERTBEFORE',0x00000002)
		win_const_mgr.add_const('LINE_CLOSE',0x00000003)
		win_const_mgr.add_const('_FACD3D',0x00000876)
		win_const_mgr.add_const('ODBC_VS_FLAG_RETCODE',0x00000004)
		win_const_mgr.add_const('META_CREATEFONTINDIRECT',0x000002FB)
		win_const_mgr.add_const('PPP_CCP_HISTORYLESS',0x01000000)
		win_const_mgr.add_const('OF_SHARE_COMPAT',0x00000000)
		win_const_mgr.add_const('UF_NORMAL_ACCOUNT',0x00000200)
		win_const_mgr.add_const('PID_DESCRIPTIONID',0x00000002)
		win_const_mgr.add_const('CBES_EX_NOSIZELIMIT',0x00000008)
		win_const_mgr.add_const('USE_VA_ADDR',0x00000020)
		win_const_mgr.add_const('EVENT_SYSTEM_MINIMIZEEND',0x00000017)
		win_const_mgr.add_const('PROVIDER_KEEPS_VALUE_LENGTH',0x00000001)
		win_const_mgr.add_const('LB_SETSEL',0x00000185)
		win_const_mgr.add_const('CERT_DIGITAL_SIGNATURE_KEY_USAGE',0x00000080)
		win_const_mgr.add_const('WSAEPROCLIM',0x00002753)
		win_const_mgr.add_const('ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY',0x00001B5D)
		win_const_mgr.add_const('DEBUG_OUTCTL_OVERRIDE_MASK',0x00000010)
		win_const_mgr.add_const('WKSTA_MAILSLOTS_PARMNUM',0x0000001E)
		win_const_mgr.add_const('CERT_ALT_NAME_EDI_PARTY_NAME',0x00000006)
		win_const_mgr.add_const('PANOSE_COUNT',0x0000000A)
		win_const_mgr.add_const('OID_FDDI_SMT_NON_MASTER_CT',0x03030209)
		win_const_mgr.add_const('OPTION_RLP_SERVERS',0x0000000B)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_PAUSE',0x0000002F)
		win_const_mgr.add_const('V86FLAGS_IOPL_BITS',0x00000012)
		win_const_mgr.add_const('D3D10_SRGB_TO_FLOAT_DENOMINATOR_1',0x0000000C)
		win_const_mgr.add_const('WIA_DPC_PICT_HEIGHT',0x00000815)
		win_const_mgr.add_const('SQL_CT_CONSTRAINT_INITIALLY_DEFERRED',0x00000020)
		win_const_mgr.add_const('D3D10_SRGB_TO_FLOAT_DENOMINATOR_2',0x00000001)
		win_const_mgr.add_const('FACILITY_BACKGROUNDCOPY',0x00000020)
		win_const_mgr.add_const('CSVER_MAJOR_WHISTLER',0x00000002)
		win_const_mgr.add_const('LANG_SOTHO',0x00000006)
		win_const_mgr.add_const('HSE_URL_FLAGS_NEGO_CERT',0x00000020)
		win_const_mgr.add_const('ERROR_VDM_HARD_ERROR',0x00000251)
		win_const_mgr.add_const('UINT16_MAX',0x00000000)
		win_const_mgr.add_const('SFVM_INVOKECOMMAND',0x00000002)
		win_const_mgr.add_const('ESLFLAG_PREV',0x00000004)
		win_const_mgr.add_const('TMT_GRADIENTACTIVECAPTION',0x0000065C)
		win_const_mgr.add_const('TTFCFP_UNICODE_CHAR_SET',0x00000001)
		win_const_mgr.add_const('MM_JOY2ZMOVE',0x000003A3)
		win_const_mgr.add_const('WCT_ASYNC_OPEN_FLAG',0x00000001)
		win_const_mgr.add_const('NDIS_PROT_OPTION_SEND_RESTRICTED',0x00000008)
		win_const_mgr.add_const('WSAEHOSTUNREACH',0x00002751)
		win_const_mgr.add_const('UMS_LISTBOX_GROUPS',0x00000001)
		win_const_mgr.add_const('CRYPT_EXT_OR_ATTR_OID_GROUP_ID',0x00000006)
		win_const_mgr.add_const('LVCFMT_FILL',0x00200000)
		win_const_mgr.add_const('DV_PAL',0x00000001)
		win_const_mgr.add_const('NCBCALL',0x00000010)
		win_const_mgr.add_const('SPINST_PROPERTIES',0x00000400)
		win_const_mgr.add_const('DMPAPER_ENV_14',0x00000017)
		win_const_mgr.add_const('WIN_CERT_TYPE_RESERVED_1',0x00000003)
		win_const_mgr.add_const('WMDM_SCP_DRMINFO_NOT_DRMPROTECTED',0x00000000)
		win_const_mgr.add_const('PSH_USEHPLWATERMARK',0x00020000)
		win_const_mgr.add_const('MCI_VCR_STATUS_NUMBER_OF_VIDEO_TRACKS',0x0000401F)
		win_const_mgr.add_const('CDIS_DISABLED',0x00000004)
		win_const_mgr.add_const('CTRY_TAIWAN',0x00000376)
		win_const_mgr.add_const('SQL_COLUMN_QUALIFIER_NAME',0x00000011)
		win_const_mgr.add_const('TPM_HORNEGANIMATION',0x00000800)
		win_const_mgr.add_const('EC_NEW_PIN',0x00000020)
		win_const_mgr.add_const('DDPF_BUMPLUMINANCE',0x00040000)
		win_const_mgr.add_const('NIIF_ERROR',0x00000003)
		win_const_mgr.add_const('TMT_IMAGEFILE1',0x00000BBA)
		win_const_mgr.add_const('TLS_MINIMUM_AVAILABLE',0x00000040)
		win_const_mgr.add_const('IME_KHOTKEY_ENGLISH',0x00000052)
		win_const_mgr.add_const('FILE_DEVICE_WAVE_IN',0x00000025)
		win_const_mgr.add_const('PS_COMPONENT_FLOW',0x00000002)
		win_const_mgr.add_const('STDOLE_LCID',0x00000000)
		win_const_mgr.add_const('DS_REPADD_PERIODIC',0x00000008)
		win_const_mgr.add_const('RPC_C_PROFILE_MATCH_BY_MBR',0x00000003)
		win_const_mgr.add_const('MD_LOGCUSTOM_DATATYPE_FLOAT',0x00000004)
		win_const_mgr.add_const('MCI_DGV_FF_AVSS',0x00004000)
		win_const_mgr.add_const('DMPAPER_ENV_12',0x00000016)
		win_const_mgr.add_const('DLL_THREAD_ATTACH',0x00000002)
		win_const_mgr.add_const('CRYPT_READ',0x00000008)
		win_const_mgr.add_const('IDM_SHOWTABLE',0x00000022)
		win_const_mgr.add_const('STREAM_SPARSE_ATTRIBUTE',0x00000008)
		win_const_mgr.add_const('WINHTTP_ENABLE_SSL_REVERT_IMPERSONATION',0x00000002)
		win_const_mgr.add_const('CRL_FIND_ANY',0x00000000)
		win_const_mgr.add_const('SECURITY_ENTERPRISE_CONTROLLERS_RID',0x00000009)
		win_const_mgr.add_const('VECTOR_RANK_JACCARD',0x00000004)
		win_const_mgr.add_const('_INC_AVIFMT',0x00000064)
		win_const_mgr.add_const('BS_DIBPATTERN8X8',0x00000008)
		win_const_mgr.add_const('STDPROP_INDEX_TERM',0x000000D2)
		win_const_mgr.add_const('PXE_PROV_FILTER_ALL',0x00000000)
		win_const_mgr.add_const('DS_REPADD_WRITEABLE',0x00000002)
		win_const_mgr.add_const('MD_EXTLOG_BYTES_RECV',0x00002000)
		win_const_mgr.add_const('PSM_AVDTP',0x00000019)
		win_const_mgr.add_const('SCARD_E_INVALID_TARGET',0x80100005)
		win_const_mgr.add_const('LVIR_ICON',0x00000001)
		win_const_mgr.add_const('DISKQUOTA_USER_ACCOUNT_UNAVAILABLE',0x00000001)
		win_const_mgr.add_const('ERROR_RMODE_APP',0x00000481)
		win_const_mgr.add_const('LVA_DEFAULT',0x00000000)
		win_const_mgr.add_const('SUBLANG_CATALAN_CATALAN',0x00000001)
		win_const_mgr.add_const('SFVM_SETITEMPOS',0x00000000)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_HANDLE_CLOSING',0x00000800)
		win_const_mgr.add_const('ISR_NA_CODE_MASK',0x0000000F)
		win_const_mgr.add_const('GOPHER_TYPE_CSO',0x00000004)
		win_const_mgr.add_const('CRYPT_LOCAL',0x00000001)
		win_const_mgr.add_const('OPTION_ROUTER_ADDRESS',0x00000003)
		win_const_mgr.add_const('OID_FDDI_PORT_MAC_INDICATED',0x0303025F)
		win_const_mgr.add_const('D3D10_DEFAULT_VIEWPORT_MIN_DEPTH',0x00000000)
		win_const_mgr.add_const('D3DTEXOPCAPS_BLENDCURRENTALPHA',0x00008000)
		win_const_mgr.add_const('FEATURESETTING_NUP',0x00000000)
		win_const_mgr.add_const('SQL_NUMERIC_FUNCTIONS',0x00000031)
		win_const_mgr.add_const('CM_DRP_HARDWAREID',0x00000002)
		win_const_mgr.add_const('SIGNERSCORE_SIGNED_MASK',0xF0000000)
		win_const_mgr.add_const('MPEGLAYER3_ID_MPEG',0x00000001)
		win_const_mgr.add_const('ERROR_DEVICE_NOT_CONNECTED',0x0000048F)
		win_const_mgr.add_const('WM_USERCHANGED',0x00000054)
		win_const_mgr.add_const('SETBREAK',0x00000008)
		win_const_mgr.add_const('TMT_INACTIVECAPTION',0x00000644)
		win_const_mgr.add_const('WKSTA_WRKHEURISTICS_PARMNUM',0x00000020)
		win_const_mgr.add_const('WORD_MAX',0x00000000)
		win_const_mgr.add_const('WIA_IPS_YRES',0x00001804)
		win_const_mgr.add_const('VIEW_PRIORITY_CACHEMISS',0x00000030)
		win_const_mgr.add_const('DISPLAYDIB_INVALIDTASK',0x00000004)
		win_const_mgr.add_const('ERROR_BUSY_DRIVE',0x0000008E)
		win_const_mgr.add_const('IMAGE_REL_MIPS_REFHALF',0x00000001)
		win_const_mgr.add_const('ALG_SID_AES_192',0x0000000F)
		win_const_mgr.add_const('FOF_MULTIDESTFILES',0x00000001)
		win_const_mgr.add_const('INTERNET_COOKIE_APPLY_P3P',0x00000080)
		win_const_mgr.add_const('TXTLOG_SETUPAPI_DEVLOG',0x00000001)
		win_const_mgr.add_const('SV_MAXMPXCT_PARMNUM',0x00000215)
		win_const_mgr.add_const('LBER_USE_DER',0x00000001)
		win_const_mgr.add_const('SUPPORTS_SAM_PROTOCOL',0x00000008)
		win_const_mgr.add_const('DNS_TYPE_WINSR',0x00000000)
		win_const_mgr.add_const('BIF_UAHINT',0x00000100)
		win_const_mgr.add_const('TH32CS_SNAPMODULE',0x00000008)
		win_const_mgr.add_const('IPP_E_LAST',0x40048106)
		win_const_mgr.add_const('SPI_GETWHEELSCROLLLINES',0x00000068)
		win_const_mgr.add_const('CALLBACK_TASK',0x00020000)
		win_const_mgr.add_const('DEBUG_STACK_FUNCTION_INFO',0x00000002)
		win_const_mgr.add_const('DRAGDROP_S_FIRST',0x00040100)
		win_const_mgr.add_const('SAMPLE_SEQ_CONTENT_P_FRAME',0x00000002)
		win_const_mgr.add_const('CERT_COMPARE_PROPERTY',0x00000005)
		win_const_mgr.add_const('SCARD_W_UNSUPPORTED_CARD',0x80100065)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_BENIGN_REINIT',0x00003636)
		win_const_mgr.add_const('ACTCTX_FLAG_APPLICATION_NAME_VALID',0x00000020)
		win_const_mgr.add_const('TF_URP_ALLPROFILES',0x00000002)
		win_const_mgr.add_const('LANG_KICHE',0x00000086)
		win_const_mgr.add_const('AUTHZ_ACCESS_CHECK_NO_DEEP_COPY_SD',0x00000001)
		win_const_mgr.add_const('MCI_OPEN',0x00000803)
		win_const_mgr.add_const('WIA_IPA_FULL_ITEM_NAME',0x00001003)
		win_const_mgr.add_const('SV_ANNDELTA_PARMNUM',0x00000012)
		win_const_mgr.add_const('WSAESHUTDOWN',0x0000274A)
		win_const_mgr.add_const('ERROR_CLUSTER_INVALID_NETWORK',0x000013BE)
		win_const_mgr.add_const('APPCOMMAND_PASTE',0x00000026)
		win_const_mgr.add_const('XP_SUPPORTS_BROADCAST',0x00000200)
		win_const_mgr.add_const('TRANSACTIONMANAGER_RENAME',0x00000008)
		win_const_mgr.add_const('ACCESS_FAIL_MASK',0x00000F00)
		win_const_mgr.add_const('ERROR_CLUSTER_NETINTERFACE_NOT_FOUND',0x000013B7)
		win_const_mgr.add_const('PSBTN_APPLYNOW',0x00000004)
		win_const_mgr.add_const('TC_VA_ABLE',0x00004000)
		win_const_mgr.add_const('SMAE_USER',0x00000004)
		win_const_mgr.add_const('ERROR_INTERNAL_DB_CORRUPTION',0x0000054E)
		win_const_mgr.add_const('MS_EXT_SET_ID',0x00000200)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW5_XMLHTTPREQUEST',0x000004A6)
		win_const_mgr.add_const('MCI_QUALITY_ITEM',0x00010000)
		win_const_mgr.add_const('PIDMSI_SOURCE',0x00000004)
		win_const_mgr.add_const('LOCALE_SMONGROUPING',0x00000018)
		win_const_mgr.add_const('NCBDGRECV',0x00000021)
		win_const_mgr.add_const('TMT_STATUSFONT',0x00000324)
		win_const_mgr.add_const('WIA_IPA_FILENAME_EXTENSION',0x0000101B)
		win_const_mgr.add_const('ERROR_INVALID_LOGON_HOURS',0x00000530)
		win_const_mgr.add_const('DDENUM_NONDISPLAYDEVICES',0x00000004)
		win_const_mgr.add_const('WMS_CONTAINER_CANSEEK',0x00000002)
		win_const_mgr.add_const('ERROR_NO_LOG_SPACE',0x000003FB)
		win_const_mgr.add_const('LINECALLREASON_FWDBUSY',0x00000002)
		win_const_mgr.add_const('IPX_PROTOCOL_BASE',0x00000001)
		win_const_mgr.add_const('REPORT_NOT_ABLE_TO_EXPORT_PRIVATE_KEY',0x00000002)
		win_const_mgr.add_const('ICW_MAX_LOGONNAME',0x00000100)
		win_const_mgr.add_const('SYMOPT_DEFERRED_LOADS',0x00000004)
		win_const_mgr.add_const('LINEERR_ALLOCATED',0x80000001)
		win_const_mgr.add_const('C1_CNTRL',0x00000020)
		win_const_mgr.add_const('TIMERR_BASE',0x00000060)
		win_const_mgr.add_const('MDPROPVAL_MSC_LESSTHANEQUAL',0x00000004)
		win_const_mgr.add_const('CTFMODEBIAS_DATETIME',0x00000004)
		win_const_mgr.add_const('ERROR_REMOTE_FILE_VERSION_MISMATCH',0x00001A9E)
		win_const_mgr.add_const('PROTO_IP_DTP',0x0000271D)
		win_const_mgr.add_const('SPCRP_SECURITY',0x00000017)
		win_const_mgr.add_const('MCGIP_CALENDARHEADER',0x00000005)
		win_const_mgr.add_const('LOCALE_IDEFAULTCODEPAGE',0x0000000B)
		win_const_mgr.add_const('LVCF_WIDTH',0x00000002)
		win_const_mgr.add_const('MCI_OPEN_ALIAS',0x00000400)
		win_const_mgr.add_const('ISO_HIERARCHICAL',0x00000000)
		win_const_mgr.add_const('ERROR_DS_DS_REQUIRED',0x0000211E)
		win_const_mgr.add_const('NLS_ALPHANUMERIC',0x00000000)
		win_const_mgr.add_const('MCI_QUALITY_ITEM_AUDIO',0x00004000)
		win_const_mgr.add_const('PIDSI_LASTAUTHOR',0x00000008)
		win_const_mgr.add_const('TMT_GLYPHTRANSPARENT',0x0000089E)
		win_const_mgr.add_const('COOKIE_ACCEPTED_CACHE_ENTRY',0x00001000)
		win_const_mgr.add_const('MB_USEGLYPHCHARS',0x00000004)
		win_const_mgr.add_const('CHANNEL_FLAG_MIDDLE',0x00000000)
		win_const_mgr.add_const('ERROR_TRUSTED_DOMAIN_FAILURE',0x000006FC)
		win_const_mgr.add_const('RPC_X_SS_IN_NULL_CONTEXT',0x000006EF)
		win_const_mgr.add_const('PIPE_ACCESS_DUPLEX',0x00000003)
		win_const_mgr.add_const('AE_RESACCESSREJ',0x00000008)
		win_const_mgr.add_const('OID_FDDI_SMT_SET_COUNT',0x0303021D)
		win_const_mgr.add_const('DB_PT_UNKNOWN',0x00000001)
		win_const_mgr.add_const('MIXER_OBJECTF_MIDIIN',0x40000000)
		win_const_mgr.add_const('GPO_INFO_FLAG_VERBOSE',0x00000040)
		win_const_mgr.add_const('ERROR_DS_DRA_DB_ERROR',0x00002103)
		win_const_mgr.add_const('LOCKP_ALLOW_WRITES',0x00000001)
		win_const_mgr.add_const('RPC_C_HTTP_AUTHN_SCHEME_PASSPORT',0x00000004)
		win_const_mgr.add_const('IASSEMBLYCACHEITEM_COMMIT_DISPOSITION_ALREADY_INSTALLED',0x00000003)
		win_const_mgr.add_const('BIF_NEWDIALOGSTYLE',0x00000040)
		win_const_mgr.add_const('ACM_METRIC_COUNT_CODECS',0x00000002)
		win_const_mgr.add_const('SW_PARENTCLOSING',0x00000001)
		win_const_mgr.add_const('DPAMM_MERGE',0x00000001)
		win_const_mgr.add_const('ERRLOC_NET',0x00000003)
		win_const_mgr.add_const('LINECALLSTATE_ONHOLDPENDTRANSFER',0x00002000)
		win_const_mgr.add_const('DS_NOTIFY_AFTER_SITE_RECORDS',0x00000002)
		win_const_mgr.add_const('DDPCAPS_2BIT',0x00000200)
		win_const_mgr.add_const('OS_WINDOWS',0x00000000)
		win_const_mgr.add_const('AUTH_REQ_ALLOW_NOADDRESS',0x00000010)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_FULL_AUXILIARY_STATE',0x00004000)
		win_const_mgr.add_const('DNS_WARNING_DOMAIN_UNDELETED',0x000025F4)
		win_const_mgr.add_const('SQL_DL_SQL92_TIMESTAMP',0x00000004)
		win_const_mgr.add_const('IDM_INSINPUTSUBMIT',0x00000845)
		win_const_mgr.add_const('STATE_SYSTEM_PRESSED',0x00000008)
		win_const_mgr.add_const('ERROR_DS_UNKNOWN_OPERATION',0x000020AD)
		win_const_mgr.add_const('ODT_LISTVIEW',0x00000066)
		win_const_mgr.add_const('DISK_LOGGING_START',0x00000000)
		win_const_mgr.add_const('BTH_ERROR_AUTHENTICATION_FAILURE',0x00000005)
		win_const_mgr.add_const('IF_TYPE_ISDN',0x0000003F)
		win_const_mgr.add_const('SET_BACKGROUND_COLOR',0x00001007)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2EVENTARGS_TOTALSYSTEMBUFFER',0x00000106)
		win_const_mgr.add_const('LVCF_TEXT',0x00000004)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_POLICY',0x00003625)
		win_const_mgr.add_const('SEE_MASK_NOCLOSEPROCESS',0x00000040)
		win_const_mgr.add_const('ESB_DISABLE_BOTH',0x00000003)
		win_const_mgr.add_const('DT_NOCLIP',0x00000100)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_MAC_FRAME',0x00008000)
		win_const_mgr.add_const('IF_TYPE_OPTICAL_TRANSPORT',0x000000C4)
		win_const_mgr.add_const('IMAGE_SUBSYSTEM_EFI_BOOT_SERVICE_DRIVER',0x0000000B)
		win_const_mgr.add_const('SQL_AT_ADD_COLUMN',0x00000001)
		win_const_mgr.add_const('POLICY_ERRV_INSUFFICIENT_PRIVILEGES',0x00000003)
		win_const_mgr.add_const('WIA_DPC_PICT_WIDTH',0x00000814)
		win_const_mgr.add_const('ET_DEVICECLASS',0x00010000)
		win_const_mgr.add_const('LOCALE_ALL',0x00000000)
		win_const_mgr.add_const('FILE_DEVICE_FIPS',0x0000003A)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_CURRENTWRITESPEED',0x0000010D)
		win_const_mgr.add_const('BTH_MFG_BANDSPEED',0x00000020)
		win_const_mgr.add_const('BACKUP_SPARSE_BLOCK',0x00000009)
		win_const_mgr.add_const('INTERNET_DEFAULT_GOPHER_PORT',0x00000046)
		win_const_mgr.add_const('CERT_CHAIN_OCSP_VALIDITY_SECONDS_DEFAULT',0x0000000C)
		win_const_mgr.add_const('PAN_FAMILY_TEXT_DISPLAY',0x00000002)
		win_const_mgr.add_const('SPC_INC_PE_IMPORT_ADDR_TABLE_FLAG',0x00000020)
		win_const_mgr.add_const('PRIMARY_CRED_OWF_PASSWORD',0x00000002)
		win_const_mgr.add_const('PDR_ENTRY',0x00000002)
		win_const_mgr.add_const('DISPID_IHTMLFRAMESCOLLECTION2_LENGTH',0x000003E9)
		win_const_mgr.add_const('UNIVERSAL_NAME_INFO_LEVEL',0x00000001)
		win_const_mgr.add_const('SQLCHARACTER',0x00000002)
		win_const_mgr.add_const('TXTLOG_DEVMGR',0x20000000)
		win_const_mgr.add_const('STI_ONLINESTATE_PAPER_JAM',0x00000010)
		win_const_mgr.add_const('KAGPROP_FORCENOREEXECUTE',0x0000000D)
		win_const_mgr.add_const('DNS_RCODE_NXDOMAIN',0x00000003)
		win_const_mgr.add_const('VP_TV_STANDARD_NTSC_M_J',0x00000002)
		win_const_mgr.add_const('BITS_MC_FILE_DELETION_FAILED',0x80194001)
		win_const_mgr.add_const('ICEE_CREATE_FILE_CORMAIN_STUB',0x00000004)
		win_const_mgr.add_const('BREAK_DEBUG_BASE',0x00080000)
		win_const_mgr.add_const('WEBPOST_ERROR_PROV_QI',0xC004210E)
		win_const_mgr.add_const('EAP_E_EAPHOST_METHOD_NOT_INSTALLED',0x80420011)
		win_const_mgr.add_const('TLMENUF_INCLUDECURRENT',0x00000001)
		win_const_mgr.add_const('MUTZ_DONT_USE_CACHE',0x00001000)
		win_const_mgr.add_const('IME_CONFIG_REGISTERWORD',0x00000002)
		win_const_mgr.add_const('PROPID_QUERY_RANKVECTOR',0x00000002)
		win_const_mgr.add_const('CDBOSC_SETFOCUS',0x00000000)
		win_const_mgr.add_const('HTTB_FIXEDBORDER',0x00000002)
		win_const_mgr.add_const('VK_OEM_MINUS',0x000000BD)
		win_const_mgr.add_const('SMC_CHEVRONGETTIP',0x0000002F)
		win_const_mgr.add_const('IDC_CI_LABEL',0x00000080)
		win_const_mgr.add_const('DNS_UPDATE_TEST_USE_LOCAL_SYS_ACCT',0x00000400)
		win_const_mgr.add_const('MFE_NO_ROUTE',0x00000009)
		win_const_mgr.add_const('DISPID_CUSTOMIZESETTINGS',0x00000011)
		win_const_mgr.add_const('IMAGE_REL_I386_SECREL',0x0000000B)
		win_const_mgr.add_const('IF_TYPE_VOICE_FXS',0x00000066)
		win_const_mgr.add_const('WRITE_OWNER',0x00080000)
		win_const_mgr.add_const('CALLBACK_FUNCTION',0x00030000)
		win_const_mgr.add_const('CRYPT_MODE_CTS',0x00000005)
		win_const_mgr.add_const('PAN_STROKEVARIATION_INDEX',0x00000005)
		win_const_mgr.add_const('DC_ACTIVE',0x00000001)
		win_const_mgr.add_const('EXTENSION_ORIGIN_MASK',0x00000000)
		win_const_mgr.add_const('PDH_ASYNC_QUERY_TIMEOUT',0x800007DB)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_SOURCE_STEREO',0x00000000)
		win_const_mgr.add_const('IF_TYPE_VOICE_FXO',0x00000065)
		win_const_mgr.add_const('TAPIMAXDEVICEIDSIZE',0x00000028)
		win_const_mgr.add_const('SYSTEM_MANDATORY_LABEL_NO_READ_UP',0x00000002)
		win_const_mgr.add_const('SYSTEM_ALARM_ACE_TYPE',0x00000003)
		win_const_mgr.add_const('STRSAFE_USE_SECURE_CRT',0x00000000)
		win_const_mgr.add_const('DPNHADDRESSTYPE_GATEWAYISLOCAL',0x00000020)
		win_const_mgr.add_const('WM_MDITILE',0x00000226)
		win_const_mgr.add_const('CONSOLE_WINDOWED_MODE',0x00000002)
		win_const_mgr.add_const('DTN_LAST',0x00000000)
		win_const_mgr.add_const('STIEDFL_ATTACHEDONLY',0x00000001)
		win_const_mgr.add_const('MCI_VD_GETDEVCAPS_CAN_REVERSE',0x00004002)
		win_const_mgr.add_const('DISPID_MOVESELECTIONTO',0x00000009)
		win_const_mgr.add_const('INTERNET_STATUS_P3P_HEADER',0x00000145)
		win_const_mgr.add_const('LINEFORWARDMODE_NOANSW',0x00000100)
		win_const_mgr.add_const('RENDBIND_DEFAULTPASSWORD',0x00000008)
		win_const_mgr.add_const('IF_TYPE_LAP_B',0x00000010)
		win_const_mgr.add_const('MCI_INFO_MEDIA_UPC',0x00000400)
		win_const_mgr.add_const('DEBUG_CSS_SYMBOL_OPTIONS',0x00000010)
		win_const_mgr.add_const('IF_TYPE_LAP_F',0x00000077)
		win_const_mgr.add_const('NDIS_OFFLOAD_FLAGS_GROUP_CHECKSUM_CAPABILITIES',0x00000001)
		win_const_mgr.add_const('SECPKG_ATTR_NATIVE_NAMES',0x0000000D)
		win_const_mgr.add_const('LINESPECIALINFO_NOCIRCUIT',0x00000001)
		win_const_mgr.add_const('SQL_ROW_ERROR',0x00000005)
		win_const_mgr.add_const('FCSM_FLAGS',0x00000040)
		win_const_mgr.add_const('SAC_PROTOCOL_V1',0x00000002)
		win_const_mgr.add_const('DI_FLAGSEX_BACKUPONREPLACE',0x00100000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGSETVALUE',0x0000000E)
		win_const_mgr.add_const('DE_E_FILTER_SERVERSCRIPT',0x80100002)
		win_const_mgr.add_const('LANG_SLOVAK',0x00000001)
		win_const_mgr.add_const('CM_PROB_LACKED_ARBITRATOR',0x00000005)
		win_const_mgr.add_const('OID_802_11_DISASSOCIATE',0x0D010115)
		win_const_mgr.add_const('SPI_SETSNAPTODEFBUTTON',0x00000060)
		win_const_mgr.add_const('WINHTTP_ADDREQ_FLAG_REPLACE',0x80000000)
		win_const_mgr.add_const('LOCALE_ILDATE',0x00000022)
		win_const_mgr.add_const('ERROR_KERNEL_APC',0x000002E2)
		win_const_mgr.add_const('IPPORT_SYSTAT',0x0000000B)
		win_const_mgr.add_const('DEBUG_BREAKPOINT_DATA',0x00000001)
		win_const_mgr.add_const('MQ_ACTION_PEEK_NEXT',0x80000001)
		win_const_mgr.add_const('TTFCFP_MS_PLATFORMID',0x00000003)
		win_const_mgr.add_const('SQL_DELETE',0x00000003)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_HOUR_TO_MINUTE',0x00002000)
		win_const_mgr.add_const('NETSETUP_JOIN_WITH_NEW_NAME',0x00000400)
		win_const_mgr.add_const('EMF_CENTERED',0x00000001)
		win_const_mgr.add_const('URLPOLICY_DONTCHECKDLGBOX',0x00000100)
		win_const_mgr.add_const('JOB_STATUS_PAUSED',0x00000001)
		win_const_mgr.add_const('ERROR_CLUSTER_GUM_NOT_LOCKER',0x000013DD)
		win_const_mgr.add_const('MCI_DGV_RECORD_HOLD',0x00020000)
		win_const_mgr.add_const('SQL_DESC_BASE_COLUMN_NAME',0x00000016)
		win_const_mgr.add_const('SAFER_POLICY_UIFLAGS_OPTION_PROMPT',0x00000002)
		win_const_mgr.add_const('PHONEFEATURE_SETRING',0x01000000)
		win_const_mgr.add_const('GPO_LIST_FLAG_NO_WMIFILTERS',0x00000004)
		win_const_mgr.add_const('NCBSENDNA',0x00000071)
		win_const_mgr.add_const('SFVM_GETDETAILSOF',0x00000017)
		win_const_mgr.add_const('DISPID_ONTHEATERMODE',0x00000104)
		win_const_mgr.add_const('D3DCS_TOP',0x00000004)
		win_const_mgr.add_const('SYMOPT_IGNORE_CVREC',0x00000080)
		win_const_mgr.add_const('SERVICE_PRIMARY_IDENTITY',0x00000008)
		win_const_mgr.add_const('ERROR_APP_WRONG_OS',0x0000047F)
		win_const_mgr.add_const('ICU_BROWSER_MODE',0x02000000)
		win_const_mgr.add_const('HSE_EXEC_URL_DISABLE_CUSTOM_ERROR',0x00000020)
		win_const_mgr.add_const('EVENT_HEADER_PROPERTY_LEGACY_EVENTLOG',0x00000004)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_CONFDROP',0x00200000)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_SYSTEM_FLAGS',0x00000040)
		win_const_mgr.add_const('USER_WORKSTATIONS_PARMNUM',0x0000000E)
		win_const_mgr.add_const('MCI_DGV_STATUS_RIGHT',0x00100000)
		win_const_mgr.add_const('ERROR_FILE_NOT_ENCRYPTED',0x00001777)
		win_const_mgr.add_const('DCR_BE',0x00000001)
		win_const_mgr.add_const('MDPROPVAL_MNF_STDDEV',0x00000004)
		win_const_mgr.add_const('UINT64_ERROR',0x00000000)
		win_const_mgr.add_const('PANE_ZONE',0x00000001)
		win_const_mgr.add_const('TC_NOTIFY_IFC_CHANGE',0x00000003)
		win_const_mgr.add_const('SQL_CA_CREATE_ASSERTION',0x00000001)
		win_const_mgr.add_const('RPC_X_SS_CANNOT_GET_CALL_HANDLE',0x000006F3)
		win_const_mgr.add_const('SPCLPASSTHROUGH2',0x000011D8)
		win_const_mgr.add_const('VDMEVENT_V86',0x00000001)
		win_const_mgr.add_const('ERROR_STATIC_INIT',0x00000FA2)
		win_const_mgr.add_const('ARCONTENT_AUTOPLAYPIX',0x00000080)
		win_const_mgr.add_const('FILE_FLAG_RANDOM_ACCESS',0x10000000)
		win_const_mgr.add_const('SEL_OBJECT',0x00000002)
		win_const_mgr.add_const('JOB_OBJECT_TERMINATE_AT_END_OF_JOB',0x00000000)
		win_const_mgr.add_const('KSMETHOD_TYPE_BASICSUPPORT',0x00000200)
		win_const_mgr.add_const('ALG_SID_IDEA',0x00000005)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2_WRITEINPROGRESS',0x00000105)
		win_const_mgr.add_const('HSE_URL_FLAGS_SSL128',0x00000100)
		win_const_mgr.add_const('ACTIVATION_CONTEXT_SECTION_COM_TYPE_LIBRARY_REDIRECTION',0x00000006)
		win_const_mgr.add_const('IME_MAXPROCESS',0x00000020)
		win_const_mgr.add_const('CR_PROP_SANITIZEDCASHORTNAME',0x00000028)
		win_const_mgr.add_const('FAPPCOMMAND_MOUSE',0x00008000)
		win_const_mgr.add_const('OID_GEN_DISCONTINUITY_TIME',0x00010282)
		win_const_mgr.add_const('RID_INPUT',0x10000003)
		win_const_mgr.add_const('ERROR_IS_JOIN_PATH',0x00000093)
		win_const_mgr.add_const('JOB_NONINTERACTIVE',0x00000010)
		win_const_mgr.add_const('CR_NO_SUCH_REGISTRY_KEY',0x0000002E)
		win_const_mgr.add_const('EMR_MODIFYWORLDTRANSFORM',0x00000024)
		win_const_mgr.add_const('TVNRET_SKIPOLD',0x00000001)
		win_const_mgr.add_const('INTERNET_AUTOPROXY_INIT_DEFAULT',0x00000001)
		win_const_mgr.add_const('DEBUG_REGISTERS_FLOAT',0x00000004)
		win_const_mgr.add_const('CERT_STORE_DEFER_CLOSE_UNTIL_LAST_FREE_FLAG',0x00000004)
		win_const_mgr.add_const('COLOR_MIX',0x000002CF)
		win_const_mgr.add_const('CR_MACHINE_UNAVAILABLE',0x00000031)
		win_const_mgr.add_const('TXTBIT_VIEWINSETCHANGE',0x00002000)
		win_const_mgr.add_const('MULTICLASSINFO_GETIIDSOURCE',0x00000008)
		win_const_mgr.add_const('D3DPTFILTERCAPS_CONVOLUTIONMONO',0x00040000)
		win_const_mgr.add_const('SUF_NETHDBOOT',0x00000040)
		win_const_mgr.add_const('CERT_ACCESS_STATE_PROP_ID',0x0000000E)
		win_const_mgr.add_const('WAVE_FORMAT_44S16',0x00000800)
		win_const_mgr.add_const('FEATURESETTING_PROTOCOL',0x00000006)
		win_const_mgr.add_const('C1_BLANK',0x00000040)
		win_const_mgr.add_const('CERT_RDN_T61_STRING',0x00000005)
		win_const_mgr.add_const('DISPID_EXPORT',0x00000007)
		win_const_mgr.add_const('CERT_DISPWELL_DISTRUST_ADD_LEAF_CERT',0x00000009)
		win_const_mgr.add_const('SEM_NOOPENFILEERRORBOX',0x00008000)
		win_const_mgr.add_const('DISP_CHANGE_RESTART',0x00000001)
		win_const_mgr.add_const('CRYPT_PREGEN',0x00000040)
		win_const_mgr.add_const('ETW_POINTER_TYPE_VALUE',0x00000069)
		win_const_mgr.add_const('D3DISSUE_END',0x00000001)
		win_const_mgr.add_const('LOCK_UNLOCK_IEPORT',0x00000001)
		win_const_mgr.add_const('DDD_RAW_TARGET_PATH',0x00000001)
		win_const_mgr.add_const('PHOTO_EXPOSUREPROGRAM_ACTION',0x00000006)
		win_const_mgr.add_const('OUT_TT_ONLY_PRECIS',0x00000007)
		win_const_mgr.add_const('MCI_ANIM_WINDOW_STATE',0x00040000)
		win_const_mgr.add_const('PORT_STATUS_TYPE_ERROR',0x00000001)
		win_const_mgr.add_const('SECURITY_FLAG_SSL',0x00000002)
		win_const_mgr.add_const('SQL_PARAM_OUTPUT',0x00000004)
		win_const_mgr.add_const('DS_REPDEL_NO_SOURCE',0x00000020)
		win_const_mgr.add_const('UNDNAME_NO_ALLOCATION_MODEL',0x00000008)
		win_const_mgr.add_const('CPF_SHADOW',0x00000008)
		win_const_mgr.add_const('CTL_CERT_SUBJECT_TYPE',0x00000002)
		win_const_mgr.add_const('KSEVENTF_DPC',0x00000010)
		win_const_mgr.add_const('TMT_MINDPI5',0x00000978)
		win_const_mgr.add_const('TMT_MINDPI2',0x00000975)
		win_const_mgr.add_const('SQL_MAX_CURSOR_NAME_LEN',0x0000001F)
		win_const_mgr.add_const('OID_802_11_BSSID',0x0D010101)
		win_const_mgr.add_const('TMT_MINDPI1',0x00000974)
		win_const_mgr.add_const('JOY_CAL_READ3',0x00040000)
		win_const_mgr.add_const('MINIDUMP_THREAD_INFO_INVALID_CONTEXT',0x00000010)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_PAL',0x00004003)
		win_const_mgr.add_const('MD_SERVER_STATE_STOPPING',0x00000003)
		win_const_mgr.add_const('JOY_CAL_READ6',0x00800000)
		win_const_mgr.add_const('JOY_CAL_READ5',0x00400000)
		win_const_mgr.add_const('JOY_CAL_READ4',0x00080000)
		win_const_mgr.add_const('THREAD_BASE_PRIORITY_LOWRT',0x0000000F)
		win_const_mgr.add_const('WMDM_STATUS_STORAGE_NOTPRESENT',0x00000100)
		win_const_mgr.add_const('OID_TAPI_GET_CALL_STATUS',0x0703010F)
		win_const_mgr.add_const('INPUTLANGCHANGE_SYSCHARSET',0x00000001)
		win_const_mgr.add_const('REGDF_NOTDETDMA',0x00000008)
		win_const_mgr.add_const('IDC_PS_PASTELINK',0x000001F5)
		win_const_mgr.add_const('IMAP_MD_ID_END_RESERVED',0x00000000)
		win_const_mgr.add_const('INTERNET_FLAG_IGNORE_REDIRECT_TO_HTTP',0x00008000)
		win_const_mgr.add_const('ERROR_DS_UNABLE_TO_SURRENDER_ROLES',0x000020F3)
		win_const_mgr.add_const('FLAG_LOOPBACK_MERGE',0x10000000)
		win_const_mgr.add_const('PRINTDLGORDMOTIF',0x00002714)
		win_const_mgr.add_const('SET_SPREAD',0x0000100A)
		win_const_mgr.add_const('NCRYPTBUFFER_PKCS_SECRET',0x0000002E)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_CLIENTINFORMATION',0x00000489)
		win_const_mgr.add_const('COPYFLG_REPLACE_BOOT_FILE',0x00001000)
		win_const_mgr.add_const('OF_SHARE_DENY_READ',0x00000030)
		win_const_mgr.add_const('GESTURE_DIAGONAL_LEFTDOWN',0x00000000)
		win_const_mgr.add_const('FLG_ADDREG_TYPE_EXPAND_SZ',0x00020000)
		win_const_mgr.add_const('BCRYPT_DH_PARAMETERS_MAGIC',0x00000004)
		win_const_mgr.add_const('CM_SETUP_BITS',0x00000007)
		win_const_mgr.add_const('GET_FEATURE_FROM_THREAD_LOCALMACHINE',0x00000008)
		win_const_mgr.add_const('SPI_SETMOUSESONAR',0x0000101D)
		win_const_mgr.add_const('DIF_DETECTCANCEL',0x00000021)
		win_const_mgr.add_const('SECBUFFER_TOKEN',0x00000002)
		win_const_mgr.add_const('SEM_NOGPFAULTERRORBOX',0x00000002)
		win_const_mgr.add_const('ERROR_BAD_NETPATH',0x00000035)
		win_const_mgr.add_const('WT_EXECUTEINPERSISTENTIOTHREAD',0x00000040)
		win_const_mgr.add_const('SCARD_CLASS_SECURITY',0x00000005)
		win_const_mgr.add_const('TBSTYLE_EX_HIDECLIPPEDBUTTONS',0x00000010)
		win_const_mgr.add_const('IDM_NEW',0x000007D1)
		win_const_mgr.add_const('DLG_FLAGS_INVALID_CA',0x01000000)
		win_const_mgr.add_const('IIS_MD_UT_FILE',0x00000002)
		win_const_mgr.add_const('ERROR_EVT_INVALID_EVENT_DATA',0x00003A9D)
		win_const_mgr.add_const('PSH_NOMARGIN',0x10000000)
		win_const_mgr.add_const('LDAP_INVALID_RES',0x00000000)
		win_const_mgr.add_const('BSIS_NOCAPTION',0x00000040)
		win_const_mgr.add_const('ERROR_CONTENT_BLOCKED',0x00000510)
		win_const_mgr.add_const('SQL_PARC_BATCH',0x00000001)
		win_const_mgr.add_const('INTERNET_CACHE_CONTAINER_RESERVED1',0x00000004)
		win_const_mgr.add_const('ERROR_TIMER_RESUME_IGNORED',0x000002D2)
		win_const_mgr.add_const('IF_TYPE_BGP_POLICY_ACCOUNTING',0x000000A2)
		win_const_mgr.add_const('ERROR_DS_SECURITY_ILLEGAL_MODIFY',0x000020E7)
		win_const_mgr.add_const('KDF_HASH_ALGORITHM',0x00000000)
		win_const_mgr.add_const('PERF_COUNTERSET_FLAG_HISTORY',0x00000008)
		win_const_mgr.add_const('KF_FLAG_NO_ALIAS',0x00001000)
		win_const_mgr.add_const('SQLIMAGE',0x00000022)
		win_const_mgr.add_const('WTS_EVENT_LOGON',0x00000020)
		win_const_mgr.add_const('DEBUG_OUTTYPE_NO_OFFSET',0x00000002)
		win_const_mgr.add_const('PFM_COLLAPSED',0x01000000)
		win_const_mgr.add_const('OID_WAN_HEADER_FORMAT',0x04010106)
		win_const_mgr.add_const('TXTLOG_COPYFILES',0x00000008)
		win_const_mgr.add_const('PIR_STATUS_MINIPORT_NORMAL',0x00000000)
		win_const_mgr.add_const('CM_DRP_LOWERFILTERS',0x00000013)
		win_const_mgr.add_const('VFN_LEN64',0x00000018)
		win_const_mgr.add_const('DBG_GPFAULT2',0x00000015)
		win_const_mgr.add_const('SSF_MAPNETDRVBUTTON',0x00001000)
		win_const_mgr.add_const('TRACE_USE_MSEC',0x00000004)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_SOURCE_INTERFACE_INDEX',0x00000100)
		win_const_mgr.add_const('TXFS_TRANSACTED_VERSION_UNCOMMITTED',0xFFFFFFFF)
		win_const_mgr.add_const('TVGN_FIRSTVISIBLE',0x00000005)
		win_const_mgr.add_const('VFT_DRV',0x00000003)
		win_const_mgr.add_const('ERROR_INVALID_OPERATION',0x000010DD)
		win_const_mgr.add_const('ICC_UPDOWN_CLASS',0x00000010)
		win_const_mgr.add_const('MDPROPVAL_MSC_GREATERTHANEQUAL',0x00000008)
		win_const_mgr.add_const('WIA_PHOTO_WHITE_0',0x00000001)
		win_const_mgr.add_const('ERROR_EVT_MESSAGE_NOT_FOUND',0x00003AB3)
		win_const_mgr.add_const('IIS_MD_APPPOOL_BASE',0x00002328)
		win_const_mgr.add_const('DWM_BB_BLURREGION',0x00000002)
		win_const_mgr.add_const('SQL_SS_DELETIONS',0x00000002)
		win_const_mgr.add_const('PRINTER_STATUS_MANUAL_FEED',0x00000020)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_TREAT_AS_EXTERNAL',0x00000040)
		win_const_mgr.add_const('MAPIFORM_OS_WINNT_35',0x00000002)
		win_const_mgr.add_const('ERROR_TOO_MANY_SESS',0x00000045)
		win_const_mgr.add_const('CERT_STORE_SHARE_CONTEXT_FLAG',0x00000080)
		win_const_mgr.add_const('IPX_FILTERPTYPE',0x00004001)
		win_const_mgr.add_const('DRM_LICENSE_STATE_DATA_OPL_PRESENT',0x00000002)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_BASS',0x00004001)
		win_const_mgr.add_const('IMAGE_REL_IA64_GPREL32',0x0000001C)
		win_const_mgr.add_const('DE_E_CANNOT_CONNECT',0x800C0004)
		win_const_mgr.add_const('STOPBITS_20',0x00000004)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MINOR_OTHERDRIVER',0x00000000)
		win_const_mgr.add_const('SFVM_THISIDLIST',0x00000029)
		win_const_mgr.add_const('ISPH_FLG_INV',0x00000080)
		win_const_mgr.add_const('MD_DIRBROW_SHOW_SIZE',0x00000008)
		win_const_mgr.add_const('OID_PNP_REMOVE_WAKE_UP_PATTERN',0xFD010104)
		win_const_mgr.add_const('TAPE_DRIVE_LOG_BLK_IMMED',0x80008000)
		win_const_mgr.add_const('STATURL_QUERYFLAG_NOURL',0x00020000)
		win_const_mgr.add_const('USER_DONT_EXPIRE_PASSWORD',0x00000200)
		win_const_mgr.add_const('SV_INITFILETABLE_PARMNUM',0x00000221)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_START',0x00000001)
		win_const_mgr.add_const('ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR',0x00000316)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_REMOTE_SCOPE_ID',0x00020000)
		win_const_mgr.add_const('CDIS_SHOWKEYBOARDCUES',0x00000200)
		win_const_mgr.add_const('VK_HANJA',0x00000019)
		win_const_mgr.add_const('DSA_NEWOBJ_CTX_POSTCOMMIT',0x00000003)
		win_const_mgr.add_const('FOFX_NOCOPYHOOKS',0x00800000)
		win_const_mgr.add_const('FACILITY_IO_ERROR_CODE',0x00000004)
		win_const_mgr.add_const('WAB_ENABLE_PROFILES',0x00400000)
		win_const_mgr.add_const('PERFSTATE_POLICY_CHANGE_IDEAL',0x00000000)
		win_const_mgr.add_const('SERVICE_REDIR_DISK_PAUSED',0x00000100)
		win_const_mgr.add_const('DBPROPVAL_RD_RESETALL',0x00000000)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_LOG_NO_CONTAINER_COUNT_MAX',0x00000040)
		win_const_mgr.add_const('OQWF_SINGLESELECT',0x00000004)
		win_const_mgr.add_const('OFN_SHOWHELP',0x00000010)
		win_const_mgr.add_const('SHGNLI_NOUNIQUE',0x00000004)
		win_const_mgr.add_const('SSPROP_INIT_ENCRYPT',0x0000000D)
		win_const_mgr.add_const('DVD_STREAM_DATA_VTSM',0x00000401)
		win_const_mgr.add_const('PERF_DISPLAY_PERCENT',0x20000000)
		win_const_mgr.add_const('SPFILENOTIFY_TARGETNEWER',0x00040000)
		win_const_mgr.add_const('DYNAWIZ_FLAG_INSTALLDET_PREV',0x00000004)
		win_const_mgr.add_const('WM_INPUTLANGCHANGEREQUEST',0x00000050)
		win_const_mgr.add_const('RF_ROUTING',0x00000001)
		win_const_mgr.add_const('IMAGE_DEBUG_MISC_EXENAME',0x00000001)
		win_const_mgr.add_const('RTCIF_DISABLE_UPNP',0x00000002)
		win_const_mgr.add_const('ISC_RET_NULL_SESSION',0x00040000)
		win_const_mgr.add_const('PHONEINITIALIZEEXOPTION_USEEVENT',0x00000002)
		win_const_mgr.add_const('CAUSE_NETWORK_OUT_OF_ORDER',0x00000026)
		win_const_mgr.add_const('ERROR_DS_KEY_NOT_UNIQUE',0x0000214F)
		win_const_mgr.add_const('TMT_TRUESIZESTRETCHMARK',0x00000973)
		win_const_mgr.add_const('SP_COPY_FORCE_NOOVERWRITE',0x00001000)
		win_const_mgr.add_const('DISPID_TIMEPLAYLIST_ITEM',0x00000000)
		win_const_mgr.add_const('WMDRM_CERTIFICATE_TYPE_V2',0x00000002)
		win_const_mgr.add_const('DEBUG_CSS_UNLOADS',0x00000002)
		win_const_mgr.add_const('TXTBIT_SHOWACCELERATOR',0x00000008)
		win_const_mgr.add_const('WINHTTP_CALLBACK_FLAG_ALL_NOTIFICATIONS',0x00000000)
		win_const_mgr.add_const('ERROR_NO_LINK_TRACKING_IN_TRANSACTION',0x00001AC4)
		win_const_mgr.add_const('MD_DIRBROW_LONG_DATE',0x00000020)
		win_const_mgr.add_const('HTTP_QUERY_VARY',0x00000041)
		win_const_mgr.add_const('UOI_FLAGS',0x00000001)
		win_const_mgr.add_const('CBM_INIT',0x00000004)
		win_const_mgr.add_const('MCI_DGV_LIST_AUDIO_ALG',0x00004000)
		win_const_mgr.add_const('AM_GBF_PREVFRAMESKIPPED',0x00000001)
		win_const_mgr.add_const('DISABLE_DATA_BP_FIX',0x00000002)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_FORCEMEDIATOBECLOSED',0x0000010D)
		win_const_mgr.add_const('MAPI_E_UNKNOWN_RECIPIENT',0x0000000E)
		win_const_mgr.add_const('ALG_SID_SHA_384',0x0000000D)
		win_const_mgr.add_const('LINECALLSELECT_CALL',0x00000004)
		win_const_mgr.add_const('DATA_E_FIRST',0x80040130)
		win_const_mgr.add_const('DFCS_SCROLLLEFT',0x00000002)
		win_const_mgr.add_const('RPC_S_INVALID_ASYNC_CALL',0x0000077B)
		win_const_mgr.add_const('METADATA_PERMISSION_WRITE',0x00000002)
		win_const_mgr.add_const('WSAVERNOTSUPPORTED',0x0000276C)
		win_const_mgr.add_const('EWX_LOGOFF',0x00000000)
		win_const_mgr.add_const('HDFT_ISDATE',0x00000002)
		win_const_mgr.add_const('IPV6ADRESSLEN',0x00000040)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2__NEWENUM',0x00000481)
		win_const_mgr.add_const('MIB_INVALID_TEREDO_PORT_NUMBER',0x00000000)
		win_const_mgr.add_const('PORT_TYPE_REDIRECTED',0x00000004)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_TRANSPORT_ENDPOINT_HANDLE',0x00008000)
		win_const_mgr.add_const('LDAP_AUTH_SASL',0x00000083)
		win_const_mgr.add_const('DS_INSTANCETYPE_NC_GOING',0x00000020)
		win_const_mgr.add_const('PTE_NOCACHE',0x00000010)
		win_const_mgr.add_const('WAVE_FORMAT_4M08',0x00000100)
		win_const_mgr.add_const('PHONESTATE_SUSPEND',0x00040000)
		win_const_mgr.add_const('VER_SUITE_EMBEDDEDNT',0x00000040)
		win_const_mgr.add_const('SQL_CONVERT_TINYINT',0x00000044)
		win_const_mgr.add_const('DDOVER_HIDE',0x00000200)
		win_const_mgr.add_const('RPC_BUFFER_NONOTIFY',0x00010000)
		win_const_mgr.add_const('GIDC_REMOVAL',0x00000002)
		win_const_mgr.add_const('DNS_TYPE_UINFO',0x00000064)
		win_const_mgr.add_const('CFU_UNDERLINELONGDASH',0x0000000D)
		win_const_mgr.add_const('PSINJECT_BEGINPAGESETUP',0x00000065)
		win_const_mgr.add_const('MCI_VCR_STATUS_WRITE_PROTECTED',0x00004015)
		win_const_mgr.add_const('PDH_PLA_COLLECTION_ALREADY_RUNNING',0xC0000BE9)
		win_const_mgr.add_const('ERROR_INVALID_CRUNTIME_PARAMETER',0x00000508)
		win_const_mgr.add_const('VIF_DIFFLANG',0x00000008)
		win_const_mgr.add_const('D3DTSS_TCI_PASSTHRU',0x00000000)
		win_const_mgr.add_const('DISPID_BROWSEMODE',0x0000001A)
		win_const_mgr.add_const('ERROR_DS_SINGLE_VALUE_CONSTRAINT',0x00002081)
		win_const_mgr.add_const('ED_MIDDLE',0x00000002)
		win_const_mgr.add_const('LANG_BASHKIR',0x00000006)
		win_const_mgr.add_const('TKF_HOTKEYACTIVE',0x00000004)
		win_const_mgr.add_const('STATE_SYSTEM_OFFSCREEN',0x00010000)
		win_const_mgr.add_const('SCH_CRED_X509_CAPI',0x00000002)
		win_const_mgr.add_const('LOCALE_SABBREVCTRYNAME',0x00000007)
		win_const_mgr.add_const('HTTP_QUERY_IF_MODIFIED_SINCE',0x00000020)
		win_const_mgr.add_const('IDC_PS_DISPLAYLIST',0x000001F9)
		win_const_mgr.add_const('CBR_57600',0x0000E100)
		win_const_mgr.add_const('SMART_CYL_LOW',0x0000004F)
		win_const_mgr.add_const('ERROR_MAGAZINE_NOT_PRESENT',0x0000048B)
		win_const_mgr.add_const('CERT_MD5_HASH_PROP_ID',0x00000004)
		win_const_mgr.add_const('SMINIT_RESTRICT_DRAGDROP',0x00000002)
		win_const_mgr.add_const('RECO_DROP',0x00000001)
		win_const_mgr.add_const('CREDUIWIN_GENERIC',0x00000001)
		win_const_mgr.add_const('USER_UNITS_PER_WEEK_PARMNUM',0x00000013)
		win_const_mgr.add_const('IDC_IO_INSERTCONTROL',0x00000842)
		win_const_mgr.add_const('SDP_ATTRIB_BROWSE_GROUP_ID',0x00000200)
		win_const_mgr.add_const('MAPI_ORIG',0x00000000)
		win_const_mgr.add_const('TPR_MMI',0x00000010)
		win_const_mgr.add_const('SERVICE_CONTROL_DEVICEEVENT',0x0000000B)
		win_const_mgr.add_const('DRV_REMOVE',0x0000000A)
		win_const_mgr.add_const('IMGLOAD_LOADING',0x00200000)
		win_const_mgr.add_const('PSD_MARGINS',0x00000002)
		win_const_mgr.add_const('PHONESTATE_SPEAKERVOLUME',0x00002000)
		win_const_mgr.add_const('IPPORT_CHARGEN',0x00000013)
		win_const_mgr.add_const('ACTRL_AUDIT_SUCCESS',0x00000004)
		win_const_mgr.add_const('DPX_MAX_HASH_SIZE',0x00000040)
		win_const_mgr.add_const('CERTVIEW_CRYPTUI_LPARAM',0x00800000)
		win_const_mgr.add_const('LOCALE_SDECIMAL',0x0000000E)
		win_const_mgr.add_const('OCSP_BASIC_UNKNOWN_CERT_STATUS',0x00000002)
		win_const_mgr.add_const('CONFIGFLAG_IGNORE_BOOT_LC',0x00000008)
		win_const_mgr.add_const('SQL_FILE_NOT_SUPPORTED',0x00000000)
		win_const_mgr.add_const('DEBUG_CES_LOG_FILE',0x00000040)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_PREDICTIVEDIALER',0x00800000)
		win_const_mgr.add_const('TCS_FORCEICONLEFT',0x00000010)
		win_const_mgr.add_const('EVENT_S_FIRST',0x00040200)
		win_const_mgr.add_const('ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY',0x00001AA8)
		win_const_mgr.add_const('DVB_DIT_TID',0x0000007E)
		win_const_mgr.add_const('PLATFORM_INTEGRATED',0x00000002)
		win_const_mgr.add_const('UNION_CONSECUTIVE_ARMS',0x00000001)
		win_const_mgr.add_const('SHCNE_MEDIAREMOVED',0x00000040)
		win_const_mgr.add_const('CSVER_MAJOR_LONGHORN',0x00000003)
		win_const_mgr.add_const('SQL_ROWVER',0x00000002)
		win_const_mgr.add_const('ODBC_VS_FLAG_STOP',0x00000008)
		win_const_mgr.add_const('MM_MPU401_MIDIOUT',0x0000000A)
		win_const_mgr.add_const('BUFFLEN',0x000000FF)
		win_const_mgr.add_const('PCD_MAX_IO',0x00000002)
		win_const_mgr.add_const('OBJ_REGION',0x00000008)
		win_const_mgr.add_const('D3D10_PS_LEGACY_PIXEL_CENTER_FRACTIONAL_COMPONENT',0x00000000)
		win_const_mgr.add_const('SSL_SESSION_RECONNECT',0x00000001)
		win_const_mgr.add_const('MD_IMPORT_INHERITED',0x00000001)
		win_const_mgr.add_const('DIF_VALIDATEDRIVER',0x0000000D)
		win_const_mgr.add_const('SERVICE_ERROR_SEVERE',0x00000002)
		win_const_mgr.add_const('PDH_FILE_NOT_FOUND',0xC0000BD1)
		win_const_mgr.add_const('DFS_VOLUME_STATE_OFFLINE',0x00000003)
		win_const_mgr.add_const('BTH_MFG_IBM',0x00000003)
		win_const_mgr.add_const('IDC_IO_ADDCONTROL',0x00000843)
		win_const_mgr.add_const('LINEGENERATETERM_CANCEL',0x00000002)
		win_const_mgr.add_const('TC_SA_DOUBLE',0x00000040)
		win_const_mgr.add_const('PAN_BENT_ARMS_DOUBLE_SERIF',0x0000000B)
		win_const_mgr.add_const('WINSTA_EXITWINDOWS',0x00000040)
		win_const_mgr.add_const('VER_ERR_OFFSET',0x00000001)
		win_const_mgr.add_const('XA_HEURCOM',0x00000007)
		win_const_mgr.add_const('PRINTER_CHANGE_DELETE_PRINTER',0x00000004)
		win_const_mgr.add_const('CAL_SMONTHNAME5',0x00000019)
		win_const_mgr.add_const('RPC_NCA_FLAGS_DEFAULT',0x00000000)
		win_const_mgr.add_const('SECURITY_CONTEXT_TRACKING',0x00040000)
		win_const_mgr.add_const('WIA_IPS_XSCALING',0x00000C25)
		win_const_mgr.add_const('PID_INTSITE_FLAGS',0x00000009)
		win_const_mgr.add_const('MAXPNAMELEN',0x00000020)
		win_const_mgr.add_const('CDO_E_CONTENTPROPXML_NOT_FOUND',0x8004022D)
		win_const_mgr.add_const('HTTP_STATUS_CREATED',0x000000C9)
		win_const_mgr.add_const('IF_TYPE_FIBRECHANNEL',0x00000038)
		win_const_mgr.add_const('COD_FORMAT_BIT_OFFSET',0x00000000)
		win_const_mgr.add_const('NSPROTO_SPXII',0x000004E9)
		win_const_mgr.add_const('D3DVTXPCAPS_MATERIALSOURCE7',0x00000002)
		win_const_mgr.add_const('OID_ATM_MAX_ACTIVE_VPI_BITS',0x08010107)
		win_const_mgr.add_const('ENM_SCROLL',0x00000004)
		win_const_mgr.add_const('SPI_SETMINIMUMHITRADIUS',0x00002015)
		win_const_mgr.add_const('HH_GET_LAST_ERROR',0x00000014)
		win_const_mgr.add_const('SV_MINCLIENTBUFFERSIZE_PARMNUM',0x00000253)
		win_const_mgr.add_const('IDM_GROUP',0x00000014)
		win_const_mgr.add_const('MDPROPVAL_MNF_DRILLDOWNMEMBERTOP',0x00001000)
		win_const_mgr.add_const('DLCTL_NO_FRAMEDOWNLOAD',0x00001000)
		win_const_mgr.add_const('LANG_FRISIAN',0x00000062)
		win_const_mgr.add_const('DDCKEYCAPS_DESTOVERLAYCLRSPACEYUV',0x00000040)
		win_const_mgr.add_const('GIL_SHIELD',0x00000200)
		win_const_mgr.add_const('FPSR_RC2',0x00000024)
		win_const_mgr.add_const('SPDRP_FRIENDLYNAME',0x0000000C)
		win_const_mgr.add_const('BS_SPLITBUTTON',0x0000000C)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_FREESECTORSONMEDIA',0x00000105)
		win_const_mgr.add_const('VK_PACKET',0x000000E7)
		win_const_mgr.add_const('DSDSOF_SIMPLEAUTHENTICATE',0x00000002)
		win_const_mgr.add_const('CSBACKUP_TYPE_LOGS_ONLY',0x00000002)
		win_const_mgr.add_const('DN_ENUM_LOADED',0x00000004)
		win_const_mgr.add_const('MM_LOMETRIC',0x00000002)
		win_const_mgr.add_const('CRYPT_MODE_CBCOFM',0x00000009)
		win_const_mgr.add_const('MD_LOGCUSTOM_DATATYPE_INT',0x00000000)
		win_const_mgr.add_const('JOY_BUTTON12',0x00000800)
		win_const_mgr.add_const('JOY_BUTTON13',0x00001000)
		win_const_mgr.add_const('JOY_BUTTON10',0x00000200)
		win_const_mgr.add_const('JOY_BUTTON11',0x00000400)
		win_const_mgr.add_const('JOY_BUTTON16',0x00008000)
		win_const_mgr.add_const('CDEF_CLASS_DEFAULT',0x00000001)
		win_const_mgr.add_const('JOY_BUTTON14',0x00002000)
		win_const_mgr.add_const('JOY_BUTTON15',0x00004000)
		win_const_mgr.add_const('DTS_RIGHTALIGN',0x00000020)
		win_const_mgr.add_const('JOY_BUTTON18',0x00020000)
		win_const_mgr.add_const('JOY_BUTTON19',0x00040000)
		win_const_mgr.add_const('WMDM_STATUS_STORAGE_UNFORMATTED',0x00001000)
		win_const_mgr.add_const('HANDLE_PARAM_IS_RETURN',0x00000010)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_FLAG_CERT_DATE_INVALID',0x00000020)
		win_const_mgr.add_const('ERROR_LIBRARY_FULL',0x000010E2)
		win_const_mgr.add_const('CDEF_DEVMON_SELECTIVE_MASK',0x00000000)
		win_const_mgr.add_const('META_RECTANGLE',0x0000041B)
		win_const_mgr.add_const('CERT_FILTER_OP_NOT_EXISTS',0x00000002)
		win_const_mgr.add_const('SS_CENTER',0x00000001)
		win_const_mgr.add_const('CDO_E_INVALID_POST',0x80040214)
		win_const_mgr.add_const('PSR_SP',0x00000014)
		win_const_mgr.add_const('IDD_SERVERNOTFOUND',0x000003FF)
		win_const_mgr.add_const('CERT_CHAIN_REVOCATION_CHECK_CACHE_ONLY',0x80000000)
		win_const_mgr.add_const('NTDSCONN_KCC_OSCILLATING_CONNECTION_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('SCESTATUS_INVALID_PARAMETER',0x00000001)
		win_const_mgr.add_const('SCARD_E_NO_SERVICE',0x8010001D)
		win_const_mgr.add_const('ERROR_DBG_EXCEPTION_HANDLED',0x000002FE)
		win_const_mgr.add_const('ABM_SETPOS',0x00000003)
		win_const_mgr.add_const('WAM_MD_ID_BEGIN_RESERVED',0x00007500)
		win_const_mgr.add_const('DTR_CONTROL_ENABLE',0x00000001)
		win_const_mgr.add_const('LANG_FILIPINO',0x00000064)
		win_const_mgr.add_const('NI_COMPOSITIONSTR',0x00000015)
		win_const_mgr.add_const('PPP_LCP_DES_56',0x00000010)
		win_const_mgr.add_const('GPT_BASIC_DATA_ATTRIBUTE_NO_DRIVE_LETTER',0x8000000000000000)
		win_const_mgr.add_const('IF_TYPE_VOICE_OVERIP',0x00000068)
		win_const_mgr.add_const('OQWF_SHOWOPTIONAL',0x00000080)
		win_const_mgr.add_const('MAPI_E_ATTACHMENT_NOT_FOUND',0x0000000B)
		win_const_mgr.add_const('PROCESS_CREATE_PROCESS',0x00000080)
		win_const_mgr.add_const('MCI_SEQ_STATUS_NAME',0x0000400B)
		win_const_mgr.add_const('SPPSR_ENUM_BASIC_DEVICE_PROPERTIES',0x00000002)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_249',0x00000000)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_248',0x00000000)
		win_const_mgr.add_const('REO_NULL',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_AM_CALL32',0x00000003)
		win_const_mgr.add_const('FILE_DEVICE_CRYPT_PROVIDER',0x0000003F)
		win_const_mgr.add_const('DBIMF_BREAK',0x00000100)
		win_const_mgr.add_const('IF_NOLOCALICERTREQUEST',0x00000004)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_246',0x00000000)
		win_const_mgr.add_const('D3DPRESENT_INTERVAL_ONE',0x00000001)
		win_const_mgr.add_const('WINEVENT_OPCODE_RESERVED_243',0x00000000)
		win_const_mgr.add_const('SQL_CURSOR_STATIC',0x00000003)
		win_const_mgr.add_const('INTERNET_COOKIE_IS_RESTRICTED',0x00000200)
		win_const_mgr.add_const('ACM_MPEG_PRIVATEBIT',0x00000001)
		win_const_mgr.add_const('MCI_FORMAT_SMPTE_25',0x00000005)
		win_const_mgr.add_const('MCI_FORMAT_SMPTE_24',0x00000004)
		win_const_mgr.add_const('POWER_ACTION_QUERY_ALLOWED',0x00000001)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_UNDOFAILED',0x0000000F)
		win_const_mgr.add_const('PORT_NETSCPROD',0x0000009A)
		win_const_mgr.add_const('OID_802_3_XMIT_ONE_COLLISION',0x01020102)
		win_const_mgr.add_const('SQL_API_SQLPARAMOPTIONS',0x00000040)
		win_const_mgr.add_const('PLAL_ALERT_CMD_LINE_M_VAL',0x00002000)
		win_const_mgr.add_const('TXTLOG_UI',0x00000100)
		win_const_mgr.add_const('MDPROPVAL_MF_WITH_NAMEDSETS',0x00000002)
		win_const_mgr.add_const('MCI_WAVE_STATUS_BLOCKALIGN',0x00004005)
		win_const_mgr.add_const('RFCOMM_CMD_MSC',0x00000001)
		win_const_mgr.add_const('PIDASI_TIMELENGTH',0x00000003)
		win_const_mgr.add_const('DDBLT_DEPTHFILL',0x02000000)
		win_const_mgr.add_const('ELEMENT_STATUS_ACCESS',0x00000008)
		win_const_mgr.add_const('DVB_SDT_PID',0x00000011)
		win_const_mgr.add_const('VFF_BUFFTOOSMALL',0x00000004)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MAGFLINEAR',0x02000000)
		win_const_mgr.add_const('MSIM_DISPID_ONAPPSHUTDOWN',0x00000E12)
		win_const_mgr.add_const('URLPOLICY_NOTIFY_ON_ALLOW',0x00000010)
		win_const_mgr.add_const('CMSG_MAIL_LIST_HANDLE_KEY_CHOICE',0x00000001)
		win_const_mgr.add_const('WSASYSCALLFAILURE',0x0000277B)
		win_const_mgr.add_const('LINEERR_DIALVOICEDETECT',0x8000005C)
		win_const_mgr.add_const('EXECUTE_FLAG_IGNORE_APPPOOL',0x00000004)
		win_const_mgr.add_const('DICS_PROPCHANGE',0x00000003)
		win_const_mgr.add_const('DBPROPVAL_TR_ABORT',0x00000010)
		win_const_mgr.add_const('DXVA_PICTURE_DECODE_BUFFER',0x00000001)
		win_const_mgr.add_const('IDM_TRIED_COPY',0x0000001E)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_PREVIOUSTRACK',0x0000000C)
		win_const_mgr.add_const('SQL_FN_NUM_SIGN',0x00001000)
		win_const_mgr.add_const('SHTDN_REASON_MAJOR_OPERATINGSYSTEM',0x00020000)
		win_const_mgr.add_const('PROTO_IP_H323',0x0000271B)
		win_const_mgr.add_const('DXVA_PICTURE_RESAMPLE_FUNCTION',0x00000004)
		win_const_mgr.add_const('JOB_OBJECT_UI_VALID_FLAGS',0x000000FF)
		win_const_mgr.add_const('MAX_TAB_STOPS',0x00000020)
		win_const_mgr.add_const('OID_CO_SIGNALING_DISABLED',0xFE000009)
		win_const_mgr.add_const('DEBUG_DATA_SPACE_BUS_DATA',0x00000005)
		win_const_mgr.add_const('ILC_PALETTE',0x00000800)
		win_const_mgr.add_const('PID_NETWORKLOCATION',0x00000004)
		win_const_mgr.add_const('DB_SEARCHABLE',0x00000004)
		win_const_mgr.add_const('HTTP_QUERY_UNLESS_MODIFIED_SINCE',0x00000046)
		win_const_mgr.add_const('VOLUME_UPGRADE_SCHEDULED',0x00000002)
		win_const_mgr.add_const('SET_FEATURE_ON_THREAD_INTERNET',0x00000040)
		win_const_mgr.add_const('SCARD_WARM_RESET',0x00000002)
		win_const_mgr.add_const('WAVE_FORMAT_PCM',0x00000001)
		win_const_mgr.add_const('EC_ACTIVATE',0x00000013)
		win_const_mgr.add_const('BTH_MFG_MACRONIX_INTERNATIONAL',0x0000002C)
		win_const_mgr.add_const('D3D10_FTOI_INSTRUCTION_MAX_INPUT',0x7FFFFFFF)
		win_const_mgr.add_const('DBIF_VIEWMODE_TRANSPARENT',0x00000004)
		win_const_mgr.add_const('IDC_GP_OBJECTICON',0x000003F6)
		win_const_mgr.add_const('SET_BOUNDS',0x0000100D)
		win_const_mgr.add_const('DOT11_MAX_PDU_SIZE',0x0000092A)
		win_const_mgr.add_const('RES_FLUSH_CACHE',0x00000002)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_UNREACHABLE',0x00000002)
		win_const_mgr.add_const('DBDTF_RETURNINOUTBOUND',0x00000010)
		win_const_mgr.add_const('SECURITY_TERMINAL_SERVER_RID',0x0000000D)
		win_const_mgr.add_const('LC_MARKER',0x00000004)
		win_const_mgr.add_const('KP_CMS_KEY_INFO',0x00000025)
		win_const_mgr.add_const('DS_GC_SERVER_REQUIRED',0x00000040)
		win_const_mgr.add_const('ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT',0x00000249)
		win_const_mgr.add_const('TR_RV1',0x00000032)
		win_const_mgr.add_const('DSOP_FILTER_INCLUDE_ADVANCED_VIEW',0x00000001)
		win_const_mgr.add_const('STM_ORDER_BY_TYPE_AND_NAME',0x00000000)
		win_const_mgr.add_const('BI_BITFIELDS',0x00000003)
		win_const_mgr.add_const('SQL_FN_TD_SECOND',0x00001000)
		win_const_mgr.add_const('SUBLANG_SPANISH_MODERN',0x00000003)
		win_const_mgr.add_const('WM_CODEC_ONEPASS_CBR',0x00000001)
		win_const_mgr.add_const('ITSSFLAG_FLAGS_MASK',0x00000003)
		win_const_mgr.add_const('R2_NOTMASKPEN',0x00000008)
		win_const_mgr.add_const('SFVM_GETTOOLTIPTEXT',0x00000004)
		win_const_mgr.add_const('RTCAU_USE_LOGON_CRED',0x00010000)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2DATA_BUFFERUNDERRUNFREEDISABLED',0x00000101)
		win_const_mgr.add_const('CERT_STORE_CTRL_COMMIT',0x00000003)
		win_const_mgr.add_const('NWF_OPTIONAL_OID',0x00000002)
		win_const_mgr.add_const('NDIS_WMI_OUTPUT_INFO_REVISION_1',0x00000001)
		win_const_mgr.add_const('NETSETUP_ACCT_DELETE',0x00000004)
		win_const_mgr.add_const('SV_VISIBLE',0x00000000)
		win_const_mgr.add_const('WPD_CONTROL_FUNCTION_GENERIC_MESSAGE',0x00000042)
		win_const_mgr.add_const('CERT_ALT_NAME_VALUE_ERR_INDEX_SHIFT',0x00000000)
		win_const_mgr.add_const('COPYFLG_OVERWRITE_OLDER_ONLY',0x00000040)
		win_const_mgr.add_const('BTHNS_RESULT_DEVICE_AUTHENTICATED',0x00040000)
		win_const_mgr.add_const('SCRIPT_TAG_UNKNOWN',0x00000000)
		win_const_mgr.add_const('ODS_DISABLED',0x00000004)
		win_const_mgr.add_const('L2_PROFILE_MAX_NAME_LENGTH',0x00000100)
		win_const_mgr.add_const('META_SELECTCLIPREGION',0x0000012C)
		win_const_mgr.add_const('CLUS_ACCESS_ANY',0x00000000)
		win_const_mgr.add_const('MAC_CHARSET',0x0000004D)
		win_const_mgr.add_const('LOCALE_SDAYNAME7',0x00000030)
		win_const_mgr.add_const('SBN_FIRST',0x00000000)
		win_const_mgr.add_const('LAP_GIAC_VALUE',0x009E8B33)
		win_const_mgr.add_const('HTTP_QUERY_ECHO_HEADERS',0x00000049)
		win_const_mgr.add_const('ACM_DRIVERADDF_NOTIFYHWND',0x00000004)
		win_const_mgr.add_const('SQL_BS_SELECT_EXPLICIT',0x00000001)
		win_const_mgr.add_const('CSC_CACHE_VDO',0x00000020)
		win_const_mgr.add_const('PROP_ADDRESSES',0x00000100)
		win_const_mgr.add_const('IDS_CAP_SEQ_MSGSTOP',0x0000019B)
		win_const_mgr.add_const('ISC_SHOWUICANDIDATEWINDOW',0x00000001)
		win_const_mgr.add_const('PDERR_DEFAULTDIFFERENT',0x0000100C)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_MIN',0x00000000)
		win_const_mgr.add_const('D3DPBLENDCAPS_ZERO',0x00000001)
		win_const_mgr.add_const('DNS_OPCODE_SERVER_STATUS',0x00000002)
		win_const_mgr.add_const('CRED_LOGON_TYPES_MASK',0x0000F000)
		win_const_mgr.add_const('FILE_FLAG_BACKUP_SEMANTICS',0x02000000)
		win_const_mgr.add_const('L2_NOTIFICATION_SOURCE_NONE',0x00000000)
		win_const_mgr.add_const('PSR_RI_LEN',0x00000002)
		win_const_mgr.add_const('LF32_FIXED',0x00000001)
		win_const_mgr.add_const('GRADIENT_FILL_OP_FLAG',0x00000000)
		win_const_mgr.add_const('S_PT_CONFLICT_RESOLVED',0x00040002)
		win_const_mgr.add_const('DBPROP_INTERLEAVEDROWS',0x00000008)
		win_const_mgr.add_const('ALERTSZ',0x00000080)
		win_const_mgr.add_const('DBT_DEVICEREMOVEPENDING',0x00008003)
		win_const_mgr.add_const('HTTP_QUERY_PUBLIC',0x00000008)
		win_const_mgr.add_const('UM_SELTYPE_NORMALUSER',0x00000001)
		win_const_mgr.add_const('SFGAO_BROWSABLE',0x08000000)
		win_const_mgr.add_const('IDC_LP_MANUAL',0x000003F9)
		win_const_mgr.add_const('MDSP_SEEK_BOF',0x00000001)
		win_const_mgr.add_const('MIB_IPROUTE_TYPE_INDIRECT',0x00000004)
		win_const_mgr.add_const('MCHT_NOWHERE',0x00000000)
		win_const_mgr.add_const('ERROR_FOUND_OUT_OF_SCOPE',0x00000259)
		win_const_mgr.add_const('LINEERR_INVALAPPNAME',0x80000015)
		win_const_mgr.add_const('CM_RESDES_WIDTH_BITS',0x00000003)
		win_const_mgr.add_const('CWP_SKIPDISABLED',0x00000002)
		win_const_mgr.add_const('STAT_MISSING_RELDOC',0x00000400)
		win_const_mgr.add_const('ERROR_DS_DRA_PREEMPTED',0x0000210D)
		win_const_mgr.add_const('LANG_CHINESE_TRADITIONAL',0x00000007)
		win_const_mgr.add_const('CI_STATE_SHADOW_MERGE',0x00000001)
		win_const_mgr.add_const('LINECALLINFOSTATE_HIGHLEVELCOMP',0x00400000)
		win_const_mgr.add_const('WT_EXECUTEINWAITTHREAD',0x00000004)
		win_const_mgr.add_const('D3DPTADDRESSCAPS_BORDER',0x00000008)
		win_const_mgr.add_const('LOAD_LIBRARY_AS_DATAFILE',0x00000002)
		win_const_mgr.add_const('MCI_VCR_STATUS_SPEED',0x00004002)
		win_const_mgr.add_const('TF_IPPMF_FORSESSION',0x20000000)
		win_const_mgr.add_const('DN_LIAR',0x00000100)
		win_const_mgr.add_const('CAUSE_NORMAL_CALL_CLEARING',0x00000010)
		win_const_mgr.add_const('BOE_LEGACYBIDICLASS',0x00000040)
		win_const_mgr.add_const('XINPUT_CAPS_VOICE_SUPPORTED',0x00000004)
		win_const_mgr.add_const('MAINTENANCE_MODE_V2_SIG',0x00000000)
		win_const_mgr.add_const('DMPAPER_B5_TRANSVERSE',0x0000003E)
		win_const_mgr.add_const('WIA_TRANSFER_MSG_STATUS',0x00000001)
		win_const_mgr.add_const('GCS_COMPATTR',0x00000010)
		win_const_mgr.add_const('SKF_RALTLATCHED',0x20000000)
		win_const_mgr.add_const('PSR_I',0x0000000E)
		win_const_mgr.add_const('ERROR_UNABLE_TO_UNLOAD_MEDIA',0x00000455)
		win_const_mgr.add_const('ILDI_STANDBY',0x00000002)
		win_const_mgr.add_const('INTERNET_STATUS_PRIVACY_IMPACTED',0x00000144)
		win_const_mgr.add_const('SC_HSCROLL',0x0000F080)
		win_const_mgr.add_const('SQL_SUCCESS_WITH_INFO',0x00000001)
		win_const_mgr.add_const('VCSTATUS_PREV',0x00000002)
		win_const_mgr.add_const('GESTURE_BRACE_RIGHT',0x00000000)
		win_const_mgr.add_const('WLX_SAS_TYPE_MAX_MSFT_VALUE',0x0000007F)
		win_const_mgr.add_const('SV_MINRCVQUEUE_PARMNUM',0x00000211)
		win_const_mgr.add_const('D3DPMISCCAPS_CLIPTLVERTS',0x00000200)
		win_const_mgr.add_const('CRYPT_X942_COUNTER_BYTE_LENGTH',0x00000004)
		win_const_mgr.add_const('USER_MARSHAL_FC_LONG',0x00000008)
		win_const_mgr.add_const('IDM_CONTEXTMENU',0x000008E8)
		win_const_mgr.add_const('VDS_REBUILD_PRIORITY_MAX',0x00000010)
		win_const_mgr.add_const('RPC_S_UNSUPPORTED_TRANS_SYN',0x000006C2)
		win_const_mgr.add_const('DSBID_BANNER',0x00000100)
		win_const_mgr.add_const('HEAP_TAIL_CHECKING_ENABLED',0x00000020)
		win_const_mgr.add_const('X3_P_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('MD_ACCESS_NO_REMOTE_WRITE',0x00000400)
		win_const_mgr.add_const('D3D10_MAX_DEPTH',0x00000001)
		win_const_mgr.add_const('INTERNET_MAX_PORT_NUMBER_VALUE',0x0000FFFF)
		win_const_mgr.add_const('DB_DISP_CA_CERT',0x0000000F)
		win_const_mgr.add_const('DCI_DWORDSIZE',0x00000080)
		win_const_mgr.add_const('MAPIFORM_CPU_PPC',0x00000004)
		win_const_mgr.add_const('DISPID_ADVANCEERROR',0x0000000A)
		win_const_mgr.add_const('CSIDL_RESOURCES_LOCALIZED',0x00000039)
		win_const_mgr.add_const('SUBSCRIPTION_V1_CAPS',0x0000000F)
		win_const_mgr.add_const('DIIRFLAG_FORCE_INF',0x00000002)
		win_const_mgr.add_const('ERROR_INVALID_UNWIND_TARGET',0x00000220)
		win_const_mgr.add_const('JS_FAILED',0x00000004)
		win_const_mgr.add_const('HDF_RIGHT',0x00000001)
		win_const_mgr.add_const('SQL_SC_UNIQUE',0x00000002)
		win_const_mgr.add_const('DXVA_PICTURE_STRUCTURE_FRAME',0x00000003)
		win_const_mgr.add_const('GESTURE_LEFT_ARROW_UP',0x00000000)
		win_const_mgr.add_const('SERKF_SERIALKEYSON',0x00000001)
		win_const_mgr.add_const('FTPWPP_ERROR_AUTHENTICATION_FAILED',0xC0042302)
		win_const_mgr.add_const('VOLUME_NAME_NT',0x00000002)
		win_const_mgr.add_const('LINECALLFEATURE2_COMPLCAMPON',0x00000004)
		win_const_mgr.add_const('RSC_BE_LITTLE',0x00000000)
		win_const_mgr.add_const('IDD_DYNAWIZ_ANALYZEDEV_PAGE',0x0000271A)
		win_const_mgr.add_const('ODBC_ERROR_OUT_OF_MEM',0x00000015)
		win_const_mgr.add_const('GESTURE_QUESTION',0x00000000)
		win_const_mgr.add_const('CONFIGFLAG_REMOVED',0x00000002)
		win_const_mgr.add_const('IPPORT_LOGINSERVER',0x00000201)
		win_const_mgr.add_const('ERROR_NO_MORE_DEVICES',0x000004E0)
		win_const_mgr.add_const('PHONESTATE_REMOVED',0x00800000)
		win_const_mgr.add_const('EVENPARITY',0x00000002)
		win_const_mgr.add_const('DRM_EL_EXPIRED',0x00001000)
		win_const_mgr.add_const('WMDM_SCP_NO_MORE_CHANGES',0x00000040)
		win_const_mgr.add_const('IP_ADD_MEMBERSHIP',0x0000000C)
		win_const_mgr.add_const('IME_CMODE_ROMAN',0x00000010)
		win_const_mgr.add_const('DRAGDROP_E_FIRST',0x80040100)
		win_const_mgr.add_const('PP_ENUMMANDROOTS',0x00000019)
		win_const_mgr.add_const('VK_OEM_1',0x000000BA)
		win_const_mgr.add_const('IPP_E_COLLECTIONEXISTS',0xC004800E)
		win_const_mgr.add_const('CBR_56000',0x0000DAC0)
		win_const_mgr.add_const('ES_MULTILINE',0x00000004)
		win_const_mgr.add_const('AE_ADMINPRIVREQD',0x00000002)
		win_const_mgr.add_const('SHOW_ICONWINDOW',0x00000002)
		win_const_mgr.add_const('FILE_DEVICE_NETWORK_BROWSER',0x00000013)
		win_const_mgr.add_const('PDH_UNMATCHED_APPEND_COUNTER',0xC0000BFC)
		win_const_mgr.add_const('SCESTATUS_BAD_FORMAT',0x00000007)
		win_const_mgr.add_const('HEBREW_CHARSET',0x000000B1)
		win_const_mgr.add_const('PFS_SIZE_MASK',0x0000007F)
		win_const_mgr.add_const('DMBIN_ENVMANUAL',0x00000006)
		win_const_mgr.add_const('CSRESTORE_TYPE_FULL',0x00000001)
		win_const_mgr.add_const('CDRF_NOTIFYITEMDRAW',0x00000020)
		win_const_mgr.add_const('DE_E_UNKNOWN_PROTOCOL',0x800C000D)
		win_const_mgr.add_const('PD_COLLATE',0x00000010)
		win_const_mgr.add_const('SQLDECIMALN',0x00000006)
		win_const_mgr.add_const('SUBLANG_QUECHUA_PERU',0x00000003)
		win_const_mgr.add_const('CRYPTPROTECT_NO_RECOVERY',0x00000020)
		win_const_mgr.add_const('PRINTER_ENUM_NAME',0x00000008)
		win_const_mgr.add_const('EMR_RESERVED_120',0x00000078)
		win_const_mgr.add_const('EMR_GLSBOUNDEDRECORD',0x00000067)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_OBJECTS',0x00000001)
		win_const_mgr.add_const('CLRRTS',0x00000004)
		win_const_mgr.add_const('DDBLTFAST_DESTCOLORKEY',0x00000002)
		win_const_mgr.add_const('MOUSETRAILS',0x00000027)
		win_const_mgr.add_const('IF_NOREMOTEICERTREQUEST',0x00000002)
		win_const_mgr.add_const('DMDITHER_NONE',0x00000001)
		win_const_mgr.add_const('DDSD_BACKBUFFERCOUNT',0x00000020)
		win_const_mgr.add_const('LDAP_OPT_CLIENT_CERTIFICATE',0x00000080)
		win_const_mgr.add_const('ATE_MASK',0xFFFFFFFFFFFFF9DE)
		win_const_mgr.add_const('DCM_FLAGS_TASKENG',0x00000001)
		win_const_mgr.add_const('MAPIFORM_EXACTMATCH',0x00000020)
		win_const_mgr.add_const('MSCS_MD_ID_END_RESERVED',0x00000000)
		win_const_mgr.add_const('ERROR_VDM_DISALLOWED',0x00000506)
		win_const_mgr.add_const('DMICMMETHOD_DRIVER',0x00000003)
		win_const_mgr.add_const('IDM_AUTODETECT',0x00000919)
		win_const_mgr.add_const('SQL_QL_START',0x00000001)
		win_const_mgr.add_const('FNERR_FILENAMECODES',0x00003000)
		win_const_mgr.add_const('OPTION_PMTU_PLATEAU_TABLE',0x00000019)
		win_const_mgr.add_const('ICM_CHECK_COLOR_MODE',0x00000004)
		win_const_mgr.add_const('SSRVOPT_GUIDPTR',0x00000008)
		win_const_mgr.add_const('WAB_DISPLAY_LDAPURL',0x00000001)
		win_const_mgr.add_const('FILE_DEVICE_SMB',0x00000002)
		win_const_mgr.add_const('COLOR_CURRENT',0x000002C5)
		win_const_mgr.add_const('MSV1_0_VALIDATION_KICKOFF_TIME',0x00000002)
		win_const_mgr.add_const('DCX_EXCLUDEUPDATE',0x00000100)
		win_const_mgr.add_const('SECPKG_ATTR_SESSION_KEY',0x00000009)
		win_const_mgr.add_const('IKEEXT_POLICY_FLAG_DISABLE_DIAGNOSTICS',0x00000001)
		win_const_mgr.add_const('CERT_RDN_UNIVERSAL_STRING',0x0000000B)
		win_const_mgr.add_const('DBT_DEVNODES_CHANGED',0x00000007)
		win_const_mgr.add_const('SAC_CERT_X509',0x00000001)
		win_const_mgr.add_const('DXVA_USUAL_BLOCK_HEIGHT',0x00000008)
		win_const_mgr.add_const('CM_LOCATE_DEVNODE_BITS',0x00000007)
		win_const_mgr.add_const('NDIS_ENCAPSULATION_IEEE_LLC_SNAP_ROUTED',0x00000010)
		win_const_mgr.add_const('ERROR_PREDEFINED_HANDLE',0x000002CA)
		win_const_mgr.add_const('AE_SESSPWERR',0x00000003)
		win_const_mgr.add_const('IF_TYPE_ISO88025R_DTR',0x00000056)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_KE',0x00003609)
		win_const_mgr.add_const('RR_RID',0x00000008)
		win_const_mgr.add_const('DIRID_DRIVERS',0x0000000C)
		win_const_mgr.add_const('WININET_API_FLAG_SYNC',0x00000004)
		win_const_mgr.add_const('SECURITY_EFFECTIVE_ONLY',0x00080000)
		win_const_mgr.add_const('SAFER_LEVELID_UNTRUSTED',0x00001000)
		win_const_mgr.add_const('MAX_REASON_DESC_LEN',0x00000100)
		win_const_mgr.add_const('FRS_ERR_INTERNAL',0x00001F45)
		win_const_mgr.add_const('ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND',0x000032D9)
		win_const_mgr.add_const('EDITF_EMAILOPTIONAL',0x00020000)
		win_const_mgr.add_const('ERROR_EFS_VERSION_NOT_SUPPORT',0x00001780)
		win_const_mgr.add_const('SYMF_VIRTUAL',0x00001000)
		win_const_mgr.add_const('SUBLANG_GERMAN_AUSTRIAN',0x00000003)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_OBJECT_NAME_WIDE',0x00000005)
		win_const_mgr.add_const('VER_PRODUCTVERSION_W',0x00000600)
		win_const_mgr.add_const('AVI_INDEX_IS_DATA',0x00000080)
		win_const_mgr.add_const('GIDC_ARRIVAL',0x00000001)
		win_const_mgr.add_const('WINHTTP_OPTION_GLOBAL_SERVER_CREDS',0x00000062)
		win_const_mgr.add_const('CSIDL_DESKTOPDIRECTORY',0x00000010)
		win_const_mgr.add_const('IMAGE_REL_IA64_IMM64',0x00000003)
		win_const_mgr.add_const('LOCALE_SABBREVDAYNAME4',0x00000034)
		win_const_mgr.add_const('IDOK',0x00000001)
		win_const_mgr.add_const('LOCALE_SABBREVDAYNAME3',0x00000033)
		win_const_mgr.add_const('WMS_SEEK_TO_IFRAME',0x00000001)
		win_const_mgr.add_const('SECPKG_FLAG_ASCII_BUFFERS',0x00004000)
		win_const_mgr.add_const('PFNS_NONUMBER',0x00000400)
		win_const_mgr.add_const('MD_ERROR_SUB502_PREMATURE_EXIT',0x00000002)
		win_const_mgr.add_const('EDS_ROTATEDMODE',0x00000004)
		win_const_mgr.add_const('ISR_RS',0x00000025)
		win_const_mgr.add_const('LOGON_GUEST',0x00000001)
		win_const_mgr.add_const('ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND',0x00000BC8)
		win_const_mgr.add_const('SES_NOINPUTSEQUENCECHK',0x00000800)
		win_const_mgr.add_const('PERCEIVEDFLAG_SOFTCODED',0x00000001)
		win_const_mgr.add_const('NCRYPT_MAX_PROPERTY_NAME',0x00000040)
		win_const_mgr.add_const('SP_COPY_IN_USE_NEEDS_REBOOT',0x00000100)
		win_const_mgr.add_const('PC_INTERIORS',0x00000080)
		win_const_mgr.add_const('DISPID_NAMESPARAM_NAMES',0x00000001)
		win_const_mgr.add_const('FWP_CONDITION_FLAG_IS_RAW_ENDPOINT',0x00000010)
		win_const_mgr.add_const('TASK_FLAG_RESTART_ON_IDLE_RESUME',0x00000800)
		win_const_mgr.add_const('ALG_CLASS_ALL',0x00000007)
		win_const_mgr.add_const('SV_ENABLERAW_PARMNUM',0x0000021B)
		win_const_mgr.add_const('DRM_OPL_TYPES',0x00000001)
		win_const_mgr.add_const('D3DTA_CURRENT',0x00000001)
		win_const_mgr.add_const('TRUST_TYPE_DOWNLEVEL',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY',0x00003610)
		win_const_mgr.add_const('TRACELOG_ACCESS_KERNEL_LOGGER',0x00000100)
		win_const_mgr.add_const('MSV1_0_SUBAUTH_LOGON_HOURS',0x00000008)
		win_const_mgr.add_const('DS_REPSYNCALL_CROSS_SITE_BOUNDARIES',0x00000040)
		win_const_mgr.add_const('DDFXCAPS_OVERLAYALPHA',0x00000004)
		win_const_mgr.add_const('DISPID_CUSTOMIZECLEARTYPE',0x00000017)
		win_const_mgr.add_const('CERT_AUTHORITY_INFO_ACCESS_PROP_ID',0x00000044)
		win_const_mgr.add_const('IMAGE_SIZEOF_ARCHIVE_MEMBER_HDR',0x0000003C)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_FOREST_TRANSITIVE',0x00000008)
		win_const_mgr.add_const('PAN_MIDLINE_LOW_SERIFED',0x0000000D)
		win_const_mgr.add_const('PXE_PROV_FILTER_PXE_ONLY',0x00000002)
		win_const_mgr.add_const('GW_HWNDLAST',0x00000001)
		win_const_mgr.add_const('RPC_C_AUTHN_LEVEL_PKT',0x00000004)
		win_const_mgr.add_const('FOCUSMODE_MACROAUTO',0x00000003)
		win_const_mgr.add_const('CSBACKUP_DISABLE_INCREMENTAL',0x00000000)
		win_const_mgr.add_const('PFM_KEEPNEXT',0x00040000)
		win_const_mgr.add_const('OID_802_5_LOST_FRAMES',0x02020102)
		win_const_mgr.add_const('OID_PNP_WAKE_UP_PATTERN_LIST',0xFD010105)
		win_const_mgr.add_const('TMT_ENUM',0x000000C8)
		win_const_mgr.add_const('ERROR_DS_DOMAIN_RENAME_IN_PROGRESS',0x000021A4)
		win_const_mgr.add_const('CDS_ENABLE_UNSAFE_MODES',0x00000100)
		win_const_mgr.add_const('ERROR_BAD_VALIDATION_CLASS',0x00000544)
		win_const_mgr.add_const('BACKGROUND_INTENSITY',0x00000080)
		win_const_mgr.add_const('DIRID_COMMON_FAVORITES',0x0000401F)
		win_const_mgr.add_const('DFS_PROPERTY_FLAG_ROOT_SCALABILITY',0x00000002)
		win_const_mgr.add_const('CI_STATE_USER_ACTIVE',0x00001000)
		win_const_mgr.add_const('LDAP_RES_REFERRAL',0x00000073)
		win_const_mgr.add_const('FD_ADDRESS_LIST_CHANGE',0x00000001)
		win_const_mgr.add_const('EVENT_SYSTEM_CAPTURESTART',0x00000008)
		win_const_mgr.add_const('NTDDI_WIN2K',0x05000000)
		win_const_mgr.add_const('SPI_GETCURSORSHADOW',0x0000101A)
		win_const_mgr.add_const('SB_PAGELEFT',0x00000002)
		win_const_mgr.add_const('EMR_GDICOMMENT',0x00000046)
		win_const_mgr.add_const('NFS_LISTCOMBO',0x00000004)
		win_const_mgr.add_const('TVC_BYKEYBOARD',0x00000002)
		win_const_mgr.add_const('IPPORT_DYNAMIC_MIN',0x00000000)
		win_const_mgr.add_const('MUI_MERGE_SYSTEM_FALLBACK',0x00000010)
		win_const_mgr.add_const('RPC_QUERY_CLIENT_PID',0x00000010)
		win_const_mgr.add_const('MB_SERVICE_NOTIFICATION_NT3X',0x00040000)
		win_const_mgr.add_const('WAVE_FILTER_UNKNOWN',0x00000000)
		win_const_mgr.add_const('ISDB_LIT_TID',0x000000D0)
		win_const_mgr.add_const('LVCFMT_BITMAP_ON_RIGHT',0x00001000)
		win_const_mgr.add_const('SECPKG_CRED_OUTBOUND',0x00000002)
		win_const_mgr.add_const('ERR_DAMAGED_FILE',0xE000000C)
		win_const_mgr.add_const('RI_KEY_TERMSRV_SHADOW',0x00000010)
		win_const_mgr.add_const('OPTION_LEASE_TIME',0x00000033)
		win_const_mgr.add_const('PRODUCT_ID_LENGTH',0x00000010)
		win_const_mgr.add_const('DSB_MAX_DISPLAYNAME_CHARS',0x00000040)
		win_const_mgr.add_const('PST_PC_PFX',0x00000001)
		win_const_mgr.add_const('ISC_REQ_NULL_SESSION',0x00040000)
		win_const_mgr.add_const('MCI_ANIM_UPDATE_HDC',0x00020000)
		win_const_mgr.add_const('TPM_NONOTIFY',0x00000080)
		win_const_mgr.add_const('D3DTA_CONSTANT',0x00000006)
		win_const_mgr.add_const('NTM_NONNEGATIVE_AC',0x00010000)
		win_const_mgr.add_const('DEX_IDS_CANT_FIND_FILTER',0x0000058A)
		win_const_mgr.add_const('IMAGE_SIZEOF_SHORT_NAME',0x00000008)
		win_const_mgr.add_const('SM_CXSIZE',0x0000001E)
		win_const_mgr.add_const('DNS_RTYPE_ALL',0x00000000)
		win_const_mgr.add_const('SQL_API_SQLFETCH',0x0000000D)
		win_const_mgr.add_const('ERROR_USER_DEFINED_BASE',0x0000F000)
		win_const_mgr.add_const('DEX_IDS_INVALID_XML',0x00000589)
		win_const_mgr.add_const('REGDF_NEEDFULLCONFIG',0x00000010)
		win_const_mgr.add_const('FLG_BITREG_CLEARBITS',0x00000000)
		win_const_mgr.add_const('VK_NEXT',0x00000022)
		win_const_mgr.add_const('IF_TYPE_TRANSPHDLC',0x0000007B)
		win_const_mgr.add_const('META_DELETEOBJECT',0x00000001)
		win_const_mgr.add_const('ERROR_CTX_NOT_CONSOLE',0x00001B7E)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_TRANSFER',0x00000002)
		win_const_mgr.add_const('CREATE_IGNORE_SYSTEM_DEFAULT',0x80000000)
		win_const_mgr.add_const('SQL_CA2_MAX_ROWS_UPDATE',0x00000400)
		win_const_mgr.add_const('TBSTYLE_GROUP',0x00000004)
		win_const_mgr.add_const('MAPI_E_TOO_MANY_FILES',0x00000009)
		win_const_mgr.add_const('DVD_DEFAULT_AUDIO_STREAM',0x00000000)
		win_const_mgr.add_const('PDERR_PRINTERNOTFOUND',0x0000100B)
		win_const_mgr.add_const('HHWIN_BUTTON_FAVORITES',0x00000001)
		win_const_mgr.add_const('RTCEF_PRESENCE_DATA',0x00800000)
		win_const_mgr.add_const('MQ_SEND_ACCESS',0x00000002)
		win_const_mgr.add_const('CERT_FIND_VALID_ENHKEY_USAGE_FLAG',0x00000020)
		win_const_mgr.add_const('NDIS_OFFLOAD_NOT_SUPPORTED',0x00000000)
		win_const_mgr.add_const('OFN_CREATEPROMPT',0x00002000)
		win_const_mgr.add_const('SQL_IC_SENSITIVE',0x00000003)
		win_const_mgr.add_const('IDC_LP_DATE',0x000003FA)
		win_const_mgr.add_const('USN_REASON_TRANSACTED_CHANGE',0x00400000)
		win_const_mgr.add_const('LVGF_ITEMS',0x00004000)
		win_const_mgr.add_const('NUMPRS_USE_ALL',0x00001000)
		win_const_mgr.add_const('SQL_SQL92_GRANT',0x0000009E)
		win_const_mgr.add_const('MC_SUPPORTED_COLOR_TEMPERATURE_7500K',0x00000008)
		win_const_mgr.add_const('CCS_NODIVIDER',0x00000040)
		win_const_mgr.add_const('NI_SELECTCANDIDATESTR',0x00000012)
		win_const_mgr.add_const('MEM_MAPPED',0x00040000)
		win_const_mgr.add_const('DOSOPTF_NEEDSETUP',0x00000020)
		win_const_mgr.add_const('D3DPS20_MIN_NUMTEMPS',0x0000000C)
		win_const_mgr.add_const('LVS_NOLABELWRAP',0x00000080)
		win_const_mgr.add_const('IDF_OEMDISK',0x80000000)
		win_const_mgr.add_const('RSVP_RESV_TEAR',0x00000006)
		win_const_mgr.add_const('CM_NO_NAMECHANGE',0x00000040)
		win_const_mgr.add_const('INVALID_CONNECTION_ID',0x00000000)
		win_const_mgr.add_const('PHOTOACQ_RUN_DEFAULT',0x00000000)
		win_const_mgr.add_const('CCS_TOP',0x00000001)
		win_const_mgr.add_const('ERROR_THREAD_WAS_SUSPENDED',0x000002BB)
		win_const_mgr.add_const('DDCAPS_BANKSWITCHED',0x08000000)
		win_const_mgr.add_const('CRYPT_EXPORT_KEY',0x00000040)
		win_const_mgr.add_const('WINDOWS_VERSION_WIN32',0x00000003)
		win_const_mgr.add_const('WM_INPUT_DEVICE_CHANGE',0x000000FE)
		win_const_mgr.add_const('KEYSTATEBLOB',0x0000000C)
		win_const_mgr.add_const('SE_ERR_NOASSOC',0x0000001F)
		win_const_mgr.add_const('MQMSG_PRIV_LEVEL_BODY_BASE',0x00000001)
		win_const_mgr.add_const('EM_GETLINECOUNT',0x000000BA)
		win_const_mgr.add_const('SQL_UPDATE_BY_BOOKMARK',0x00000005)
		win_const_mgr.add_const('COD_COMPUTER_MINOR_WEARABLE',0x00000006)
		win_const_mgr.add_const('RTCMT_VIDEO_RECEIVE',0x00000008)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_STARTOFNEXTSESSION',0x00000103)
		win_const_mgr.add_const('ERROR_CHILD_ALIVE_NOWAIT',0x000000B9)
		win_const_mgr.add_const('INSTALLFLAG_BITS',0x00000007)
		win_const_mgr.add_const('IPN_LAST',0x00000000)
		win_const_mgr.add_const('WIA_DPC_BATTERY_STATUS',0x00000811)
		win_const_mgr.add_const('D3DLOCK_READONLY',0x00000010)
		win_const_mgr.add_const('SV_MINPAGEDPOOLCHUNKSIZE_PARMNUM',0x00000247)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_ADMINS',0x00000220)
		win_const_mgr.add_const('LANG_KINYARWANDA',0x00000087)
		win_const_mgr.add_const('ERROR_ATOMIC_LOCKS_NOT_SUPPORTED',0x000000AE)
		win_const_mgr.add_const('DS_WRITABLE_REQUIRED',0x00001000)
		win_const_mgr.add_const('CRYPT_STRING_BASE64',0x00000001)
		win_const_mgr.add_const('ERROR_ICM_NOT_ENABLED',0x000007E2)
		win_const_mgr.add_const('MD_ERROR_CANNOT_REMOVE_SECURE_ATTRIBUTE',0x800CC808)
		win_const_mgr.add_const('CDO_E_NNTP_POST_FAILED',0x80040210)
		win_const_mgr.add_const('PIDASI_SAMPLE_RATE',0x00000005)
		win_const_mgr.add_const('CABINETSTATE_VERSION',0x00000002)
		win_const_mgr.add_const('CERT_PHYSICAL_STORE_ADD_ENABLE_FLAG',0x00000001)
		win_const_mgr.add_const('NCBDGSEND',0x00000020)
		win_const_mgr.add_const('PSNRET_NOERROR',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_EBC_SECTION',0x00000003)
		win_const_mgr.add_const('CMSG_SIGNED_DATA_V3',0x00000003)
		win_const_mgr.add_const('FMEVENT_UNLOAD',0x00000065)
		win_const_mgr.add_const('SECPKG_ATTR_AUTHORITY',0x00000006)
		win_const_mgr.add_const('PDH_OBJECT_HAS_INSTANCES',0x00000001)
		win_const_mgr.add_const('KSDEVICE_FLAG_ENABLE_REMOTE_WAKEUP',0x00000001)
		win_const_mgr.add_const('DMBIN_ENVELOPE',0x00000005)
		win_const_mgr.add_const('QOS_QUERYFLOW_FRESH',0x00000001)
		win_const_mgr.add_const('MM_WOM_DONE',0x000003BD)
		win_const_mgr.add_const('WPF_FORCE_BIND',0x00000100)
		win_const_mgr.add_const('DSBI_SIMPLEAUTHENTICATE',0x00800000)
		win_const_mgr.add_const('MCI_VD_SPIN_DOWN',0x00020000)
		win_const_mgr.add_const('BACKUP_PROPERTY_DATA',0x00000006)
		win_const_mgr.add_const('SQL_CODE_TIMESTAMP',0x00000003)
		win_const_mgr.add_const('IMAGE_REL_SHM_RELLO',0x00000016)
		win_const_mgr.add_const('IMF_AUTOKEYBOARD',0x00000001)
		win_const_mgr.add_const('LVIS_ACTIVATING',0x00000020)
		win_const_mgr.add_const('D3DSP_DCL_USAGE_MASK',0x00000000)
		win_const_mgr.add_const('NDIS_PROT_OPTION_NO_LOOPBACK',0x00000002)
		win_const_mgr.add_const('SQL_NC_LOW',0x00000001)
		win_const_mgr.add_const('ERROR_PWD_TOO_SHORT',0x00000267)
		win_const_mgr.add_const('SQL_API_SQLDRIVERCONNECT',0x00000029)
		win_const_mgr.add_const('TMT_TOHUE3',0x00000710)
		win_const_mgr.add_const('IDM_MIMECSET__LAST__',0x00000E73)
		win_const_mgr.add_const('IMAGE_REL_ARM_SECREL',0x0000000F)
		win_const_mgr.add_const('LINETERMMODE_MEDIATOLINE',0x00000020)
		win_const_mgr.add_const('ARCONTENT_PHASE_SNIFFING',0x20000000)
		win_const_mgr.add_const('PSH_WIZARD',0x00000020)
		win_const_mgr.add_const('SP_COPY_FORCE_IN_USE',0x00000200)
		win_const_mgr.add_const('FVSIF_NEWFAILED',0x08000000)
		win_const_mgr.add_const('VER_ERR_ITEM_2',0x00000100)
		win_const_mgr.add_const('DDPF_BUMPDUDV',0x00080000)
		win_const_mgr.add_const('SRRF_RM_SAFENETWORK',0x00040000)
		win_const_mgr.add_const('MAPI_E_TEXT_TOO_LARGE',0x00000012)
		win_const_mgr.add_const('SHUTDOWN_NORETRY',0x00000001)
		win_const_mgr.add_const('NDIS_802_11_AI_REQFI_CAPABILITIES',0x00000001)
		win_const_mgr.add_const('PDH_PATH_WBEM_RESULT',0x00000001)
		win_const_mgr.add_const('EVENT_SYSTEM_SWITCHSTART',0x00000014)
		win_const_mgr.add_const('PROPCALLER_REQUEST',0x00000500)
		win_const_mgr.add_const('RAS_EAP_FLAG_RESERVED',0x00100000)
		win_const_mgr.add_const('REG_DWORD_BIG_ENDIAN',0x00000005)
		win_const_mgr.add_const('ALG_SID_PCT1_MASTER',0x00000004)
		win_const_mgr.add_const('DC_BINS',0x00000006)
		win_const_mgr.add_const('DISPID_MOUSEOVER',0x00000008)
		win_const_mgr.add_const('RSVP_PATH_ERR',0x00000003)
		win_const_mgr.add_const('PORT_AT8',0x000000D0)
		win_const_mgr.add_const('PHOTO_METERINGMODE_UNKNOWN',0x00000000)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_XMIT_ERROR',0x00000400)
		win_const_mgr.add_const('SQL_API_SQLGETCONNECTATTR',0x000003EF)
		win_const_mgr.add_const('IDD_CHANGESOURCE',0x000003F1)
		win_const_mgr.add_const('PSINJECT_ENDDEFAULTS',0x0000000D)
		win_const_mgr.add_const('WNDN_MKDIR',0x00000001)
		win_const_mgr.add_const('SPDRP_INSTALL_STATE',0x00000022)
		win_const_mgr.add_const('RSC_MBZ1_V',0x00000003)
		win_const_mgr.add_const('ERROR_PRINTER_ALREADY_EXISTS',0x0000070A)
		win_const_mgr.add_const('DNS_ERROR_ZONE_NOT_SECONDARY',0x0000258D)
		win_const_mgr.add_const('OID_GEN_SUPPORTED_GUIDS',0x00010117)
		win_const_mgr.add_const('DLG_ACMFORMATCHOOSE_ID',0x00000046)
		win_const_mgr.add_const('SPI_GETTOGGLEKEYS',0x00000034)
		win_const_mgr.add_const('PDH_BINARY_LOG_CORRUPT',0xC0000BF7)
		win_const_mgr.add_const('MCI_VCR_PLAY_REVERSE',0x00010000)
		win_const_mgr.add_const('SFVM_MERGEMENU',0x00000001)
		win_const_mgr.add_const('HTTOPRIGHT',0x0000000E)
		win_const_mgr.add_const('BSSF_NOTITLE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY',0x00002164)
		win_const_mgr.add_const('SQL_API_SQLFOREIGNKEYS',0x0000003C)
		win_const_mgr.add_const('SP_BACKUP_DEMANDPASS',0x00000002)
		win_const_mgr.add_const('CRYPT_KEY_LEN',0x00000007)
		win_const_mgr.add_const('GIL_PERINSTANCE',0x00000002)
		win_const_mgr.add_const('IPPORT_EXECSERVER',0x00000200)
		win_const_mgr.add_const('MAX_DEVICE_NAME',0x00000080)
		win_const_mgr.add_const('BG_E_INSUFFICIENT_HTTP_SUPPORT',0x80200012)
		win_const_mgr.add_const('ERROR_CTX_WINSTATION_NAME_INVALID',0x00001B59)
		win_const_mgr.add_const('VER_ERR_ITEM_E',0x00000400)
		win_const_mgr.add_const('EC_PREPROCESS_COMPLETE',0x00000056)
		win_const_mgr.add_const('WM_DELETEITEM',0x0000002D)
		win_const_mgr.add_const('TAPIMAXDESTADDRESSSIZE',0x00000050)
		win_const_mgr.add_const('TOKEN_MANDATORY_POLICY_OFF',0x00000000)
		win_const_mgr.add_const('LINEFEATURE_FORWARDDND',0x00000100)
		win_const_mgr.add_const('IF_TYPE_HIPERLAN2',0x000000B7)
		win_const_mgr.add_const('POLYGONALCAPS',0x00000020)
		win_const_mgr.add_const('CLIP_DFA_DISABLE',0x00000004)
		win_const_mgr.add_const('SYMSTOREOPT_OVERWRITE',0x00000002)
		win_const_mgr.add_const('SQL_INTERVAL_MONTH',0x00000064)
		win_const_mgr.add_const('DNS_WINS_FLAG_SCOPE',0x80000000)
		win_const_mgr.add_const('KSPROPERTY_VIDEOPROCAMP_FLAGS_AUTO',0x00000000)
		win_const_mgr.add_const('ERROR_SERVICE_DOES_NOT_EXIST',0x00000424)
		win_const_mgr.add_const('OID_FDDI_PATH_SBA_PAYLOAD',0x03030254)
		win_const_mgr.add_const('CR_NOT_DISABLEABLE',0x00000028)
		win_const_mgr.add_const('QITIPF_LINKNOTARGET',0x00000002)
		win_const_mgr.add_const('DTR_PAL_INDEX',0x00000006)
		win_const_mgr.add_const('ERROR_DS_SYNTAX_MISMATCH',0x000020C0)
		win_const_mgr.add_const('VHDR_KEYFRAME',0x00000008)
		win_const_mgr.add_const('PFD_DIRECT3D_ACCELERATED',0x00004000)
		win_const_mgr.add_const('LINEERR_INVALPARKID',0x80000033)
		win_const_mgr.add_const('MDM_PIAFS_OUTGOING',0x00000001)
		win_const_mgr.add_const('ERROR_EVT_FILTER_INVTYPE',0x00003AAA)
		win_const_mgr.add_const('TIME_ZONE_ID_INVALID',0xFFFFFFFF)
		win_const_mgr.add_const('SORT_KOREAN_KSC',0x00000000)
		win_const_mgr.add_const('SNMPAPI_ALLOC_ERROR',0x00000002)
		win_const_mgr.add_const('SQL_CVT_BIGINT',0x00004000)
		win_const_mgr.add_const('INT128_MAX',0x7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF)
		win_const_mgr.add_const('STI_RAW_RESERVED',0x00001000)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM7B_INST_WORD_POS_X',0x00000004)
		win_const_mgr.add_const('NETE_TOOMANYFILES',0x00000010)
		win_const_mgr.add_const('GT_MODULE',0x00000006)
		win_const_mgr.add_const('WTS_SESSION_LOGON',0x00000005)
		win_const_mgr.add_const('EM_SETRECTNP',0x000000B4)
		win_const_mgr.add_const('LINEAGENTSESSIONSTATE_RELEASED',0x00000020)
		win_const_mgr.add_const('COD_MAJOR_COMPUTER',0x00000001)
		win_const_mgr.add_const('IDM_MENUEXT_FIRST__',0x00000E74)
		win_const_mgr.add_const('DISKQUOTA_USER_ACCOUNT_UNKNOWN',0x00000004)
		win_const_mgr.add_const('NIF_TIP',0x00000004)
		win_const_mgr.add_const('WIA_DPS_OPTICAL_XRES',0x00000C12)
		win_const_mgr.add_const('PSN_LAST',0x00000000)
		win_const_mgr.add_const('PAN_MIDLINE_CONSTANT_POINTED',0x00000009)
		win_const_mgr.add_const('DAOBINDING_VARIANT',0x00000002)
		win_const_mgr.add_const('SQL_ROW_SUCCESS',0x00000000)
		win_const_mgr.add_const('SAMPLE_SEQ_GOP_HEADER',0x00000002)
		win_const_mgr.add_const('LINKSBAND',0x00000004)
		win_const_mgr.add_const('SQL_FN_STR_LOCATE',0x00000020)
		win_const_mgr.add_const('IDM_CHISELED',0x00000040)
		win_const_mgr.add_const('LDAP_OPT_ERROR_NUMBER',0x00000031)
		win_const_mgr.add_const('RQ_ACQUIRE_REQUEST_STATE',0x00000020)
		win_const_mgr.add_const('SUBLANG_ARABIC_TUNISIA',0x00000007)
		win_const_mgr.add_const('ERROR_INVALID_DATATYPE',0x0000070C)
		win_const_mgr.add_const('SCESTATUS_OTHER_ERROR',0x0000000C)
		win_const_mgr.add_const('BTH_ADDR_IAC_LAST',0x0009E8B3)
		win_const_mgr.add_const('ERROR_CANCELLED',0x000004C7)
		win_const_mgr.add_const('SECPKG_FLAG_IMPERSONATION',0x00000100)
		win_const_mgr.add_const('FACILITY_HID_ERROR_CODE',0x00000011)
		win_const_mgr.add_const('SQL_API_SQLROWCOUNT',0x00000014)
		win_const_mgr.add_const('CDIS_SELECTED',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_ACCEPT_LANGUAGE',0x0000001B)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_DIRECTED_FRAMES_RCV',0x00000001)
		win_const_mgr.add_const('DEBUG_FILTER_UNLOAD_MODULE',0x00000005)
		win_const_mgr.add_const('XP_FRAGMENTATION',0x00001000)
		win_const_mgr.add_const('URLACTION_CHANNEL_SOFTDIST_MAX',0x0000001E)
		win_const_mgr.add_const('MCI_DEVTYPE_FIRST_USER',0x00001000)
		win_const_mgr.add_const('MMIO_DENYNONE',0x00000040)
		win_const_mgr.add_const('POLICY_SET_AUDIT_REQUIREMENTS',0x00000100)
		win_const_mgr.add_const('PAN_STROKE_RAPID_VERT',0x00000006)
		win_const_mgr.add_const('SSPROP_INIT_PACKETSIZE',0x00000009)
		win_const_mgr.add_const('DNS_TYPE_MB',0x00000007)
		win_const_mgr.add_const('DNS_TYPE_MG',0x00000008)
		win_const_mgr.add_const('LOAD_TLB_AS_64BIT',0x00000040)
		win_const_mgr.add_const('VMRBITMAP_DISABLE',0x00000001)
		win_const_mgr.add_const('DNS_TYPE_MD',0x00000003)
		win_const_mgr.add_const('N_TMASK',0x00000030)
		win_const_mgr.add_const('API_VERSION_NUMBER',0x0000000B)
		win_const_mgr.add_const('PHONEBUTTONSTATE_UP',0x00000001)
		win_const_mgr.add_const('BLLI_L3_ISO_TR9577',0x0000000B)
		win_const_mgr.add_const('DBPROP_DEFAULT_EQUALS_BEHAVIOR',0x00000002)
		win_const_mgr.add_const('DIF_TROUBLESHOOTER',0x00000026)
		win_const_mgr.add_const('FCIDM_GLOBALFIRST',0x00008000)
		win_const_mgr.add_const('ERROR_NO_ITEMS',0x0000005D)
		win_const_mgr.add_const('MAX_ADAPTER_NAME_LEN',0x00000030)
		win_const_mgr.add_const('ERROR_DS_INVALID_SEARCH_FLAG',0x00002134)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_M32R',0x00009041)
		win_const_mgr.add_const('CSIDL_DESKTOP',0x00000000)
		win_const_mgr.add_const('PRODUCT_WEB_SERVER',0x00000011)
		win_const_mgr.add_const('CRYPT_IPSEC_HMAC_KEY',0x00000100)
		win_const_mgr.add_const('SFGAO_STORAGECAPMASK',0x70C50008)
		win_const_mgr.add_const('MCI_VCR_PLAY_AT',0x00020000)
		win_const_mgr.add_const('SM_CXMENUCHECK',0x00000047)
		win_const_mgr.add_const('DOT11_FLAGS_PS_ON',0x00000008)
		win_const_mgr.add_const('MQMSG_AUTHENTICATED_QM_MESSAGE',0x0000000B)
		win_const_mgr.add_const('SERVICE_STOP_REASON_FLAG_MIN',0x00000000)
		win_const_mgr.add_const('SPI_GETMOUSEHOVERTIME',0x00000066)
		win_const_mgr.add_const('SQL_FN_NUM_ATAN2',0x00000010)
		win_const_mgr.add_const('BATTERY_SYSTEM_BATTERY',0x80000000)
		win_const_mgr.add_const('IF_TYPE_ATM_SUBINTERFACE',0x00000086)
		win_const_mgr.add_const('EXCHIVERB_FORWARD',0x00000068)
		win_const_mgr.add_const('RFCOMM_MAX_MTU',0x000003F3)
		win_const_mgr.add_const('SUBLANG_ARABIC_MOROCCO',0x00000006)
		win_const_mgr.add_const('WLAN_CONNECTION_NOTIFICATION_CONSOLE_USER_PROFILE',0x00000004)
		win_const_mgr.add_const('CMSG_CTRL_VERIFY_SIGNATURE',0x00000001)
		win_const_mgr.add_const('IMAGE_NT_SIGNATURE',0x50450000)
		win_const_mgr.add_const('PRJOB_INTERV',0x00000008)
		win_const_mgr.add_const('XP_GUARANTEED_ORDER',0x00000004)
		win_const_mgr.add_const('DCACHE_SIZE',0x00000004)
		win_const_mgr.add_const('PERF_COUNTERSET_FLAG_AGGREGATE',0x00000004)
		win_const_mgr.add_const('DISPID_ONMOUSEDOWN',0x00000005)
		win_const_mgr.add_const('BZ_DISABLECANCELBUTTON',0x00000001)
		win_const_mgr.add_const('IPP_E_RESELECTPROVIDER',0xC0048102)
		win_const_mgr.add_const('FOFX_EARLYFAILURE',0x00100000)
		win_const_mgr.add_const('AE_DELETE',0x00000001)
		win_const_mgr.add_const('SUBLANG_ARABIC_UAE',0x00000000)
		win_const_mgr.add_const('DBPROP_INIT_MARKFOROFFLINE',0x00000005)
		win_const_mgr.add_const('IME_SMODE_SINGLECONVERT',0x00000002)
		win_const_mgr.add_const('FLG_ADDREG_TYPE_DWORD',0x00010000)
		win_const_mgr.add_const('WIA_DPC_BURST_INTERVAL',0x0000081B)
		win_const_mgr.add_const('RTM_NEXTHOP_FLAGS_REMOTE',0x00000001)
		win_const_mgr.add_const('LVIF_DI_SETITEM',0x00001000)
		win_const_mgr.add_const('IDM_UI_OUTDENT',0x00000967)
		win_const_mgr.add_const('DDSCAPS_ALPHA',0x00000002)
		win_const_mgr.add_const('LDAP_API_INFO_VERSION',0x00000001)
		win_const_mgr.add_const('RQ_READ_ENTITY',0x40000000)
		win_const_mgr.add_const('KP_SALT',0x00000002)
		win_const_mgr.add_const('MAPI_E_NETWORK_FAILURE',0x00000017)
		win_const_mgr.add_const('DRMENVHANDLE_INVALID',0x00000000)
		win_const_mgr.add_const('URLACTION_COOKIES_ENABLED',0x00001A10)
		win_const_mgr.add_const('SECPKG_ATTR_ACCESS_TOKEN',0x00000012)
		win_const_mgr.add_const('OBJECT_PUSH_FORMAT_ICAL_2_0',0x00000004)
		win_const_mgr.add_const('SDP_SERVICE_ATTRIBUTE_REQUEST',0x00000002)
		win_const_mgr.add_const('HTTP_LOG_FIELD_SUB_STATUS',0x00200000)
		win_const_mgr.add_const('NUM_POINTS',0x00000003)
		win_const_mgr.add_const('RPC_X_WRONG_STUB_VERSION',0x00000725)
		win_const_mgr.add_const('POLYFILL_LAST',0x00000002)
		win_const_mgr.add_const('CRYPT_TEMPLATE_OID_GROUP_ID',0x00000009)
		win_const_mgr.add_const('OID_GEN_TRANSMIT_BUFFER_SPACE',0x00010108)
		win_const_mgr.add_const('NTE_OP_OK',0x00000000)
		win_const_mgr.add_const('MF_KERNEL_MODE_COMPONENT_LOAD',0x00000002)
		win_const_mgr.add_const('WAVE_FORMAT_48S08',0x00002000)
		win_const_mgr.add_const('SV_MAX_SRV_HEUR_LEN',0x00000020)
		win_const_mgr.add_const('VOS_DOS_WINDOWS16',0x00010001)
		win_const_mgr.add_const('SECBUFFER_EXTRA',0x00000005)
		win_const_mgr.add_const('IMGLOAD_STOPPED',0x00400000)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2EVENTARGS_USEDSYSTEMBUFFER',0x00000107)
		win_const_mgr.add_const('LINECALLSELECT_ADDRESS',0x00000002)
		win_const_mgr.add_const('WMDM_LOG_SEV_INFO',0x00000001)
		win_const_mgr.add_const('WIA_PROP_RANGE',0x00000010)
		win_const_mgr.add_const('D3DCS_LEFT',0x00000001)
		win_const_mgr.add_const('SQL_FETCH_BOOKMARK',0x00000008)
		win_const_mgr.add_const('VK_CONVERT',0x0000001C)
		win_const_mgr.add_const('SHUTDOWN_GRACE_OVERRIDE',0x00000020)
		win_const_mgr.add_const('BSIS_NODROPTARGET',0x00000020)
		win_const_mgr.add_const('LOCALE_SABBREVDAYNAME6',0x00000036)
		win_const_mgr.add_const('WH_CALLWNDPROC',0x00000004)
		win_const_mgr.add_const('TARGET_IS_NT50_OR_LATER',0x00000000)
		win_const_mgr.add_const('CDO_E_UNSAFE_OPERATION',0x8004021D)
		win_const_mgr.add_const('SQL_DYNAMIC_CURSOR_ATTRIBUTES2',0x00000091)
		win_const_mgr.add_const('IOCTL_IP_RTCHANGE_NOTIFY_REQUEST',0x00000065)
		win_const_mgr.add_const('IMAGE_REL_BASED_ABSOLUTE',0x00000000)
		win_const_mgr.add_const('ISOPROTO_ESIS',0x00000022)
		win_const_mgr.add_const('DDPCAPS_1BIT',0x00000100)
		win_const_mgr.add_const('INADDR_LOOPBACK',0x00000007)
		win_const_mgr.add_const('HTTP_QUERY_SERVER',0x00000025)
		win_const_mgr.add_const('GENERIC_READ',0x80000000)
		win_const_mgr.add_const('DSBI_EXPANDONOPEN',0x00040000)
		win_const_mgr.add_const('D3DUSAGE_DYNAMIC',0x00000200)
		win_const_mgr.add_const('MIN_PST_ERROR',0x800C0001)
		win_const_mgr.add_const('PFN_ARABIC',0x00000002)
		win_const_mgr.add_const('ERROR_TAG_NOT_FOUND',0x000007DC)
		win_const_mgr.add_const('IDM_FILE',0x0000087C)
		win_const_mgr.add_const('GT_DATA',0x00000002)
		win_const_mgr.add_const('ADS_PRINTER_PAGE_PUNT',0x00080000)
		win_const_mgr.add_const('SCHANNEL_SESSION',0x00000003)
		win_const_mgr.add_const('RP_GENERAL_FAILURE',0x00000020)
		win_const_mgr.add_const('SV_TYPE_DFS',0x00800000)
		win_const_mgr.add_const('SVSI_TRANSLATEPT',0x00000020)
		win_const_mgr.add_const('ADAPTER_FLOW_MODE_DIFFSERV',0x00000001)
		win_const_mgr.add_const('WIA_PAGE_JIS_B10',0x00000031)
		win_const_mgr.add_const('CAUSE_NA_ABNORMAL',0x00000004)
		win_const_mgr.add_const('RECEIVE_TIME_INDICATION_CAPABLE',0x00000008)
		win_const_mgr.add_const('IP_OPT_SSRR',0x00000089)
		win_const_mgr.add_const('EMR_POLYBEZIERTO',0x00000005)
		win_const_mgr.add_const('TC_NONCONF_SHAPE',0x00000001)
		win_const_mgr.add_const('DEBUG_OUTTYPE_ADDRESS_OF_FIELD',0x00010000)
		win_const_mgr.add_const('IS_TEXT_UNICODE_UNICODE_MASK',0x0000000F)
		win_const_mgr.add_const('MCW_WINDOW',0x00000002)
		win_const_mgr.add_const('SQL_DIAG_CLASS_ORIGIN',0x00000008)
		win_const_mgr.add_const('SYSFXUI_DONOTSHOW_ROOMCORRECTION',0x00000002)
		win_const_mgr.add_const('CMC_FAIL_BAD_TIME',0x00000003)
		win_const_mgr.add_const('DI_READ_SPOOL_JOB',0x00000003)
		win_const_mgr.add_const('PSH_MODELESS',0x00000400)
		win_const_mgr.add_const('WIA_DPV_IMAGES_DIRECTORY',0x00000E03)
		win_const_mgr.add_const('BLLI_L2_ISO_7776',0x00000011)
		win_const_mgr.add_const('BG_E_FILE_NOT_FOUND',0x80200029)
		win_const_mgr.add_const('VER_DEBUG',0x00000000)
		win_const_mgr.add_const('CR_PROP_SHAREDFOLDER',0x00000008)
		win_const_mgr.add_const('ODS_HOTLIGHT',0x00000040)
		win_const_mgr.add_const('EVENTLOG_INFORMATION_TYPE',0x00000004)
		win_const_mgr.add_const('NCRYPTBUFFER_PKCS_KEY_NAME',0x0000002D)
		win_const_mgr.add_const('LVTVIM_LABELMARGIN',0x00000004)
		win_const_mgr.add_const('WM_MOVE',0x00000003)
		win_const_mgr.add_const('BG_E_NO_PROGRESS',0x80200024)
		win_const_mgr.add_const('SPSVCINST_NOCLOBBER_STARTTYPE',0x00000010)
		win_const_mgr.add_const('DOMAIN_GROUP_RID_ENTERPRISE_ADMINS',0x00000207)
		win_const_mgr.add_const('PDH_SQL_ALLOCCON_FAILED',0xC0000BE1)
		win_const_mgr.add_const('ERROR_DS_EXISTS_IN_SUB_CLS',0x000020CA)
		win_const_mgr.add_const('DMPAPER_JENV_CHOU3_ROTATED',0x00000056)
		win_const_mgr.add_const('IMAGE_SCN_MEM_FARDATA',0x00008000)
		win_const_mgr.add_const('CM_REGISTRY_CONFIG',0x00000200)
		win_const_mgr.add_const('ERROR_SERVICE_LOGON_FAILED',0x0000042D)
		win_const_mgr.add_const('ERROR_INVALID_DOMAINNAME',0x000004BC)
		win_const_mgr.add_const('CHANGER_TO_DRIVE',0x00000008)
		win_const_mgr.add_const('SECPKG_PACKAGE_CHANGE_LOAD',0x00000000)
		win_const_mgr.add_const('CERT_NAME_STR_DISABLE_IE4_UTF8_FLAG',0x00010000)
		win_const_mgr.add_const('INTERNET_PER_CONN_AUTOCONFIG_URL',0x00000004)
		win_const_mgr.add_const('INTERNET_FLAG_MAKE_PERSISTENT',0x02000000)
		win_const_mgr.add_const('EN_LOWFIRTF',0x00000070)
		win_const_mgr.add_const('ACCESS_FAIL_WRITE',0x00000200)
		win_const_mgr.add_const('TPM_LAYOUTRTL',0x00008000)
		win_const_mgr.add_const('DNS_TYPE_AFSDB',0x00000012)
		win_const_mgr.add_const('NLA_ALLUSERS_NETWORK',0x00000001)
		win_const_mgr.add_const('DS_REPSYNC_FULL_IN_PROGRESS',0x00400000)
		win_const_mgr.add_const('FACILITY_NTWIN32',0x00000007)
		win_const_mgr.add_const('RPC_C_NOTIFY_ON_SEND_COMPLETE',0x00000001)
		win_const_mgr.add_const('SQL_FN_TSI_MONTH',0x00000040)
		win_const_mgr.add_const('PSH_WATERMARK',0x00008000)
		win_const_mgr.add_const('SNMPAPI_UNTRANSLATED_V2',0x00000002)
		win_const_mgr.add_const('LINEAGENTSTATUS_GROUP',0x00000001)
		win_const_mgr.add_const('SHGSI_ICONLOCATION',0x00000000)
		win_const_mgr.add_const('SQL_NULL_HSTMT',0x00000000)
		win_const_mgr.add_const('ERROR_DS_CROSS_NC_DN_RENAME',0x000020B0)
		win_const_mgr.add_const('BIF_BROWSEFORPRINTER',0x00002000)
		win_const_mgr.add_const('NTDDI_WS03',0x05020000)
		win_const_mgr.add_const('WNPS_FILE',0x00000000)
		win_const_mgr.add_const('ERROR_ALIAS_EXISTS',0x00000563)
		win_const_mgr.add_const('RSC_MODE_SI',0x00000001)
		win_const_mgr.add_const('CERT_TRUST_IS_CYCLIC',0x00000080)
		win_const_mgr.add_const('NORMAL_MODE',0x00000002)
		win_const_mgr.add_const('SPQ_FLAG_FILES_MODIFIED',0x00000004)
		win_const_mgr.add_const('NTDSSITELINK_OPT_TWOWAY_SYNC',0x00000001)
		win_const_mgr.add_const('CRL_REASON_KEY_COMPROMISE',0x00000001)
		win_const_mgr.add_const('PORT_CHARGEN',0x00000013)
		win_const_mgr.add_const('TMT_DEFAULTPANESIZE',0x0000138A)
		win_const_mgr.add_const('PORT_LDAP2',0x00000CC4)
		win_const_mgr.add_const('PORT_LDAP1',0x00000185)
		win_const_mgr.add_const('ASYNC_MODE_COMPATIBILITY',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_ERROR_MASK',0x0000003E)
		win_const_mgr.add_const('DEVPROP_TYPE_DOUBLE',0x0000000B)
		win_const_mgr.add_const('VK_OEM_AUTO',0x000000F3)
		win_const_mgr.add_const('IMAGE_REL_PPC_TOCDEFN',0x00000800)
		win_const_mgr.add_const('MND_CONTINUE',0x00000000)
		win_const_mgr.add_const('HTTP_STATUS_REDIRECT',0x0000012E)
		win_const_mgr.add_const('SESSION_ABORTED',0x00000006)
		win_const_mgr.add_const('SQL_CDO_CONSTRAINT_INITIALLY_DEFERRED',0x00000020)
		win_const_mgr.add_const('CALLBACK_TYPEMASK',0x00070000)
		win_const_mgr.add_const('RTCEF_GROUP',0x00002000)
		win_const_mgr.add_const('IMAGE_REL_PPC_SECTION',0x0000000C)
		win_const_mgr.add_const('TC_IA_ABLE',0x00000400)
		win_const_mgr.add_const('EVCCBF_LASTNOTIFICATION',0x00000001)
		win_const_mgr.add_const('SQL_SC_TRY_UNIQUE',0x00000001)
		win_const_mgr.add_const('WEBPOST_ERROR_DELETE_SITE',0xC004210C)
		win_const_mgr.add_const('GMEM_NOCOMPACT',0x00000010)
		win_const_mgr.add_const('KSPROPERTY_TYPE_UNSERIALIZERAW',0x00004000)
		win_const_mgr.add_const('SPI_GETWHEELSCROLLCHARS',0x0000006C)
		win_const_mgr.add_const('ET_RENDERINGINTENT',0x00004000)
		win_const_mgr.add_const('TMENDRSCAN',0x00800000)
		win_const_mgr.add_const('WINHTTP_OPTION_PASSPORT_SIGN_OUT',0x00000056)
		win_const_mgr.add_const('VK_F20',0x00000083)
		win_const_mgr.add_const('DFCS_SCROLLRIGHT',0x00000003)
		win_const_mgr.add_const('RF_MULTICAST',0x00000020)
		win_const_mgr.add_const('LNH_48_CPU',0x00000061)
		win_const_mgr.add_const('FDTF_SHORTDATE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION',0x0000212C)
		win_const_mgr.add_const('VK_F21',0x00000084)
		win_const_mgr.add_const('DWORD_MAX',0x00000000)
		win_const_mgr.add_const('BTH_MFG_TRANSILICA',0x00000018)
		win_const_mgr.add_const('OLEUI_ERR_HINSTANCEINVALID',0x0000006B)
		win_const_mgr.add_const('IF_TYPE_SDSL',0x00000060)
		win_const_mgr.add_const('VDMDBG_BREAK_LOADDLL',0x00000004)
		win_const_mgr.add_const('PAN_CONTRAST_VERY_HIGH',0x00000009)
		win_const_mgr.add_const('CRYPT_BLOB_VER3',0x00000080)
		win_const_mgr.add_const('TRACE_LEVEL_NONE',0x00000000)
		win_const_mgr.add_const('DDCAPS2_FLIPNOVSYNC',0x00400000)
		win_const_mgr.add_const('PHOTO_SATURATION_HIGH',0x00000002)
		win_const_mgr.add_const('IDM_BLOCKDIRRTL',0x00000931)
		win_const_mgr.add_const('VK_F24',0x00000087)
		win_const_mgr.add_const('EVENT_HEADER_FLAG_CLASSIC_HEADER',0x00000100)
		win_const_mgr.add_const('OID_ATM_RELEASE_ACCESS_NET_RESOURCES',0x08010204)
		win_const_mgr.add_const('SKF_LALTLATCHED',0x10000000)
		win_const_mgr.add_const('ERROR_INTERNAL_ERROR',0x0000054F)
		win_const_mgr.add_const('THREAD_QUERY_LIMITED_INFORMATION',0x00000800)
		win_const_mgr.add_const('IMN_CHANGECANDIDATE',0x00000003)
		win_const_mgr.add_const('SQL_SP_MATCH_UNIQUE_PARTIAL',0x00000040)
		win_const_mgr.add_const('XINPUT_GAMEPAD_RIGHT_THUMB_DEADZONE',0x000021F1)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_SG_DMA_DESCRIPTION',0x00000083)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_BACKUP_OPS',0x00000227)
		win_const_mgr.add_const('RPC_S_UNKNOWN_IF',0x000006B5)
		win_const_mgr.add_const('SYMF_FRAMEREL',0x00000020)
		win_const_mgr.add_const('SPEAKER_FRONT_CENTER',0x00000004)
		win_const_mgr.add_const('ASC_REQ_DELEGATE',0x00000001)
		win_const_mgr.add_const('D3DUSAGE_DONOTCLIP',0x00000020)
		win_const_mgr.add_const('GDIP_EMFPLUSFLAGS_DISPLAY',0x00000001)
		win_const_mgr.add_const('SQL_CONVERT_REAL',0x00000040)
		win_const_mgr.add_const('DEBUG_STATUS_GO_NOT_HANDLED',0x00000003)
		win_const_mgr.add_const('ELEMENT_STATUS_NOT_BUS',0x00008000)
		win_const_mgr.add_const('DLGC_HASSETSEL',0x00000008)
		win_const_mgr.add_const('USER_MARSHAL_REF',0x00000040)
		win_const_mgr.add_const('OIC_HAND',0x00007F01)
		win_const_mgr.add_const('DBG_TASKSTOP',0x0000000B)
		win_const_mgr.add_const('IPX_RELIABLE_DELIVERY_PACKET_TYPE',0x00000002)
		win_const_mgr.add_const('INTERNET_OPTION_HTTP_DECODING',0x00000041)
		win_const_mgr.add_const('IDC_CI_ICONLIST',0x0000007F)
		win_const_mgr.add_const('AF_DLI',0x0000000D)
		win_const_mgr.add_const('HH_INITIALIZE',0x0000001C)
		win_const_mgr.add_const('RPC_S_UNKNOWN_AUTHN_SERVICE',0x000006D3)
		win_const_mgr.add_const('DNS_ERROR_RCODE_BADTIME',0x0000233A)
		win_const_mgr.add_const('OS_WIN2000PRO',0x00000008)
		win_const_mgr.add_const('SCE_LOG_LEVEL_DETAIL',0x00000002)
		win_const_mgr.add_const('SQL_NC_START',0x00000002)
		win_const_mgr.add_const('FWPS_INCOMING_FLAG_CACHE_SAFE',0x00000001)
		win_const_mgr.add_const('NO_LONG_NAMES',0x00000002)
		win_const_mgr.add_const('DDOVER_BOB',0x00200000)
		win_const_mgr.add_const('D3DSI_TEXLD_BIAS',0x00000002)
		win_const_mgr.add_const('SQL_ISV_CONSTRAINT_COLUMN_USAGE',0x00000080)
		win_const_mgr.add_const('IDM_DIRRTL',0x0000092F)
		win_const_mgr.add_const('PP_NAME',0x00000004)
		win_const_mgr.add_const('ICM_LEVEL2',0x00000002)
		win_const_mgr.add_const('ICM_LEVEL3',0x00000001)
		win_const_mgr.add_const('SERVICE_DEMAND_START',0x00000003)
		win_const_mgr.add_const('CSA_A',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAOEVENTARGS_ELAPSEDTIME',0x00000302)
		win_const_mgr.add_const('TBSTYLE_CHECK',0x00000002)
		win_const_mgr.add_const('WMDM_FILE_ATTR_CANPLAY',0x00004000)
		win_const_mgr.add_const('IMAGE_REL_ALPHA_GPREL32',0x00000003)
		win_const_mgr.add_const('MAX_RPT',0x00000010)
		win_const_mgr.add_const('HTTP_QUERY_CONTENT_LENGTH',0x00000005)
		win_const_mgr.add_const('PRIVATEKEYBLOB',0x00000007)
		win_const_mgr.add_const('ACM_STREAMCONVERTF_BLOCKALIGN',0x00000004)
		win_const_mgr.add_const('PROPID_STG_CONTENTS',0x00000013)
		win_const_mgr.add_const('SOUND_SYSTEM_APPSTART',0x0000000C)
		win_const_mgr.add_const('TMT_TEXTSHADOWTYPE',0x00000FAA)
		win_const_mgr.add_const('TMT_MENUTEXT',0x00000648)
		win_const_mgr.add_const('ENDDOC',0x0000000B)
		win_const_mgr.add_const('VIDCF_CRUNCH',0x00000002)
		win_const_mgr.add_const('XECI_AUTOENROLL',0x00000002)
		win_const_mgr.add_const('MAX_OPT_SIZE',0x00000028)
		win_const_mgr.add_const('DB_PT_FUNCTION',0x00000003)
		win_const_mgr.add_const('MCI_VCR_STATUS_VIDEO_MONITOR_NUMBER',0x0000400D)
		win_const_mgr.add_const('PID_IS_ICONINDEX',0x00000008)
		win_const_mgr.add_const('SQL_ACTIVE_ENVIRONMENTS',0x00000074)
		win_const_mgr.add_const('COM_RIGHTS_ACTIVATE_LOCAL',0x00000008)
		win_const_mgr.add_const('AF_12844',0x00000019)
		win_const_mgr.add_const('KEYEVENTF_EXTENDEDKEY',0x00000001)
		win_const_mgr.add_const('D3DUSAGE_SOFTWAREPROCESSING',0x00000010)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_PROCESS_PATH',0x00000008)
		win_const_mgr.add_const('HCF_HIGHCONTRASTON',0x00000001)
		win_const_mgr.add_const('CRYPTUI_WIZ_NO_UI',0x00000001)
		win_const_mgr.add_const('UF_PASSWD_NOTREQD',0x00000020)
		win_const_mgr.add_const('MF_GRL_LOAD_FAILED',0x00000010)
		win_const_mgr.add_const('SSA_METAFILE',0x00000800)
		win_const_mgr.add_const('MDAXIS_SLICERS',0x00000000)
		win_const_mgr.add_const('PHOTO_EXPOSUREPROGRAM_CREATIVE',0x00000005)
		win_const_mgr.add_const('CRYPT_NO_AUTH_RETRIEVAL',0x00020000)
		win_const_mgr.add_const('HHWIN_PARAM_TABPOS',0x00000001)
		win_const_mgr.add_const('ITWW_CBKEY_MAX',0x00000400)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_MEMBER_OF_STRUCT',0x00000008)
		win_const_mgr.add_const('NCRYPT_KEY_STORAGE_INTERFACE',0x00010001)
		win_const_mgr.add_const('OID_GEN_PROTOCOL_OPTIONS',0x00010112)
		win_const_mgr.add_const('IDM_MULTILEVELUNDO',0x0000002C)
		win_const_mgr.add_const('D3DVS_Z_Z',0x00000002)
		win_const_mgr.add_const('D3DVS_Z_Y',0x00000001)
		win_const_mgr.add_const('D3DVS_Z_X',0x00000000)
		win_const_mgr.add_const('SPMODE_MEMWATCH',0x00001000)
		win_const_mgr.add_const('SM_CYSMICON',0x00000032)
		win_const_mgr.add_const('ERROR_RESOURCE_FAILED',0x000013AE)
		win_const_mgr.add_const('EAP_FLAG_PRE_LOGON',0x00020000)
		win_const_mgr.add_const('D3DVS_Z_W',0x00000003)
		win_const_mgr.add_const('ALINF_QUIET',0x00000004)
		win_const_mgr.add_const('MAX_COLUMN_NAME_LEN',0x00000050)
		win_const_mgr.add_const('PORT_UUCPPATH',0x00000075)
		win_const_mgr.add_const('EVENT_OBJECT_SELECTION',0x00008006)
		win_const_mgr.add_const('DISPATCH_PROPERTYPUT',0x00000004)
		win_const_mgr.add_const('MCI_WAVE_SET_BLOCKALIGN',0x00100000)
		win_const_mgr.add_const('GAA_FLAG_INCLUDE_ALL_INTERFACES',0x00000100)
		win_const_mgr.add_const('TMT_BITMAPREF',0x000000D7)
		win_const_mgr.add_const('FWPM_ACTRL_OPEN',0x00000040)
		win_const_mgr.add_const('SPDRP_REMOVAL_POLICY_HW_DEFAULT',0x00000020)
		win_const_mgr.add_const('ATSC_VCT_PID',0x00001FFB)
		win_const_mgr.add_const('COLOR_BTNTEXT',0x00000012)
		win_const_mgr.add_const('NETSCAPE_SIGN_CERT_TYPE',0x00000010)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MAGFPOINT',0x01000000)
		win_const_mgr.add_const('DEBUG_ATTACH_KERNEL_CONNECTION',0x00000000)
		win_const_mgr.add_const('FPF_RECEIVE',0x00000001)
		win_const_mgr.add_const('SPFILELOG_OEMFILE',0x00000001)
		win_const_mgr.add_const('LGRPID_GREEK',0x00000004)
		win_const_mgr.add_const('ICM_DELETEPROFILE',0x00000002)
		win_const_mgr.add_const('S_WHITEVOICE',0x00000007)
		win_const_mgr.add_const('OID_FDDI_IF_MTU',0x0303027B)
		win_const_mgr.add_const('TIMEDVDPLAYEROBJECT_OFFSET',0x00000D00)
		win_const_mgr.add_const('ERROR_THREAD_NOT_IN_PROCESS',0x00000236)
		win_const_mgr.add_const('DEBUG_SCOPE_GROUP_ARGUMENTS',0x00000001)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_ENLIST_MASK',0x00040000)
		win_const_mgr.add_const('PHONEBUTTONMODE_DUMMY',0x00000001)
		win_const_mgr.add_const('SQL_CURSOR_ROLLBACK_BEHAVIOR',0x00000018)
		win_const_mgr.add_const('MCI_DGV_STATUS_BITSPERPEL',0x00000402)
		win_const_mgr.add_const('ERROR_NO_DATA',0x000000E8)
		win_const_mgr.add_const('CR_PROP_CACERTSTATUSCODE',0x00000022)
		win_const_mgr.add_const('MOD_IGNORE_ALL_MODIFIER',0x00000400)
		win_const_mgr.add_const('POLICY_ERRV_SUBNET_DEF_SUM_PEAK_RATE',0x0000002D)
		win_const_mgr.add_const('ADS_PRINTER_SERVER_UNKNOWN',0x00800000)
		win_const_mgr.add_const('DISPID_HTMLAPP',0x00001388)
		win_const_mgr.add_const('IDM_SCRIPTDEBUGGER',0x0000091A)
		win_const_mgr.add_const('WMIGUID_EXECUTE',0x00000010)
		win_const_mgr.add_const('DBG_DLLSTART',0x0000000C)
		win_const_mgr.add_const('CREATE_SEPARATE_WOW_VDM',0x00000800)
		win_const_mgr.add_const('CAUSE_INVALID_IE_CONTENTS',0x00000064)
		win_const_mgr.add_const('SQL_BRC_ROLLED_UP',0x00000004)
		win_const_mgr.add_const('IDB_VIEW_SMALL_COLOR',0x00000004)
		win_const_mgr.add_const('MCI_DGV_REALIZE_BKGD',0x00020000)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_NAVIGATE',0x00000019)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_SMT',0x00000040)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_ADDAUDIOTRACK',0x00000201)
		win_const_mgr.add_const('IEIFLAG_NOSTAMP',0x00000080)
		win_const_mgr.add_const('MSGNAME_NOT_FORWARDED',0x00000000)
		win_const_mgr.add_const('ECO_AUTOVSCROLL',0x00000040)
		win_const_mgr.add_const('OID_ARCNET_PERMANENT_ADDRESS',0x06010101)
		win_const_mgr.add_const('MCI_DGV_STATUS_RECORD',0x01000000)
		win_const_mgr.add_const('MCI_DGV_SIGNAL_CANCEL',0x00080000)
		win_const_mgr.add_const('DNS_ERROR_ZONE_IS_SHUTDOWN',0x00002595)
		win_const_mgr.add_const('ACMDRIVERDETAILS_SUPPORTF_ASYNC',0x00000010)
		win_const_mgr.add_const('URLACTION_JAVA_PERMISSIONS',0x00001C00)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_TOTAL_PAGES',0x00000016)
		win_const_mgr.add_const('GET_FEATURE_FROM_PROCESS',0x00000002)
		win_const_mgr.add_const('PDH_NO_DATA',0x800007D5)
		win_const_mgr.add_const('PAGE_READWRITE',0x00000004)
		win_const_mgr.add_const('PORT_MAILQ',0x000000AE)
		win_const_mgr.add_const('LINE_MONITORDIGITS',0x00000009)
		win_const_mgr.add_const('LINEERR_BADDEVICEID',0x80000002)
		win_const_mgr.add_const('WIA_DATA_COLOR_DITHER',0x00000005)
		win_const_mgr.add_const('ERROR_I24_BAD_LENGTH',0x00000005)
		win_const_mgr.add_const('TXTBIT_SCROLLBARCHANGE',0x00010000)
		win_const_mgr.add_const('DFC_CAPTION',0x00000001)
		win_const_mgr.add_const('SW_SHOWNORMAL',0x00000001)
		win_const_mgr.add_const('MDPROPVAL_MSF_TOPSUM',0x00000004)
		win_const_mgr.add_const('NDIS_MAC_OPTION_FULL_DUPLEX',0x00000010)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_USER_NAME',0x00000003)
		win_const_mgr.add_const('FACILITY_RPC',0x00000001)
		win_const_mgr.add_const('COOKIE_CACHE_ENTRY',0x00100000)
		win_const_mgr.add_const('ERROR_LISTBOX_ID_NOT_FOUND',0x00000588)
		win_const_mgr.add_const('OID_FDDI_PATH_INDEX',0x03030251)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_POWERPC',0x000001F0)
		win_const_mgr.add_const('CM_REMOVE_UI_NOT_OK',0x00000001)
		win_const_mgr.add_const('RATING_UNRATED_MAX',0x00000000)
		win_const_mgr.add_const('DFCS_BUTTONPUSH',0x00000010)
		win_const_mgr.add_const('DNS_MAX_NAME_BUFFER_LENGTH',0x00000100)
		win_const_mgr.add_const('TIMEMEDIAPLAYERNETWORK_OFFSET',0x00001600)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REGDELETEVALUE',0x0000000F)
		win_const_mgr.add_const('NETE_NONETACCESS',0x0000000A)
		win_const_mgr.add_const('DISKQUOTA_FILESTATE_INCOMPLETE',0x00000100)
		win_const_mgr.add_const('USN_REASON_CLOSE',0x80000000)
		win_const_mgr.add_const('DISPID_GETERRORLINE',0x0000000E)
		win_const_mgr.add_const('SYMF_PARAMETER',0x00000040)
		win_const_mgr.add_const('SUBLANG_HAUSA_NIGERIA_LATIN',0x00000001)
		win_const_mgr.add_const('DEBUG_HANDLE_DATA_TYPE_OBJECT_NAME',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_CEF_ADDR32NB',0x00000003)
		win_const_mgr.add_const('RPC_S_NO_MORE_MEMBERS',0x000006DD)
		win_const_mgr.add_const('D3D10_SHADER_AVOID_FLOW_CONTROL',0x00000001)
		win_const_mgr.add_const('MSV1_0_LANMAN_SESSION_KEY_LENGTH',0x00000008)
		win_const_mgr.add_const('DEBUG_VALUE_INT64',0x00000004)
		win_const_mgr.add_const('CERT_COMPARE_SIGNATURE_HASH',0x0000000E)
		win_const_mgr.add_const('FWP_CALLOUT_FLAG_ALLOW_OFFLOAD',0x00000002)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_CO_MINIPORT_CHARACTERISTICS',0x00000091)
		win_const_mgr.add_const('EMR_POLYPOLYLINE16',0x0000005A)
		win_const_mgr.add_const('TRANSACTION_QUERY_INFORMATION',0x00000001)
		win_const_mgr.add_const('DNS_RCODE_FORMERR',0x00000001)
		win_const_mgr.add_const('STD_FILENEW',0x00000006)
		win_const_mgr.add_const('CRYPT_STICKY_CACHE_RETRIEVAL',0x00001000)
		win_const_mgr.add_const('AE_MOD',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_AM_REL32_1',0x00000005)
		win_const_mgr.add_const('ML_CROSSCODEPAGE',0x00000002)
		win_const_mgr.add_const('OID_ATM_ACQUIRE_ACCESS_NET_RESOURCES',0x08010203)
		win_const_mgr.add_const('MCI_REALIZE',0x00000840)
		win_const_mgr.add_const('WSAEBADF',0x00002719)
		win_const_mgr.add_const('NEGOTIATE_MAX_PREFIX',0x00000020)
		win_const_mgr.add_const('DNS_QUERY_DONT_RESET_TTL_VALUES',0x00100000)
		win_const_mgr.add_const('LINEERR_INVALTONEMODE',0x8000003E)
		win_const_mgr.add_const('AEC_STATUS_FD_HISTORY_PREVIOUSLY_DIVERGED',0x00000002)
		win_const_mgr.add_const('DBIM_MAXSIZE',0x00000002)
		win_const_mgr.add_const('IP_DEL_IFLIST',0x0000001E)
		win_const_mgr.add_const('XP1_CONNECTIONLESS',0x00000001)
		win_const_mgr.add_const('VIDEO_EXTERNALOUT',0x00000002)
		win_const_mgr.add_const('JOB_OBJECT_MSG_NEW_PROCESS',0x00000006)
		win_const_mgr.add_const('GESTURE_RIGHT_UP',0x00000000)
		win_const_mgr.add_const('TRUST_ATTRIBUTE_FILTER_SIDS',0x00000004)
		win_const_mgr.add_const('AVIIF_FIRSTPART',0x00000020)
		win_const_mgr.add_const('CLCTL_MODIFY_SHIFT',0x00000016)
		win_const_mgr.add_const('APPCOMMAND_COPY',0x00000024)
		win_const_mgr.add_const('VK_SCROLL',0x00000091)
		win_const_mgr.add_const('ILLUMINANT_B',0x00000002)
		win_const_mgr.add_const('SV_MAXKEEPCOMPLSEARCH_PARMNUM',0x0000020D)
		win_const_mgr.add_const('HTTP_QUERY_PROXY_SUPPORT',0x0000004B)
		win_const_mgr.add_const('LPM_TIME_OUT',0x00000002)
		win_const_mgr.add_const('DOT11_STATUS_RESET_CONFIRM',0x00000004)
		win_const_mgr.add_const('VIEW_SORTSIZE',0x00000005)
		win_const_mgr.add_const('SE_SACL_PRESENT',0x00000010)
		win_const_mgr.add_const('RP_FAILED',0x00000830)
		win_const_mgr.add_const('DT_CHARSTREAM',0x00000004)
		win_const_mgr.add_const('INTERNET_FLAG_PRAGMA_NOCACHE',0x00000100)
		win_const_mgr.add_const('IAS_ATTRIB_NO_CLASS',0x00000010)
		win_const_mgr.add_const('DBPROPVAL_TR_OPTIMISTIC',0x00000200)
		win_const_mgr.add_const('ERROR_EXCEPTION_IN_RESOURCE_CALL',0x0000172A)
		win_const_mgr.add_const('ACM_STREAMOPENF_NONREALTIME',0x00000004)
		win_const_mgr.add_const('VTBIT_UI8',0x00000001)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_COPY_ARP',0x00000013)
		win_const_mgr.add_const('ILLUMINANT_C',0x00000003)
		win_const_mgr.add_const('SQLNCHAR',0x00000000)
		win_const_mgr.add_const('ENM_PROTECTED',0x00200000)
		win_const_mgr.add_const('NNTP_MD_ID_END_RESERVED',0x00000000)
		win_const_mgr.add_const('OLEUI_QUERY_GETCLASSID',0x0000FF00)
		win_const_mgr.add_const('CONTAINER_INHERIT_ACE',0x00000002)
		win_const_mgr.add_const('LANG_TURKMEN',0x00000042)
		win_const_mgr.add_const('LDAP_OPT_CACHE_FN_PTRS',0x00000000)
		win_const_mgr.add_const('LINECALLFEATURE2_COMPLCALLBACK',0x00000008)
		win_const_mgr.add_const('IP_FLAGS_SHIFT',0x0000000D)
		win_const_mgr.add_const('WLX_SAS_TYPE_SCRNSVR_TIMEOUT',0x00000002)
		win_const_mgr.add_const('SQL_UNKNOWN_TYPE',0x00000000)
		win_const_mgr.add_const('MQ_RECEIVE_ACCESS',0x00000001)
		win_const_mgr.add_const('SNMPAPI_TL_OTHER',0x000000C7)
		win_const_mgr.add_const('SPDRP_DRIVER',0x00000009)
		win_const_mgr.add_const('ACTIVEOBJECT_WEAK',0x00000001)
		win_const_mgr.add_const('NDIS_PORT_ARRAY_REVISION_1',0x00000001)
		win_const_mgr.add_const('DN_MF_CHILD',0x00020000)
		win_const_mgr.add_const('CDS_TEST',0x00000002)
		win_const_mgr.add_const('ERROR_LOG_POLICY_ALREADY_INSTALLED',0x000019DB)
		win_const_mgr.add_const('LVGMF_NONE',0x00000000)
		win_const_mgr.add_const('UDI_C_PLANE_PROTOCOL_UUID16',0x0000001D)
		win_const_mgr.add_const('LINECALLINFOSTATE_RELATEDCALLID',0x00000080)
		win_const_mgr.add_const('SQL_FN_STR_REPEAT',0x00000080)
		win_const_mgr.add_const('IME_ESC_HANJA_MODE',0x00001008)
		win_const_mgr.add_const('LVGF_SUBTITLE',0x00000100)
		win_const_mgr.add_const('FORMATCHOOSE_MESSAGE',0x00000000)
		win_const_mgr.add_const('IME_CAND_UNKNOWN',0x00000000)
		win_const_mgr.add_const('MD_SERVER_STATE_PAUSING',0x00000005)
		win_const_mgr.add_const('PP_KEYEXCHANGE_KEYSIZE',0x0000000C)
		win_const_mgr.add_const('SQL_SCC_ISO92_CLI',0x00000002)
		win_const_mgr.add_const('MQMSG_NOT_LAST_IN_XACT',0x00000000)
		win_const_mgr.add_const('INDEX_GUID_INKBULLET',0x00000009)
		win_const_mgr.add_const('SNMP_MAX_OID_LEN',0x00000080)
		win_const_mgr.add_const('SUBLANG_GUJARATI_INDIA',0x00000001)
		win_const_mgr.add_const('LGRPID_TRADITIONAL_CHINESE',0x00000009)
		win_const_mgr.add_const('IDB_STD_LARGE_COLOR',0x00000001)
		win_const_mgr.add_const('FWP_ACTION_FLAG_TERMINATING',0x00001000)
		win_const_mgr.add_const('DLCTL_NO_RUNACTIVEXCTLS',0x00000200)
		win_const_mgr.add_const('SQL_CONVERT_VARCHAR',0x00000046)
		win_const_mgr.add_const('ASC_RET_INTEGRITY',0x00020000)
		win_const_mgr.add_const('MAX_SHUTDOWN_TIMEOUT',0x0000000A)
		win_const_mgr.add_const('WMDM_E_USER_CANCELLED',0x8004500B)
		win_const_mgr.add_const('PHONEERR_INVALBUTTONMODE',0x9000000A)
		win_const_mgr.add_const('PP_KEYEXCHANGE_PIN',0x00000020)
		win_const_mgr.add_const('MAPVK_VK_TO_CHAR',0x00000002)
		win_const_mgr.add_const('CTLCOLOR_EDIT',0x00000001)
		win_const_mgr.add_const('IMAGE_SCN_CNT_INITIALIZED_DATA',0x00000040)
		win_const_mgr.add_const('CBN_CLOSEUP',0x00000008)
		win_const_mgr.add_const('MAX_MEDIA_NAME',0x00000010)
		win_const_mgr.add_const('AUDIO_MIN_CHANNELS',0x00000001)
		win_const_mgr.add_const('BFFM_IUNKNOWN',0x00000005)
		win_const_mgr.add_const('CRR_LIFETIME_LIMIT',0xFFFFFFFF)
		win_const_mgr.add_const('NCRYPT_ALLOW_ALL_USAGES',0x00000000)
		win_const_mgr.add_const('MC_CAPS_RESTORE_FACTORY_COLOR_DEFAULTS',0x00000800)
		win_const_mgr.add_const('DSS_NORMAL',0x00000000)
		win_const_mgr.add_const('DM_UPDATE',0x00000001)
		win_const_mgr.add_const('PHONEFEATURE_GETHOOKSWITCHHANDSET',0x00000040)
		win_const_mgr.add_const('SQL_DECIMAL',0x00000003)
		win_const_mgr.add_const('CTF_INHERITWOW64',0x00000100)
		win_const_mgr.add_const('DMPAPER_LETTERSMALL',0x00000002)
		win_const_mgr.add_const('CMSG_CTRL_VERIFY_SIGNATURE_EX',0x00000013)
		win_const_mgr.add_const('MOD_ALT',0x00000001)
		win_const_mgr.add_const('KERB_ETYPE_DEFAULT',0x00000000)
		win_const_mgr.add_const('DS_ABSALIGN',0x00000001)
		win_const_mgr.add_const('ISC_REQ_REPLAY_DETECT',0x00000004)
		win_const_mgr.add_const('SQL_POS_ADD',0x00000010)
		win_const_mgr.add_const('OID_802_3_XMIT_MAX_COLLISIONS',0x01020202)
		win_const_mgr.add_const('SNAPSHOT_POLICY_NEVER',0x00000000)
		win_const_mgr.add_const('SQL_CN_ON',0x00000001)
		win_const_mgr.add_const('EAP_E_USER_ROOT_CERT_FIRST',0x80420300)
		win_const_mgr.add_const('HTTP_STATUS_REDIRECT_KEEP_VERB',0x00000133)
		win_const_mgr.add_const('APPLY_OPTION_VALID_FLAGS',0x00000007)
		win_const_mgr.add_const('CR_INVALID_REFERENCE_STRING',0x00000038)
		win_const_mgr.add_const('TF_LBI_STATUS_DISABLED',0x00000002)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_LOCATION',0x00000033)
		win_const_mgr.add_const('DESKTOP_WRITEOBJECTS',0x00000080)
		win_const_mgr.add_const('OF_WRITE',0x00000001)
		win_const_mgr.add_const('CLONE_FLAG_HEADERS',0x00000002)
		win_const_mgr.add_const('LOCALE_IPOSSYMPRECEDES',0x00000054)
		win_const_mgr.add_const('SPI_GETSOUNDSENTRY',0x00000040)
		win_const_mgr.add_const('LVIS_FOCUSED',0x00000001)
		win_const_mgr.add_const('WSATYPE_NOT_FOUND',0x0000277D)
		win_const_mgr.add_const('COLOR_HIGHLIGHT',0x0000000D)
		win_const_mgr.add_const('GW_MAX',0x00000006)
		win_const_mgr.add_const('OID_802_3_RCV_ERROR_ALIGNMENT',0x01020101)
		win_const_mgr.add_const('VK_SEPARATOR',0x0000006C)
		win_const_mgr.add_const('PHOTOACQ_DISABLE_METADATA_WRITE',0x00000100)
		win_const_mgr.add_const('WIA_IPS_TRANSFER_CAPABILITIES',0x00001819)
		win_const_mgr.add_const('DB_PROT_LEVEL_PKT_INTEGRITY',0x00000004)
		win_const_mgr.add_const('FILE_UNKNOWN',0x00000005)
		win_const_mgr.add_const('KEY_WOW64_RES',0x00000300)
		win_const_mgr.add_const('SV_CACHEDOPENLIMIT_PARMNUM',0x0000023B)
		win_const_mgr.add_const('GM_COMPATIBLE',0x00000001)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_802_11_ALL_MULTICAST_MGMT',0x00100000)
		win_const_mgr.add_const('S_PERIOD512',0x00000000)
		win_const_mgr.add_const('MM_DRVM_ERROR',0x000003D3)
		win_const_mgr.add_const('IMAGE_REL_AMD64_ADDR32NB',0x00000003)
		win_const_mgr.add_const('COLORRES',0x0000006C)
		win_const_mgr.add_const('GD_NAMETABLE',0x0000000F)
		win_const_mgr.add_const('MAPI_OLE',0x00000001)
		win_const_mgr.add_const('MCI_VD_PLAY_SPEED',0x00040000)
		win_const_mgr.add_const('PROV_DH_SCHANNEL',0x00000012)
		win_const_mgr.add_const('TBSTYLE_ALTDRAG',0x00000400)
		win_const_mgr.add_const('SAVE_FORMAT_RICHTEXT',0x00000002)
		win_const_mgr.add_const('COLOR_3DLIGHT',0x00000016)
		win_const_mgr.add_const('RASLCPO_AES_128',0x00000020)
		win_const_mgr.add_const('AUDIT_QUERY_USER_POLICY',0x00000008)
		win_const_mgr.add_const('IF_TYPE_DS1',0x00000012)
		win_const_mgr.add_const('SQL_U_UNION_ALL',0x00000002)
		win_const_mgr.add_const('CR_REMOVE_VETOED',0x00000017)
		win_const_mgr.add_const('MCI_VCR_SETVIDEO_TO',0x00100000)
		win_const_mgr.add_const('MODERATELY_DELAY_SENSITIVE',0xFFFFFFFD)
		win_const_mgr.add_const('CRL_REASON_CERTIFICATE_HOLD',0x00000006)
		win_const_mgr.add_const('ERROR_NO_NETWORK',0x000004C6)
		win_const_mgr.add_const('XP1_MULTIPOINT_DATA_PLANE',0x00001000)
		win_const_mgr.add_const('SUBLANG_FAEROESE_FAROE_ISLANDS',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_BUFFERUNDERRUNFREEDISABLED',0x00000102)
		win_const_mgr.add_const('INDEX_GUID_SHAPENAME',0x00000002)
		win_const_mgr.add_const('SQL_ATTR_FETCH_BOOKMARK_PTR',0x00000010)
		win_const_mgr.add_const('IDM_SENDTOBACK',0x00000021)
		win_const_mgr.add_const('SPI_GETMOUSETRAILS',0x0000005E)
		win_const_mgr.add_const('REG_OPENED_EXISTING_KEY',0x00000002)
		win_const_mgr.add_const('CQPM_HELP',0x00000008)
		win_const_mgr.add_const('INTERNET_CACHE_CONTAINER_NOSUBDIRS',0x00000001)
		win_const_mgr.add_const('OLEIVERB_PRIMARY',0x00000000)
		win_const_mgr.add_const('MF_32_BYTE_ALIGNMENT',0x00000001)
		win_const_mgr.add_const('SESSION_CRYPT_KLEN',0x00000015)
		win_const_mgr.add_const('CM_GLOBAL_STATE_SERVICES_AVAILABLE',0x00000004)
		win_const_mgr.add_const('BASIC_LOG_CONF',0x00000000)
		win_const_mgr.add_const('SQL_CA2_OPT_VALUES_CONCURRENCY',0x00000008)
		win_const_mgr.add_const('NDIS_RING_SINGLE_STATION',0x00000080)
		win_const_mgr.add_const('KDF_TLS_PRF_LABEL',0x00000004)
		win_const_mgr.add_const('SYMFLAG_PARAMETER',0x00000040)
		win_const_mgr.add_const('OID_FDDI_MAC_TRANSMIT_CT',0x0303023D)
		win_const_mgr.add_const('DEBUG_END_DISCONNECT',0x00000004)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_MM_LIMIT',0x0000363A)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_SHUTTING_DOWN',0x00003643)
		win_const_mgr.add_const('CREATE_BYPASS_CSC',0x00000002)
		win_const_mgr.add_const('BCRYPT_PAD_OAEP',0x00000004)
		win_const_mgr.add_const('IF_TYPE_EPLRS',0x00000057)
		win_const_mgr.add_const('NETE_NETDATAERR',0x0000000F)
		win_const_mgr.add_const('COLOR_MATCH_VERSION',0x00000200)
		win_const_mgr.add_const('PANE_OFFLINE',0x00000002)
		win_const_mgr.add_const('DS_RETURN_FLAT_NAME',0x80000000)
		win_const_mgr.add_const('SCARD_E_READER_UNAVAILABLE',0x80100017)
		win_const_mgr.add_const('RASCS_PAUSED',0x00001000)
		win_const_mgr.add_const('SKF_RCTLLOCKED',0x00080000)
		win_const_mgr.add_const('SPI_SETLISTBOXSMOOTHSCROLLING',0x00001007)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_REQUESTEDROTATIONTYPEISPURECAV',0x00000110)
		win_const_mgr.add_const('RIDI_DEVICENAME',0x20000007)
		win_const_mgr.add_const('LVCFMT_SPLITBUTTON',0x01000000)
		win_const_mgr.add_const('_WIN32_IE_WS03',0x00000602)
		win_const_mgr.add_const('UF_WORKSTATION_TRUST_ACCOUNT',0x00001000)
		win_const_mgr.add_const('IDM_TRIED_SEND_BACKWARD',0x00000008)
		win_const_mgr.add_const('SE_ADT_PARAMETERS_SELF_RELATIVE',0x00000001)
		win_const_mgr.add_const('REO_GETMETAFILE',0x00400000)
		win_const_mgr.add_const('TC_CP_STROKE',0x00000004)
		win_const_mgr.add_const('RPC_C_AUTHN_DIGEST',0x00000015)
		win_const_mgr.add_const('SQL_CUR_USE_IF_NEEDED',0x00000000)
		win_const_mgr.add_const('SMC_PROMOTE',0x00000012)
		win_const_mgr.add_const('RP_REMOTE_MTA_NO_DSN',0x00080000)
		win_const_mgr.add_const('SPI_GETHOTTRACKING',0x0000100E)
		win_const_mgr.add_const('LDAP_VERSION_MAX',0x00000003)
		win_const_mgr.add_const('MAX_PACKET_PROPERTY_COUNT',0x00000020)
		win_const_mgr.add_const('ICDRAW_HURRYUP',0x80000000)
		win_const_mgr.add_const('STDPROP_TITLE',0x00000002)
		win_const_mgr.add_const('D3DPRESENT_BACK_BUFFERS_MAX_EX',0x0000001E)
		win_const_mgr.add_const('SERVICE_STOP_REASON_MAJOR_NONE',0x00060000)
		win_const_mgr.add_const('NTMS_REVISION_LENGTH',0x00000020)
		win_const_mgr.add_const('LVBKIF_STYLE_TILE',0x00000010)
		win_const_mgr.add_const('MD_FILTER_STATE_UNLOADED',0x00000004)
		win_const_mgr.add_const('RSVP_DEFAULT_STYLE',0x00000000)
		win_const_mgr.add_const('ILR_VERTICAL_TOP',0x00000000)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_WANT_PROVIDER_WINNT',0x00000002)
		win_const_mgr.add_const('SYSFXUI_DONOTSHOW_LOUDNESSEQUALIZATION',0x00000001)
		win_const_mgr.add_const('PATHLEN',0x00000100)
		win_const_mgr.add_const('FRS_ERR_INVALID_API_SEQUENCE',0x00001F41)
		win_const_mgr.add_const('FACILITY_FWP',0x00000032)
		win_const_mgr.add_const('HTRIGHT',0x0000000B)
		win_const_mgr.add_const('TIFLAGS_EXTENDDISPATCHONLY',0x00000001)
		win_const_mgr.add_const('DEF_MIN_PWLEN',0x00000006)
		win_const_mgr.add_const('SUBLANG_HEBREW_ISRAEL',0x00000001)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_LOAD',0x0000000A)
		win_const_mgr.add_const('BSF_SETNAVIGATABLECODEPAGE',0x00008000)
		win_const_mgr.add_const('RTM_ROUTE_FLAGS_ONES_SUBNETBC',0x00008000)
		win_const_mgr.add_const('F_TAGMISSMATCH',0x00000007)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_WINDOW',0x00000016)
		win_const_mgr.add_const('ISOPROTO_TP0',0x00000019)
		win_const_mgr.add_const('PORT_LOCSRV',0x00000087)
		win_const_mgr.add_const('DMPAPER_JAPANESE_POSTCARD',0x0000002B)
		win_const_mgr.add_const('DOCKINFO_UNDOCKED',0x00000001)
		win_const_mgr.add_const('ALERT_SYSTEM_INFORMATIONAL',0x00000001)
		win_const_mgr.add_const('ISC_RET_IDENTIFY',0x00020000)
		win_const_mgr.add_const('OID_802_11_STATISTICS',0x0D020212)
		win_const_mgr.add_const('WINHTTP_QUERY_PASSPORT_URLS',0x0000004D)
		win_const_mgr.add_const('ERROR_EVT_INVALID_PUBLISHER_NAME',0x00003A9C)
		win_const_mgr.add_const('XEKL_KEYSPEC_SIG',0x00000002)
		win_const_mgr.add_const('LDAPF_SIGNDISABLE',0x00000002)
		win_const_mgr.add_const('ID_BROWSE_CHANGESOURCE',0x00000004)
		win_const_mgr.add_const('KERB_ETYPE_RC4_HMAC_NT',0x00000017)
		win_const_mgr.add_const('ERRACT_RETRY',0x00000001)
		win_const_mgr.add_const('CMSG_SIGNER_ONLY_FLAG',0x00000002)
		win_const_mgr.add_const('MCHT_NEXT',0x01000000)
		win_const_mgr.add_const('ERROR_DS_DECODING_ERROR',0x0000203D)
		win_const_mgr.add_const('MC_SUPPORTED_COLOR_TEMPERATURE_6500K',0x00000004)
		win_const_mgr.add_const('REO_STATIC',0x40000000)
		win_const_mgr.add_const('COLOR_INACTIVECAPTION',0x00000003)
		win_const_mgr.add_const('ERROR_STREAM_MINIVERSION_NOT_FOUND',0x00001A98)
		win_const_mgr.add_const('PPP_CCP_ENCRYPTION56BIT',0x00000080)
		win_const_mgr.add_const('LOCALE_INEGSEPBYSPACE',0x00000057)
		win_const_mgr.add_const('WINHTTP_QUERY_LAST_MODIFIED',0x0000000B)
		win_const_mgr.add_const('SQL_XOPEN_CLI_YEAR',0x00002710)
		win_const_mgr.add_const('LCRED_STATUS_NOCRED',0x00000000)
		win_const_mgr.add_const('IF_TYPE_FR_DLCI_ENDPT',0x000000C1)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_TIMER_CHARACTERISTICS',0x00000097)
		win_const_mgr.add_const('LINEROAMMODE_ROAMB',0x00000010)
		win_const_mgr.add_const('ERROR_CALLBACK_SUPPLIED_INVALID_DATA',0x000004F9)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_ON_DSTNODE',0x00000020)
		win_const_mgr.add_const('PROTO_IP_VRRP',0x00000070)
		win_const_mgr.add_const('LINETRANSLATERESULT_DIALQUIET',0x00000080)
		win_const_mgr.add_const('DDBLT_ALPHASRC',0x00000020)
		win_const_mgr.add_const('CLFS_FLAG_USE_RESERVATION',0x00000004)
		win_const_mgr.add_const('DVM_USER',0x00000000)
		win_const_mgr.add_const('OID_802_11_FRAGMENTATION_THRESHOLD',0x0D010209)
		win_const_mgr.add_const('ERROR_REM_NOT_LIST',0x00000033)
		win_const_mgr.add_const('LVS_SORTDESCENDING',0x00000020)
		win_const_mgr.add_const('PORT_PROFILE',0x00000088)
		win_const_mgr.add_const('DEX_IDS_OUTOFMEMORY',0x00000580)
		win_const_mgr.add_const('ADO_MAJOR',0x00000006)
		win_const_mgr.add_const('DEBUG_GETFNENT_DEFAULT',0x00000000)
		win_const_mgr.add_const('TASK_FRIDAY',0x00000020)
		win_const_mgr.add_const('SV_LANMASK_PARMNUM',0x00000197)
		win_const_mgr.add_const('CHANGER_IEPORT_USER_CONTROL_OPEN',0x80000080)
		win_const_mgr.add_const('MPEG_CAT_TID',0x00000001)
		win_const_mgr.add_const('VIDEO_CONFIGURE_SET',0x00001000)
		win_const_mgr.add_const('METADATA_REFERENCE',0x00000008)
		win_const_mgr.add_const('C2_OTHERNEUTRAL',0x0000000B)
		win_const_mgr.add_const('DPNHINITIALIZE_DISABLEGATEWAYSUPPORT',0x00000001)
		win_const_mgr.add_const('ERROR_DS_OBJ_GUID_EXISTS',0x000020A9)
		win_const_mgr.add_const('HHWIN_BUTTON_HOME',0x00000001)
		win_const_mgr.add_const('ERROR_NO_WRITABLE_DC_FOUND',0x000021AD)
		win_const_mgr.add_const('WIA_AUTO_DESKEW_ON',0x00000000)
		win_const_mgr.add_const('CERT_RDN_ANY_TYPE',0x00000000)
		win_const_mgr.add_const('HHWIN_BUTTON_JUMP2',0x00000001)
		win_const_mgr.add_const('SQL_FN_TD_TIMESTAMPADD',0x00002000)
		win_const_mgr.add_const('HHWIN_BUTTON_JUMP1',0x00000001)
		win_const_mgr.add_const('WEBPOST_ERROR_INIT_FAILED',0xC0042107)
		win_const_mgr.add_const('ALG_SID_SCHANNEL_ENC_KEY',0x00000007)
		win_const_mgr.add_const('WINHTTP_ERROR_BASE',0x00002EE0)
		win_const_mgr.add_const('PXE_REG_INDEX_BOTTOM',0xFFFFFFFF)
		win_const_mgr.add_const('NETE_INVALIDCONN',0x0000000E)
		win_const_mgr.add_const('VHDR_DONE',0x00000001)
		win_const_mgr.add_const('METADATA_INHERIT',0x00000001)
		win_const_mgr.add_const('PDH_INVALID_PATH',0xC0000BC4)
		win_const_mgr.add_const('ERROR_INVALID_WORKSTATION',0x00000531)
		win_const_mgr.add_const('GCP_GLYPHSHAPE',0x00000010)
		win_const_mgr.add_const('ERROR_CTX_MODEM_RESPONSE_ERROR',0x00001B63)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_REPLY',0x00000006)
		win_const_mgr.add_const('SFVM_SETISFV',0x00000027)
		win_const_mgr.add_const('SMC_SFEXEC',0x00000009)
		win_const_mgr.add_const('TF_SFT_LABELS',0x00000080)
		win_const_mgr.add_const('TABLET_DISABLE_SMOOTHSCROLLING',0x00080000)
		win_const_mgr.add_const('D3DSGR_NO_CALIBRATION',0x00000000)
		win_const_mgr.add_const('WNNC_SPEC_VERSION51',0x00050001)
		win_const_mgr.add_const('DNS_ERROR_ZONE_CREATION_FAILED',0x00002588)
		win_const_mgr.add_const('WM_NCMBUTTONUP',0x000000A8)
		win_const_mgr.add_const('ERROR_NO_YIELD_PERFORMED',0x000002D1)
		win_const_mgr.add_const('LCPRI_REBOOT',0x00009000)
		win_const_mgr.add_const('FACILITY_GRAPHICS_KERNEL',0x0000001E)
		win_const_mgr.add_const('MAX_INTERFACE_INDEX',0xFFFFFFFE)
		win_const_mgr.add_const('FAX_ERR_NOT_NTFS',0x00001B5E)
		win_const_mgr.add_const('BITS_MC_FILE_DELETION_FAILED_MORE',0x80194002)
		win_const_mgr.add_const('ERROR_LOG_READ_CONTEXT_INVALID',0x000019CE)
		win_const_mgr.add_const('ERROR_IPSEC_SA_LIFETIME_EXPIRED',0x00003657)
		win_const_mgr.add_const('WC_DEFAULTCHAR',0x00000040)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_IMAGE',0x00000465)
		win_const_mgr.add_const('DDSCAPS_LIVEVIDEO',0x00080000)
		win_const_mgr.add_const('ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER',0x00001A39)
		win_const_mgr.add_const('FS_RECEIVING',0x20000004)
		win_const_mgr.add_const('TRACE_LEVEL_WARNING',0x00000003)
		win_const_mgr.add_const('FR_PROP_OTHERINFOCHOICE',0x00000006)
		win_const_mgr.add_const('AW_BLEND',0x00080000)
		win_const_mgr.add_const('CERT_ENROLLMENT_PROP_ID',0x0000001A)
		win_const_mgr.add_const('SFGAO_HASPROPSHEET',0x00000040)
		win_const_mgr.add_const('BATTERY_IS_SHORT_TERM',0x20000000)
		win_const_mgr.add_const('LOGON_NTLM_V2',0x00002000)
		win_const_mgr.add_const('D3DVS20_MAX_STATICFLOWCONTROLDEPTH',0x00000004)
		win_const_mgr.add_const('ICM_LEVEL2_SUI',0x00000004)
		win_const_mgr.add_const('GCPGLYPH_LINKBEFORE',0x00008000)
		win_const_mgr.add_const('SPRP_NORMAL',0x00000000)
		win_const_mgr.add_const('PS_4M',0x00000016)
		win_const_mgr.add_const('PS_4K',0x0000000C)
		win_const_mgr.add_const('OID_802_11_ASSOCIATION_INFORMATION',0x0D01011F)
		win_const_mgr.add_const('SCARD_E_UNKNOWN_READER',0x80100009)
		win_const_mgr.add_const('VIF_CANNOTLOADCABINET',0x00100000)
		win_const_mgr.add_const('ERROR_GLOBAL_ONLY_HOOK',0x00000595)
		win_const_mgr.add_const('IDM_SETPRINTHANDLES',0x00003A9A)
		win_const_mgr.add_const('INTERNET_OPTION_REQUEST_FLAGS',0x00000017)
		win_const_mgr.add_const('SHCNF_FLUSH',0x00001000)
		win_const_mgr.add_const('AMDDS_RGBOVR',0x00000004)
		win_const_mgr.add_const('HTTP_STATUS_PARTIAL_CONTENT',0x000000CE)
		win_const_mgr.add_const('WIA_DPS_DOCUMENT_HANDLING_CAPABILITIES',0x00000C0E)
		win_const_mgr.add_const('FILE_DEVICE_MULTI_UNC_PROVIDER',0x00000010)
		win_const_mgr.add_const('PIDSI_LYRICS',0x0000000C)
		win_const_mgr.add_const('FILE_ACTION_ADDED',0x00000001)
		win_const_mgr.add_const('IDM_LINEBREAKRIGHT',0x00000869)
		win_const_mgr.add_const('DDSCAPS2_OPAQUE',0x00000080)
		win_const_mgr.add_const('MSIM_DISPID_ONNEWSESSIONREQUEST',0x00000E0F)
		win_const_mgr.add_const('CHECKSUM_SUCCESS',0x00000000)
		win_const_mgr.add_const('ETO_NUMERICSLOCAL',0x00000400)
		win_const_mgr.add_const('SECPKG_MAX_OID_LENGTH',0x00000020)
		win_const_mgr.add_const('SMINIT_VERTICAL',0x10000000)
		win_const_mgr.add_const('SERKF_INDICATOR',0x00000004)
		win_const_mgr.add_const('SUBSCRIPTION_CAP_ALLOWPLAY',0x00000001)
		win_const_mgr.add_const('STATE_SYSTEM_MARQUEED',0x00002000)
		win_const_mgr.add_const('INTERNET_STATUS_DETECTING_PROXY',0x00000050)
		win_const_mgr.add_const('STRICT',0x00000001)
		win_const_mgr.add_const('KSEG3_VRN',0x00000004)
		win_const_mgr.add_const('LINECALLREASON_ROUTEREQUEST',0x00008000)
		win_const_mgr.add_const('DVM_CONFIGURE_END',0x00001FFF)
		win_const_mgr.add_const('VK_OEM_PLUS',0x000000BB)
		win_const_mgr.add_const('STAT_DONE',0x00000002)
		win_const_mgr.add_const('MFSESSIONCAP_RATE_FORWARD',0x00000010)
		win_const_mgr.add_const('VK_INSERT',0x0000002D)
		win_const_mgr.add_const('REPL_ROLE_EXPORT',0x00000001)
		win_const_mgr.add_const('MCI_VCR_GETDEVCAPS_CAN_DETECT_LENGTH',0x00004001)
		win_const_mgr.add_const('TA_UPDATECP',0x00000001)
		win_const_mgr.add_const('ERROR_CS_ENCRYPTION_FILE_NOT_CSE',0x00001785)
		win_const_mgr.add_const('WMDM_SEEK_STREAMINGAUDIO',0x00000002)
		win_const_mgr.add_const('D3DVS_ADDRESSMODE_SHIFT',0x0000000D)
		win_const_mgr.add_const('ERROR_RELOC_CHAIN_XEEDS_SEGLIM',0x000000C9)
		win_const_mgr.add_const('NRC_INUSE',0x00000016)
		win_const_mgr.add_const('ADN_DONT_DEL_SUBDIRS',0x00000002)
		win_const_mgr.add_const('CRYPT_DEFAULT_CONTAINER_OPTIONAL',0x00000080)
		win_const_mgr.add_const('LANG_RUSSIAN',0x00000019)
		win_const_mgr.add_const('LINECALLHUBTRACKING_PROVIDERLEVEL',0x00000001)
		win_const_mgr.add_const('PPP_LCP_CHAP_MSV2',0x00000081)
		win_const_mgr.add_const('IMAGE_REL_PPC_TYPEMASK',0x000000FF)
		win_const_mgr.add_const('LVS_EX_TWOCLICKACTIVATE',0x00000080)
		win_const_mgr.add_const('CBEIF_DI_SETITEM',0x10000000)
		win_const_mgr.add_const('URLACTION_SCRIPT_CURR_MAX',0x00001408)
		win_const_mgr.add_const('IDM_OPEN',0x000007D0)
		win_const_mgr.add_const('ERRCLASS_TIME',0x0000000F)
		win_const_mgr.add_const('BITSPIXEL',0x0000000C)
		win_const_mgr.add_const('R2_NOTXORPEN',0x0000000A)
		win_const_mgr.add_const('PRINTER_ENUM_NETWORK',0x00000040)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_ND_BOUNDARY',0x00000002)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_ACTIONS',0x00000008)
		win_const_mgr.add_const('IF_TYPE_STACKTOSTACK',0x0000006F)
		win_const_mgr.add_const('DRIVE_RAMDISK',0x00000006)
		win_const_mgr.add_const('MCI_DGV_FF_DIB',0x00004002)
		win_const_mgr.add_const('DSF_CPL_MODE',0x00010000)
		win_const_mgr.add_const('OID_CO_TAPI_GET_CALL_DIAGNOSTICS',0xFE001007)
		win_const_mgr.add_const('MDIS_ALLCHILDSTYLES',0x00000001)
		win_const_mgr.add_const('RPC_C_MQ_AUTHN_LEVEL_PKT_PRIVACY',0x00000010)
		win_const_mgr.add_const('ISCSI_TARGET_FLAG_HIDE_STATIC_TARGET',0x00000002)
		win_const_mgr.add_const('VFT_FONT',0x00000004)
		win_const_mgr.add_const('ISO_MAX_ADDR_LENGTH',0x00000040)
		win_const_mgr.add_const('CSRESTORE_TYPE_MASK',0x00000005)
		win_const_mgr.add_const('NS_WINS',0x0000000E)
		win_const_mgr.add_const('PLANES',0x0000000E)
		win_const_mgr.add_const('DISPLAY_DEVICE_UNSAFE_MODES_ON',0x00080000)
		win_const_mgr.add_const('TMT_SOURCESHRINK',0x000008A5)
		win_const_mgr.add_const('TABLET_DISABLE_TOUCHSWITCH',0x00008000)
		win_const_mgr.add_const('VFT2_FONT_TRUETYPE',0x00000003)
		win_const_mgr.add_const('HSHELL_REDRAW',0x00000006)
		win_const_mgr.add_const('CERT_NON_REPUDIATION_KEY_USAGE',0x00000040)
		win_const_mgr.add_const('IDM_IMAGEMAP',0x0000087B)
		win_const_mgr.add_const('DMDITHER_COARSE',0x00000002)
		win_const_mgr.add_const('PFL_HIDDEN',0x00000004)
		win_const_mgr.add_const('STI_GENCAP_POLLING_NEEDED',0x00000002)
		win_const_mgr.add_const('SETDIBSCALING',0x00000020)
		win_const_mgr.add_const('WB_LEFT',0x00000000)
		win_const_mgr.add_const('RPC_C_AUTHN_DEC_PUBLIC',0x00000004)
		win_const_mgr.add_const('NABTS_PAYLOAD_PER_LINE',0x0000001C)
		win_const_mgr.add_const('DNS_RTYPE_MAILB',0x00000000)
		win_const_mgr.add_const('TSF_COPY_WRITE_TIME',0x00000020)
		win_const_mgr.add_const('ID_APP',0x00000064)
		win_const_mgr.add_const('MDMEASURE_AGGR_COUNT',0x00000002)
		win_const_mgr.add_const('LINEERR_USERCANCELLED',0x8000005D)
		win_const_mgr.add_const('PHONEHOOKSWITCHDEV_HEADSET',0x00000004)
		win_const_mgr.add_const('MD_CPU_ENABLE_ACTIVE_PROCS',0x00000040)
		win_const_mgr.add_const('WMAAECMA_E_NO_ACTIVE_RENDER_STREAM',0x87CC000A)
		win_const_mgr.add_const('WKSTA_LOCKQUOTA_PARMNUM',0x00000029)
		win_const_mgr.add_const('EAP_E_USER_CREDENTIALS_REJECTED',0x80420111)
		win_const_mgr.add_const('IMAGE_RESOURCE_DATA_IS_DIRECTORY',0x80000000)
		win_const_mgr.add_const('IDM_TRISTATEITALIC',0x00000060)
		win_const_mgr.add_const('TMT_FROMHUE1',0x00000709)
		win_const_mgr.add_const('TMT_FROMHUE2',0x0000070A)
		win_const_mgr.add_const('TMT_FROMHUE3',0x0000070B)
		win_const_mgr.add_const('MCI_DGV_UPDATE_HDC',0x00020000)
		win_const_mgr.add_const('CMF_RESERVED',0x00000000)
		win_const_mgr.add_const('PHOTO_SATURATION_LOW',0x00000001)
		win_const_mgr.add_const('LVGA_HEADER_RIGHT',0x00000004)
		win_const_mgr.add_const('TCS_RAGGEDRIGHT',0x00000800)
		win_const_mgr.add_const('IDM_STATUSBAR',0x00000853)
		win_const_mgr.add_const('PERF_DATA_REVISION',0x00000001)
		win_const_mgr.add_const('RECOVERY_MAX_PING_INTERVAL',0x00000005)
		win_const_mgr.add_const('RPC_C_HTTP_AUTHN_TARGET_SERVER',0x00000001)
		win_const_mgr.add_const('BF_TOP',0x00000002)
		win_const_mgr.add_const('POWER_SETTING_VALUE_VERSION',0x00000001)
		win_const_mgr.add_const('MCI_ANIM_REALIZE_NORM',0x00010000)
		win_const_mgr.add_const('WAVECAPS_PITCH',0x00000001)
		win_const_mgr.add_const('SQL_FN_STR_SOUNDEX',0x00020000)
		win_const_mgr.add_const('WPWIZ_ERROR_PROPSHEET_ERROR',0xC0042009)
		win_const_mgr.add_const('UDP_PROTOCOL_UUID16',0x00000002)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_RESERVED',0x00000080)
		win_const_mgr.add_const('CIF_SELECTCURRENT',0x00000002)
		win_const_mgr.add_const('DBIF_VIEWMODE_FLOATING',0x00000002)
		win_const_mgr.add_const('ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED',0x000004FA)
		win_const_mgr.add_const('QUERY_ACTCTX_FLAG_ACTCTX_IS_ADDRESS',0x00000010)
		win_const_mgr.add_const('PORT_MITDOV',0x0000005B)
		win_const_mgr.add_const('PID_IS_COMMENT',0x0000000D)
		win_const_mgr.add_const('CM_GLOBAL_STATE_SHUTTING_DOWN',0x00000008)
		win_const_mgr.add_const('FOFX_MOVEACLSACROSSVOLUMES',0x02000000)
		win_const_mgr.add_const('SV_REQUIRESECURITYSIGNATURE_PARMNUM',0x00000252)
		win_const_mgr.add_const('AF_OP_ACCOUNTS',0x00000008)
		win_const_mgr.add_const('DEBUG_OUTPUT_VERBOSE',0x00000008)
		win_const_mgr.add_const('MF_2_BYTE_ALIGNMENT',0x00000001)
		win_const_mgr.add_const('SQL_KEYSET_SIZE',0x00000008)
		win_const_mgr.add_const('CDO_E_OUTOFDATE',0x80040239)
		win_const_mgr.add_const('DDSCAPS2_MIPMAPSUBLEVEL',0x00010000)
		win_const_mgr.add_const('SQL_API_SQLEXECUTE',0x0000000C)
		win_const_mgr.add_const('IDM_SHOWZEROBORDERATDESIGNTIME',0x00000918)
		win_const_mgr.add_const('WIA_COMPRESSION_G4',0x00000004)
		win_const_mgr.add_const('MAX_DMA_CHANNELS',0x00000007)
		win_const_mgr.add_const('GC_WCH_CONTAINED',0x00000003)
		win_const_mgr.add_const('SCS_32BIT_BINARY',0x00000000)
		win_const_mgr.add_const('WSAEAFNOSUPPORT',0x0000273F)
		win_const_mgr.add_const('WIA_DPS_SERVICE_ID',0x00000C29)
		win_const_mgr.add_const('CTFMODEBIAS_KATAKANA',0x00000008)
		win_const_mgr.add_const('OPF_OBJECTISLINK',0x00000001)
		win_const_mgr.add_const('CCH_RM_MAX_APP_NAME',0x000000FF)
		win_const_mgr.add_const('OID_FDDI_PORT_HARDWARE_PRESENT',0x03030276)
		win_const_mgr.add_const('D3D9_RESOURCE_PRIORITY_MAXIMUM',0x00000000)
		win_const_mgr.add_const('ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT',0x00003717)
		win_const_mgr.add_const('CERT_PHYSICAL_STORE_REMOTE_OPEN_DISABLE_FLAG',0x00000004)
		win_const_mgr.add_const('KSPROPERTY_TYPE_SETSUPPORT',0x00000100)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_VOLUMEPATHNAMES',0x00000205)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_CLOCKTIME',0x00040000)
		win_const_mgr.add_const('LP_COLOR',0x00000004)
		win_const_mgr.add_const('WM_IME_COMPOSITIONFULL',0x00000284)
		win_const_mgr.add_const('SQL_OSC_CORE',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_DERIVED_FROM',0x0000000E)
		win_const_mgr.add_const('PAN_MIDLINE_HIGH_POINTED',0x00000006)
		win_const_mgr.add_const('DDSCAPS3_MULTISAMPLE_QUALITY_MASK',0x000000E0)
		win_const_mgr.add_const('MAX_EVENT_DATA_DESCRIPTORS',0x00000080)
		win_const_mgr.add_const('PRODUCT_HOME_BASIC',0x00000002)
		win_const_mgr.add_const('DEBUG_SYMBOL_IS_ARRAY',0x00000040)
		win_const_mgr.add_const('PID_INTSITE_LASTMOD',0x00000005)
		win_const_mgr.add_const('GOPHER_TYPE_ASK',0x40000000)
		win_const_mgr.add_const('MD_SCRIPTMAPFLAG_SCRIPT',0x00000001)
		win_const_mgr.add_const('TF_SHOW_BALLOON',0x00000001)
		win_const_mgr.add_const('PORT_SGMP',0x00000099)
		win_const_mgr.add_const('EMARCH_ENC_I17_IC_INST_WORD_POS_X',0x0000000C)
		win_const_mgr.add_const('MCI_VD_STATUS_DISC_SIZE',0x00004006)
		win_const_mgr.add_const('REGDF_CONFLICTDMA',0x00080000)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_LOG_AUTO_SHRINK_PERCENTAGE',0x00000020)
		win_const_mgr.add_const('ILDRF_IMAGELOWQUALITY',0x00000001)
		win_const_mgr.add_const('TASK_FLAG_DISABLED',0x00000004)
		win_const_mgr.add_const('TB_PAGEDOWN',0x00000003)
		win_const_mgr.add_const('TRUSTERROR_STEP_VERIFY_MSGHASH',0x00000012)
		win_const_mgr.add_const('WIA_DPA_FIRMWARE_VERSION',0x00000402)
		win_const_mgr.add_const('NTM_REGULAR',0x00000040)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_BLOCK',0x00000064)
		win_const_mgr.add_const('TR_A',0x00000005)
		win_const_mgr.add_const('ISR_PROBE_FAULT',0x00000005)
		win_const_mgr.add_const('FMFOCUS_SEARCH',0x00000004)
		win_const_mgr.add_const('TR_D',0x00000006)
		win_const_mgr.add_const('MIXERLINE_TARGETTYPE_AUX',0x00000005)
		win_const_mgr.add_const('DATABITS_6',0x00000002)
		win_const_mgr.add_const('BACKUP_LINK',0x00000005)
		win_const_mgr.add_const('QOS_OBJECT_TCP_TRAFFIC',0x00000004)
		win_const_mgr.add_const('DOSOPTF_MULTIPLE',0x00000080)
		win_const_mgr.add_const('RTL_RUN_ONCE_CHECK_ONLY',0x00000001)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_NOACCESS',0x00000006)
		win_const_mgr.add_const('NRC_OPENERR',0x00000003)
		win_const_mgr.add_const('DS_DNS_DOMAIN_FLAG',0x40000000)
		win_const_mgr.add_const('LINEINITIALIZEEXOPTION_CALLHUBTRACKING',0x80000000)
		win_const_mgr.add_const('STGM_COLLECTION',0x00002000)
		win_const_mgr.add_const('COOKIEACTION_NONE',0x00000000)
		win_const_mgr.add_const('TLS1_ALERT_UNKNOWN_CA',0x00000030)
		win_const_mgr.add_const('WINHTTP_OPTION_PROXY_USERNAME',0x00001002)
		win_const_mgr.add_const('HHWIN_PROP_TAB_ADVSEARCH',0x00000001)
		win_const_mgr.add_const('MAPI_PEEK',0x00000080)
		win_const_mgr.add_const('ABM_GETAUTOHIDEBAR',0x00000007)
		win_const_mgr.add_const('HTTP_URL_FLAG_REMOVE_ALL',0x00000001)
		win_const_mgr.add_const('CERT_STORE_PROV_GET_CERT_PROPERTY_FUNC',0x00000010)
		win_const_mgr.add_const('GPT_PARTITION_NAME_LENGTH',0x00000024)
		win_const_mgr.add_const('IDO_SHGIOI_SLOWFILE',0xFFFFFFFD)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_HUNG',0x00000005)
		win_const_mgr.add_const('TVHT_TOLEFT',0x00000800)
		win_const_mgr.add_const('DNS_ERROR_DATAFILE_PARSING',0x000025B7)
		win_const_mgr.add_const('VK_HELP',0x0000002F)
		win_const_mgr.add_const('SPOOL_FILE_PERSISTENT',0x00000001)
		win_const_mgr.add_const('IDM_INSINPUTRESET',0x00000844)
		win_const_mgr.add_const('HCF_HOTKEYSOUND',0x00000010)
		win_const_mgr.add_const('DDOVER_ALPHAEDGEBLEND',0x00000010)
		win_const_mgr.add_const('PLA_CAPABILITY_LEGACY_SVC',0x00000010)
		win_const_mgr.add_const('OID_FDDI_MAC_TVX_EXPIRED_CT',0x03030241)
		win_const_mgr.add_const('CLIP_TT_ALWAYS',0x00000002)
		win_const_mgr.add_const('SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES2',0x00000093)
		win_const_mgr.add_const('SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES1',0x00000092)
		win_const_mgr.add_const('ARCONTENT_NONE',0x00000000)
		win_const_mgr.add_const('NDIS_STATISTICS_FLAGS_VALID_BROADCAST_BYTES_XMIT',0x00200000)
		win_const_mgr.add_const('MAPMIME_DEFAULT_ALWAYS',0x00000003)
		win_const_mgr.add_const('ERROR_NOT_ENOUGH_SERVER_MEMORY',0x0000046A)
		win_const_mgr.add_const('SUBLANG_GERMAN_LIECHTENSTEIN',0x00000005)
		win_const_mgr.add_const('PBT_APMOEMEVENT',0x0000000B)
		win_const_mgr.add_const('PAN_BENT_ARMS_HORZ',0x00000007)
		win_const_mgr.add_const('OID_802_11_RSSI',0x0D010206)
		win_const_mgr.add_const('TCP_OFFLOAD_PREFERRED',0x00000002)
		win_const_mgr.add_const('HHT_ONHEADER',0x00000002)
		win_const_mgr.add_const('MIN_DIMENSION',0x00000001)
		win_const_mgr.add_const('TOKEN_QUERY',0x00000008)
		win_const_mgr.add_const('NS_VNS',0x00000032)
		win_const_mgr.add_const('MDPROPVAL_MMF_PARALLELPERIOD',0x00000002)
		win_const_mgr.add_const('IPPORT_NETBIOS_DGM',0x0000008A)
		win_const_mgr.add_const('SMC_SETSFOBJECT',0x0000002D)
		win_const_mgr.add_const('IMAGE_REL_BASED_HIGH',0x00000001)
		win_const_mgr.add_const('DUPLICATE',0x00000006)
		win_const_mgr.add_const('IDS_CAP_WAVE_ALLOC_ERROR',0x000001A4)
		win_const_mgr.add_const('PHOTOACQ_DISABLE_THUMBNAIL_PROGRESS',0x00000200)
		win_const_mgr.add_const('MIXERR_BASE',0x00000400)
		win_const_mgr.add_const('COMMON_LVB_SBCSDBCS',0x00000300)
		win_const_mgr.add_const('DXVA_MV_PRECISION_AND_CHROMA_RELATION_H261',0x00000002)
		win_const_mgr.add_const('DOMAIN_REFUSE_PASSWORD_CHANGE',0x00000020)
		win_const_mgr.add_const('DEVPROP_TYPE_NULL',0x00000001)
		win_const_mgr.add_const('TXTLOG_FLUSH_FILE',0x00100000)
		win_const_mgr.add_const('HTTP_QUERY_IF_RANGE',0x0000003A)
		win_const_mgr.add_const('DIRID_BOOT',0x0000001E)
		win_const_mgr.add_const('DXVA_CONFIG_DATA_TYPE_IA44',0x00000000)
		win_const_mgr.add_const('SO_REUSEADDR',0x00000004)
		win_const_mgr.add_const('IDM_FORMATMARK',0x00000854)
		win_const_mgr.add_const('ABE_BOTTOM',0x00000003)
		win_const_mgr.add_const('TXFS_START_RM_FLAG_LOG_CONTAINER_SIZE',0x00000004)
		win_const_mgr.add_const('SCARD_E_NOT_READY',0x80100010)
		win_const_mgr.add_const('WMS_STREAM_BROADCAST_GENERATION_ID',0x00000010)
		win_const_mgr.add_const('D3DSGR_CALIBRATE',0x00000001)
		win_const_mgr.add_const('IR_STRINGEND',0x00000101)
		win_const_mgr.add_const('ISR_MBZ0_V',0x00000000)
		win_const_mgr.add_const('DMDITHER_USER',0x00000100)
		win_const_mgr.add_const('DAV_LEVEL1_STATUS',0x00000001)
		win_const_mgr.add_const('ALG_TYPE_ANY',0x00000000)
		win_const_mgr.add_const('MAPI_ONE_OFF_NO_RICH_INFO',0x00000001)
		win_const_mgr.add_const('SPI_GETMOUSE',0x00000003)
		win_const_mgr.add_const('ERROR_DS_GROUP_CONVERSION_ERROR',0x0000219F)
		win_const_mgr.add_const('VK_RWIN',0x0000005C)
		win_const_mgr.add_const('AD_APPLY_DYNAMICREFRESH',0x00000020)
		win_const_mgr.add_const('ENM_REQUESTRESIZE',0x00040000)
		win_const_mgr.add_const('RAS_EAP_ROLE_AUTHENTICATOR',0x00000001)
		win_const_mgr.add_const('SQL_CONVERT_FUNCTIONS',0x00000030)
		win_const_mgr.add_const('PROTO_IP_ALG',0x0000271A)
		win_const_mgr.add_const('TF_MOD_IGNORE_ALL_MODIFIER',0x00000400)
		win_const_mgr.add_const('MAPI_CC',0x00000002)
		win_const_mgr.add_const('DDOVERZ_SENDTOBACK',0x00000001)
		win_const_mgr.add_const('HCBT_MOVESIZE',0x00000000)
		win_const_mgr.add_const('PHOTO_LIGHTSOURCE_D65',0x00000015)
		win_const_mgr.add_const('MF_MEDIATYPE_EQUAL_FORMAT_USER_DATA',0x00000008)
		win_const_mgr.add_const('NORM_IGNORESYMBOLS',0x00000004)
		win_const_mgr.add_const('ERROR_ABANDON_HIBERFILE',0x00000313)
		win_const_mgr.add_const('ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE',0x00001B92)
		win_const_mgr.add_const('WIA_PAGE_JIS_2A',0x00000032)
		win_const_mgr.add_const('VP_TV_STANDARD_NTSC_M',0x00000001)
		win_const_mgr.add_const('RPC_S_MAX_CALLS_TOO_SMALL',0x000006CE)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_HOUR_TO_SECOND',0x00004000)
		win_const_mgr.add_const('PFM_OUTLINELEVEL',0x02000000)
		win_const_mgr.add_const('MB_OKCANCEL',0x00000001)
		win_const_mgr.add_const('INTERNET_ERROR_MASK_COMBINED_SEC_CERT',0x00000002)
		win_const_mgr.add_const('ES_DISABLENOSCROLL',0x00002000)
		win_const_mgr.add_const('ERROR_INDOUBT_TRANSACTIONS_EXIST',0x00001AAB)
		win_const_mgr.add_const('CERT_SOURCE_URL_PROP_ID',0x00000049)
		win_const_mgr.add_const('WINHTTP_OPTION_REDIRECT_POLICY_DISALLOW_HTTPS_TO_HTTP',0x00000001)
		win_const_mgr.add_const('WIA_PROPPAGE_SCANNER_ITEM_GENERAL',0x00000001)
		win_const_mgr.add_const('SQL_DESC_PRECISION',0x000003ED)
		win_const_mgr.add_const('DEBUG_NOTIFY_SESSION_ACCESSIBLE',0x00000002)
		win_const_mgr.add_const('DISPID_NEWDOCUMENT',0x0000001B)
		win_const_mgr.add_const('MQMSG_AUTHENTICATED_SIG30',0x00000005)
		win_const_mgr.add_const('DDPCAPS_VSYNC',0x00000080)
		win_const_mgr.add_const('INDEX_GUID_CONFIDENCELEVEL',0x0000000C)
		win_const_mgr.add_const('IDF_USEDISKNAMEASPROMPT',0x00002000)
		win_const_mgr.add_const('GOPHER_TYPE_MAC_BINHEX',0x00000010)
		win_const_mgr.add_const('MIIM_CHECKMARKS',0x00000008)
		win_const_mgr.add_const('SPDRP_DEVICEDESC',0x00000000)
		win_const_mgr.add_const('CSIDL_RESOURCES',0x00000038)
		win_const_mgr.add_const('LINECALLFEATURE_REMOVEFROMCONF',0x00040000)
		win_const_mgr.add_const('COLORMGMTDLGORD',0x0000060F)
		win_const_mgr.add_const('MOUSE_MOVE_NOCOALESCE',0x00000008)
		win_const_mgr.add_const('SQL_FN_STR_SPACE',0x00040000)
		win_const_mgr.add_const('ERROR_TOO_MANY_THREADS',0x00000235)
		win_const_mgr.add_const('DDPCAPS_INITIALIZE',0x00000000)
		win_const_mgr.add_const('LINEDEVSTATE_REINIT',0x00040000)
		win_const_mgr.add_const('HHWIN_PROP_NODEF_EXSTYLES',0x00000001)
		win_const_mgr.add_const('ERROR_DS_NO_RESULTS_RETURNED',0x00002041)
		win_const_mgr.add_const('DLCTL_BGSOUNDS',0x00000040)
		win_const_mgr.add_const('SAFER_CRITERIA_URLZONE',0x00000010)
		win_const_mgr.add_const('ERROR_UNMAPPED_SUBSTITUTION_STRING',0x00003710)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_MIPS16',0x00000266)
		win_const_mgr.add_const('PS_TYPE_MASK',0x000F0000)
		win_const_mgr.add_const('NDIS_802_11_AI_RESFI_ASSOCIATIONID',0x00000004)
		win_const_mgr.add_const('CAUSE_NA_NORMAL',0x00000000)
		win_const_mgr.add_const('TAPIMAXDEVICECLASSSIZE',0x00000028)
		win_const_mgr.add_const('DICS_FLAG_GLOBAL',0x00000001)
		win_const_mgr.add_const('LOGON_LM_V2',0x00001000)
		win_const_mgr.add_const('C1_LOWER',0x00000002)
		win_const_mgr.add_const('ERROR_DS_COULDNT_UPDATE_SPNS',0x0000214D)
		win_const_mgr.add_const('WTS_EVENT_CONNECT',0x00000008)
		win_const_mgr.add_const('MUI_FILETYPE_LANGUAGE_NEUTRAL_MUI',0x00000004)
		win_const_mgr.add_const('MCI_DGV_LIST_VIDEO_SOURCE',0x00004008)
		win_const_mgr.add_const('IP_TTL',0x00000004)
		win_const_mgr.add_const('CSA_RGB',0x00000006)
		win_const_mgr.add_const('MM_MOM_POSITIONCB',0x000003CA)
		win_const_mgr.add_const('LCID_SUPPORTED',0x00000002)
		win_const_mgr.add_const('SQL_UB_VARIABLE',0x00000002)
		win_const_mgr.add_const('SSPROP_INIT_AUTOTRANSLATE',0x00000008)
		win_const_mgr.add_const('RPCFLG_HAS_GUARANTEE',0x00000010)
		win_const_mgr.add_const('LAPI_MAJOR_VER1',0x00000001)
		win_const_mgr.add_const('TRACE_LEVEL_VERBOSE',0x00000005)
		win_const_mgr.add_const('RSC_MODE_LY',0x00000000)
		win_const_mgr.add_const('COOKIE_DONT_ALLOW',0x00000001)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_FAST_FORWARD',0x00000031)
		win_const_mgr.add_const('RDW_ERASE',0x00000004)
		win_const_mgr.add_const('SOUND_SYSTEM_WARNING',0x00000006)
		win_const_mgr.add_const('ACCESS_CREATE',0x00000004)
		win_const_mgr.add_const('NDR64_FC_NO_HANDLE',0x00000005)
		win_const_mgr.add_const('PDH_SQL_MORE_RESULTS_FAILED',0xC0000BE5)
		win_const_mgr.add_const('WNPS_DIR',0x00000001)
		win_const_mgr.add_const('RTCSI_PC_TO_PC',0x00000001)
		win_const_mgr.add_const('URLACTION_SHELL_ENHANCED_DRAGDROP_SECURITY',0x0000180B)
		win_const_mgr.add_const('RSC_MODE_LI',0x00000002)
		win_const_mgr.add_const('MM_JOY2BUTTONDOWN',0x000003B6)
		win_const_mgr.add_const('GCS_VERBA',0x00000000)
		win_const_mgr.add_const('DEVPROP_TYPE_CURRENCY',0x0000000E)
		win_const_mgr.add_const('VER_CONDITION_MASK',0x00000007)
		win_const_mgr.add_const('INK_ERROR_BASE',0x00000000)
		win_const_mgr.add_const('SQL_DIAG_CONNECTION_NAME',0x0000000A)
		win_const_mgr.add_const('EMR_POLYTEXTOUTW',0x00000061)
		win_const_mgr.add_const('FLAG_ENABLE_CHROMATIC_ADAPTATION',0x02000000)
		win_const_mgr.add_const('PRODUCT_BUSINESS',0x00000006)
		win_const_mgr.add_const('RAS_EAP_FLAG_PEAP_FORCE_FULL_AUTH',0x00001000)
		win_const_mgr.add_const('NDIS_LINK_STATE_PAUSE_FUNCTIONS_AUTO_NEGOTIATED',0x00000008)
		win_const_mgr.add_const('SUPPORTS_MSCPLUS_VAL',0x00000001)
		win_const_mgr.add_const('LINEDEVSTATE_TERMINALS',0x00002000)
		win_const_mgr.add_const('GCS_VERBW',0x00000004)
		win_const_mgr.add_const('CI_STATE_STARTING',0x00002000)
		win_const_mgr.add_const('LINECALLFEATURE_SETUPTRANSFER',0x02000000)
		win_const_mgr.add_const('STATE_SYSTEM_MIXED',0x00000020)
		win_const_mgr.add_const('CDB2GVF_ALLOWPREVIEWPANE',0x00000004)
		win_const_mgr.add_const('NDIS_ETH_TYPE_SLOW_PROTOCOL',0x00008809)
		win_const_mgr.add_const('CP_LEVEL',0x00000003)
		win_const_mgr.add_const('PSD_INTHOUSANDTHSOFINCHES',0x00000004)
		win_const_mgr.add_const('OID_GEN_MEDIA_CAPABILITIES',0x00010201)
		win_const_mgr.add_const('WINHTTP_QUERY_REQUEST_METHOD',0x0000002D)
		win_const_mgr.add_const('CBA_READ_MEMORY',0x00000006)
		win_const_mgr.add_const('EMR_POLYLINETO16',0x00000059)
		win_const_mgr.add_const('MS_SHOWMAGNIFIEDCURSOR',0x00000001)
		win_const_mgr.add_const('LVS_EX_SIMPLESELECT',0x00100000)
		win_const_mgr.add_const('PSINJECT_ORIENTATION',0x00000008)
		win_const_mgr.add_const('ERROR_SXS_IDENTITIES_DIFFERENT',0x00003716)
		win_const_mgr.add_const('EXTTEXTOUT',0x00000200)
		win_const_mgr.add_const('RES_ICON',0x00000001)
		win_const_mgr.add_const('IF_TYPE_IEEE1394',0x00000090)
		win_const_mgr.add_const('BLKHOLE_XURTYPE',0x00000004)
		win_const_mgr.add_const('OBJ_BITMAP',0x00000007)
		win_const_mgr.add_const('CSIDL_MYPICTURES',0x00000027)
		win_const_mgr.add_const('FAIL',0x00000000)
		win_const_mgr.add_const('WM_NCPAINT',0x00000085)
		win_const_mgr.add_const('SQL_PT_UNKNOWN',0x00000000)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_INCONSISTENTNAME',0x00000012)
		win_const_mgr.add_const('NET_IGNORE_UNSUPPORTED_FLAGS',0x00000001)
		win_const_mgr.add_const('DDSCAPS_SYSTEMMEMORY',0x00000800)
		win_const_mgr.add_const('CM_OPEN_CLASS_KEY_INSTALLER',0x00000000)
		win_const_mgr.add_const('NT4SP4_MAJOR_VERSION',0x00000002)
		win_const_mgr.add_const('EMR_POLYTEXTOUTA',0x00000060)
		win_const_mgr.add_const('WKSTA_LANGROUP_PARMNUM',0x00000002)
		win_const_mgr.add_const('MINLONG',0x80000000)
		win_const_mgr.add_const('SBSP_WRITENOHISTORY',0x08000000)
		win_const_mgr.add_const('DS_ROLE_SCHEMA_OWNER',0x00000000)
		win_const_mgr.add_const('PAN_ARMSTYLE_INDEX',0x00000006)
		win_const_mgr.add_const('PAN_LETT_OBLIQUE_FLATTENED',0x0000000C)
		win_const_mgr.add_const('CLUS_ACCESS_READ',0x00000001)
		win_const_mgr.add_const('ACCESS_SUCCESS_WRITE',0x00000020)
		win_const_mgr.add_const('DI_SHOWCOMPAT',0x00000002)
		win_const_mgr.add_const('COD_SERVICE_CAPTURING',0x00000040)
		win_const_mgr.add_const('PS_GEOMETRIC',0x00010000)
		win_const_mgr.add_const('SFGAO_CANDELETE',0x00000020)
		win_const_mgr.add_const('LOCALE_IPAPERSIZE',0x0000100A)
		win_const_mgr.add_const('TCS_RIGHTJUSTIFY',0x00000000)
		win_const_mgr.add_const('IDF_WARNIFSKIP',0x00000800)
		win_const_mgr.add_const('CSIDL_SYSTEM',0x00000025)
		win_const_mgr.add_const('ERROR_NO_MORE_FILES',0x00000012)
		win_const_mgr.add_const('MENUEXT_SHOWDIALOG',0x00000001)
		win_const_mgr.add_const('ACCESS_ATRIB',0x00000020)
		win_const_mgr.add_const('CPF_BASE',0x00000001)
		win_const_mgr.add_const('OID_TAPI_SECURE_CALL',0x0703011A)
		win_const_mgr.add_const('CM_REMOVAL_POLICY_EXPECT_NO_REMOVAL',0x00000001)
		win_const_mgr.add_const('KSPROPERTY_MEMBER_RANGES',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_SECURITY_SELECT_CLIENT_CERT',0x0000002F)
		win_const_mgr.add_const('NCRYPTBUFFER_PKCS_ALG_ID',0x0000002B)
		win_const_mgr.add_const('ERROR_DS_CROSS_DOM_MOVE_ERROR',0x00002018)
		win_const_mgr.add_const('ERROR_RESOURCE_PROPERTY_UNCHANGEABLE',0x000013E1)
		win_const_mgr.add_const('SETDIRID_NOT_FULL_PATH',0x00000001)
		win_const_mgr.add_const('CMM_DRIVER_VERSION',0x00000002)
		win_const_mgr.add_const('IMF_MULTIPLEEDIT',0x00000400)
		win_const_mgr.add_const('GW_HWNDFIRST',0x00000000)
		win_const_mgr.add_const('IASSEMBLYCACHE_INSTALL_FLAG_FORCE_REFRESH',0x00000002)
		win_const_mgr.add_const('STI_VERSION_MIN_ALLOWED',0x00000002)
		win_const_mgr.add_const('MCI_SYSINFO_INSTALLNAME',0x00000800)
		win_const_mgr.add_const('MF_EVENT_FLAG_NO_WAIT',0x00000001)
		win_const_mgr.add_const('CORDLESS_EXTERNAL_NETWORK_GSM',0x00000003)
		win_const_mgr.add_const('CC_ENABLETEMPLATEHANDLE',0x00000040)
		win_const_mgr.add_const('DRM_SERVICE_LOCATION_ENTERPRISE',0x00000002)
		win_const_mgr.add_const('WINHTTP_QUERY_PROXY_SUPPORT',0x0000004B)
		win_const_mgr.add_const('FWPM_CONTEXT_TCP_CHIMNEY_OFFLOAD_ENABLE',0x00000001)
		win_const_mgr.add_const('PROGDLG_NOPROGRESSBAR',0x00000010)
		win_const_mgr.add_const('DNS_ERROR_ZONE_HAS_NO_NS_RECORDS',0x00002586)
		win_const_mgr.add_const('PDH_LOG_ACCESS_MASK',0x000F0000)
		win_const_mgr.add_const('FACILITY_WPD',0x0000002A)
		win_const_mgr.add_const('LINECALLINFOSTATE_COMPLETIONID',0x00000400)
		win_const_mgr.add_const('CACHE_ENTRY_ATTRIBUTE_FC',0x00000004)
		win_const_mgr.add_const('ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT',0x0000070F)
		win_const_mgr.add_const('RTCRMF_ALL_ROAMING',0x0000000F)
		win_const_mgr.add_const('EMR_SETDIBITSTODEVICE',0x00000050)
		win_const_mgr.add_const('BL_40M',0x02800000)
		win_const_mgr.add_const('X3_IMM20_SIGN_VAL_POS_X',0x00000000)
		win_const_mgr.add_const('DISPID_TIME_MIN',0x00000001)
		win_const_mgr.add_const('SES_CTFALLOWEMBED',0x00200000)
		win_const_mgr.add_const('ERROR_DS_RDN_DOESNT_MATCH_SCHEMA',0x00002073)
		win_const_mgr.add_const('KERB_DECRYPT_FLAG_DEFAULT_KEY',0x00000001)
		win_const_mgr.add_const('MQ_PEEK_ACCESS',0x00000020)
		win_const_mgr.add_const('MIXERCONTROL_CT_UNITS_SIGNED',0x00020000)
		win_const_mgr.add_const('SIGNERSCORE_MASK',0xFF000000)
		win_const_mgr.add_const('ERROR_NO_SIGNAL_SENT',0x000000CD)
		win_const_mgr.add_const('D3D10_DEFAULT_BLEND_FACTOR_GREEN',0x00000001)
		win_const_mgr.add_const('CRSWPP_NO_MATCHING_MAPURL',0xC0042202)
		win_const_mgr.add_const('BCPFILECP',0x0000000C)
		win_const_mgr.add_const('DFS_PROPERTY_FLAG_TARGET_FAILBACK',0x00000008)
		win_const_mgr.add_const('MARSHAL_E_FIRST',0x80040120)
		win_const_mgr.add_const('ODS_COMBOBOXEDIT',0x00001000)
		win_const_mgr.add_const('CICAT_READONLY',0x00000002)
		win_const_mgr.add_const('WM_NCRBUTTONUP',0x000000A5)
		win_const_mgr.add_const('CTRY_COSTA_RICA',0x000001FA)
		win_const_mgr.add_const('PGK_CONTROL',0x00000002)
		win_const_mgr.add_const('BLLI_L3_PACKET_4096',0x0000000C)
		win_const_mgr.add_const('MDPROPVAL_MNF_DRILLUPMEMBER',0x00010000)
		win_const_mgr.add_const('MEMORY_ALLOCATION_ALIGNMENT',0x00000008)
		win_const_mgr.add_const('PHOTO_PROGRAMMODE_LANDSCAPE',0x00000008)
		win_const_mgr.add_const('BTH_VID_DEFAULT_VALUE',0x0000FFFF)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_PROMPT',0x00000457)
		win_const_mgr.add_const('DCI_STATUS_FORMATCHANGED',0x00000004)
		win_const_mgr.add_const('TIMEFACTORY_OFFSET',0x00000500)
		win_const_mgr.add_const('ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS',0x0000216B)
		win_const_mgr.add_const('SQL_PARAM_DIAG_UNAVAILABLE',0x00000001)
		win_const_mgr.add_const('IF_ADMIN_STATUS_DOWN',0x00000002)
		win_const_mgr.add_const('DRM_EL_CLIENTLICENSOR',0x00000080)
		win_const_mgr.add_const('X3_IMM39_2_INST_WORD_X',0x00000001)
		win_const_mgr.add_const('TIMEMEDIAPLAYERAUDIO_OFFSET',0x00000900)
		win_const_mgr.add_const('GPO_OPTION_DISABLE_USER',0x00000001)
		win_const_mgr.add_const('PHOTO_PROGRAMMODE_NOTDEFINED',0x00000000)
		win_const_mgr.add_const('STD_FILESAVE',0x00000008)
		win_const_mgr.add_const('TXTLOG_DETAILS',0x00000005)
		win_const_mgr.add_const('PROV_MS_EXCHANGE',0x00000005)
		win_const_mgr.add_const('CDO_E_NO_METHOD',0x80040224)
		win_const_mgr.add_const('SYSTEM_MANDATORY_LABEL_ACE_TYPE',0x00000011)
		win_const_mgr.add_const('CR_PROP_CABACKWARDCROSSCERT',0x00000024)
		win_const_mgr.add_const('OID_IRDA_LINK_SPEED',0x0A010103)
		win_const_mgr.add_const('SQL_KEYWORDS',0x00000059)
		win_const_mgr.add_const('OID_QOS_RESERVED2',0xFB010101)
		win_const_mgr.add_const('OID_QOS_RESERVED3',0xFB010102)
		win_const_mgr.add_const('OID_QOS_RESERVED1',0xFB010100)
		win_const_mgr.add_const('IDC_CV_CONVERTLIST',0x0000009E)
		win_const_mgr.add_const('OID_QOS_RESERVED7',0xFB010106)
		win_const_mgr.add_const('OID_QOS_RESERVED4',0xFB010103)
		win_const_mgr.add_const('OID_QOS_RESERVED5',0xFB010104)
		win_const_mgr.add_const('PROCESS_HEAP_REGION',0x00000001)
		win_const_mgr.add_const('OID_QOS_RESERVED8',0xFB010107)
		win_const_mgr.add_const('OID_QOS_RESERVED9',0xFB010108)
		win_const_mgr.add_const('LMEM_NOCOMPACT',0x00000010)
		win_const_mgr.add_const('IME_ESC_IME_NAME',0x00001006)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY6',0x00000040)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY7',0x00000080)
		win_const_mgr.add_const('PIDVSI_FRAME_HEIGHT',0x00000004)
		win_const_mgr.add_const('SQL_CT_GLOBAL_TEMPORARY',0x00000008)
		win_const_mgr.add_const('ISC_REQ_USE_DCE_STYLE',0x00000200)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY3',0x00000008)
		win_const_mgr.add_const('PORT_IMAP2',0x0000008F)
		win_const_mgr.add_const('RPC_C_PARM_BUFFER_LENGTH',0x00000002)
		win_const_mgr.add_const('MSV1_0_VALIDATION_LOGOFF_TIME',0x00000001)
		win_const_mgr.add_const('IME_REGWORD_STYLE_EUDC',0x00000001)
		win_const_mgr.add_const('WINHTTP_QUERY_MAX',0x0000004E)
		win_const_mgr.add_const('WGL_SWAP_OVERLAY8',0x00000100)
		win_const_mgr.add_const('IDD_DYNAWIZ_INSTALLDETECTED_NEXTPAGE',0x00002717)
		win_const_mgr.add_const('MB_DEFBUTTON2',0x00000100)
		win_const_mgr.add_const('CTRL_C_EVENT',0x00000000)
		win_const_mgr.add_const('VIRTUAL_CHANNEL_VERSION_WIN2000',0x00000001)
		win_const_mgr.add_const('VCSTATUS_SAVE',0x00200000)
		win_const_mgr.add_const('SCRIPTSTAT_TOTAL_TIME',0x00000004)
		win_const_mgr.add_const('DS_REPL_NBR_COMPRESS_CHANGES',0x10000000)
		win_const_mgr.add_const('SF_DENIED_FILTER',0x00000004)
		win_const_mgr.add_const('SIOM_OVERLAYINDEX',0x00000001)
		win_const_mgr.add_const('DCR_LC',0x00000002)
		win_const_mgr.add_const('SQL_IS_INSERT_SEARCHED',0x00000002)
		win_const_mgr.add_const('TXTBIT_BACKSTYLECHANGE',0x00004000)
		win_const_mgr.add_const('CRR_NO_REASON_SUPPLIED',0x00000000)
		win_const_mgr.add_const('CP_OEMCP',0x00000001)
		win_const_mgr.add_const('CMSG_CRYPT_RELEASE_CONTEXT_FLAG',0x00008000)
		win_const_mgr.add_const('OID_FDDI_PATH_TVX_LOWER_BOUND',0x03030259)
		win_const_mgr.add_const('ERROR_PROFILE_DOES_NOT_MATCH_DEVICE',0x000007E7)
		win_const_mgr.add_const('SQL_SP_MATCH_FULL',0x00000008)
		win_const_mgr.add_const('OID_FDDI_PORT_LEM_REJECT_CT',0x0303026E)
		win_const_mgr.add_const('CSS_HIDE_PROPERTIES',0x00000001)
		win_const_mgr.add_const('ISOPROTO_CLNP',0x0000001F)
		win_const_mgr.add_const('MCI_DGV_STATUS_STILL_FILEFORMAT',0x00000401)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_CURRENTROTATIONTYPEISPURECAV',0x00000112)
		win_const_mgr.add_const('GL_CACHE_CLEANUP',0x00000004)
		win_const_mgr.add_const('STD_CUT',0x00000000)
		win_const_mgr.add_const('IDC_PS_RESULTTEXT',0x000001FE)
		win_const_mgr.add_const('SQL_DTC_DONE',0x00000000)
		win_const_mgr.add_const('DRM_LICENSE_STATE_DATA_VAGUE',0x00000001)
		win_const_mgr.add_const('L2_NOTIFICATION_SOURCE_ONEX',0x00000000)
		win_const_mgr.add_const('IT_MSG_FILE_PREVIEW_DATA_HEADER',0x00000007)
		win_const_mgr.add_const('PS_ENDCAP_FLAT',0x00000200)
		win_const_mgr.add_const('TRANSACTION_MANAGER_COMMIT_SYSTEM_VOLUME',0x00000002)
		win_const_mgr.add_const('DRM_EL_SPECIFIED_CLIENTLICENSOR',0x00000200)
		win_const_mgr.add_const('BM_SETCHECK',0x000000F1)
		win_const_mgr.add_const('CSIDL_BITBUCKET',0x00000000)
		win_const_mgr.add_const('EISAFLAG_NO_IO_MERGE',0x00000001)
		win_const_mgr.add_const('STREAM_FLAGS_DONTCACHEMAPPINGSCHEMA',0x00000008)
		win_const_mgr.add_const('PDH_CALC_NEGATIVE_DENOMINATOR',0x800007D6)
		win_const_mgr.add_const('MODALS_PRIMARY_PARMNUM',0x00000007)
		win_const_mgr.add_const('SQL_PARAM_BIND_BY_COLUMN',0x00000000)
		win_const_mgr.add_const('SM_PENWINDOWS',0x00000029)
		win_const_mgr.add_const('GS_HANDOBJ_CURRENT',0x00000001)
		win_const_mgr.add_const('FPS_BAD_ADDRESS',0x20000100)
		win_const_mgr.add_const('DMICMMETHOD_USER',0x00000100)
		win_const_mgr.add_const('LINEPROXYREQUEST_SETAGENTGROUP',0x00000001)
		win_const_mgr.add_const('ERROR_PASSWORD_MUST_CHANGE',0x00000773)
		win_const_mgr.add_const('LINEERR_INVALCALLSTATE',0x8000001C)
		win_const_mgr.add_const('ERROR_PRINTER_NOT_FOUND',0x00000BC4)
		win_const_mgr.add_const('CHANNEL_FLAG_FAIL',0x00000100)
		win_const_mgr.add_const('MDPROPVAL_VISUAL_MODE_VISUAL',0x00000001)
		win_const_mgr.add_const('SV_MAXRAWWORKITEMS_PARMNUM',0x0000022D)
		win_const_mgr.add_const('IDM_TRIED_SPLITCELL',0x00000013)
		win_const_mgr.add_const('SQLVARBINARY',0x00000025)
		win_const_mgr.add_const('PRIVACY_TEMPLATE_CUSTOM',0x00000064)
		win_const_mgr.add_const('WTPF_OFFLINEOK_IND',0x00000400)
		win_const_mgr.add_const('IMGBITS_TOTAL',0x08000000)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_PROCESS_MEMORY',0x00000100)
		win_const_mgr.add_const('TLS1_ALERT_CERTIFICATE_UNKNOWN',0x0000002E)
		win_const_mgr.add_const('LGRPID_WESTERN_EUROPE',0x00000001)
		win_const_mgr.add_const('MCI_DGV_PASTE_AT',0x00010000)
		win_const_mgr.add_const('RFCOMM_CMD_NONE',0x00000000)
		win_const_mgr.add_const('FILE_END',0x00000002)
		win_const_mgr.add_const('NRB_SUCCESS',0x00000000)
		win_const_mgr.add_const('SHCNE_DRIVEADD',0x00000100)
		win_const_mgr.add_const('CRYPT_Y_ONLY',0x00000001)
		win_const_mgr.add_const('SE_ADT_PARAMETER_WRITE_SYNCHRONOUS',0x00000010)
		win_const_mgr.add_const('FEATURESETTING_MIRROR',0x00000004)
		win_const_mgr.add_const('PBS_MARQUEE',0x00000008)
		win_const_mgr.add_const('ERROR_COUNTER_TIMEOUT',0x00000461)
		win_const_mgr.add_const('URLPOLICY_ALLOW',0x00000000)
		win_const_mgr.add_const('MKF_HOTKEYACTIVE',0x00000004)
		win_const_mgr.add_const('LOCALE_ITLZERO',0x00000025)
		win_const_mgr.add_const('CRL_FIND_ISSUED_BY_SIGNATURE_FLAG',0x00000002)
		win_const_mgr.add_const('MIXER_GETLINEINFOF_LINEID',0x00000002)
		win_const_mgr.add_const('ARCONTENT_VCD',0x00000400)
		win_const_mgr.add_const('ERROR_HIBERNATION_FAILURE',0x00000290)
		win_const_mgr.add_const('LONG_LIVED',0x00000000)
		win_const_mgr.add_const('CAPSLOCK_ON',0x00000080)
		win_const_mgr.add_const('BST_CHECKED',0x00000001)
		win_const_mgr.add_const('CERT_AUTO_ENROLL_PROP_ID',0x00000015)
		win_const_mgr.add_const('LR_DEFAULTSIZE',0x00000040)
		win_const_mgr.add_const('LVGA_FOOTER_RIGHT',0x00000020)
		win_const_mgr.add_const('TF_SENTENCEMODE_AUTOMATIC',0x00000004)
		win_const_mgr.add_const('ICMP6_INFOMSG_MASK',0x00000080)
		win_const_mgr.add_const('EVENT_OBJECT_DESCRIPTIONCHANGE',0x0000800D)
		win_const_mgr.add_const('JT_RECEIVE',0x00000002)
		win_const_mgr.add_const('TBN_LAST',0x00000000)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_MINIMUM_RATE',0x00000400)
		win_const_mgr.add_const('CHANGER_OPEN_IEPORT',0x00000008)
		win_const_mgr.add_const('CCHILDREN_SCROLLBAR',0x00000005)
		win_const_mgr.add_const('ERROR_INVALID_CLEANER',0x000010D6)
		win_const_mgr.add_const('ERROR_ABANDONED_WAIT_63',0x000002E0)
		win_const_mgr.add_const('MB_DEFBUTTON3',0x00000200)
		win_const_mgr.add_const('DEBUG_STACK_ARGUMENTS',0x00000001)
		win_const_mgr.add_const('POSTSCRIPT_IDENTIFY',0x00001015)
		win_const_mgr.add_const('EXECUTE_FLAG_DISABLE_CUSTOM_ERROR',0x00000008)
		win_const_mgr.add_const('IMAGE_REL_M32R_REFHI',0x00000009)
		win_const_mgr.add_const('D3DWRAP_U',0x00000001)
		win_const_mgr.add_const('D3DWRAP_W',0x00000004)
		win_const_mgr.add_const('D3DWRAP_V',0x00000002)
		win_const_mgr.add_const('ERRACT_INTRET',0x00000007)
		win_const_mgr.add_const('WIA_IPS_OPTICAL_XRES',0x00000C12)
		win_const_mgr.add_const('PROGRESS_QUIET',0x00000003)
		win_const_mgr.add_const('MICROSOFT_ROOT_CERT_CHAIN_POLICY_ENABLE_TEST_ROOT_FLAG',0x00010000)
		win_const_mgr.add_const('STGM_SIMPLE',0x08000000)
		win_const_mgr.add_const('OID_FDDI_MAC_NOT_COPIED_CT',0x03030242)
		win_const_mgr.add_const('CACHEGROUP_ATTRIBUTE_GROUPNAME',0x00000010)
		win_const_mgr.add_const('IDM_REPLACE',0x00000849)
		win_const_mgr.add_const('CRYPT_ONLINE',0x00000080)
		win_const_mgr.add_const('SQL_CA1_LOCK_NO_CHANGE',0x00000040)
		win_const_mgr.add_const('SHCNE_ASSOCCHANGED',0x08000000)
		win_const_mgr.add_const('WGL_FONT_POLYGONS',0x00000001)
		win_const_mgr.add_const('D3DSP_REGTYPE_SHIFT2',0x00000008)
		win_const_mgr.add_const('CR_INVALID_DATA',0x0000001F)
		win_const_mgr.add_const('_BDATYPES_',0x00000001)
		win_const_mgr.add_const('CENCODEMAX',0x00000040)
		win_const_mgr.add_const('D3DPBLENDCAPS_DESTALPHA',0x00000040)
		win_const_mgr.add_const('LANG_INUKTITUT',0x00000005)
		win_const_mgr.add_const('KEY_CREATE_SUB_KEY',0x00000004)
		win_const_mgr.add_const('DMPAPER_QUARTO',0x0000000F)
		win_const_mgr.add_const('TABLE_RESTRICT_DONE',0x00000007)
		win_const_mgr.add_const('ATA_FLAGS_NO_MULTIPLE',0x00000001)
		win_const_mgr.add_const('PSTF_NO_ENCRYPTION',0x80000000)
		win_const_mgr.add_const('LOCALE_IFIRSTDAYOFWEEK',0x0000100C)
		win_const_mgr.add_const('RF_DOWN_AND_RIGHT',0x00000200)
		win_const_mgr.add_const('SCRIPTPROC_IMPLICIT_THIS',0x00000100)
		win_const_mgr.add_const('NEWFILEOPENV2ORD',0x00000610)
		win_const_mgr.add_const('TUISPIDLL_OBJECT_LINEID',0x00000001)
		win_const_mgr.add_const('HSE_EXEC_URL_NO_HEADERS',0x00000002)
		win_const_mgr.add_const('VK_HOME',0x00000024)
		win_const_mgr.add_const('EVENT_OBJECT_ACCELERATORCHANGE',0x00008012)
		win_const_mgr.add_const('TAPE_DRIVE_VARIABLE_BLOCK',0x00000800)
		win_const_mgr.add_const('HELP_WM_HELP',0x00000000)
		win_const_mgr.add_const('ERROR_RECEIVE_EXPEDITED',0x000002C4)
		win_const_mgr.add_const('CE_BREAK',0x00000010)
		win_const_mgr.add_const('OCR_CROSS',0x00007F03)
		win_const_mgr.add_const('DFCS_MENUBULLET',0x00000002)
		win_const_mgr.add_const('DMPAPER_JENV_YOU4_ROTATED',0x0000005C)
		win_const_mgr.add_const('AUTH_REQ_ALLOW_VALIDATE',0x00000040)
		win_const_mgr.add_const('DISPATCH_METHOD',0x00000001)
		win_const_mgr.add_const('D3DCS_RIGHT',0x00000002)
		win_const_mgr.add_const('TTFCFP_FLAGS_GLYPHLIST',0x00000008)
		win_const_mgr.add_const('CBR_1200',0x000004B0)
		win_const_mgr.add_const('STDPROP_INDEX_DTYPE',0x000000CA)
		win_const_mgr.add_const('ILFIP_ALWAYS',0x00000000)
		win_const_mgr.add_const('EM_FMTLINES',0x000000C8)
		win_const_mgr.add_const('WIA_DPS_HORIZONTAL_BED_REGISTRATION',0x00000C07)
		win_const_mgr.add_const('MSG_SERVICE_INSTALL',0x00000001)
		win_const_mgr.add_const('DDSCAPS2_POINTS',0x00800000)
		win_const_mgr.add_const('PIDSI_APPNAME',0x00000012)
		win_const_mgr.add_const('SPREG_LOADLIBRARY',0x00000001)
		win_const_mgr.add_const('ERROR_DISK_TOO_FRAGMENTED',0x0000012E)
		win_const_mgr.add_const('ERROR_INVALID_VERIFY_SWITCH',0x00000076)
		win_const_mgr.add_const('TBTS_RIGHT',0x00000003)
		win_const_mgr.add_const('WS_EX_MDICHILD',0x00000040)
		win_const_mgr.add_const('SERVICE_ADDRESS_FLAG_RPC_NB',0x00000004)
		win_const_mgr.add_const('SB_PAGEUP',0x00000002)
		win_const_mgr.add_const('CSIDL_COMMON_STARTMENU',0x00000016)
		win_const_mgr.add_const('UNDNAME_NO_SPECIAL_SYMS',0x00004000)
		win_const_mgr.add_const('IDS_CAP_STAT_CAP_L_FRAMES',0x000001FC)
		win_const_mgr.add_const('RTM_VIEW_MASK_ANY',0x00000000)
		win_const_mgr.add_const('_SAPI_VER',0x00000051)
		win_const_mgr.add_const('WPSTYLE_TILE',0x00000001)
		win_const_mgr.add_const('TMT_IMAGECOUNT',0x00000961)
		win_const_mgr.add_const('NLS_CP_MBTOWC',0x40000000)
		win_const_mgr.add_const('MSG_SERVICE_PROVIDER_DELETE',0x00000007)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_CANCELADDTRACK',0x00000202)
		win_const_mgr.add_const('V86FLAGS_DIRECTION',0x00000400)
		win_const_mgr.add_const('LCPRI_DISABLED',0x0000FFFF)
		win_const_mgr.add_const('PROPID_QUERY_UNFILTERED',0x00000007)
		win_const_mgr.add_const('ICC_COOL_CLASSES',0x00000400)
		win_const_mgr.add_const('STREAM_CLEAR_ENCRYPTION',0x00000004)
		win_const_mgr.add_const('EC_PAUSED',0x0000000E)
		win_const_mgr.add_const('WCT_OUT_OF_PROC_FLAG',0x00000001)
		win_const_mgr.add_const('MIIM_BITMAP',0x00000080)
		win_const_mgr.add_const('FACILITY_CONFIGURATION',0x00000021)
		win_const_mgr.add_const('IDM_TRIED_DELETECOLS',0x00000011)
		win_const_mgr.add_const('ERROR_DUP_NAME',0x00000034)
		win_const_mgr.add_const('NETLOGON_CONTROL_SET_DBFLAG',0x0000FFFE)
		win_const_mgr.add_const('WH_MOUSE',0x00000007)
		win_const_mgr.add_const('WEBPOST_ERROR_PROV_CORRUPT',0xC0042104)
		win_const_mgr.add_const('DNS_CLASS_NONE',0x00000000)
		win_const_mgr.add_const('ISR_PRIV_REG',0x00000002)
		win_const_mgr.add_const('CRYPT_PROXY_CACHE_RETRIEVAL',0x00200000)
		win_const_mgr.add_const('DS_DOMAIN_NATIVE_MODE',0x00000010)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_TIME',0x00000013)
		win_const_mgr.add_const('COLOR_SOLID',0x000002C9)
		win_const_mgr.add_const('MDPROPVAL_MOQ_DIMHIER_MEMBER',0x00000100)
		win_const_mgr.add_const('D3DDEVCAPS_CANRENDERAFTERFLIP',0x00000800)
		win_const_mgr.add_const('MIB_IPROUTE_TYPE_INVALID',0x00000002)
		win_const_mgr.add_const('MMIO_EXCLUSIVE',0x00000010)
		win_const_mgr.add_const('DNS_RTYPE_SINK',0x00002800)
		win_const_mgr.add_const('SCARD_W_REMOVED_CARD',0x80100069)
		win_const_mgr.add_const('CTRY_SWEDEN',0x0000002E)
		win_const_mgr.add_const('SBARS_SIZEGRIP',0x00000100)
		win_const_mgr.add_const('META_FILLREGION',0x00000228)
		win_const_mgr.add_const('WINHTTP_HANDLE_TYPE_REQUEST',0x00000003)
		win_const_mgr.add_const('CERT_REGISTRY_STORE_CLIENT_GPT_FLAG',0x80000000)
		win_const_mgr.add_const('CTRY_INDONESIA',0x0000003E)
		win_const_mgr.add_const('DXVA_SCAN_METHOD_ALTERNATE_HORIZONTAL',0x00000002)
		win_const_mgr.add_const('ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL',0x000021A3)
		win_const_mgr.add_const('MCI_STOP',0x00000808)
		win_const_mgr.add_const('ADS_SERVICE_ERROR_CRITICAL',0x00000003)
		win_const_mgr.add_const('GESTURE_DOUBLE_CIRCLE',0x00000000)
		win_const_mgr.add_const('LDAP_OPT_SIZELIMIT',0x00000003)
		win_const_mgr.add_const('LOGON_SUBAUTH_SESSION_KEY',0x00000040)
		win_const_mgr.add_const('DISPID_DIAGNOSECONNECTION',0x00000016)
		win_const_mgr.add_const('DRV_DISABLE',0x00000005)
		win_const_mgr.add_const('FIEF_FLAG_PEEK',0x00000002)
		win_const_mgr.add_const('SPQ_SCAN_INFORM_USER',0x00000010)
		win_const_mgr.add_const('FLG_ADDREG_APPEND',0x00000008)
		win_const_mgr.add_const('LOCALE_SMONTHNAME11',0x00000042)
		win_const_mgr.add_const('LOCALE_SMONTHNAME10',0x00000041)
		win_const_mgr.add_const('BCRYPT_DSA_PUBLIC_MAGIC',0x42505344)
		win_const_mgr.add_const('CHANGER_IEPORT_USER_CONTROL_CLOSE',0x80000100)
		win_const_mgr.add_const('MCI_ON_S',0x00008000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_SIGNATURE',0x00003602)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_DRIVER_WRAPPER_OBJECT',0x000000AA)
		win_const_mgr.add_const('SUBLANG_SERBIAN_CROATIA',0x00000001)
		win_const_mgr.add_const('SHIL_SYSSMALL',0x00000003)
		win_const_mgr.add_const('WMSZ_TOPRIGHT',0x00000005)
		win_const_mgr.add_const('GPO_SECTION_ROOT',0x00000000)
		win_const_mgr.add_const('FILE_DEVICE_MASS_STORAGE',0x00000002)
		win_const_mgr.add_const('IDM_CLEARSELECTION',0x000007D7)
		win_const_mgr.add_const('OPPROGDLG_ENABLEPAUSE',0x00000080)
		win_const_mgr.add_const('ERROR_DS_NC_STILL_HAS_DSAS',0x00002162)
		win_const_mgr.add_const('OPATH_TOK_COMMA',0x0000006D)
		win_const_mgr.add_const('PORT_PHONEBOOK',0x000002FF)
		win_const_mgr.add_const('SERVICE_NO_QOS_SIGNALING',0x40000000)
		win_const_mgr.add_const('ELF_CULTURE_LATIN',0x00000000)
		win_const_mgr.add_const('DEBUG_MANAGED_ALLOWED',0x00000001)
		win_const_mgr.add_const('DNS_RFC_MAX_UDP_PACKET_LENGTH',0x00000200)
		win_const_mgr.add_const('LINEMEDIACONTROL_VOLUMEUP',0x00000100)
		win_const_mgr.add_const('PHONEERR_INVALDEVICECLASS',0x9000000D)
		win_const_mgr.add_const('DEBUG_SCOPE_GROUP_ALL',0x00000003)
		win_const_mgr.add_const('GCPCLASS_PREBOUNDLTR',0x00000080)
		win_const_mgr.add_const('CF_OEMTEXT',0x00000007)
		win_const_mgr.add_const('JIFMK_DRI',0x0000FFDD)
		win_const_mgr.add_const('SQL_CURSOR_DYNAMIC',0x00000002)
		win_const_mgr.add_const('ACM_STREAMOPENF_ASYNC',0x00000002)
		win_const_mgr.add_const('GAA_FLAG_SKIP_MULTICAST',0x00000004)
		win_const_mgr.add_const('IMFT_SEPARATOR',0x00000002)
		win_const_mgr.add_const('MCI_VD_PLAY_FAST',0x00020000)
		win_const_mgr.add_const('CERT_STORE_PROV_READ_CERT_FUNC',0x00000001)
		win_const_mgr.add_const('CRED_PACK_WOW_BUFFER',0x00000002)
		win_const_mgr.add_const('INTERNET_SUPPRESS_COOKIE_POLICY',0x00000001)
		win_const_mgr.add_const('CFU_CF1UNDERLINE',0x000000FF)
		win_const_mgr.add_const('COLORMGMTCAPS',0x00000079)
		win_const_mgr.add_const('FCS_FORCEWRITE',0x00000002)
		win_const_mgr.add_const('STREAM_FLAGS_DONTCACHETEMPLATE',0x00000010)
		win_const_mgr.add_const('BL_PAL_INDEX',0x00000006)
		win_const_mgr.add_const('VAR_DATEVALUEONLY',0x00000002)
		win_const_mgr.add_const('D3D10_PS_PIXEL_CENTER_FRACTIONAL_COMPONENT',0x00000000)
		win_const_mgr.add_const('RR_INDEX',0x0000003D)
		win_const_mgr.add_const('WS_EX_LTRREADING',0x00000000)
		win_const_mgr.add_const('SQL_SRVC_DEFAULT',0x00000004)
		win_const_mgr.add_const('SQL_CODE_HOUR',0x00000004)
		win_const_mgr.add_const('DISPLAYDIB_NOERROR',0x00000000)
		win_const_mgr.add_const('MB_DEFBUTTON1',0x00000000)
		win_const_mgr.add_const('RAS_EAP_FLAG_NON_INTERACTIVE',0x00000002)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_OFFLOAD_ATTRIBUTES',0x000000A0)
		win_const_mgr.add_const('SQL_EXT_API_START',0x00000028)
		win_const_mgr.add_const('IDM_SCROLL_PAGELEFT',0x00000955)
		win_const_mgr.add_const('HDF_CHECKED',0x00000080)
		win_const_mgr.add_const('IN4ADDR_MULTICASTPREFIX_LENGTH',0x00000004)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_CGA_AUTH_FAILED',0x00003644)
		win_const_mgr.add_const('DIALOPTION_QUIET',0x00000080)
		win_const_mgr.add_const('PDH_INSUFFICIENT_BUFFER',0xC0000BC2)
		win_const_mgr.add_const('DISPID_LOADURL',0x0000001D)
		win_const_mgr.add_const('OID_GEN_UNKNOWN_PROTOS',0x00010286)
		win_const_mgr.add_const('KS_VBI_FLAG_VBIINFOHEADER_CHANGE',0x00000020)
		win_const_mgr.add_const('RPC_CALL_STATUS_CANCELLED',0x00000001)
		win_const_mgr.add_const('DBPROP_GENERICOPTIONS_STRING',0x00000006)
		win_const_mgr.add_const('DMPAPER_ENV_C65',0x00000020)
		win_const_mgr.add_const('OID_802_5_FRAME_COPIED_ERRORS',0x02020204)
		win_const_mgr.add_const('SECURITY_NETWORK_RID',0x00000002)
		win_const_mgr.add_const('NOTIFY_PRE',0x00000001)
		win_const_mgr.add_const('WMDM_MODE_BLOCK',0x00000001)
		win_const_mgr.add_const('SPCRP_LOWERFILTERS',0x00000012)
		win_const_mgr.add_const('RPC_C_HTTP_AUTHN_TARGET_PROXY',0x00000002)
		win_const_mgr.add_const('DMO_E_TYPE_NOT_SET',0x80040203)
		win_const_mgr.add_const('MXDCOP_PRINTTICKET_FIXED_DOC',0x00000018)
		win_const_mgr.add_const('LINEAGENTSESSIONSTATUS_UPDATEINFO',0x00000004)
		win_const_mgr.add_const('INTERNET_CACHE_FLAG_INSTALLED_ENTRY',0x00000200)
		win_const_mgr.add_const('DDBLT_ALPHADESTNEG',0x00000004)
		win_const_mgr.add_const('PERF_ATTRIB_DISPLAY_AS_HEX',0x00000010)
		win_const_mgr.add_const('SUBLANG_UPPER_SORBIAN_GERMANY',0x00000001)
		win_const_mgr.add_const('ERR_INVALID_TIMESTAMP',0xE0000008)
		win_const_mgr.add_const('SSF_SHOWSTARTPAGE',0x00400000)
		win_const_mgr.add_const('PORT_BLIDM',0x0000008E)
		win_const_mgr.add_const('DISABLE_SMART',0x000000D9)
		win_const_mgr.add_const('MCI_TRACK',0x00000010)
		win_const_mgr.add_const('DNS_RTYPE_WINSR',0x00000002)
		win_const_mgr.add_const('WIZ_BODYX',0x0000005C)
		win_const_mgr.add_const('IPPORT_ROUTESERVER',0x00000208)
		win_const_mgr.add_const('SO_UPDATE_ACCEPT_CONTEXT',0x0000700B)
		win_const_mgr.add_const('PDH_LOG_UPDATE_ACCESS',0x00040000)
		win_const_mgr.add_const('CDO_E_INVALID_ENCODING_TYPE',0x800CCE1D)
		win_const_mgr.add_const('RESTART_NO_REBOOT',0x00000008)
		win_const_mgr.add_const('MFBYTESTREAM_IS_PARTIALLY_DOWNLOADED',0x00000200)
		win_const_mgr.add_const('PHONESTATE_RINGMODE',0x00000080)
		win_const_mgr.add_const('SQL_AD_ADD_CONSTRAINT_NON_DEFERRABLE',0x00000100)
		win_const_mgr.add_const('SQL_AM_CONNECTION',0x00000001)
		win_const_mgr.add_const('WIA_DPS_USER_NAME',0x00000C28)
		win_const_mgr.add_const('SHCNE_SERVERDISCONNECT',0x00004000)
		win_const_mgr.add_const('D3DUSAGE_QUERY_FILTER',0x00020000)
		win_const_mgr.add_const('IDM_TRIED_FONTNAME',0x00000024)
		win_const_mgr.add_const('SP_PROT_TLS1_SERVER',0x00000040)
		win_const_mgr.add_const('STATE_SYSTEM_ANIMATED',0x00004000)
		win_const_mgr.add_const('MDPROPVAL_MNF_LINREGSLOPE',0x00000080)
		win_const_mgr.add_const('GESTURE_TRIPLE_DOWN',0x00000000)
		win_const_mgr.add_const('WINHTTP_QUERY_MIME_VERSION',0x00000000)
		win_const_mgr.add_const('FRSCONN_PRIORITY_MASK',0x70000000)
		win_const_mgr.add_const('OLEUI_ERR_STRUCTUREINVALID',0x00000066)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_CLOSED',0x00000200)
		win_const_mgr.add_const('OFN_ENABLEINCLUDENOTIFY',0x00400000)
		win_const_mgr.add_const('MCI_DGV_CUE_INPUT',0x00010000)
		win_const_mgr.add_const('NIIF_USER',0x00000004)
		win_const_mgr.add_const('GRADIENT_FILL_RECT_H',0x00000000)
		win_const_mgr.add_const('DTT_COLORPROP',0x00000001)
		win_const_mgr.add_const('KSPROBE_SYSTEMADDRESS',0x00000040)
		win_const_mgr.add_const('MD_ERROR_SUB403_READ_ACCESS_DENIED',0x00000002)
		win_const_mgr.add_const('LVFI_STRING',0x00000002)
		win_const_mgr.add_const('TAPE_PSEUDO_LOGICAL_BLOCK',0x00000003)
		win_const_mgr.add_const('DFS_VOLUME_FLAVOR_UNUSED1',0x00000000)
		win_const_mgr.add_const('RTM_MAX_ADDRESS_SIZE',0x00000010)
		win_const_mgr.add_const('STM_GETIMAGE',0x00000173)
		win_const_mgr.add_const('AM_MPEG_AUDIO_DUAL_RIGHT',0x00000002)
		win_const_mgr.add_const('WMIREG_FLAG_TRACE_CONTROL_GUID',0x00001000)
		win_const_mgr.add_const('MESSAGE_RESOURCE_UNICODE',0x00000001)
		win_const_mgr.add_const('RPC_C_OPT_UNIQUE_BINDING',0x0000000B)
		win_const_mgr.add_const('SEE_MASK_WAITFORINPUTIDLE',0x02000000)
		win_const_mgr.add_const('UNION_LARGE_ARMS',0x00000003)
		win_const_mgr.add_const('DEVICE_NOTIFY_SERVICE_HANDLE',0x00000001)
		win_const_mgr.add_const('DEVICE_NOTIFY_WINDOW_HANDLE',0x00000000)
		win_const_mgr.add_const('ERROR_SECRET_TOO_LONG',0x00000566)
		win_const_mgr.add_const('OLEUI_ERR_LPSZCAPTIONINVALID',0x00000069)
		win_const_mgr.add_const('ERROR_IOPL_NOT_ENABLED',0x000000C5)
		win_const_mgr.add_const('ERROR_NOT_CAPABLE',0x00000307)
		win_const_mgr.add_const('CRYPT_FLAG_SIGNING',0x00000020)
		win_const_mgr.add_const('ERROR_PROCESS_IS_PROTECTED',0x0000050D)
		win_const_mgr.add_const('MQSEC_QUEUE_GENERIC_EXECUTE',0x00000000)
		win_const_mgr.add_const('DISPLAY_DEVICE_MODESPRUNED',0x08000000)
		win_const_mgr.add_const('MAX_COLUMN_DESC_LEN',0x00000080)
		win_const_mgr.add_const('SPI_SETFASTTASKSWITCH',0x00000024)
		win_const_mgr.add_const('QUERY_PHYSICAL_PATH',0x00000000)
		win_const_mgr.add_const('URLPOLICY_DISALLOW',0x00000003)
		win_const_mgr.add_const('CMSG_ENVELOPED_DATA_V2',0x00000002)
		win_const_mgr.add_const('ERR_NO_DISK_SPACE',0xE0000001)
		win_const_mgr.add_const('SECURITY_MANDATORY_SYSTEM_RID',0x00004000)
		win_const_mgr.add_const('ERROR_DS_DRA_NAME_COLLISION',0x0000210A)
		win_const_mgr.add_const('MRINFO_QUERIER_FLAG',0x00000040)
		win_const_mgr.add_const('ACM_MPEG_PROTECTIONBIT',0x00000008)
		win_const_mgr.add_const('HS_BDIAGONAL',0x00000003)
		win_const_mgr.add_const('ISC_REQ_USE_SESSION_KEY',0x00000020)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_TERMSRV',0x00000020)
		win_const_mgr.add_const('SQL_POS_OPERATIONS',0x0000004F)
		win_const_mgr.add_const('MCI_DGV_OPEN_16BIT',0x00080000)
		win_const_mgr.add_const('TMT_IMAGELAYOUT',0x00000FAB)
		win_const_mgr.add_const('MAX_TRANSACTION_DESCRIPTION_LENGTH',0x00000040)
		win_const_mgr.add_const('LDAP_OPT_DEREF',0x00000002)
		win_const_mgr.add_const('CLUSTER_CONFIGURED',0x00000002)
		win_const_mgr.add_const('HTTP_LOG_FIELD_COOKIE',0x00020000)
		win_const_mgr.add_const('PROCESS_HEAP_ENTRY_DDESHARE',0x00000020)
		win_const_mgr.add_const('DRMPUBHANDLE_INVALID',0x00000000)
		win_const_mgr.add_const('JS_DELETING',0x00000002)
		win_const_mgr.add_const('SERVICE_CTRL_REDIR_PRINT',0x00000002)
		win_const_mgr.add_const('DLCTL_NO_JAVA',0x00000100)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_DEVICECANLOADMEDIA',0x00000206)
		win_const_mgr.add_const('WM_NULL',0x00000000)
		win_const_mgr.add_const('QITIPF_USENAME',0x00000001)
		win_const_mgr.add_const('SET_SCREEN_ANGLE',0x00001009)
		win_const_mgr.add_const('DDBLT_ASYNC',0x00000200)
		win_const_mgr.add_const('RTCSI_PC_TO_PHONE',0x00000002)
		win_const_mgr.add_const('ERROR_INVALID_FLAGS',0x000003EC)
		win_const_mgr.add_const('OBM_OLD_REDUCE',0x00007FF5)
		win_const_mgr.add_const('ERROR_SXS_EARLY_DEACTIVATION',0x00003704)
		win_const_mgr.add_const('PSPCB_CREATE',0x00000002)
		win_const_mgr.add_const('FPS_COMPLETED',0x20000008)
		win_const_mgr.add_const('DAOBINDING_DIRECT',0x00000001)
		win_const_mgr.add_const('CAUSE_NORMAL_UNSPECIFIED',0x0000001F)
		win_const_mgr.add_const('RAS_EAP_FLAG_RESUME_FROM_HIBERNATE',0x00000200)
		win_const_mgr.add_const('SUBLANG_DEFAULT',0x00000001)
		win_const_mgr.add_const('DDCAPS2_SYSTONONLOCAL_AS_SYSTOLOCAL',0x04000000)
		win_const_mgr.add_const('SQL_CONCUR_LOCK',0x00000002)
		win_const_mgr.add_const('MDM_HDLCPPP_AUTH_PAP',0x00000002)
		win_const_mgr.add_const('CTLCOLOR_SCROLLBAR',0x00000005)
		win_const_mgr.add_const('EMR_SETBKMODE',0x00000012)
		win_const_mgr.add_const('NDW_INSTALLFLAG_KNOWNCLASS',0x00080000)
		win_const_mgr.add_const('SQL_QUALIFIER_TERM',0x0000002A)
		win_const_mgr.add_const('LL_DISCONNECTING',0x00000003)
		win_const_mgr.add_const('WNODE_FLAG_TRACED_GUID',0x00020000)
		win_const_mgr.add_const('FKF_HOTKEYSOUND',0x00000010)
		win_const_mgr.add_const('PAN_STRAIGHT_ARMS_HORZ',0x00000002)
		win_const_mgr.add_const('DDSCL_NORMAL',0x00000008)
		win_const_mgr.add_const('TMT_IMAGESELECTTYPE',0x00000FAD)
		win_const_mgr.add_const('COOKIE_OP_SET',0x00000001)
		win_const_mgr.add_const('SE_MAX_AUDIT_PARAMETERS',0x00000020)
		win_const_mgr.add_const('WINHTTP_AUTOLOGON_SECURITY_LEVEL_LOW',0x00000001)
		win_const_mgr.add_const('LINECALLTREATMENT_BUSY',0x00000003)
		win_const_mgr.add_const('MAX_ISCSI_TEXT_ADDRESS_LEN',0x00000100)
		win_const_mgr.add_const('IF_TYPE_ARCNET_PLUS',0x00000024)
		win_const_mgr.add_const('DEX_IDS_TIMELINE_PARSE',0x00000592)
		win_const_mgr.add_const('CPL_NEWINQUIRE',0x00000008)
		win_const_mgr.add_const('TCS_HOTTRACK',0x00000040)
		win_const_mgr.add_const('DDSCAPS_HWCODEC',0x00100000)
		win_const_mgr.add_const('RTCAU_DIGEST',0x00000002)
		win_const_mgr.add_const('ERROR_INVALID_SHARENAME',0x000004BF)
		win_const_mgr.add_const('PIDSI_TEMPLATE',0x00000007)
		win_const_mgr.add_const('SCARD_T0_CMD_LENGTH',0x00000005)
		win_const_mgr.add_const('DMPAPER_LETTER_PLUS',0x0000003B)
		win_const_mgr.add_const('KDF_SECRET_APPEND',0x00000002)
		win_const_mgr.add_const('RPC_C_MQ_CLEAR_ON_OPEN',0x00000002)
		win_const_mgr.add_const('TASK_OCTOBER',0x00000200)
		win_const_mgr.add_const('DISPID_IMULTISESSION_IMPORTRECORDER',0x00000102)
		win_const_mgr.add_const('BLLI_L2_USER_SPECIFIED',0x00000010)
		win_const_mgr.add_const('FLAG_ICC_FORCE_CONNECTION',0x00000001)
		win_const_mgr.add_const('PSINJECT_EOF',0x00000013)
		win_const_mgr.add_const('SERIAL_IOC_FCR_RES1',0x00000010)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_NO_EXPLICIT_CRED_MATCH',0x00000080)
		win_const_mgr.add_const('D3DMAX30SHADERINSTRUCTIONS',0x00008000)
		win_const_mgr.add_const('PSH_USEICONID',0x00000004)
		win_const_mgr.add_const('ULONG_PTR_ERROR',0x00000000)
		win_const_mgr.add_const('EXPOSUREMODE_MANUAL',0x00000001)
		win_const_mgr.add_const('ET_MANUFACTURER',0x00000800)
		win_const_mgr.add_const('EXTENSION_ORIGIN_IMPORTEDCERT',0x00060000)
		win_const_mgr.add_const('MCI_DGV_CUE_OUTPUT',0x00020000)
		win_const_mgr.add_const('KDF_HMAC_KEY',0x00000003)
		win_const_mgr.add_const('RESOURCEMANAGER_ENLIST',0x00000008)
		win_const_mgr.add_const('ERROR_DATABASE_BACKUP_CORRUPT',0x000013DF)
		win_const_mgr.add_const('DDCAPS_3D',0x00000001)
		win_const_mgr.add_const('D3D10_DEFAULT_VIEWPORT_MAX_DEPTH',0x00000000)
		win_const_mgr.add_const('DS_EXIST_ADVISORY_MODE',0x00000001)
		win_const_mgr.add_const('LINEAGENTFEATURE_SETAGENTGROUP',0x00000001)
		win_const_mgr.add_const('CREATE_THREAD_DEBUG_EVENT',0x00000002)
		win_const_mgr.add_const('VK_BROWSER_BACK',0x000000A6)
		win_const_mgr.add_const('MM_MOM_OPEN',0x000003C7)
		win_const_mgr.add_const('SFGAO_DISPLAYATTRMASK',0x000FC000)
		win_const_mgr.add_const('D3DPRESENT_DONOTFLIP',0x00000004)
		win_const_mgr.add_const('CHANGER_CLEANER_OPS_NOT_SUPPORTED',0x80000040)
		win_const_mgr.add_const('CDB2GVF_SHOWALLFILES',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_OP_STRING',0x00000004)
		win_const_mgr.add_const('CM_PROB_NO_SOFTCONFIG',0x00000022)
		win_const_mgr.add_const('CERT_TRUST_HAS_NOT_SUPPORTED_NAME_CONSTRAINT',0x00001000)
		win_const_mgr.add_const('AM_VIDEO_FLAG_INTERLEAVED_FRAME',0x00000000)
		win_const_mgr.add_const('LC_NONE',0x00000000)
		win_const_mgr.add_const('CBENF_RETURN',0x00000002)
		win_const_mgr.add_const('ED_AUDIO_19',0x00040000)
		win_const_mgr.add_const('DI_RESOURCEPAGE_ADDED',0x00002000)
		win_const_mgr.add_const('PSM_AVCTP',0x00000017)
		win_const_mgr.add_const('SCHEDULE_DATA_ENTRIES',0x00000007)
		win_const_mgr.add_const('PDH_QUERY_PERF_DATA_TIMEOUT',0xC0000BFE)
		win_const_mgr.add_const('ED_AUDIO_13',0x00001000)
		win_const_mgr.add_const('ED_AUDIO_12',0x00000800)
		win_const_mgr.add_const('SQL_CONVERT_FLOAT',0x0000003C)
		win_const_mgr.add_const('ED_AUDIO_10',0x00000200)
		win_const_mgr.add_const('ED_AUDIO_17',0x00010000)
		win_const_mgr.add_const('ED_AUDIO_16',0x00008000)
		win_const_mgr.add_const('ED_AUDIO_15',0x00004000)
		win_const_mgr.add_const('ED_AUDIO_14',0x00002000)
		win_const_mgr.add_const('SQL_SQLSTATE_SIZE',0x00000005)
		win_const_mgr.add_const('ERROR_NO_BROWSER_SERVERS_FOUND',0x000017E6)
		win_const_mgr.add_const('CRL_DIST_POINT_NO_NAME',0x00000000)
		win_const_mgr.add_const('ERROR_CANNOT_DETECT_PROCESS_ABORT',0x00000439)
		win_const_mgr.add_const('IDM_GETZOOM',0x00000044)
		win_const_mgr.add_const('SVSI_DESELECTOTHERS',0x00000004)
		win_const_mgr.add_const('WIA_DPC_ZOOM_POSITION',0x0000080B)
		win_const_mgr.add_const('ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY',0x000000DA)
		win_const_mgr.add_const('DMPAPER_P32K_ROTATED',0x0000006B)
		win_const_mgr.add_const('WMS_TOTAL_PACKETS_LO',0x00000008)
		win_const_mgr.add_const('OBM_MNARROW',0x00007FE3)
		win_const_mgr.add_const('DMPAPER_PENV_10_ROTATED',0x00000076)
		win_const_mgr.add_const('SQL_OPT_TRACE_ON',0x00000001)
		win_const_mgr.add_const('MDM_HDLCPPP_ML_2',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN',0x00003639)
		win_const_mgr.add_const('ATTR_TARGET_NOTCONVERTED',0x00000003)
		win_const_mgr.add_const('STYPE_DISKTREE',0x00000000)
		win_const_mgr.add_const('PHONESTATUSFLAGS_CONNECTED',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNEXPECTEDENDTAG',0x000036E3)
		win_const_mgr.add_const('RTM_BLOCK_METHODS',0x00000001)
		win_const_mgr.add_const('LV_VIEW_DETAILS',0x00000001)
		win_const_mgr.add_const('ERROR_CANT_EVICT_ACTIVE_NODE',0x00001391)
		win_const_mgr.add_const('WSB_PROP_PALETTE',0x00000800)
		win_const_mgr.add_const('SDP_ATTRIB_LAN_LPSUBNET',0x00000200)
		win_const_mgr.add_const('GPO_FLAG_FORCE',0x00000002)
		win_const_mgr.add_const('HHT_ONITEMSTATEICON',0x00001000)
		win_const_mgr.add_const('FORM_BUILTIN',0x00000001)
		win_const_mgr.add_const('WAVECAPS_SYNC',0x00000010)
		win_const_mgr.add_const('MF_END',0x00000080)
		win_const_mgr.add_const('MCIWNDF_NOTIFYALL',0x00001F00)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG14',0x00000000)
		win_const_mgr.add_const('ARCONTENT_AUTOPLAYMUSIC',0x00000100)
		win_const_mgr.add_const('GCPCLASS_LOCALNUMBER',0x00000004)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG11',0x00000000)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG10',0x00000000)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG13',0x00000000)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_CURRENT_USER_GROUP_POLICY_ID',0x00000007)
		win_const_mgr.add_const('RI_KEY_E1',0x00000004)
		win_const_mgr.add_const('BLLI_L3_PACKET_16',0x00000004)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_ABBREVDIAL',0x0000000B)
		win_const_mgr.add_const('CACHE_NOTIFY_URL_UNSET_STICKY',0x00000020)
		win_const_mgr.add_const('PID_INTSITE_WATCH',0x0000000D)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_LASTPOSSIBLESTARTOFLEADOUT',0x00000104)
		win_const_mgr.add_const('DC_PAPERSIZE',0x00000003)
		win_const_mgr.add_const('X3_IMM20_INST_WORD_POS_X',0x00000004)
		win_const_mgr.add_const('MDM_V110_SPEED_38DOT4K',0x00000009)
		win_const_mgr.add_const('ENUMPAPERMETRICS',0x00000022)
		win_const_mgr.add_const('EMR_RESERVED_108',0x0000006C)
		win_const_mgr.add_const('IMAGE_REL_AM_SECREL',0x00000007)
		win_const_mgr.add_const('MDPROPVAL_MOQ_LEVEL_MEMBER',0x00000040)
		win_const_mgr.add_const('CM_PROB_BIOS_TABLE',0x00000023)
		win_const_mgr.add_const('WINEVENT_LEVEL_CRITICAL',0x00000001)
		win_const_mgr.add_const('KSDATAFORMAT_ATTRIBUTES',0x00000001)
		win_const_mgr.add_const('SQL_SG_INSERT_TABLE',0x00000040)
		win_const_mgr.add_const('SPI_GETLISTBOXSMOOTHSCROLLING',0x00001006)
		win_const_mgr.add_const('CF_SELECTCONVERTTO',0x00000008)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_SCREEN',0x00000484)
		win_const_mgr.add_const('WPP_ERROR_FIRST',0x40042380)
		win_const_mgr.add_const('PAN_STRAIGHT_ARMS_SINGLE_SERIF',0x00000005)
		win_const_mgr.add_const('URLACTION_CROSS_DOMAIN_DATA',0x00001406)
		win_const_mgr.add_const('GESTURE_LEFT',0x00000000)
		win_const_mgr.add_const('SS_LEFT',0x00000000)
		win_const_mgr.add_const('FS_WANSUNG',0x00080000)
		win_const_mgr.add_const('READ_COMPRESSION_INFO_VALID',0x00000020)
		win_const_mgr.add_const('HYBRID_NODETYPE',0x00000008)
		win_const_mgr.add_const('CSIDL_PERSONAL',0x00000005)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_SECTION',0x00000068)
		win_const_mgr.add_const('FPS_NO_DIAL_TONE',0x20000200)
		win_const_mgr.add_const('JOB_OBJECT_MSG_PROCESS_MEMORY_LIMIT',0x00000009)
		win_const_mgr.add_const('LIST_MODULES_DEFAULT',0x00000000)
		win_const_mgr.add_const('VMR_RENDER_DEVICE_VIDMEM',0x00000002)
		win_const_mgr.add_const('RESOURCETYPE_PRINT',0x00000002)
		win_const_mgr.add_const('RPC_C_QOS_CAPABILITIES_MAKE_FULLSIC',0x00000002)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_RESPONSE_RECEIVED',0x00000080)
		win_const_mgr.add_const('WINEVENT_KEYWORDE_RESERVED_60',0x1000000000000000)
		win_const_mgr.add_const('MW_BIG_FILEOPENORD',0x00002710)
		win_const_mgr.add_const('UPPER_HINT_MASK',0x0000FF00)
		win_const_mgr.add_const('IF_TYPE_FDDI',0x0000000F)
		win_const_mgr.add_const('MDMEASURE_AGGR_UNKNOWN',0x00000000)
		win_const_mgr.add_const('FLAG_NO_USER',0x00000001)
		win_const_mgr.add_const('DEBUG_IOUTPUT_BREAKPOINT',0x20000000)
		win_const_mgr.add_const('GCPGLYPH_LINKAFTER',0x00004000)
		win_const_mgr.add_const('STAP_ALLOW_CONTROLS',0x00000001)
		win_const_mgr.add_const('CERT_TRUST_INVALID_EXTENSION',0x00000100)
		win_const_mgr.add_const('PS_ENDCAP_ROUND',0x00000000)
		win_const_mgr.add_const('CERT_STORE_NO_CRYPT_RELEASE_FLAG',0x00000001)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_CURRENTFEATUREPAGES',0x00000209)
		win_const_mgr.add_const('ERROR_DISK_FULL',0x00000070)
		win_const_mgr.add_const('STYLE_DESCRIPTION_SIZE',0x00000020)
		win_const_mgr.add_const('NIIF_NOSOUND',0x00000010)
		win_const_mgr.add_const('MP_MSGCLASS_SYSTEM',0x00000001)
		win_const_mgr.add_const('CMSG_ENVELOPED_DATA_V0',0x00000000)
		win_const_mgr.add_const('LDAP_OPT_SSL_INFO',0x00000093)
		win_const_mgr.add_const('ERROR_WMI_ALREADY_DISABLED',0x00001074)
		win_const_mgr.add_const('WIA_DPV_DSHOW_DEVICE_PATH',0x00000E04)
		win_const_mgr.add_const('CRED_MAX_USERNAME_LENGTH',0x00000100)
		win_const_mgr.add_const('IPX_PROTOCOL_STATIC',0x00000002)
		win_const_mgr.add_const('SF_NOTIFY_AUTH_COMPLETE',0x04000000)
		win_const_mgr.add_const('IDM_SIZETOCONTROLWIDTH',0x00000025)
		win_const_mgr.add_const('HTTP_STATUS_REDIRECT_METHOD',0x0000012F)
		win_const_mgr.add_const('MCI_DGV_SIGNAL_AT',0x00010000)
		win_const_mgr.add_const('CAL_SABBREVDAYNAME1',0x00000000)
		win_const_mgr.add_const('WMS_CONTAINER_SEEKABLE_EMULATING_BROADCAST',0x00000400)
		win_const_mgr.add_const('OID_LTALK_IN_BROADCASTS',0x05020101)
		win_const_mgr.add_const('SQL_DESC_TYPE',0x000003EA)
		win_const_mgr.add_const('INTERNET_STATUS_REDIRECT',0x0000006E)
		win_const_mgr.add_const('SFC_DISABLE_ASK',0x00000001)
		win_const_mgr.add_const('EVENT_ACTIVITY_CTRL_CREATE_ID',0x00000003)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCD_BUFFERUNDERRUNFREEDISABLED',0x00000102)
		win_const_mgr.add_const('SECURITY_FLAG_IGNORE_CERT_DATE_INVALID',0x00002000)
		win_const_mgr.add_const('ERROR_INVALID_HOOK_HANDLE',0x0000057C)
		win_const_mgr.add_const('TMT_ATLASINPUTIMAGE',0x00001F41)
		win_const_mgr.add_const('GL_ID_CANNOTSAVE',0x00000011)
		win_const_mgr.add_const('CBR_9600',0x00002580)
		win_const_mgr.add_const('LINECALLINFOSTATE_NUMOWNERINCR',0x00000800)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_FTP_FILE',0x00000007)
		win_const_mgr.add_const('CR_PROP_ROLESEPARATIONENABLED',0x00000017)
		win_const_mgr.add_const('NCRYPT_ALLOW_SIGNING_FLAG',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_MIPS_TOKEN',0x0000000E)
		win_const_mgr.add_const('MIDICAPS_LRVOLUME',0x00000002)
		win_const_mgr.add_const('REGDB_E_FIRST',0x80040150)
		win_const_mgr.add_const('SHCIDS_CANONICALONLY',0x10000000)
		win_const_mgr.add_const('WM_UNICHAR',0x00000109)
		win_const_mgr.add_const('FCW_STATUS',0x00000001)
		win_const_mgr.add_const('CERT_FRIENDLY_NAME_PROP_ID',0x0000000B)
		win_const_mgr.add_const('CMSG_CERT_PARAM',0x0000000C)
		win_const_mgr.add_const('LB_OKAY',0x00000000)
		win_const_mgr.add_const('OID_GEN_PROMISCUOUS_MODE',0x00010280)
		win_const_mgr.add_const('D3DDEVCAPS_RTPATCHES',0x00400000)
		win_const_mgr.add_const('VARIANT_ALPHABOOL',0x00000002)
		win_const_mgr.add_const('CERT_FIND_NO_ENHKEY_USAGE_FLAG',0x00000008)
		win_const_mgr.add_const('LINEERR_INVALCALLPARAMS',0x80000019)
		win_const_mgr.add_const('DXVA_DEBLOCKING_FILTER_FUNCTION',0x00000005)
		win_const_mgr.add_const('NOTIFIER_FLAG_ONE_SHOT',0x00000002)
		win_const_mgr.add_const('TBDDRET_TREATPRESSED',0x00000002)
		win_const_mgr.add_const('PATCH_SYMBOL_NO_FAILURES',0x00000002)
		win_const_mgr.add_const('BCRYPT_ECDH_PUBLIC_P521_MAGIC',0x354B4345)
		win_const_mgr.add_const('MQMSG_PRIV_LEVEL_BODY_AES',0x00000005)
		win_const_mgr.add_const('ERROR_BAD_DEV_TYPE',0x00000042)
		win_const_mgr.add_const('TF_URP_LOCALPROCESS',0x00000004)
		win_const_mgr.add_const('HHWIN_PARAM_NAV_WIDTH',0x00000001)
		win_const_mgr.add_const('WSAEPFNOSUPPORT',0x0000273E)
		win_const_mgr.add_const('IDM_FONT',0x0000005A)
		win_const_mgr.add_const('MD_SERVER_SIZE_LARGE',0x00000002)
		win_const_mgr.add_const('ENCRYPTED_PWLEN',0x00000010)
		win_const_mgr.add_const('URLACTION_CREDENTIALS_USE',0x00001A00)
		win_const_mgr.add_const('DEBUG_SYMINFO_GET_SYMBOL_NAME_BY_OFFSET_AND_TAG_WIDE',0x00000002)
		win_const_mgr.add_const('IDM_TRIED_PASTE',0x00000032)
		win_const_mgr.add_const('FILE_VER_GET_NEUTRAL',0x00000002)
		win_const_mgr.add_const('BITS_MC_JOB_PROPERTY_CHANGE',0x80194003)
		win_const_mgr.add_const('CPF_POSTPONED_BASE_LDAP_ERROR',0x00001000)
		win_const_mgr.add_const('MD_SERVER_SIZE_SMALL',0x00000000)
		win_const_mgr.add_const('SPI_SETKEYBOARDPREF',0x00000045)
		win_const_mgr.add_const('IP6_ADDRESS_STRING_BUFFER_LENGTH',0x00000041)
		win_const_mgr.add_const('SQL_REAL',0x00000007)
		win_const_mgr.add_const('CREDUI_FLAGS_USERNAME_TARGET_CREDENTIALS',0x00080000)
		win_const_mgr.add_const('EMR_POLYDRAW16',0x0000005C)
		win_const_mgr.add_const('SS_NOPREFIX',0x00000080)
		win_const_mgr.add_const('ERROR_DS_MASTERDSA_REQUIRED',0x0000207A)
		win_const_mgr.add_const('IMAGE_REL_ARM_GPREL12',0x00000006)
		win_const_mgr.add_const('PGS_VERT',0x00000000)
		win_const_mgr.add_const('MAX_MEM_REGISTERS',0x00000009)
		win_const_mgr.add_const('QUOTA_LIMITS_HARDWS_MAX_DISABLE',0x00000008)
		win_const_mgr.add_const('NUMRESERVED',0x0000006A)
		win_const_mgr.add_const('RPC_S_UNKNOWN_AUTHN_TYPE',0x000006CD)
		win_const_mgr.add_const('LF_FACESIZE',0x00000020)
		win_const_mgr.add_const('FR_MATCHDIAC',0x20000000)
		win_const_mgr.add_const('SYNC_HANDLERTYPE_FOLDERS',0x00000003)
		win_const_mgr.add_const('FRSCONN_MAX_PRIORITY',0x00000008)
		win_const_mgr.add_const('CERT_RDN_BMP_STRING',0x0000000C)
		win_const_mgr.add_const('PORT_ANYDIALOUT',0x0000004B)
		win_const_mgr.add_const('DBPROPVAL_SQ_CORRELATEDSUBQUERIES',0x00000001)
		win_const_mgr.add_const('DOUBLE_CLICK',0x00000002)
		win_const_mgr.add_const('CTRY_LATVIA',0x00000173)
		win_const_mgr.add_const('HDF_STRING',0x00004000)
		win_const_mgr.add_const('PLA_CAPABILITY_LOCAL',0x10000000)
		win_const_mgr.add_const('EVENT_OBJECT_NAMECHANGE',0x0000800C)
		win_const_mgr.add_const('ACMDRIVERDETAILS_SUPPORTF_FILTER',0x00000004)
		win_const_mgr.add_const('CERT_STORE_PROV_LM_SYSTEM_STORE_FLAG',0x00000010)
		win_const_mgr.add_const('PP_IMPTYPE',0x00000003)
		win_const_mgr.add_const('ERROR_DOMAIN_CONTROLLER_NOT_FOUND',0x00000774)
		win_const_mgr.add_const('CHANNEL_OPTION_ENCRYPT_CS',0x10000000)
		win_const_mgr.add_const('DNS_UPDATE_SKIP_NO_UPDATE_ADAPTERS',0x00002000)
		win_const_mgr.add_const('SV_SESSUSERS_PARMNUM',0x000001FE)
		win_const_mgr.add_const('IGIMII_SMODE',0x00000002)
		win_const_mgr.add_const('SQL_TC_NONE',0x00000000)
		win_const_mgr.add_const('FKF_CONFIRMHOTKEY',0x00000008)
		win_const_mgr.add_const('SQL_IC_LOWER',0x00000002)
		win_const_mgr.add_const('TAPE_RESET_STATISTICS',0x00000002)
		win_const_mgr.add_const('WIA_DPC_SHARPNESS',0x0000081F)
		win_const_mgr.add_const('ERROR_NOT_OWNER',0x00000120)
		win_const_mgr.add_const('NS_DEFAULT',0x00000000)
		win_const_mgr.add_const('COMPRESSION_FORMAT_NONE',0x00000000)
		win_const_mgr.add_const('SE_GROUP_MANDATORY',0x00000001)
		win_const_mgr.add_const('ET_CLASS',0x00000020)
		win_const_mgr.add_const('DDBD_4',0x00001000)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_BASE',0x00000032)
		win_const_mgr.add_const('ERROR_FT_WRITE_RECOVERY',0x000002C1)
		win_const_mgr.add_const('WINEVENT_LEVEL_RESERVED_9',0x00000009)
		win_const_mgr.add_const('DRM_CANCEL_PLAYLIST_BURN',0x00000001)
		win_const_mgr.add_const('DEVPROP_TYPE_UINT64',0x00000009)
		win_const_mgr.add_const('MNS_DRAGDROP',0x20000000)
		win_const_mgr.add_const('SQL_ODBC_INTERFACE_CONFORMANCE',0x00000098)
		win_const_mgr.add_const('DEBUG_CES_EXECUTION_STATUS',0x00000010)
		win_const_mgr.add_const('OID_802_5_INTERNAL_ERRORS',0x02020207)
		win_const_mgr.add_const('KS_VIDEO_FLAG_FRAME',0x00000000)
		win_const_mgr.add_const('DT_NOFULLWIDTHCHARBREAK',0x00080000)
		win_const_mgr.add_const('CAL_SDAYNAME2',0x00000008)
		win_const_mgr.add_const('DDBD_1',0x00004000)
		win_const_mgr.add_const('TCIF_PARAM',0x00000008)
		win_const_mgr.add_const('CM_DRP_CAPABILITIES',0x00000010)
		win_const_mgr.add_const('CAL_SDAYNAME6',0x00000000)
		win_const_mgr.add_const('SECPKG_ATTR_USE_VALIDATED',0x0000000F)
		win_const_mgr.add_const('ERROR_DS_DRA_DN_EXISTS',0x000020F9)
		win_const_mgr.add_const('PRF_DONTFINDLNK',0x00000008)
		win_const_mgr.add_const('CDEF_MERIT_ABOVE_DO_NOT_USE',0x00000008)
		win_const_mgr.add_const('SPI_LANGDRIVER',0x0000000C)
		win_const_mgr.add_const('DISPID_RESETSORT',0x00000003)
		win_const_mgr.add_const('DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP',0x0000258C)
		win_const_mgr.add_const('IP_OPTIONS',0x00000001)
		win_const_mgr.add_const('URLACTION_ACTIVEX_OVERRIDE_REPURPOSEDETECTION',0x00001207)
		win_const_mgr.add_const('WPC_SYSTEM',0x00000017)
		win_const_mgr.add_const('HTTP_QUERY_VERSION',0x00000012)
		win_const_mgr.add_const('OID_IRDA_MEDIA_BUSY',0x0A010104)
		win_const_mgr.add_const('PWPROP_OSPVALUE',0x00000002)
		win_const_mgr.add_const('ASN_APPLICATION',0x00000040)
		win_const_mgr.add_const('DI_ENUMSINGLEINF',0x00010000)
		win_const_mgr.add_const('MMIO_CREATELIST',0x00000040)
		win_const_mgr.add_const('SQL_CT_COMMIT_PRESERVE',0x00000002)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_VRAM_DATA_TRANSFER',0x00000800)
		win_const_mgr.add_const('TLS1_ALERT_ILLEGAL_PARAMETER',0x0000002F)
		win_const_mgr.add_const('OID_TCP_CONNECTION_OFFLOAD_CURRENT_CONFIG',0xFC01020E)
		win_const_mgr.add_const('LINEOFFERINGMODE_INACTIVE',0x00000002)
		win_const_mgr.add_const('CR_PROP_KRACERTCOUNT',0x00000019)
		win_const_mgr.add_const('FCIDM_SHVIEWLAST',0x00000007)
		win_const_mgr.add_const('ALG_SID_SCHANNEL_MASTER_HASH',0x00000002)
		win_const_mgr.add_const('FD_FLAGS_NOSYN',0x00000001)
		win_const_mgr.add_const('CERT_TRUST_CTL_IS_NOT_SIGNATURE_VALID',0x00040000)
		win_const_mgr.add_const('HID_PROTOCOL_UUID16',0x00000011)
		win_const_mgr.add_const('IDHELP',0x00000009)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_MACHINE_NAME',0x00000001)
		win_const_mgr.add_const('ERROR_DIRECTORY_NOT_RM',0x00001A93)
		win_const_mgr.add_const('LPD_STEREO',0x00000002)
		win_const_mgr.add_const('PD_USEDEVMODECOPIESANDCOLLATE',0x00040000)
		win_const_mgr.add_const('D3DPTEXTURECAPS_PERSPECTIVE',0x00000001)
		win_const_mgr.add_const('LIS_DEFAULTCOLORS',0x00000010)
		win_const_mgr.add_const('DBPROPVAL_DST_TDPANDMDP',0x00000003)
		win_const_mgr.add_const('SQL_DTC_UNENLIST_EXPENSIVE',0x00000002)
		win_const_mgr.add_const('WMDM_FILE_ATTR_LINK',0x00000010)
		win_const_mgr.add_const('WMDM_STORAGE_ATTR_HAS_FOLDERS',0x02000000)
		win_const_mgr.add_const('IMAGE_DIRECTORY_ENTRY_BOUND_IMPORT',0x0000000B)
		win_const_mgr.add_const('FEATURESETTING_OUTPUT',0x00000001)
		win_const_mgr.add_const('PROV_RSA_SIG',0x00000002)
		win_const_mgr.add_const('LINEADDRESSSHARING_MONITORED',0x00000010)
		win_const_mgr.add_const('MDPROP_MEMBER',0x00000001)
		win_const_mgr.add_const('WSK_SO_BASE',0x00004000)
		win_const_mgr.add_const('D3DTEXOPCAPS_ADDSIGNED2X',0x00000100)
		win_const_mgr.add_const('LB_GETSELCOUNT',0x00000190)
		win_const_mgr.add_const('D3DPTFILTERCAPS_MAGFANISOTROPIC',0x04000000)
		win_const_mgr.add_const('ERROR_INVALID_LOGON_TYPE',0x00000557)
		win_const_mgr.add_const('FLG_BITREG_64BITKEY',0x00001000)
		win_const_mgr.add_const('DEBUG_END_ACTIVE_DETACH',0x00000002)
		win_const_mgr.add_const('EDITF_ENABLEUPNMAP',0x01000000)
		win_const_mgr.add_const('LINEAGENTSTATE_BUSYINCOMING',0x00000010)
		win_const_mgr.add_const('KP_VERIFY_PARAMS',0x00000028)
		win_const_mgr.add_const('AF_UNIX',0x00000001)
		win_const_mgr.add_const('WBF_WORDBREAK',0x00000020)
		win_const_mgr.add_const('GL_ID_NOCONVERT',0x00000020)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_SUPPORTEDWRITESPEEDS',0x00000113)
		win_const_mgr.add_const('MCI_DGV_STATUS_BASS',0x00000400)
		win_const_mgr.add_const('SSF_STARTPANELON',0x00200000)
		win_const_mgr.add_const('ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND',0x000032D5)
		win_const_mgr.add_const('CERT_TRUST_PERMIT_MISSING_CRLS',0x00000002)
		win_const_mgr.add_const('TOKEN_DUPLICATE',0x00000002)
		win_const_mgr.add_const('VFT_STATIC_LIB',0x00000007)
		win_const_mgr.add_const('PTE_VALID_MASK',0x00000001)
		win_const_mgr.add_const('ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD',0x0000213B)
		win_const_mgr.add_const('LINEERR_INVALADDRESSMODE',0x80000012)
		win_const_mgr.add_const('MAP_EXPAND_LIGATURES',0x00002000)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_CONNECTING_TO_SERVER',0x00000004)
		win_const_mgr.add_const('WIA_DATA_RAW_CMYK',0x0000000B)
		win_const_mgr.add_const('WIA_IPS_ROTATION',0x0000180D)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_PRIVATEOBJECTS',0x00001000)
		win_const_mgr.add_const('SDP_ATTRIB_HID_DEVICE_RELEASE_NUMBER',0x00000200)
		win_const_mgr.add_const('ITSSFLAG_COMPLETE_ON_DESTROY',0x00000000)
		win_const_mgr.add_const('SE_DACL_DEFAULTED',0x00000008)
		win_const_mgr.add_const('SQL_SR_DELETE_TABLE',0x00000080)
		win_const_mgr.add_const('OID_WAN_SET_LINK_INFO',0x04010108)
		win_const_mgr.add_const('IDM_TRIED_JUSTIFYLEFT',0x0000002D)
		win_const_mgr.add_const('SQL_CURSOR_FAST_FORWARD_ONLY',0x00000008)
		win_const_mgr.add_const('IDC_IO_OBJECTTYPELIST',0x00000837)
		win_const_mgr.add_const('MMIOERR_BASE',0x00000100)
		win_const_mgr.add_const('OS_SERVERADMINUI',0x00000022)
		win_const_mgr.add_const('SQL_SRJO_RIGHT_OUTER_JOIN',0x00000100)
		win_const_mgr.add_const('WIA_IPS_SHEET_FEEDER_REGISTRATION',0x00000C06)
		win_const_mgr.add_const('LB_GETITEMHEIGHT',0x000001A1)
		win_const_mgr.add_const('NETE_ENCRYPT_NOTSUP',0x00000014)
		win_const_mgr.add_const('INTERNET_OPTION_FROM_CACHE_TIMEOUT',0x0000003F)
		win_const_mgr.add_const('SQL_AF_DISTINCT',0x00000020)
		win_const_mgr.add_const('SS_BITMAP',0x0000000E)
		win_const_mgr.add_const('RDW_FRAME',0x00000400)
		win_const_mgr.add_const('ERROR_SIGNAL_REFUSED',0x0000009C)
		win_const_mgr.add_const('CERT_TRUST_MASK',0x00000000)
		win_const_mgr.add_const('DRVM_MAPPER',0x00002000)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_TYPE_DEFINITION',0x0000000D)
		win_const_mgr.add_const('COPYFILE_SIS_REPLACE',0x00000002)
		win_const_mgr.add_const('CBN_KILLFOCUS',0x00000004)
		win_const_mgr.add_const('ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION',0x00001A40)
		win_const_mgr.add_const('DNS_TYPE_SRV',0x00000021)
		win_const_mgr.add_const('SHGFI_LINKOVERLAY',0x00008000)
		win_const_mgr.add_const('SM_CMOUSEBUTTONS',0x0000002B)
		win_const_mgr.add_const('WMDM_SEEK_END',0x00000008)
		win_const_mgr.add_const('IPV6_RECVIF',0x00000018)
		win_const_mgr.add_const('BF_SOFT',0x00001000)
		win_const_mgr.add_const('SQL_ATTR_PARAMSET_SIZE',0x00000016)
		win_const_mgr.add_const('WMS_STREAM_NAME',0x00000008)
		win_const_mgr.add_const('PRJOB_QSTATUS',0x00000003)
		win_const_mgr.add_const('GADOF_DIRTY',0x00000001)
		win_const_mgr.add_const('DEBUG_SYMBOL_IS_ARGUMENT',0x00000100)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_STOP',0x00000002)
		win_const_mgr.add_const('IDM_OLEWINDOWSTATECHANGED',0x00003A9E)
		win_const_mgr.add_const('ICDRAW_RENDER',0x00000080)
		win_const_mgr.add_const('SYNCMGRITEM_ITEMFLAGMASK',0x0000007F)
		win_const_mgr.add_const('SECPKG_CALL_KERNEL_MODE',0x00000001)
		win_const_mgr.add_const('_AUTHZ_SS_MAXSIZE',0x00000080)
		win_const_mgr.add_const('LINE_REQUEST',0x0000000D)
		win_const_mgr.add_const('CERT_CHAIN_FIND_BY_ISSUER_CACHE_ONLY_URL_FLAG',0x00000004)
		win_const_mgr.add_const('ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION',0x00001ABC)
		win_const_mgr.add_const('DDSVCAPS_RESERVED2',0x00000002)
		win_const_mgr.add_const('WM_IME_ENDCOMPOSITION',0x0000010E)
		win_const_mgr.add_const('CERT_INFO_SUBJECT_UNIQUE_ID_FLAG',0x0000000A)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNCLOSEDDECL',0x000036F0)
		win_const_mgr.add_const('PHOTO_ORIENTATION_FLIPVERTICAL',0x00000004)
		win_const_mgr.add_const('PATCH_OPTION_USE_LZX_B',0x00000002)
		win_const_mgr.add_const('WM_TABLET_LAST',0x00000002)
		win_const_mgr.add_const('NRC_SNUMOUT',0x00000008)
		win_const_mgr.add_const('PATCH_OPTION_USE_LZX_A',0x00000001)
		win_const_mgr.add_const('CRSWPP_POSTINFO_NEEDED',0x40042209)
		win_const_mgr.add_const('DIF_ASSIGNRESOURCES',0x00000003)
		win_const_mgr.add_const('SBS_SIZEGRIP',0x00000010)
		win_const_mgr.add_const('ERROR_RESOURCE_NOT_PRESENT',0x000010DC)
		win_const_mgr.add_const('DISPID_IDISCRECORDER2_VENDORID',0x00000201)
		win_const_mgr.add_const('BTH_ERROR_COMMAND_DISALLOWED',0x00000000)
		win_const_mgr.add_const('CF_SHOWHELP',0x00000004)
		win_const_mgr.add_const('CRYPT_VERIFY_CERT_SIGN_SUBJECT_CRL',0x00000003)
		win_const_mgr.add_const('DBFLAGS_MULTITHREADTRANSACTIONS',0x00000200)
		win_const_mgr.add_const('ERROR_DBG_RIPEXCEPTION',0x000002B7)
		win_const_mgr.add_const('KSALLOCATOR_FLAG_NO_FRAME_INTEGRITY',0x00000100)
		win_const_mgr.add_const('SC_MANAGER_MODIFY_BOOT_CONFIG',0x00000020)
		win_const_mgr.add_const('PBT_APMPOWERSTATUSCHANGE',0x0000000A)
		win_const_mgr.add_const('IDM_TRIED_INSERTTABLE',0x00000016)
		win_const_mgr.add_const('IMC_OPENSTATUSWINDOW',0x00000022)
		win_const_mgr.add_const('NCRYPTBUFFER_EMPTY',0x00000000)
		win_const_mgr.add_const('SKF_TRISTATE',0x00000080)
		win_const_mgr.add_const('ERROR_EVT_FILTER_NOTELTSET',0x00003AA7)
		win_const_mgr.add_const('NRB_INVALID_PARAMETER',0x00000002)
		win_const_mgr.add_const('DNS_TKEY_MODE_SERVER_ASSIGN',0x00000001)
		win_const_mgr.add_const('DMPAPER_A6',0x00000046)
		win_const_mgr.add_const('FLG_ADDREG_BINVALUETYPE',0x00000001)
		win_const_mgr.add_const('TMT_BLENDCOLOR',0x0000138B)
		win_const_mgr.add_const('IDC_BZ_SWITCHTO',0x0000025C)
		win_const_mgr.add_const('V86FLAGS_TRACE',0x00000100)
		win_const_mgr.add_const('SPI_SETICONS',0x00000058)
		win_const_mgr.add_const('MCI_WAVE_OUTPUT',0x00800000)
		win_const_mgr.add_const('DWFAF_AUTOHIDE',0x00000010)
		win_const_mgr.add_const('UF_DONT_EXPIRE_PASSWD',0x00010000)
		win_const_mgr.add_const('PHONELAMPMODE_FLUTTER',0x00000020)
		win_const_mgr.add_const('MIXERCONTROL_CT_SC_TIME_MILLISECS',0x01000000)
		win_const_mgr.add_const('LVGF_SUBSET',0x00008000)
		win_const_mgr.add_const('OQWF_SAVEQUERYONOK',0x00000200)
		win_const_mgr.add_const('MDM_SHIFT_AUTO_SPEED',0x00000000)
		win_const_mgr.add_const('DT_EXTERNALLEADING',0x00000200)
		win_const_mgr.add_const('SQL_COLUMN_PRECISION',0x00000004)
		win_const_mgr.add_const('VK_MEDIA_NEXT_TRACK',0x000000B0)
		win_const_mgr.add_const('SQL_DM_VER',0x000000AB)
		win_const_mgr.add_const('WINDOWS_AF_IRDA',0x0000001A)
		win_const_mgr.add_const('SPI_SETDESKWALLPAPER',0x00000014)
		win_const_mgr.add_const('USER_MARSHAL_FC_CHAR',0x00000002)
		win_const_mgr.add_const('FF_SCRIPT',0x00000004)
		win_const_mgr.add_const('IDS_CAP_SEQ_MSGSTART',0x0000019A)
		win_const_mgr.add_const('D3DPTADDRESSCAPS_INDEPENDENTUV',0x00000010)
		win_const_mgr.add_const('PCS_REPLACEDCHAR',0x00000001)
		win_const_mgr.add_const('LVFI_PARTIAL',0x00000008)
		win_const_mgr.add_const('SQL_CA1_POS_REFRESH',0x00001000)
		win_const_mgr.add_const('RTM_ROUTE_STATE_DELETED',0x00000002)
		win_const_mgr.add_const('WIA_IPC_THUMB_HEIGHT',0x00001404)
		win_const_mgr.add_const('EAP_FLAG_FULL_AUTH',0x00001000)
		win_const_mgr.add_const('HANGUL_CHARSET',0x00000081)
		win_const_mgr.add_const('DSOP_SCOPE_FLAG_DEFAULT_FILTER_CONTACTS',0x00000200)
		win_const_mgr.add_const('NIM_SETFOCUS',0x00000003)
		win_const_mgr.add_const('EVENT_OBJECT_SELECTIONWITHIN',0x00008009)
		win_const_mgr.add_const('SHACF_AUTOSUGGEST_FORCE_ON',0x10000000)
		win_const_mgr.add_const('CERT_OCSP_CACHE_PREFIX_PROP_ID',0x0000004B)
		win_const_mgr.add_const('SERVICETYPE_NOCHANGE',0x00000006)
		win_const_mgr.add_const('SQL_TXN_ISOLATION_OPTION',0x00000048)
		win_const_mgr.add_const('APPCOMMAND_BROWSER_FAVORITES',0x00000006)
		win_const_mgr.add_const('SPI_SETWHEELSCROLLLINES',0x00000069)
		win_const_mgr.add_const('MD_BACKUP_NEXT_VERSION',0x00000000)
		win_const_mgr.add_const('SPEAKER_RESERVED',0x7FFC0000)
		win_const_mgr.add_const('R2_MASKNOTPEN',0x00000003)
		win_const_mgr.add_const('RR_PS',0x00000002)
		win_const_mgr.add_const('MCI_DGV_SIGNAL_EVERY',0x00020000)
		win_const_mgr.add_const('APPCOMMAND_MEDIA_CHANNEL_DOWN',0x00000034)
		win_const_mgr.add_const('IDM_BLOCKFMT',0x000008BA)
		win_const_mgr.add_const('ERROR_VERIFIER_STOP',0x00000219)
		win_const_mgr.add_const('PIDDSI_SCALE',0x0000000B)
		win_const_mgr.add_const('NLS_IME_DISABLE',0x20000000)
		win_const_mgr.add_const('MCI_LAST',0x00000FFF)
		win_const_mgr.add_const('WST_BYTES_PER_LINE',0x0000002A)
		win_const_mgr.add_const('DISPID_FONT_CHANGED',0x00000009)
		win_const_mgr.add_const('CDBOSC_STATECHANGE',0x00000004)
		win_const_mgr.add_const('URLACTION_HTML_JAVA_RUN',0x00001605)
		win_const_mgr.add_const('WMDRM_CLIENT_NEEDINDIV',0x00000008)
		win_const_mgr.add_const('PDH_PLA_ERROR_FILEPATH',0xC0000BF0)
		win_const_mgr.add_const('CRED_MAX_STRING_LENGTH',0x00000100)
		win_const_mgr.add_const('SQL_ATTR_PARAM_STATUS_PTR',0x00000014)
		win_const_mgr.add_const('DB_DISP_LOG_FAILED_MIN',0x0000001E)
		win_const_mgr.add_const('PKRNUM',0x00000010)
		win_const_mgr.add_const('DDSCAPS2_CUBEMAP',0x00000200)
		win_const_mgr.add_const('SQL_INTERVAL_DAY_TO_HOUR',0x00000064)
		win_const_mgr.add_const('IDM_JAVAAPPLET',0x0000087F)
		win_const_mgr.add_const('DEBUG_CSS_LOADS',0x00000001)
		win_const_mgr.add_const('DNS_RTYPE_MINFO',0x00000000)
		win_const_mgr.add_const('IF_TYPE_ATM_LOGICAL',0x00000050)
		win_const_mgr.add_const('SDP_ATTRIB_HID_NORMALLY_CONNECTABLE',0x0000020D)
		win_const_mgr.add_const('DEBUG_FORMAT_USER_SMALL_NO_AUXILIARY_STATE',0x00002000)
		win_const_mgr.add_const('SERIAL_IOC_MCR_OUT2',0x00000008)
		win_const_mgr.add_const('NRC_NORES',0x00000009)
		win_const_mgr.add_const('ADS_SERVICE_RUNNING',0x00000004)
		win_const_mgr.add_const('DC_INBUTTON',0x00000010)
		win_const_mgr.add_const('V86FLAGS_OVERFLOW',0x00000800)
		win_const_mgr.add_const('SUBLANG_SPANISH_CHILE',0x00000000)
		win_const_mgr.add_const('CERT_VALIDITY_ISSUER_DISTRUST',0x02000000)
		win_const_mgr.add_const('SPFILENOTIFY_FILEINCABINET',0x00000011)
		win_const_mgr.add_const('TMT_ACTIVECAPTION',0x00000643)
		win_const_mgr.add_const('LVGF_EXTENDEDIMAGE',0x00002000)
		win_const_mgr.add_const('SHACF_FILESYSTEM',0x00000001)
		win_const_mgr.add_const('CHANGER_CARTRIDGE_MAGAZINE',0x00000100)
		win_const_mgr.add_const('BTH_ERROR_ENCRYPTION_MODE_NOT_ACCEPTABLE',0x00000025)
		win_const_mgr.add_const('FILE_DEVICE_DFS',0x00000006)
		win_const_mgr.add_const('BG_E_STRING_TOO_LONG',0x80200021)
		win_const_mgr.add_const('POLICY_CREATE_ACCOUNT',0x00000010)
		win_const_mgr.add_const('IDD_CHANGESOURCE4',0x000003F5)
		win_const_mgr.add_const('SPCRP_UPPERFILTERS',0x00000011)
		win_const_mgr.add_const('ACM_FORMATTAGDETAILSF_INDEX',0x00000000)
		win_const_mgr.add_const('EVCF_ENABLEBYDEFAULT',0x00000002)
		win_const_mgr.add_const('DICD_INHERIT_CLASSDRVS',0x00000002)
		win_const_mgr.add_const('ENABLEPAIRKERNING',0x00000301)
		win_const_mgr.add_const('SQL_FILE_USAGE',0x00000054)
		win_const_mgr.add_const('HTTP_MIN_SERVER_QUEUE_LENGTH',0x00000001)
		win_const_mgr.add_const('SM_CYHSCROLL',0x00000003)
		win_const_mgr.add_const('FR_SHOWHELP',0x00000080)
		win_const_mgr.add_const('ERROR_DS_LOCAL_ERROR',0x0000203B)
		win_const_mgr.add_const('FILE_DEVICE_PHYSICAL_NETCARD',0x00000017)
		win_const_mgr.add_const('ERROR_MISSING_SYSTEMFILE',0x0000023D)
		win_const_mgr.add_const('PDERR_CREATEICFAILURE',0x0000100A)
		win_const_mgr.add_const('WINHTTP_OPTION_SECURITY_FLAGS',0x0000001F)
		win_const_mgr.add_const('DDSCAPS_VIDEOPORT',0x08000000)
		win_const_mgr.add_const('DISCHARGE_POLICY_CRITICAL',0x00000000)
		win_const_mgr.add_const('ERROR_DS_ILLEGAL_SUPERIOR',0x00002099)
		win_const_mgr.add_const('BAUD_57600',0x00040000)
		win_const_mgr.add_const('CLUS_GLOBAL',0x00000001)
		win_const_mgr.add_const('MM_JOY1BUTTONDOWN',0x000003B5)
		win_const_mgr.add_const('OPTION_LOG_SERVERS',0x00000007)
		win_const_mgr.add_const('ERROR_DS_INCOMPATIBLE_VERSION',0x00002177)
		win_const_mgr.add_const('SO_SNDLOWAT',0x00001003)
		win_const_mgr.add_const('WM_CODEC_TWOPASS_CBR',0x00000004)
		win_const_mgr.add_const('HTTB_RESIZINGBORDER_LEFT',0x00000010)
		win_const_mgr.add_const('FWPS_FILTER_FLAG_CLEAR_ACTION_RIGHT',0x00000001)
		win_const_mgr.add_const('D3DVS_ADDRESSMODE_MASK',0x00000001)
		win_const_mgr.add_const('TVIF_STATEEX',0x00000100)
		win_const_mgr.add_const('SCARD_PROTOCOL_T1',0x00000002)
		win_const_mgr.add_const('DVB_TDT_PID',0x00000014)
		win_const_mgr.add_const('NETSETUP_WIN9X_UPGRADE',0x00000010)
		win_const_mgr.add_const('MFBYTESTREAM_IS_SEEKABLE',0x00000004)
		win_const_mgr.add_const('TASK_SEPTEMBER',0x00000100)
		win_const_mgr.add_const('WINHTTP_QUERY_FORWARDED',0x0000001E)
		win_const_mgr.add_const('WINHTTP_OPTION_MAX_RESPONSE_DRAIN_SIZE',0x0000005C)
		win_const_mgr.add_const('MIXERCONTROL_CT_UNITS_CUSTOM',0x00000000)
		win_const_mgr.add_const('EC_STREAM_ERROR_STILLPLAYING',0x00000007)
		win_const_mgr.add_const('INTERNET_HANDLE_TYPE_FTP_FILE_HTML',0x00000008)
		win_const_mgr.add_const('CB_OID_4',0x0000000C)
		win_const_mgr.add_const('CB_OID_3',0x0000000B)
		win_const_mgr.add_const('CB_OID_2',0x0000000A)
		win_const_mgr.add_const('CB_OID_1',0x00000009)
		win_const_mgr.add_const('ERROR_CLEANER_CARTRIDGE_INSTALLED',0x000010F4)
		win_const_mgr.add_const('SQL_API_SQLCONNECT',0x00000007)
		win_const_mgr.add_const('IDM_RIGHTALIGNPARA',0x000008CC)
		win_const_mgr.add_const('WCT_OUT_OF_PROC_COM_FLAG',0x00000002)
		win_const_mgr.add_const('VK_OEM_FJ_MASSHOU',0x00000093)
		win_const_mgr.add_const('TXTLOG_VERY_VERBOSE',0x00000007)
		win_const_mgr.add_const('SES_NOXLTSYMBOLRANGE',0x00000020)
		win_const_mgr.add_const('ODBC_ERROR_INVALID_STR',0x00000004)
		win_const_mgr.add_const('WSAEREMOTE',0x00002757)
		win_const_mgr.add_const('D3DPCMPCAPS_GREATER',0x00000010)
		win_const_mgr.add_const('SFF_PWD',0x00000800)
		win_const_mgr.add_const('SYMOPT_PUBLICS_ONLY',0x00004000)
		win_const_mgr.add_const('SFGAO_ISSLOW',0x00004000)
		win_const_mgr.add_const('OCSP_TRY_LATER_RESPONSE',0x00000003)
		win_const_mgr.add_const('WINHTTP_QUERY_COOKIE',0x0000002C)
		win_const_mgr.add_const('WLX_SAS_ACTION_FORCE_LOGOFF',0x00000009)
		win_const_mgr.add_const('PDERR_PARSEFAILURE',0x00001002)
		win_const_mgr.add_const('FLAGCOLOR_GREEN',0x00000003)
		win_const_mgr.add_const('ICON_SMALL2',0x00000002)
		win_const_mgr.add_const('BCPFIRST',0x00000002)
		win_const_mgr.add_const('TIME_CALLBACK_EVENT_PULSE',0x00000020)
		win_const_mgr.add_const('MIB_IF_TYPE_ETHERNET',0x00000006)
		win_const_mgr.add_const('EC_SYSTEMBASE',0x00000000)
		win_const_mgr.add_const('DVD_AUDIO_CAPS_DTS',0x00000008)
		win_const_mgr.add_const('PROC_THREAD_ATTRIBUTE_THREAD',0x00010000)
		win_const_mgr.add_const('EAP_E_USER_CERT_INVALID',0x80420101)
		win_const_mgr.add_const('WMDM_STATUS_DEVICECONTROL_PLAYING',0x00000008)
		win_const_mgr.add_const('BL_DRIVER0_INDEX',0x00000002)
		win_const_mgr.add_const('WMDRM_DELETE_LICENSE_IMMEDIATELY',0x00000001)
		win_const_mgr.add_const('FW_EXTRALIGHT',0x000000C8)
		win_const_mgr.add_const('HTTP_STATUS_BAD_REQUEST',0x00000190)
		win_const_mgr.add_const('JIFMK_APP7',0x0000FFE7)
		win_const_mgr.add_const('JIFMK_APP6',0x0000FFE6)
		win_const_mgr.add_const('CPF_LDAP_ERROR',0x00000100)
		win_const_mgr.add_const('JIFMK_APP4',0x0000FFE4)
		win_const_mgr.add_const('JIFMK_APP3',0x0000FFE3)
		win_const_mgr.add_const('JIFMK_APP2',0x0000FFE2)
		win_const_mgr.add_const('JIFMK_APP1',0x0000FFE1)
		win_const_mgr.add_const('JIFMK_APP0',0x0000FFE0)
		win_const_mgr.add_const('MDPROPVAL_MD_BEFORE',0x00000002)
		win_const_mgr.add_const('INCL_WINSOCK_API_TYPEDEFS',0x00000000)
		win_const_mgr.add_const('DRIVERSIGN_WARNING',0x00000001)
		win_const_mgr.add_const('ENDPOINT_SYSFX_ENABLED',0x00000000)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_TIMED_OUT',0x000035ED)
		win_const_mgr.add_const('DEBUG_DATA_PROCESSOR_IDENTIFICATION',0x00000004)
		win_const_mgr.add_const('SV_MAXCOPYREADLEN_PARMNUM',0x00000208)
		win_const_mgr.add_const('SHELLSTATEVERSION_IE4',0x00000009)
		win_const_mgr.add_const('SMINIT_AUTOEXPAND',0x00000100)
		win_const_mgr.add_const('ERROR_IS_SUBST_TARGET',0x00000095)
		win_const_mgr.add_const('OID_FDDI_SMT_TRANSITION_TIME_STAMP',0x0303021C)
		win_const_mgr.add_const('HTTP_STATUS_LENGTH_REQUIRED',0x0000019B)
		win_const_mgr.add_const('FR_REPLACE',0x00000010)
		win_const_mgr.add_const('SERVICE_CTRL_REDIR_DISK',0x00000001)
		win_const_mgr.add_const('SDP_ATTRIB_FAX_CLASS_1_SUPPORT',0x00000302)
		win_const_mgr.add_const('CPL_STARTWPARMSA',0x00000009)
		win_const_mgr.add_const('CM_PROB_DRIVER_BLOCKED',0x00000030)
		win_const_mgr.add_const('PAN_XHEIGHT_INDEX',0x00000009)
		win_const_mgr.add_const('DB_LIKE_ONLY',0x00000002)
		win_const_mgr.add_const('MOVEFILE_FAIL_IF_NOT_TRACKABLE',0x00000020)
		win_const_mgr.add_const('TBSTYLE_LIST',0x00001000)
		win_const_mgr.add_const('RTCRMF_BUDDY_ROAMING',0x00000001)
		win_const_mgr.add_const('HH_UNINITIALIZE',0x0000001D)
		win_const_mgr.add_const('CREDUI_FLAGS_PASSWORD_ONLY_OK',0x00000200)
		win_const_mgr.add_const('LDAP_SESSION_CMD',0x00000071)
		win_const_mgr.add_const('MD_PASSPORT_NEED_MAPPING',0x00000002)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_LOCAL_MACHINE_GROUP_POLICY_ID',0x00000008)
		win_const_mgr.add_const('STATURL_QUERYFLAG_NOTITLE',0x00040000)
		win_const_mgr.add_const('DDSCAPS_VISIBLE',0x00008000)
		win_const_mgr.add_const('CERT_NAME_EMAIL_TYPE',0x00000001)
		win_const_mgr.add_const('NET_STRING_NAMED_ADDRESS',0x00000100)
		win_const_mgr.add_const('SMINIT_CACHED',0x00000010)
		win_const_mgr.add_const('IF_TYPE_DOCSCABLE_MACLAYER',0x0000007F)
		win_const_mgr.add_const('PIDSI_LASTPRINTED',0x00000000)
		win_const_mgr.add_const('AC_LINE_ONLINE',0x00000001)
		win_const_mgr.add_const('POWERMODE_LINE',0x00000001)
		win_const_mgr.add_const('FILTER_INTERDOMAIN_TRUST_ACCOUNT',0x00000008)
		win_const_mgr.add_const('ISR_LFETCH',0x00000004)
		win_const_mgr.add_const('MDFF_UNDERLINE',0x00000004)
		win_const_mgr.add_const('CCLOCKSKEWMINUTESDEFAULT',0x0000000A)
		win_const_mgr.add_const('META_BITBLT',0x00000922)
		win_const_mgr.add_const('PRIORITY_PROP_LOW',0x00000000)
		win_const_mgr.add_const('SM_CYSMCAPTION',0x00000033)
		win_const_mgr.add_const('CBEIF_SELECTEDIMAGE',0x00000004)
		win_const_mgr.add_const('DIODI_NO_ADD',0x00000001)
		win_const_mgr.add_const('DLCTL_NO_DLACTIVEXCTLS',0x00000400)
		win_const_mgr.add_const('INDEX_GUID_COERCETOFACTOID',0x00000003)
		win_const_mgr.add_const('DFS_VOLUME_FLAVOR_AD_BLOB',0x00000200)
		win_const_mgr.add_const('GESTURE_RIGHT',0x00000000)
		win_const_mgr.add_const('PSRL_INITIAL',0x00000086)
		win_const_mgr.add_const('ISR_TB_TRAP',0x00000002)
		win_const_mgr.add_const('ERROR_EXE_MARKED_INVALID',0x000000C0)
		win_const_mgr.add_const('DISPID_SKIPRUNONCE',0x00000010)
		win_const_mgr.add_const('CI_STATE_SCANNING',0x00000010)
		win_const_mgr.add_const('SV_NUMFILETASKS_PARMNUM',0x000001A7)
		win_const_mgr.add_const('FOFX_DONTDISPLAYSOURCEPATH',0x04000000)
		win_const_mgr.add_const('SQL_FN_STR_INSERT',0x00000002)
		win_const_mgr.add_const('DISPID_BASE',0x00000000)
		win_const_mgr.add_const('MSIMWND_DISPID_ONCLOSE',0x000000E1)
		win_const_mgr.add_const('ERROR_PATCH_INVALID_OPTIONS',0xC00E3102)
		win_const_mgr.add_const('WINHTTP_QUERY_AUTHENTICATION_INFO',0x0000004C)
		win_const_mgr.add_const('IDTB_NOTES',0x000000D2)
		win_const_mgr.add_const('FILE_DEVICE_SCANNER',0x00000019)
		win_const_mgr.add_const('WINHTTP_OPTION_MAX_CONNS_PER_1_0_SERVER',0x0000004A)
		win_const_mgr.add_const('OLECMDARGINDEX_ACTIVEXINSTALL_PUBLISHER',0x00000000)
		win_const_mgr.add_const('IDS_CAP_MCI_CANT_STEP_ERROR',0x000001B5)
		win_const_mgr.add_const('TIMEPLAYLIST_OFFSET',0x00000B00)
		win_const_mgr.add_const('VIDEO_CONFIGURE_QUERY',0x00008000)
		win_const_mgr.add_const('LVS_EX_HEADERINALLVIEWS',0x02000000)
		win_const_mgr.add_const('GCM_RIGHTMOUSEDROP',0x00008000)
		win_const_mgr.add_const('LANG_KASHMIRI',0x00000060)
		win_const_mgr.add_const('MSSIP_FLAGS_PROHIBIT_RESIZE_ON_CREATE',0x00010000)
		win_const_mgr.add_const('WSASYSNOTREADY',0x0000276B)
		win_const_mgr.add_const('DDBD_32',0x00000100)
		win_const_mgr.add_const('MKF_LEFTBUTTONSEL',0x10000000)
		win_const_mgr.add_const('IDM_INLINEDIRLTR',0x00000932)
		win_const_mgr.add_const('INTERNET_OPTION_SECURITY_FLAGS',0x0000001F)
		win_const_mgr.add_const('IME_ESC_PRIVATE_HOTKEY',0x00000100)
		win_const_mgr.add_const('SQL_ATTR_ANSI_APP',0x00000073)
		win_const_mgr.add_const('KSAUDDECOUTMODE_STEREO_ANALOG',0x00000001)
		win_const_mgr.add_const('PORT_LOCUSCON',0x0000007F)
		win_const_mgr.add_const('SQL_MAX_DRIVER_CONNECTIONS',0x00000000)
		win_const_mgr.add_const('OLEUI_ERR_LPSZTEMPLATEINVALID',0x0000006C)
		win_const_mgr.add_const('SQL_DESC_LITERAL_SUFFIX',0x0000001C)
		win_const_mgr.add_const('STATSOPT_CLR',0x00000001)
		win_const_mgr.add_const('SI_ACCESS_GENERAL',0x00020000)
		win_const_mgr.add_const('IDM_CONTEXT',0x00000001)
		win_const_mgr.add_const('WIA_DPA_CONNECT_STATUS',0x00000403)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_NONE',0x00000000)
		win_const_mgr.add_const('RRF_RT_ANY',0x00000000)
		win_const_mgr.add_const('PIPE_SERVER_END',0x00000001)
		win_const_mgr.add_const('IO_ALIAS_16_BIT_DECODE',0x00000000)
		win_const_mgr.add_const('FD_CONNECT_BIT',0x00000004)
		win_const_mgr.add_const('FLAGCOLOR_BLUE',0x00000005)
		win_const_mgr.add_const('INTERNET_COOKIE_IE6',0x00000400)
		win_const_mgr.add_const('SQL_PARAM_INPUT_OUTPUT',0x00000002)
		win_const_mgr.add_const('API_QUERY_DATA_AVAILABLE',0x00000002)
		win_const_mgr.add_const('ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET',0x00001AB4)
		win_const_mgr.add_const('ERROR_DS_REFERRAL_LIMIT_EXCEEDED',0x00002044)
		win_const_mgr.add_const('SPSVCINST_NOCLOBBER_DISPLAYNAME',0x00000008)
		win_const_mgr.add_const('COMP_TYPE_CONTROL',0x00000003)
		win_const_mgr.add_const('TAPE_UNLOCK',0x00000004)
		win_const_mgr.add_const('SUBLANG_ARABIC_BAHRAIN',0x00000000)
		win_const_mgr.add_const('TF_PROFILETYPE_KEYBOARDLAYOUT',0x00000002)
		win_const_mgr.add_const('LGRPID_SUPPORTED',0x00000002)
		win_const_mgr.add_const('SQL_PACKET_SIZE',0x00000070)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_RECONFIG',0x00000004)
		win_const_mgr.add_const('OID_GEN_RNDIS_CONFIG_PARAMETER',0x0001021B)
		win_const_mgr.add_const('MD_ACR_READ',0x00000001)
		win_const_mgr.add_const('DBPROPVAL_SU_DML_STATEMENTS',0x00000001)
		win_const_mgr.add_const('LANG_BASE_LANGUAGE_INDEX',0x00000000)
		win_const_mgr.add_const('D3DVS20_MAX_DYNAMICFLOWCONTROLDEPTH',0x00000018)
		win_const_mgr.add_const('FILE_CASE_SENSITIVE_SEARCH',0x00000001)
		win_const_mgr.add_const('DLG_SCRNSAVECONFIGURE',0x000007D3)
		win_const_mgr.add_const('DIF_UNUSED1',0x0000001F)
		win_const_mgr.add_const('POLLWRNORM',0x00000010)
		win_const_mgr.add_const('CMF_CANRENAME',0x00000010)
		win_const_mgr.add_const('LINECONNECTEDMODE_ACTIVEHELD',0x00000004)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_HALF_YEAR',0x00000024)
		win_const_mgr.add_const('DEX_IDS_BAD_SOURCE_NAME2',0x00000579)
		win_const_mgr.add_const('IMAGE_SCN_ALIGN_8192BYTES',0x00E00000)
		win_const_mgr.add_const('MC_SUPPORTED_COLOR_TEMPERATURE_NONE',0x00000000)
		win_const_mgr.add_const('SERVICE_UIC_NORMAL',0x00000000)
		win_const_mgr.add_const('CONFIGFLAG_DISABLED',0x00000001)
		win_const_mgr.add_const('SQL_AT_CONSTRAINT_INITIALLY_IMMEDIATE',0x00020000)
		win_const_mgr.add_const('NDIS_ENCAPSULATION_NULL',0x00000001)
		win_const_mgr.add_const('OS_WOW6432',0x0000001E)
		win_const_mgr.add_const('LOCALE_SSORTNAME',0x00001013)
		win_const_mgr.add_const('IDM_UNLOADDOCUMENT',0x0000096B)
		win_const_mgr.add_const('IMAGE_REL_AMD64_ADDR64',0x00000001)
		win_const_mgr.add_const('CRYPT_KEYID_SET_NEW_FLAG',0x00002000)
		win_const_mgr.add_const('MCI_VCR_SETTUNER_CHANNEL_UP',0x00020000)
		win_const_mgr.add_const('ERROR_TOO_MANY_SEMAPHORES',0x00000064)
		win_const_mgr.add_const('MDPROPVAL_MOQ_CATALOG_CUBE',0x00000002)
		win_const_mgr.add_const('POSTSCRIPT_PASSTHROUGH',0x00001013)
		win_const_mgr.add_const('CERT_BACKED_UP_PROP_ID',0x00000045)
		win_const_mgr.add_const('WNCON_FORNETCARD',0x00000001)
		win_const_mgr.add_const('EXP_SZ_ICON_SIG',0xA0000007)
		win_const_mgr.add_const('CERT_TRUST_HAS_NAME_MATCH_ISSUER',0x00000004)
		win_const_mgr.add_const('REG_HIVE_NO_RM',0x00000100)
		win_const_mgr.add_const('SSPROP_INIT_CURRENTLANGUAGE',0x00000004)
		win_const_mgr.add_const('NETSH_ERROR_BASE',0x00003A98)
		win_const_mgr.add_const('SN_LEAVE_KEY',0x00000001)
		win_const_mgr.add_const('EAP_FLAG_PREFER_ALT_CREDENTIALS',0x00002000)
		win_const_mgr.add_const('TIME_ZONE_ID_STANDARD',0x00000001)
		win_const_mgr.add_const('DOT11_ASSOC_STATUS_ROAMING_BETTER_AP_FOUND',0x00000000)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_NULL',0x00000000)
		win_const_mgr.add_const('IMPORTANCE_HIGH_SET',0x00000005)
		win_const_mgr.add_const('IKEEXT_CERT_FLAG_DISABLE_REQUEST_PAYLOAD',0x00000002)
		win_const_mgr.add_const('WMDM_E_CALL_OUT_OF_SEQUENCE',0x80045007)
		win_const_mgr.add_const('URLACTION_AUTOMATIC_DOWNLOAD_UI_MIN',0x00002200)
		win_const_mgr.add_const('MCI_DGV_CUT_AUDIO_STREAM',0x00020000)
		win_const_mgr.add_const('SQL_DRIVER_COMPLETE',0x00000001)
		win_const_mgr.add_const('CTRY_TUNISIA',0x000000D8)
		win_const_mgr.add_const('FRS_ERR_SYSVOL_POPULATE_TIMEOUT',0x00001F4E)
		win_const_mgr.add_const('BSF_FEEDSUBSCRIBED',0x00100000)
		win_const_mgr.add_const('IDC_CI_FROMFILE',0x0000007D)
		win_const_mgr.add_const('IDM_GETPRINTTEMPLATE',0x000008F7)
		win_const_mgr.add_const('OID_802_11_REMOVE_KEY',0x0D01011E)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_DC_START',0x00000003)
		win_const_mgr.add_const('ERROR_DS_DUP_LDAP_DISPLAY_NAME',0x000020BE)
		win_const_mgr.add_const('CRYPT_MESSAGE_BARE_CONTENT_OUT_FLAG',0x00000001)
		win_const_mgr.add_const('DRM_SIGN_CANCEL',0x00000004)
		win_const_mgr.add_const('ICW_USE_SHELLNEXT',0x00000400)
		win_const_mgr.add_const('ACM_FORMATENUMF_WBITSPERSAMPLE',0x00080000)
		win_const_mgr.add_const('URLACTION_COOKIES_SESSION',0x00001A03)
		win_const_mgr.add_const('SQL_FN_TD_WEEK',0x00000080)
		win_const_mgr.add_const('LOCALE_SSHORTESTDAYNAME5',0x00000064)
		win_const_mgr.add_const('REO_BLANK',0x00000010)
		win_const_mgr.add_const('MSIM_DISPID_ONSENDRESULT',0x00000E09)
		win_const_mgr.add_const('MDPROPVAL_MF_SCOPE_GLOBAL',0x00000020)
		win_const_mgr.add_const('CRESTRICTIONS_MDSCHEMA_LEVELS',0x00000007)
		win_const_mgr.add_const('DRM_ACTIVATE_TEMPORARY',0x00000004)
		win_const_mgr.add_const('LOCALE_SSHORTESTDAYNAME2',0x00000061)
		win_const_mgr.add_const('SCARD_CLASS_PROTOCOL',0x00000003)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_REGISTER',0x00000004)
		win_const_mgr.add_const('SCARD_W_UNRESPONSIVE_CARD',0x80100066)
		win_const_mgr.add_const('MOUSE_HWHEELED',0x00000008)
		win_const_mgr.add_const('WINHTTP_DISABLE_SPN_SERVER_PORT',0x00000000)
		win_const_mgr.add_const('DMPAPER_PENV_8_ROTATED',0x00000074)
		win_const_mgr.add_const('SQL_COLUMN_TYPE_NAME',0x0000000E)
		win_const_mgr.add_const('CM_SET_DEVNODE_PROBLEM_BITS',0x00000001)
		win_const_mgr.add_const('DEBUG_MODNAME_IMAGE',0x00000000)
		win_const_mgr.add_const('SERVICE_MAXTIME',0x000000FF)
		win_const_mgr.add_const('SQL_API_SQLBINDPARAM',0x000003EA)
		win_const_mgr.add_const('LOCALE_STIMEFORMAT',0x00001003)
		win_const_mgr.add_const('ISSCERT_ENABLE',0x00000100)
		win_const_mgr.add_const('ERROR_JOIN_TO_JOIN',0x0000008A)
		win_const_mgr.add_const('CR_NEED_RESTART',0x00000022)
		win_const_mgr.add_const('ERROR_DS_NAME_TOO_LONG',0x0000209C)
		win_const_mgr.add_const('SQL_DESC_BIND_OFFSET_PTR',0x00000018)
		win_const_mgr.add_const('SV_SECURITY_WINNT',0x00000001)
		win_const_mgr.add_const('ALG_SID_MD5',0x00000003)
		win_const_mgr.add_const('SPI_GETMESSAGEDURATION',0x00002016)
		win_const_mgr.add_const('ERROR_WMI_UNRESOLVED_INSTANCE_REF',0x0000106D)
		win_const_mgr.add_const('ALG_SID_MD2',0x00000001)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_SERVICE',0x80002000)
		win_const_mgr.add_const('DEVPROP_TYPE_STRING',0x00000012)
		win_const_mgr.add_const('CERT_CHAIN_CRL_VALIDITY_EXT_PERIOD_HOURS_DEFAULT',0x0000000C)
		win_const_mgr.add_const('STI_DEVICE_CREATE_BOTH',0x00000003)
		win_const_mgr.add_const('MOUSE_WHEELED',0x00000004)
		win_const_mgr.add_const('SQL_CA1_POS_UPDATE',0x00000400)
		win_const_mgr.add_const('MSV1_0_SUBAUTH_PASSWORD_EXPIRY',0x00000020)
		win_const_mgr.add_const('LINECALLINFOSTATE_LOWLEVELCOMP',0x00800000)
		win_const_mgr.add_const('VP_FLAGS_COPYPROTECT',0x00000100)
		win_const_mgr.add_const('ERROR_ADAP_HDW_ERR',0x00000039)
		win_const_mgr.add_const('DISPID_ISSUBSCRIBED',0x00000007)
		win_const_mgr.add_const('WINHTTP_FLAG_ESCAPE_PERCENT',0x00000004)
		win_const_mgr.add_const('OID_WAN_GET_STATS_INFO',0x0401020E)
		win_const_mgr.add_const('DISPID_SHELLUIHELPERLAST',0x0000001E)
		win_const_mgr.add_const('DBPROPVAL_OO_DIRECTBIND',0x00000010)
		win_const_mgr.add_const('MH_CLEANUP',0x00000004)
		win_const_mgr.add_const('KS_TVAUDIO_MODE_STEREO',0x00000002)
		win_const_mgr.add_const('EWX_FORCE',0x00000004)
		win_const_mgr.add_const('DIF_ALLOW_INSTALL',0x00000018)
		win_const_mgr.add_const('INDETERMINATE_LATENCY',0xFFFFFFFF)
		win_const_mgr.add_const('CERT_ACCESS_STATE_GP_SYSTEM_STORE_FLAG',0x00000008)
		win_const_mgr.add_const('WM_UPDATEUISTATE',0x00000128)
		win_const_mgr.add_const('SQL_MAX_CONCURRENT_ACTIVITIES',0x00000001)
		win_const_mgr.add_const('VIEW_PRIORITY_INHERIT',0x00000020)
		win_const_mgr.add_const('DLGC_RADIOBUTTON',0x00000040)
		win_const_mgr.add_const('INTERNET_OPTION_PASSWORD',0x0000001D)
		win_const_mgr.add_const('LINEDISCONNECTMODE_UNAVAIL',0x00000800)
		win_const_mgr.add_const('RIDEV_DEVNOTIFY',0x00002000)
		win_const_mgr.add_const('SHDID_COMPUTER_CDROM',0x0000000A)
		win_const_mgr.add_const('D3DPRESENT_DONOTWAIT',0x00000001)
		win_const_mgr.add_const('TBSTYLE_BUTTON',0x00000000)
		win_const_mgr.add_const('LVNI_TOLEFT',0x00000400)
		win_const_mgr.add_const('CM_DRP_DEVICE_POWER_DATA',0x0000001F)
		win_const_mgr.add_const('REGDF_MAPIRQ2TO9',0x00100000)
		win_const_mgr.add_const('NDR_STRICT_CONTEXT_HANDLE',0x00000008)
		win_const_mgr.add_const('ERROR_CLUSTER_CANT_DESERIALIZE_DATA',0x00001723)
		win_const_mgr.add_const('ERROR_CLEANER_SLOT_SET',0x000010EB)
		win_const_mgr.add_const('CRYPT_HASH_ALG_OID_GROUP_ID',0x00000001)
		win_const_mgr.add_const('SORT_STRINGSORT',0x00001000)
		win_const_mgr.add_const('OUT_DEFAULT_PRECIS',0x00000000)
		win_const_mgr.add_const('IDS_RE',0x0001100C)
		win_const_mgr.add_const('CFM_REVAUTHOR',0x00008000)
		win_const_mgr.add_const('TASK_THIRD_WEEK',0x00000003)
		win_const_mgr.add_const('TB_ENTRY_SIZE',0x00000003)
		win_const_mgr.add_const('PRINTER_ERROR_INFORMATION',0x80000000)
		win_const_mgr.add_const('TMT_MINCOLORDEPTH',0x00000515)
		win_const_mgr.add_const('DDFXCAPS_BLTSHRINKYN',0x00002000)
		win_const_mgr.add_const('GESTURE_ARROW_UP',0x00000000)
		win_const_mgr.add_const('TMT_EDGEFILLCOLOR',0x00000EE0)
		win_const_mgr.add_const('MD_BACKUP_HIGHEST_VERSION',0x00000000)
		win_const_mgr.add_const('DXVA_ALPHA_BLEND_DATA_LOAD_FUNCTION',0x00000002)
		win_const_mgr.add_const('ERROR_DS_NONSAFE_SCHEMA_CHANGE',0x0000213C)
		win_const_mgr.add_const('WNFMT_CONNECTION',0x00000020)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_EXECSCRIPT',0x0000048D)
		win_const_mgr.add_const('ERROR_NOT_SAFEBOOT_SERVICE',0x0000043C)
		win_const_mgr.add_const('XINPUT_FLAG_GAMEPAD',0x00000001)
		win_const_mgr.add_const('IMAGE_COMDAT_SELECT_NODUPLICATES',0x00000001)
		win_const_mgr.add_const('HSE_APP_FLAG_POOLED_OOP',0x00000002)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_R10000',0x00000168)
		win_const_mgr.add_const('IDI_ASTERISK',0x00007F04)
		win_const_mgr.add_const('TRUSTEE_ACCESS_WRITE',0x00000004)
		win_const_mgr.add_const('ERROR_SXS_XML_E_UNCLOSEDCDATA',0x000036F1)
		win_const_mgr.add_const('VOLUME_IS_DIRTY',0x00000001)
		win_const_mgr.add_const('CPF_FTP_ERROR',0x00000400)
		win_const_mgr.add_const('GL_LEVEL_NOGUIDELINE',0x00000000)
		win_const_mgr.add_const('CLR_NONE',0xFFFFFFFF)
		win_const_mgr.add_const('MCI_VCR_SETTUNER_CHANNEL_SEEK_UP',0x00080000)
		win_const_mgr.add_const('FACILITY_SCARD',0x00000010)
		win_const_mgr.add_const('IME_GETCONVERSIONMODE',0x00000011)
		win_const_mgr.add_const('CREATE_PRESERVE_CODE_AUTHZ_LEVEL',0x02000000)
		win_const_mgr.add_const('PIPE_ACCESS_OUTBOUND',0x00000002)
		win_const_mgr.add_const('WKSTA_NUMSERVICES_PARMNUM',0x00000015)
		win_const_mgr.add_const('PSR_LP',0x00000019)
		win_const_mgr.add_const('ERROR_LOG_SECTOR_REMAPPED',0x000019CA)
		win_const_mgr.add_const('TF_CONVERSIONMODE_ALPHANUMERIC',0x00000000)
		win_const_mgr.add_const('ECO_AUTOHSCROLL',0x00000080)
		win_const_mgr.add_const('RPC_C_PROFILE_MATCH_BY_BOTH',0x00000004)
		win_const_mgr.add_const('CRYPT_MATCH_ANY_ENCODING_TYPE',0xFFFFFFFF)
		win_const_mgr.add_const('LDAP_VERSION3',0x00000003)
		win_const_mgr.add_const('CRYPT_MODE_ECB',0x00000002)
		win_const_mgr.add_const('SDP_ATTRIB_HID_BOOT_DEVICE',0x0000020E)
		win_const_mgr.add_const('SUBLANG_ENGLISH_MALAYSIA',0x00000011)
		win_const_mgr.add_const('MCI_VCR_SETVIDEO_NUMBER',0x00200000)
		win_const_mgr.add_const('SSA_PASSWORD',0x00000001)
		win_const_mgr.add_const('L2_REASON_CODE_SUCCESS',0x00000000)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_ACTION_DENY',0x00000002)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_WRITE_COMPLETE',0x00100000)
		win_const_mgr.add_const('ERROR_UNKNOWN_FEATURE',0x00000646)
		win_const_mgr.add_const('CREDUIWIN_PACK_32_WOW',0x10000000)
		win_const_mgr.add_const('GLOBAL_LRU',0x00000001)
		win_const_mgr.add_const('CR_INVALID_DEVICE_ID',0x0000001E)
		win_const_mgr.add_const('HTTP_ADDREQ_FLAG_ADD_IF_NEW',0x10000000)
		win_const_mgr.add_const('SECURITY_AUTHENTICATED_USER_RID',0x0000000B)
		win_const_mgr.add_const('ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP',0x00001708)
		win_const_mgr.add_const('SPDRP_REMOVAL_POLICY_OVERRIDE',0x00000021)
		win_const_mgr.add_const('ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE',0x00001781)
		win_const_mgr.add_const('SF_NOTIFY_END_OF_REQUEST',0x00000080)
		win_const_mgr.add_const('ECO_WANTRETURN',0x00001000)
		win_const_mgr.add_const('ERROR_FLOAT_MULTIPLE_TRAPS',0x00000277)
		win_const_mgr.add_const('SPDRP_DEVTYPE',0x00000019)
		win_const_mgr.add_const('NTDSSITECONN_OPT_USE_NOTIFY',0x00000001)
		win_const_mgr.add_const('_WIN32_WINDOWS',0x00000410)
		win_const_mgr.add_const('DEBUG_CES_SYSTEMS',0x00000800)
		win_const_mgr.add_const('LB_ADDFILE',0x00000196)
		win_const_mgr.add_const('MCI_DGV_CAPTURE_AS',0x00010000)
		win_const_mgr.add_const('PDH_PLA_VALIDATION_ERROR',0xC0000BF2)
		win_const_mgr.add_const('RSC_MBZ0_V',0x00000003)
		win_const_mgr.add_const('VER_PRODUCT_TYPE',0x00000080)
		win_const_mgr.add_const('AVIFILECAPS_CANREAD',0x00000001)
		win_const_mgr.add_const('LVGF_DESCRIPTIONTOP',0x00000400)
		win_const_mgr.add_const('DNF_INSTALLEDDRIVER',0x00040000)
		win_const_mgr.add_const('WCB16_MAX_CBARGS',0x00000010)
		win_const_mgr.add_const('OID_PNP_CAPABILITIES',0xFD010100)
		win_const_mgr.add_const('SQL_FN_STR_OCTET_LENGTH',0x00400000)
		win_const_mgr.add_const('VIEW_DETAILS',0x00000003)
		win_const_mgr.add_const('DLCTL_FORCEOFFLINE',0x10000000)
		win_const_mgr.add_const('WMDRM_IMPORT_SESSION_KEY_DEFINED',0x00000001)
		win_const_mgr.add_const('GPO_BROWSE_DISABLENEW',0x00000001)
		win_const_mgr.add_const('ERROR_I24_NOT_DOS_DISK',0x00000007)
		win_const_mgr.add_const('EMR_PLGBLT',0x0000004F)
		win_const_mgr.add_const('SEEK_CUR',0x00000001)
		win_const_mgr.add_const('CQFF_ISOPTIONAL',0x00000002)
		win_const_mgr.add_const('POLICY_ERRV_USER_CHANGED',0x00000036)
		win_const_mgr.add_const('IGP_SENTENCE',0x00000000)
		win_const_mgr.add_const('IEIFLAG_OFFLINE',0x00000008)
		win_const_mgr.add_const('ENABLERELATIVEWIDTHS',0x00000300)
		win_const_mgr.add_const('FR_REPLACEALL',0x00000020)
		win_const_mgr.add_const('MCI_OPEN_TYPE_ID',0x00001000)
		win_const_mgr.add_const('ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC',0x00002169)
		win_const_mgr.add_const('TVS_EX_AUTOHSCROLL',0x00000020)
		win_const_mgr.add_const('CMF_NODEFAULT',0x00000020)
		win_const_mgr.add_const('ALG_TYPE_DSS',0x00000001)
		win_const_mgr.add_const('PFD_MAIN_PLANE',0x00000000)
		win_const_mgr.add_const('LANG_ENGLISH',0x00000009)
		win_const_mgr.add_const('PHOTO_EXPOSUREPROGRAM_SHUTTER',0x00000004)
		win_const_mgr.add_const('ACM_DRIVERPRIORITYF_DEFERMASK',0x00030000)
		win_const_mgr.add_const('POWER_ACTION_LOCK_CONSOLE',0x20000000)
		win_const_mgr.add_const('CM_PROB_REENUMERATION',0x0000000F)
		win_const_mgr.add_const('SHCNF_TYPE',0x000000FF)
		win_const_mgr.add_const('ODBC_USER_DSN',0x00000001)
		win_const_mgr.add_const('SECPKG_ATTR_LOCAL_CERT_CONTEXT',0x00000054)
		win_const_mgr.add_const('CACHE_CONFIG_STICKY_CONTENT_USAGE_FC',0x00004000)
		win_const_mgr.add_const('DTR_HAL_INDEX',0x00000006)
		win_const_mgr.add_const('RTM_ROUTE_STATE_DELETING',0x00000001)
		win_const_mgr.add_const('IME_CMODE_LANGUAGE',0x00000003)
		win_const_mgr.add_const('D3DPRESENTFLAG_VIDEO',0x00000010)
		win_const_mgr.add_const('DSA_NOTIFY_FLAG_ADDITIONAL_DATA',0x00000002)
		win_const_mgr.add_const('TRACE_NO_SYNCH',0x00000004)
		win_const_mgr.add_const('SQL_MAX_MESSAGE_LENGTH',0x00000200)
		win_const_mgr.add_const('SQL_API_SQLGETENVATTR',0x000003F4)
		win_const_mgr.add_const('WIZ_CXDLG',0x00000114)
		win_const_mgr.add_const('BSF_CANMAXIMIZE',0x00000400)
		win_const_mgr.add_const('KSNODEPIN_STANDARD_OUT',0x00000000)
		win_const_mgr.add_const('MDPROPVAL_MSF_YTD',0x00000040)
		win_const_mgr.add_const('MCI_VCR_STEP_FRAMES',0x00010000)
		win_const_mgr.add_const('DST_ICON',0x00000003)
		win_const_mgr.add_const('VER_DRM_PLAY_OPL_V1',0x00000001)
		win_const_mgr.add_const('SERVICE_ERROR_NORMAL',0x00000001)
		win_const_mgr.add_const('JOYCAPS_POV4DIR',0x00000020)
		win_const_mgr.add_const('DST_PREFIXTEXT',0x00000002)
		win_const_mgr.add_const('WMS_STREAM_DISTRIBUTION_PLAYLIST_GENERATION_ID',0x0000000D)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_STREAM',0x00004003)
		win_const_mgr.add_const('LINECALLREASON_FWDNOANSWER',0x00000004)
		win_const_mgr.add_const('CLFS_FLAG_REENTRANT_FILTER',0x00000020)
		win_const_mgr.add_const('TMT_TEXTCOLOR',0x00000EDB)
		win_const_mgr.add_const('ERROR_FLOPPY_BAD_REGISTERS',0x00000465)
		win_const_mgr.add_const('DEBUG_STATUS_NO_DEBUGGEE',0x00000007)
		win_const_mgr.add_const('TBS_HORZ',0x00000000)
		win_const_mgr.add_const('CMSG_ENCODE_SORTED_CTL_FLAG',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_WRONG_SA',0x00003658)
		win_const_mgr.add_const('ADS_PRINTER_WAITING',0x00002000)
		win_const_mgr.add_const('COD_PERIPHERAL_MINOR_NO_CATEGORY',0x00000000)
		win_const_mgr.add_const('ERROR_DS_DIFFERENT_REPL_EPOCHS',0x00002191)
		win_const_mgr.add_const('ASC_RET_EXTENDED_ERROR',0x00008000)
		win_const_mgr.add_const('DBIF_VIEWMODE_NORMAL',0x00000000)
		win_const_mgr.add_const('ISSCERT_HTTPURL_OLD',0x00000002)
		win_const_mgr.add_const('D3DPBLENDCAPS_DESTCOLOR',0x00000100)
		win_const_mgr.add_const('AM_QUERY_DECODER_ATSC_SD_SUPPORT',0x00000004)
		win_const_mgr.add_const('WM_IME_CHAR',0x00000286)
		win_const_mgr.add_const('MIXER_GETCONTROLDETAILSF_QUERYMASK',0x0000000F)
		win_const_mgr.add_const('SHCNE_NETUNSHARE',0x00000400)
		win_const_mgr.add_const('EN_PARAGRAPHEXPANDED',0x00000070)
		win_const_mgr.add_const('MCI_DGV_STATUS_HPAL',0x00004004)
		win_const_mgr.add_const('MODALS_ROLE_PARMNUM',0x00000006)
		win_const_mgr.add_const('CSA_CMYK',0x00000007)
		win_const_mgr.add_const('INTERNET_OPTION_SECURITY_CERTIFICATE_STRUCT',0x00000020)
		win_const_mgr.add_const('DXVA_BITSTREAM_CONCEALMENT_NEED_MILD',0x00000001)
		win_const_mgr.add_const('CERT_UNICODE_RDN_ERR_INDEX_MASK',0x000003FF)
		win_const_mgr.add_const('CERT_COMPARE_MD5_HASH',0x00000004)
		win_const_mgr.add_const('GESTURE_LEFT_UP',0x00000000)
		win_const_mgr.add_const('DBPROPVAL_LM_RITE',0x00000008)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_VIEWS',0x00000003)
		win_const_mgr.add_const('NI_NOFQDN',0x00000001)
		win_const_mgr.add_const('INDEX_GUID_SUFFIXTEXT',0x00000006)
		win_const_mgr.add_const('CAUSE_LOC_USER',0x00000000)
		win_const_mgr.add_const('QUEUE_ADMIN_MAX_BUFFER_REQUIRED',0x000000C8)
		win_const_mgr.add_const('WIA_IPA_BITS_PER_CHANNEL',0x0000100E)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_NOINTERNALCALLS',0x08000000)
		win_const_mgr.add_const('BTH_ERROR_UNIT_KEY_NOT_USED',0x00000026)
		win_const_mgr.add_const('SERVICE_BASE',0x00000BEA)
		win_const_mgr.add_const('CRYPT_DONT_CACHE_RESULT',0x00000008)
		win_const_mgr.add_const('C2_EUROPETERMINATOR',0x00000005)
		win_const_mgr.add_const('CRYPT_CREATE_IV',0x00000200)
		win_const_mgr.add_const('CTRY_GERMANY',0x00000031)
		win_const_mgr.add_const('INTERNET_OPTION_RECEIVE_THROUGHPUT',0x00000039)
		win_const_mgr.add_const('MD_SCRIPTMAPFLAG_ALLOWED_ON_READ_DIR',0x00000001)
		win_const_mgr.add_const('ATMPROTO_AAL34',0x00000003)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_PORT_NAME',0x00000002)
		win_const_mgr.add_const('SQL_CA2_SIMULATE_UNIQUE',0x00010000)
		win_const_mgr.add_const('SCARD_CLASS_SYSTEM',0x00000007)
		win_const_mgr.add_const('PIDMSI_SUPPLIER',0x00000003)
		win_const_mgr.add_const('MM_MPU401_MIDIIN',0x0000000B)
		win_const_mgr.add_const('SQL_POSITION',0x00000000)
		win_const_mgr.add_const('PRODUCT_HOME_BASIC_N',0x00000005)
		win_const_mgr.add_const('SCARD_READER_CONFISCATES',0x00000004)
		win_const_mgr.add_const('PERCEIVEDFLAG_NATIVESUPPORT',0x00000004)
		win_const_mgr.add_const('MCI_DGV_FILE_MODE_EDITING_S',0x00008006)
		win_const_mgr.add_const('ERROR_SHUTDOWN_IS_SCHEDULED',0x000004A6)
		win_const_mgr.add_const('URLACTION_BEHAVIOR_MIN',0x00002000)
		win_const_mgr.add_const('SPI_SETCARETWIDTH',0x00002007)
		win_const_mgr.add_const('DNS_RTYPE_PX',0x00000001)
		win_const_mgr.add_const('DIBCI_NOINSTALLCLASS',0x00000001)
		win_const_mgr.add_const('PRINTER_CHANGE_ALL',0x7777FFFF)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_OFFSCREENBUFFERING',0x0000048C)
		win_const_mgr.add_const('LINEADDRCAPFLAGS_BLOCKIDDEFAULT',0x00000008)
		win_const_mgr.add_const('SPI_GETSERIALKEYS',0x0000003E)
		win_const_mgr.add_const('DNSSEC_KEY_FLAG_SIG2',0x00002000)
		win_const_mgr.add_const('SF_USECODEPAGE',0x00000020)
		win_const_mgr.add_const('SPINST_INIFILES',0x00000002)
		win_const_mgr.add_const('MDPROPVAL_FS_NO_SUPPORT',0x00000004)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_FIELD2_MASK',0x00001F00)
		win_const_mgr.add_const('WM_NCCALCSIZE',0x00000083)
		win_const_mgr.add_const('IMAGE_SYM_TYPE_INT',0x00000004)
		win_const_mgr.add_const('ERROR_DS_CANT_REM_MISSING_ATT_VAL',0x00002085)
		win_const_mgr.add_const('CAUSE_INVALID_STATE_FOR_MESSAGE',0x00000065)
		win_const_mgr.add_const('PID_WHICHFOLDER',0x00000003)
		win_const_mgr.add_const('OID_ATM_RCV_REASSEMBLY_ERROR',0x08020203)
		win_const_mgr.add_const('ERROR_GENERIC_COMMAND_FAILED',0x0000371D)
		win_const_mgr.add_const('DDCAPS_RESERVED1',0x00040000)
		win_const_mgr.add_const('MSV1_0_RETURN_PASSWORD_EXPIRY',0x00000040)
		win_const_mgr.add_const('TF_MOD_RCONTROL',0x00000010)
		win_const_mgr.add_const('_INC_DIGITALV',0x00000064)
		win_const_mgr.add_const('FF_DECORATIVE',0x00000005)
		win_const_mgr.add_const('OID_FFP_DRIVER_STATS',0xFC020210)
		win_const_mgr.add_const('MONITORS_MAX',0x0000000A)
		win_const_mgr.add_const('HHWIN_TB_MARGIN',0x00000001)
		win_const_mgr.add_const('WMDM_SCP_DECIDE_DATA',0x00000008)
		win_const_mgr.add_const('URLACTION_CHANNEL_SOFTDIST_MIN',0x00001E00)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2RAWCDEVENTARGS_ELAPSEDTIME',0x00000300)
		win_const_mgr.add_const('CPEX_DEST_STDCALL',0x00000000)
		win_const_mgr.add_const('DMPAPER_PENV_9_ROTATED',0x00000075)
		win_const_mgr.add_const('SNMP_TRAP_EGPNEIGHBORLOSS',0x00000005)
		win_const_mgr.add_const('ERROR_ALLOCATE_BUCKET',0x0000025A)
		win_const_mgr.add_const('SUBLANG_TELUGU_INDIA',0x00000001)
		win_const_mgr.add_const('WTS_REMOTE_DISCONNECT',0x00000004)
		win_const_mgr.add_const('OPTION_NETBIOS_NAME_SERVER',0x0000002C)
		win_const_mgr.add_const('SM_CLEANBOOT',0x00000043)
		win_const_mgr.add_const('VK_OEM_8',0x000000DF)
		win_const_mgr.add_const('MCI_STATUS_MEDIA_PRESENT',0x00000005)
		win_const_mgr.add_const('EMO_ENTER',0x00000001)
		win_const_mgr.add_const('PIDASI_AVG_DATA_RATE',0x00000004)
		win_const_mgr.add_const('SHARE_REMARK_PARMNUM',0x00000004)
		win_const_mgr.add_const('MW_FILTERMODE_INCLUDE',0x00000001)
		win_const_mgr.add_const('ERROR_WRONG_COMPARTMENT',0x000005BC)
		win_const_mgr.add_const('ET_DATACOLORSPACE',0x00000040)
		win_const_mgr.add_const('D3DLOCK_NOSYSLOCK',0x00000800)
		win_const_mgr.add_const('PRIMARY_CACHE_CLEAN_EXCLUSIVE',0x00000002)
		win_const_mgr.add_const('DWN_MIRRORIMAGE',0x00000200)
		win_const_mgr.add_const('SQL_SP_EXISTS',0x00000001)
		win_const_mgr.add_const('ISO_REGISTRY',0x00000002)
		win_const_mgr.add_const('MIXERCONTROL_CT_SC_SWITCH_BUTTON',0x01000000)
		win_const_mgr.add_const('CHANGER_VOLUME_UNDEFINE',0x01000000)
		win_const_mgr.add_const('MANAGED_APPTYPE_SETUPEXE',0x00000002)
		win_const_mgr.add_const('KERB_ETYPE_DES3_CBC_MD5',0x00000005)
		win_const_mgr.add_const('KSAC3_SERVICE_COMMENTARY',0x00000005)
		win_const_mgr.add_const('DEBUG_STATUS_IGNORE_EVENT',0x00000009)
		win_const_mgr.add_const('SE_SELF_RELATIVE',0x00008000)
		win_const_mgr.add_const('COD_AUDIO_MINOR_HANDS_FREE',0x00000002)
		win_const_mgr.add_const('DESKTOP_CREATEMENU',0x00000004)
		win_const_mgr.add_const('SV_SECURITY_WINNTAS',0x00000002)
		win_const_mgr.add_const('ASC_RET_DELEGATE',0x00000001)
		win_const_mgr.add_const('STREAM_FLAGS_DISALLOW_UPDATEGRAMS',0x00000040)
		win_const_mgr.add_const('MF_1_BYTE_ALIGNMENT',0x00000000)
		win_const_mgr.add_const('DEBUG_STACK_FRAME_ADDRESSES',0x00000008)
		win_const_mgr.add_const('NDIS_OBJECT_TYPE_RSS_CAPABILITIES',0x00000088)
		win_const_mgr.add_const('PRINTER_ENUM_SHARED',0x00000020)
		win_const_mgr.add_const('IMAGE_REL_AM_FUNCINFO',0x00000004)
		win_const_mgr.add_const('ERROR_VIRUS_INFECTED',0x000000E1)
		win_const_mgr.add_const('WM_CODEC_ONEPASS_VBR',0x00000002)
		win_const_mgr.add_const('SHTDN_REASON_MAJOR_SYSTEM',0x00050000)
		win_const_mgr.add_const('CRM_PROTOCOL_EXPLICIT_MARSHAL_ONLY',0x00000001)
		win_const_mgr.add_const('WM_CL_INTERLACED420',0x00000000)
		win_const_mgr.add_const('ACCESS_DENIED_CALLBACK_ACE_TYPE',0x0000000A)
		win_const_mgr.add_const('KSPIN_FLAG_USE_STANDARD_TRANSPORT',0x00040000)
		win_const_mgr.add_const('VK_BROWSER_STOP',0x000000A9)
		win_const_mgr.add_const('ERROR_CTX_SESSION_IN_USE',0x00001B96)
		win_const_mgr.add_const('TASK_FLAG_INTERACTIVE',0x00000001)
		win_const_mgr.add_const('MCI_BREAK_OFF',0x00000400)
		win_const_mgr.add_const('MD_NOTIFY_ORDER_HIGH',0x00080000)
		win_const_mgr.add_const('LDAP_OPT_PROTOCOL_VERSION',0x00000011)
		win_const_mgr.add_const('IDM_PREFORMATTED',0x0000088C)
		win_const_mgr.add_const('QDI_DIBTOSCREEN',0x00000004)
		win_const_mgr.add_const('DI_VENDOR_ID_SOURCE_BLUETOOTH_SIG',0x00000001)
		win_const_mgr.add_const('GESTURE_ARROW_RIGHT',0x00000000)
		win_const_mgr.add_const('STGFMT_ANY',0x00000004)
		win_const_mgr.add_const('TSF_SUSPEND_SHELLEVENTS',0x00000800)
		win_const_mgr.add_const('IDC_IO_CHANGEICON',0x00000839)
		win_const_mgr.add_const('RFCOMM_CMD_RLS',0x00000002)
		win_const_mgr.add_const('CREDENTIAL_SUB_TYPE_PGP_CERT',0x00000005)
		win_const_mgr.add_const('TXTLOG_SUMMARY',0x00000004)
		win_const_mgr.add_const('KS_CC_SUBSTREAM_SERVICE_XDS',0x00001000)
		win_const_mgr.add_const('DEBUG_OUTPUT_SYMBOLS',0x00000200)
		win_const_mgr.add_const('EMARCH_ENC_I17_IMM5C_INST_WORD_X',0x00000003)
		win_const_mgr.add_const('SQL_SO_STATIC',0x00000010)
		win_const_mgr.add_const('IPADDRESSLEN',0x0000000F)
		win_const_mgr.add_const('UNDNAME_NO_THISTYPE',0x00000060)
		win_const_mgr.add_const('ERROR_FLOATED_SECTION',0x00001ABE)
		win_const_mgr.add_const('MDLEVEL_TYPE_TIME_MONTHS',0x00000084)
		win_const_mgr.add_const('ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE',0x000021B2)
		win_const_mgr.add_const('ULONG64_MAX',0x00000000)
		win_const_mgr.add_const('RPC_C_SECURITY_QOS_VERSION_2',0x00000002)
		win_const_mgr.add_const('RPC_C_SECURITY_QOS_VERSION_3',0x00000003)
		win_const_mgr.add_const('MD_AUTH_SINGLEREQUESTALWAYSIFPROXY',0x00000100)
		win_const_mgr.add_const('CRYPTUI_WIZ_DIGITAL_SIGN_SUBJECT_FILE',0x00000001)
		win_const_mgr.add_const('BCPUNICODEFILE',0x0000000D)
		win_const_mgr.add_const('RPC_C_SECURITY_QOS_VERSION_4',0x00000004)
		win_const_mgr.add_const('ERROR_DS_AUTH_UNKNOWN',0x0000202A)
		win_const_mgr.add_const('LINEBEARERMODE_SPEECH',0x00000002)
		win_const_mgr.add_const('SSPROP_INIT_NETWORKLIBRARY',0x00000006)
		win_const_mgr.add_const('PORT_KLOGIN',0x0000021F)
		win_const_mgr.add_const('ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED',0x000036C0)
		win_const_mgr.add_const('STAT_PARTIAL_SCOPE',0x00000008)
		win_const_mgr.add_const('ECOOP_XOR',0x00000004)
		win_const_mgr.add_const('COMP_ELEM_SIZE_WIDTH',0x00000040)
		win_const_mgr.add_const('ETW_BYTE_TYPE_VALUE',0x00000004)
		win_const_mgr.add_const('FEI_IDLE',0x00000013)
		win_const_mgr.add_const('ABN_STATECHANGE',0x00000000)
		win_const_mgr.add_const('VP_FLAGS_CONTRAST',0x00000080)
		win_const_mgr.add_const('SCARD_P_SHUTDOWN',0x80100018)
		win_const_mgr.add_const('WINHTTP_QUERY_AGE',0x00000030)
		win_const_mgr.add_const('NTM_DSIG',0x00200000)
		win_const_mgr.add_const('DBPROPVAL_TR_NONE',0x00000100)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_IO_FLUSH_INIT',0x0000000F)
		win_const_mgr.add_const('SQL_DIAG_CREATE_COLLATION',0x0000000A)
		win_const_mgr.add_const('NLA_FRIENDLY_NAME',0x00000002)
		win_const_mgr.add_const('PORT_PROSPERO',0x000000BF)
		win_const_mgr.add_const('INTERNET_OPTION_RESTORE_WORKER_THREAD_DEFAULTS',0x0000005D)
		win_const_mgr.add_const('SQL_SQ_COMPARISON',0x00000001)
		win_const_mgr.add_const('PHONEFEATURE_GETVOLUMESPEAKER',0x00001000)
		win_const_mgr.add_const('IMAGE_SCN_TYPE_NO_PAD',0x00000008)
		win_const_mgr.add_const('INTERNET_STATUS_FILTER_RESOLVING',0x00000001)
		win_const_mgr.add_const('UM_FOCUS_TYPE_WINNT',0x00000002)
		win_const_mgr.add_const('TTFMFP_DELTA',0x00000002)
		win_const_mgr.add_const('WIA_IPS_XRES',0x00001803)
		win_const_mgr.add_const('VK_SPACE',0x00000020)
		win_const_mgr.add_const('MAX_REASON_COMMENT_LEN',0x00000200)
		win_const_mgr.add_const('EXCEPTION_EXECUTE_FAULT',0x00000002)
		win_const_mgr.add_const('E_FILTER_FRAMESET',0x80100001)
		win_const_mgr.add_const('TMT_BORDERCOLOR',0x00000ED9)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_ITEM',0x00800000)
		win_const_mgr.add_const('CRYPTUI_WARN_REMOTE_TRUST',0x00001000)
		win_const_mgr.add_const('NET_IF_OPER_STATUS_DORMANT_LOW_POWER',0x00000008)
		win_const_mgr.add_const('IME_THOTKEY_SHAPE_TOGGLE',0x00000071)
		win_const_mgr.add_const('IF_TYPE_DVBRCC_UPSTREAM',0x00000094)
		win_const_mgr.add_const('BPPF_NONCLIENT',0x00000004)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_CONFIG_IRQ',0x00000015)
		win_const_mgr.add_const('WINHTTP_FLAG_SECURE_PROTOCOL_SSL3',0x00000020)
		win_const_mgr.add_const('SQL_DRIVER_VER',0x00000007)
		win_const_mgr.add_const('PDH_LOG_TYPE_PERFMON',0x00000006)
		win_const_mgr.add_const('CM_PROB_FAILED_POST_START',0x0000002B)
		win_const_mgr.add_const('ERROR_INSUFFICIENT_BUFFER',0x0000007A)
		win_const_mgr.add_const('MPR_INTERFACE_NO_MEDIA_SENSE',0x00000020)
		win_const_mgr.add_const('WINHTTP_QUERY_CONTENT_ID',0x00000003)
		win_const_mgr.add_const('CCS_NOPARENTALIGN',0x00000008)
		win_const_mgr.add_const('ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY',0x00002152)
		win_const_mgr.add_const('SSF_AUTOCHECKSELECT',0x00800000)
		win_const_mgr.add_const('MCI_VCR_CUE_PREROLL',0x00040000)
		win_const_mgr.add_const('VS_FF_DEBUG',0x00000001)
		win_const_mgr.add_const('IDM_GETBYTESDOWNLOADED',0x0000091B)
		win_const_mgr.add_const('CR_NO_REGISTRY_HANDLE',0x0000001C)
		win_const_mgr.add_const('MCI_DGV_PUT_WINDOW',0x00200000)
		win_const_mgr.add_const('REPLACEFILE_IGNORE_MERGE_ERRORS',0x00000002)
		win_const_mgr.add_const('SN_INFLAG_FORCE_VER',0x00000001)
		win_const_mgr.add_const('SV_PLATFORM_ID_OS2',0x00000190)
		win_const_mgr.add_const('LASTGOOD_OPERATION_NOPOSTPROC',0x00000000)
		win_const_mgr.add_const('EVENT_TRACE_FLAG_PROFILE',0x01000000)
		win_const_mgr.add_const('DDOVER_ALPHASRCCONSTOVERRIDE',0x00000040)
		win_const_mgr.add_const('OID_FDDI_SMT_CONFIG_POLICY',0x0303020D)
		win_const_mgr.add_const('CERT_ALT_NAME_REGISTERED_ID',0x00000009)
		win_const_mgr.add_const('LOCKFILE_EXCLUSIVE_LOCK',0x00000002)
		win_const_mgr.add_const('TASK_FIRST_WEEK',0x00000001)
		win_const_mgr.add_const('CVT_DAYS',0x00000018)
		win_const_mgr.add_const('RBBS_VARIABLEHEIGHT',0x00000040)
		win_const_mgr.add_const('NDIS_MAC_OPTION_EOTX_INDICATION',0x00000020)
		win_const_mgr.add_const('SNMPAPI_PDU_INVALID',0x0000000C)
		win_const_mgr.add_const('SPMODE_DEBUGBREAK',0x00000200)
		win_const_mgr.add_const('OID_GEN_SUPPORTED_LIST',0x00010101)
		win_const_mgr.add_const('ACM_DRIVERADDF_GLOBAL',0x00000008)
		win_const_mgr.add_const('SSPROP_STREAM_XMLROOT',0x00000013)
		win_const_mgr.add_const('ORD_LANGDRIVER',0x00000001)
		win_const_mgr.add_const('DWM_TNP_OPACITY',0x00000004)
		win_const_mgr.add_const('AE_ERROR',0x00000001)
		win_const_mgr.add_const('TF_USE_KERNEL_APC',0x00000020)
		win_const_mgr.add_const('ERROR_INVALID_PLUGPLAY_DEVICE_PATH',0x0000026C)
		win_const_mgr.add_const('WIA_PAGE_LETTER',0x00000001)
		win_const_mgr.add_const('IPSEC_SA_BUNDLE_FLAG_NLB',0x00000010)
		win_const_mgr.add_const('CMSG_VERIFY_SIGNER_NULL',0x00000004)
		win_const_mgr.add_const('MCI_SET_DOOR_CLOSED',0x00000200)
		win_const_mgr.add_const('STDOLE2_MINORVERNUM',0x00000000)
		win_const_mgr.add_const('DEBUG_REGSRC_EXPLICIT',0x00000001)
		win_const_mgr.add_const('ERROR_LOG_RESIZE_INVALID_SIZE',0x00001A96)
		win_const_mgr.add_const('VER_DRM_PLAY_OPL',0x00000002)
		win_const_mgr.add_const('HTTP_QUERY_IF_NONE_MATCH',0x00000039)
		win_const_mgr.add_const('ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME',0x000036C6)
		win_const_mgr.add_const('PP_ENUMALGS_EX',0x00000016)
		win_const_mgr.add_const('SECPKG_ATTR_USE_NCRYPT',0x00000062)
		win_const_mgr.add_const('MD_EXPORT_NODE_ONLY',0x00000002)
		win_const_mgr.add_const('TSF_OVERWRITE_EXIST',0x00000002)
		win_const_mgr.add_const('EC_PLEASE_REOPEN',0x00000040)
		win_const_mgr.add_const('MCI_DGV_STATUS_BLOCKALIGN',0x00004029)
		win_const_mgr.add_const('SQL_FN_TSI_QUARTER',0x00000080)
		win_const_mgr.add_const('EDITF_IGNOREREQUESTERGROUP',0x00000400)
		win_const_mgr.add_const('LINE_DEVSPECIFICEX',0x00000022)
		win_const_mgr.add_const('RATING_FOUR_STARS_MIN',0x0000003F)
		win_const_mgr.add_const('IDM_GETFRAMEZONE',0x00001795)
		win_const_mgr.add_const('DISABLE_MAX_PRIVILEGE',0x00000001)
		win_const_mgr.add_const('METADATA_NO_ATTRIBUTES',0x00000000)
		win_const_mgr.add_const('VARIANT_LOCALBOOL',0x00000010)
		win_const_mgr.add_const('DEBUG_SYMTYPE_PDB',0x00000003)
		win_const_mgr.add_const('XINPUT_GAMEPAD_RIGHT_THUMB',0x00000080)
		win_const_mgr.add_const('RIM_TYPEMOUSE',0x00000000)
		win_const_mgr.add_const('CERT_STORE_SET_LOCALIZED_NAME_FLAG',0x00000002)
		win_const_mgr.add_const('DEX_IDS_UNKNOWN_SOURCE',0x0000057B)
		win_const_mgr.add_const('SPI_SETICONMETRICS',0x0000002E)
		win_const_mgr.add_const('CMM_DLL_VERSION',0x00000003)
		win_const_mgr.add_const('PHONEFEATURE_SETGAINHEADSET',0x00080000)
		win_const_mgr.add_const('SV_ENABLESECURITYSIGNATURE_PARMNUM',0x00000251)
		win_const_mgr.add_const('DS_CONTEXTHELP',0x00002000)
		win_const_mgr.add_const('DBPROPVAL_ORS_TABLE',0x00000000)
		win_const_mgr.add_const('SQL_DC_DROP_COLLATION',0x00000001)
		win_const_mgr.add_const('BCPLAST',0x00000003)
		win_const_mgr.add_const('DELTA_OPTIONS_SIZE_LIMIT',0x00000080)
		win_const_mgr.add_const('VAR_CALENDAR_THAI',0x00000080)
		win_const_mgr.add_const('PHOTO_ORIENTATION_ROTATE90',0x00000008)
		win_const_mgr.add_const('DMPAPER_10X14',0x00000010)
		win_const_mgr.add_const('SECURITY_SERVICE_RID',0x00000006)
		win_const_mgr.add_const('INTERNET_OPTION_DISABLE_NTLM_PREAUTH',0x00000048)
		win_const_mgr.add_const('EXCHIVERB_OPEN',0x00000000)
		win_const_mgr.add_const('MCI_STRING_OFFSET',0x00000200)
		win_const_mgr.add_const('TMT_RESERVEDLOW',0x00000000)
		win_const_mgr.add_const('COLOR_MENUTEXT',0x00000007)
		win_const_mgr.add_const('HTMLDLG_NOUI',0x00000010)
		win_const_mgr.add_const('DN_NT_DRIVER',0x01000000)
		win_const_mgr.add_const('FILE_NAME_OPENED',0x00000008)
		win_const_mgr.add_const('OID_IRDA_RESERVED1',0x0A01020A)
		win_const_mgr.add_const('CERT_VERIFY_TRUSTED_SIGNERS_FLAG',0x00000002)
		win_const_mgr.add_const('WMDM_STATUS_STORAGECONTROL_READING',0x00020000)
		win_const_mgr.add_const('INTERNET_CONNECTION_LAN',0x00000002)
		win_const_mgr.add_const('NETSETUP_IGNORE_UNSUPPORTED_FLAGS',0x10000000)
		win_const_mgr.add_const('SF_NOTIFY_READ_RAW_DATA',0x00008000)
		win_const_mgr.add_const('CFM_ITALIC',0x00000002)
		win_const_mgr.add_const('GESTURE_TAP',0x00000000)
		win_const_mgr.add_const('ITIR_RV0',0x00000000)
		win_const_mgr.add_const('OID_CO_TAPI_TRANSLATE_TAPI_SAP',0xFE001006)
		win_const_mgr.add_const('STI_SUBSCRIBE_FLAG_EVENT',0x00000002)
		win_const_mgr.add_const('WMDM_SCP_EXAMINE_EXTENSION',0x00000001)
		win_const_mgr.add_const('PFD_NEED_SYSTEM_PALETTE',0x00000100)
		win_const_mgr.add_const('SPI_SETMOUSEHOVERHEIGHT',0x00000065)
		win_const_mgr.add_const('DDCAPS_GDI',0x00000400)
		win_const_mgr.add_const('SFSP_ACCESS_OWNER',0x00008000)
		win_const_mgr.add_const('API_READ_DATA',0x00000003)
		win_const_mgr.add_const('QOS_OUTGOING_DEFAULT_MINIMUM_BANDWIDTH',0xFFFFFFFF)
		win_const_mgr.add_const('SQL_AUTOCOMMIT_OFF',0x00000000)
		win_const_mgr.add_const('TBS_COMMAND_LOCALITY_THREE',0x00000003)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_HARDWARE_DRIVER',0x00000000)
		win_const_mgr.add_const('KS_NABTS_GROUPID_SYNDICATED_SHOW_ADVERTISER_BASE',0x00000850)
		win_const_mgr.add_const('WSAENOTCONN',0x00002749)
		win_const_mgr.add_const('OID_FDDI_PORT_ACTION',0x03030278)
		win_const_mgr.add_const('SET_TAPE_MEDIA_INFORMATION',0x00000000)
		win_const_mgr.add_const('FDTF_SHORTTIME',0x00000001)
		win_const_mgr.add_const('SQL_CA1_POS_POSITION',0x00000200)
		win_const_mgr.add_const('TAPE_INITIATOR_PARTITIONS',0x00000002)
		win_const_mgr.add_const('ETW_REDUCED_ANSISTRING_TYPE_VALUE',0x00000071)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_MAXIMUM_RATE',0x00000400)
		win_const_mgr.add_const('FS_HEBREW',0x00000020)
		win_const_mgr.add_const('ALG_CLASS_MSG_ENCRYPT',0x00000002)
		win_const_mgr.add_const('PSBTN_CANCEL',0x00000005)
		win_const_mgr.add_const('WIA_DPC_FLASH_MODE',0x00000808)
		win_const_mgr.add_const('CHANNEL_RC_ALREADY_INITIALIZED',0x00000001)
		win_const_mgr.add_const('CSS_SELECTCERT_MASK',0x00000000)
		win_const_mgr.add_const('SQL_DROP_TABLE',0x0000008D)
		win_const_mgr.add_const('PERF_NUMBER_DECIMAL',0x00010000)
		win_const_mgr.add_const('IF_TYPE_SOFTWARE_LOOPBACK',0x00000018)
		win_const_mgr.add_const('TMT_EDGEDKSHADOWCOLOR',0x00000EDF)
		win_const_mgr.add_const('EAP_E_SERVER_CERT_OTHER_ERROR',0x80420204)
		win_const_mgr.add_const('D3DCREATE_DISABLE_DRIVER_MANAGEMENT',0x00000100)
		win_const_mgr.add_const('DS_REPL_INFO_FLAG_IMPROVE_LINKED_ATTRS',0x00000001)
		win_const_mgr.add_const('DB_IMP_LEVEL_IDENTIFY',0x00000001)
		win_const_mgr.add_const('KSSTREAM_HEADER_OPTIONSF_TIMEVALID',0x00000010)
		win_const_mgr.add_const('DBPROP_MAINTAINPROPS',0x00000005)
		win_const_mgr.add_const('MAP_FOLDDIGITS',0x00000080)
		win_const_mgr.add_const('DDCAPS_ALPHA',0x00800000)
		win_const_mgr.add_const('SQL_SFKU_SET_DEFAULT',0x00000004)
		win_const_mgr.add_const('PRF_VERIFYEXISTS',0x00000001)
		win_const_mgr.add_const('TIMER_QUERY_STATE',0x00000001)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_SH5',0x00000001)
		win_const_mgr.add_const('RPC_X_PIPE_DISCIPLINE_ERROR',0x0000077D)
		win_const_mgr.add_const('AIF_FORCE_FILE_IN_USE',0x00000008)
		win_const_mgr.add_const('LINECALLFEATURE_DIAL',0x00000040)
		win_const_mgr.add_const('MCI_VCR_STATUS_TIMECODE_PRESENT',0x0000401E)
		win_const_mgr.add_const('PID_MISC_PICS',0x00000006)
		win_const_mgr.add_const('EVENTLOG_END_PAIRED_EVENT',0x00000002)
		win_const_mgr.add_const('MIB_IF_TYPE_OTHER',0x00000001)
		win_const_mgr.add_const('SUBSCRIPTION_CAP_UILESSMODE_ALLOWPLAY',0x00000100)
		win_const_mgr.add_const('DISPID_IHTMLWINDOW2_SHOWHELP',0x00000483)
		win_const_mgr.add_const('DBT_SHELLLOGGEDON',0x00000020)
		win_const_mgr.add_const('ERROR_CLUSTER_NETWORK_ALREADY_ONLINE',0x000013C7)
		win_const_mgr.add_const('TF_IPPMF_ENABLEPROFILE',0x00000001)
		win_const_mgr.add_const('MCI_DGV_STATUS_MONITOR_METHOD',0x00000400)
		win_const_mgr.add_const('DNS_RTYPE_TSIG',0x00000000)
		win_const_mgr.add_const('DI_DISABLED',0x00000800)
		win_const_mgr.add_const('IDENTITY_CACHE_ENTRY',0x80000000)
		win_const_mgr.add_const('MDM_AUTO_SPEED_DEFAULT',0x00000000)
		win_const_mgr.add_const('FMMENU_LAST',0x00000063)
		win_const_mgr.add_const('LBER_TRANSLATE_STRINGS',0x00000004)
		win_const_mgr.add_const('MCI_NOTIFY',0x00000001)
		win_const_mgr.add_const('SDP_ATTRIB_IMAGING_TOTAL_DATA_CAPACITY',0x00000313)
		win_const_mgr.add_const('ARABIC_CHARSET',0x000000B2)
		win_const_mgr.add_const('LCPRI_SUBOPTIMAL',0x00005000)
		win_const_mgr.add_const('SO_ERROR',0x00001007)
		win_const_mgr.add_const('JOB_STATUS_USER_INTERVENTION',0x00000400)
		win_const_mgr.add_const('ANTIALIASED_QUALITY',0x00000004)
		win_const_mgr.add_const('SNMPAPI_FAILURE',0x00000000)
		win_const_mgr.add_const('HTTOPLEFT',0x0000000D)
		win_const_mgr.add_const('GESTURE_ARROW_DOWN',0x00000000)
		win_const_mgr.add_const('SFVM_ADDPROPERTYPAGES',0x0000002F)
		win_const_mgr.add_const('ERROR_INVALID_COMMAND_LINE',0x00000667)
		win_const_mgr.add_const('OBM_OLD_RESTORE',0x00007FF3)
		win_const_mgr.add_const('SEARCH_PRI_NO_SEQ',0x00000005)
		win_const_mgr.add_const('F_NOTFOUND',0x00000009)
		win_const_mgr.add_const('STI_DIAGCODE_HWPRESENCE',0x00000001)
		win_const_mgr.add_const('SAFER_SCOPEID_MACHINE',0x00000001)
		win_const_mgr.add_const('SQL_API_SQLCLOSECURSOR',0x000003EB)
		win_const_mgr.add_const('BS_AUTO3STATE',0x00000006)
		win_const_mgr.add_const('FSB_REGULAR_MODE',0x00000000)
		win_const_mgr.add_const('IDM_INLINEDIRRTL',0x00000933)
		win_const_mgr.add_const('OID_FFP_SUPPORT',0xFC010210)
		win_const_mgr.add_const('CAUSE_NO_VPI_VCI_AVAILABLE',0x0000002D)
		win_const_mgr.add_const('SWP_NOACTIVATE',0x00000010)
		win_const_mgr.add_const('TRACELOG_CREATE_INPROC',0x00000200)
		win_const_mgr.add_const('GCPCLASS_LATIN',0x00000001)
		win_const_mgr.add_const('DSOP_DOWNLEVEL_FILTER_BATCH',0x80000080)
		win_const_mgr.add_const('CERT_SYSTEM_STORE_LOCATION_MASK',0x00FF0000)
		win_const_mgr.add_const('DBT_DEVTYP_NET',0x00000004)
		win_const_mgr.add_const('CACHE_NOTIFY_DELETE_URL',0x00000002)
		win_const_mgr.add_const('DFCS_SCROLLUP',0x00000000)
		win_const_mgr.add_const('AI_CANONNAME',0x00000002)
		win_const_mgr.add_const('PATCH_SYMBOL_NO_IMAGEHLP',0x00000001)
		win_const_mgr.add_const('CERT_UNICODE_IS_RDN_ATTRS_FLAG',0x00000001)
		win_const_mgr.add_const('MAX_NUM_REASONS',0x00000100)
		win_const_mgr.add_const('FAX_ERR_VERSION_MISMATCH',0x00001B64)
		win_const_mgr.add_const('SQL_CUR_USE_ODBC',0x00000001)
		win_const_mgr.add_const('SCRIPTPROP_NAME',0x00000000)
		win_const_mgr.add_const('FD_ACCEPT_BIT',0x00000003)
		win_const_mgr.add_const('IMAGE_SEPARATE_DEBUG_MISMATCH',0x00008000)
		win_const_mgr.add_const('DRM_ACTIVATE_SILENT',0x00000010)
		win_const_mgr.add_const('MSG_CTRUNC',0x00000200)
		win_const_mgr.add_const('GPO_LIST_FLAG_NO_SECURITYFILTERS',0x00000008)
		win_const_mgr.add_const('IMAGE_REL_M32R_PAIR',0x0000000B)
		win_const_mgr.add_const('URLACTION_HTML_MAX',0x00000017)
		win_const_mgr.add_const('ERROR_EXTENDED_ERROR',0x000004B8)
		win_const_mgr.add_const('EC_DISPLAY_CHANGED',0x00000016)
		win_const_mgr.add_const('AUTH_FLAG_ENABLE_NEGOTIATE',0x00000002)
		win_const_mgr.add_const('DDOVER_ADDDIRTYRECT',0x00008000)
		win_const_mgr.add_const('WMS_STREAM_PLAYLIST_GENERATION_ID',0x0000000A)
		win_const_mgr.add_const('MDPROPVAL_MOQ_CUBE_DIM',0x00000008)
		win_const_mgr.add_const('MCI_VCR_STATUS_MEDIA_TYPE',0x00004003)
		win_const_mgr.add_const('SM_CXFOCUSBORDER',0x00000053)
		win_const_mgr.add_const('PAN_WEIGHT_HEAVY',0x00000009)
		win_const_mgr.add_const('CHECKSUM_MAPVIEW_FAILURE',0x00000003)
		win_const_mgr.add_const('ERROR_ARITHMETIC_OVERFLOW',0x00000216)
		win_const_mgr.add_const('PERF_SIZE_LARGE',0x00000100)
		win_const_mgr.add_const('CR_PROP_CAFORWARDCROSSCERTSTATE',0x00000025)
		win_const_mgr.add_const('MSV1_0_DISABLE_PERSONAL_FALLBACK',0x00001000)
		win_const_mgr.add_const('DS_SETFONT',0x00000040)
		win_const_mgr.add_const('CR_DLVXD_NOT_FOUND',0x0000000C)
		win_const_mgr.add_const('DE_E_CANNOT_LOAD_DATA',0x800C000F)
		win_const_mgr.add_const('MM_ISOTROPIC',0x00000007)
		win_const_mgr.add_const('MEM_FREE',0x00010000)
		win_const_mgr.add_const('EVENT_TRACE_TYPE_END',0x00000002)
		win_const_mgr.add_const('SO_GROUP_ID',0x00002001)
		win_const_mgr.add_const('QIF_DONTEXPANDFOLDER',0x00000002)
		win_const_mgr.add_const('OUT_STRING_PRECIS',0x00000001)
		win_const_mgr.add_const('TC_SO_ABLE',0x00001000)
		win_const_mgr.add_const('GL_APPLICATION_STOP',0x00000800)
		win_const_mgr.add_const('FILE_READ_ONLY',0x00000008)
		win_const_mgr.add_const('DI_INF_IS_SORTED',0x00008000)
		win_const_mgr.add_const('SRCINFO_TAGFILE2',0x00000005)
		win_const_mgr.add_const('LUP_FLUSHPREVIOUS',0x00002000)
		win_const_mgr.add_const('DEVPROP_TYPE_DEVPROPKEY',0x00000015)
		win_const_mgr.add_const('MINIDUMP_VERSION',0x0000A793)
		win_const_mgr.add_const('SPI_GETMENUANIMATION',0x00001002)
		win_const_mgr.add_const('IS_TEXT_UNICODE_ILLEGAL_CHARS',0x00000100)
		win_const_mgr.add_const('DMPAPER_JAPANESE_POSTCARD_ROTATED',0x00000051)
		win_const_mgr.add_const('SPQ_SCAN_PRUNE_DELREN',0x00000080)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_TREBLE',0x00004000)
		win_const_mgr.add_const('FR_PROP_STATUSINFOCOUNT',0x00000002)
		win_const_mgr.add_const('DNS_TYPE_MAILB',0x00000000)
		win_const_mgr.add_const('AUDIOMEDIATYPE_EQUAL_FORMAT_USER_DATA',0x00000008)
		win_const_mgr.add_const('SQL_RESULT_COL',0x00000003)
		win_const_mgr.add_const('OID_GEN_LINK_STATE',0x00010207)
		win_const_mgr.add_const('BCRYPT_ASYMMETRIC_ENCRYPTION_INTERFACE',0x00000003)
		win_const_mgr.add_const('WMS_TOTAL_PACKETS_HI',0x00000009)
		win_const_mgr.add_const('CQPM_CLEARFORM',0x00000006)
		win_const_mgr.add_const('SPI_SETMOUSE',0x00000004)
		win_const_mgr.add_const('FF_DONTCARE',0x00000000)
		win_const_mgr.add_const('DISPID_IADCCTL_SORT',0x00000102)
		win_const_mgr.add_const('WSASERVICE_NOT_FOUND',0x0000277C)
		win_const_mgr.add_const('TF_TRANSITORYEXTENSION_ATSELECTION',0x00000002)
		win_const_mgr.add_const('LB_ITEMFROMPOINT',0x000001A9)
		win_const_mgr.add_const('AW_VER_NEGATIVE',0x00000008)
		win_const_mgr.add_const('DISPLAYDIB_NOIMAGE',0x00000080)
		win_const_mgr.add_const('ERROR_INVALID_PIXEL_FORMAT',0x000007D0)
		win_const_mgr.add_const('SQL_GB_NO_RELATION',0x00000003)
		win_const_mgr.add_const('CONNECT_LOCALDRIVE',0x00000100)
		win_const_mgr.add_const('CICAT_GET_STATE',0x00000010)
		win_const_mgr.add_const('EVENT_ENABLE_PROPERTY_SID',0x00000001)
		win_const_mgr.add_const('LGRPID_HEBREW',0x00000000)
		win_const_mgr.add_const('D3DTEXOPCAPS_BLENDDIFFUSEALPHA',0x00000800)
		win_const_mgr.add_const('PMSF_NORMAL',0x00000000)
		win_const_mgr.add_const('KF_MENUMODE',0x00001000)
		win_const_mgr.add_const('JOB_OBJECT_LIMIT_ACTIVE_PROCESS',0x00000008)
		win_const_mgr.add_const('DS_KDC_FLAG',0x00000020)
		win_const_mgr.add_const('DI_FLAGSEX_DIDCOMPATINFO',0x00000020)
		win_const_mgr.add_const('OID_GEN_TRANSMIT_BLOCK_SIZE',0x0001010A)
		win_const_mgr.add_const('SQL_DESCRIBE_PARAMETER',0x00002712)
		win_const_mgr.add_const('REG_DWORD_LITTLE_ENDIAN',0x00000004)
		win_const_mgr.add_const('X3_OPCODE_SIZE_X',0x00000004)
		win_const_mgr.add_const('CM_GETIDLIST_FILTER_BITS',0x1000007F)
		win_const_mgr.add_const('MD_GLOBAL_CHANGE_NUMBER',0x0000270D)
		win_const_mgr.add_const('TMT_IMAGEFILE3',0x00000BBC)
		win_const_mgr.add_const('TMT_IMAGEFILE2',0x00000BBB)
		win_const_mgr.add_const('RPC_C_BINDING_INFINITE_TIMEOUT',0x0000000A)
		win_const_mgr.add_const('TMT_IMAGEFILE5',0x00000BBE)
		win_const_mgr.add_const('TMT_IMAGEFILE4',0x00000BBD)
		win_const_mgr.add_const('MQMSG_NOT_FIRST_IN_XACT',0x00000000)
		win_const_mgr.add_const('CONFIGFLAG_REINSTALL',0x00000020)
		win_const_mgr.add_const('ADM_CTRL_FAILED',0x00000003)
		win_const_mgr.add_const('IASSEMBLYCACHE_UNINSTALL_DISPOSITION_HAS_INSTALL_REFERENCES',0x00000005)
		win_const_mgr.add_const('AE_NETLOGDENIED',0x00000010)
		win_const_mgr.add_const('CM_CDFLAGS_RESERVED',0x00000004)
		win_const_mgr.add_const('WIA_IPA_PREFERRED_FORMAT',0x00001009)
		win_const_mgr.add_const('MCI_RESUME',0x00000855)
		win_const_mgr.add_const('AVIIF_KEYFRAME',0x00000010)
		win_const_mgr.add_const('DSF_FS_DEVICES',0x00000020)
		win_const_mgr.add_const('DDOVERZ_MOVEFORWARD',0x00000002)
		win_const_mgr.add_const('KS_VBI_FLAG_MV_PRESENT',0x00000100)
		win_const_mgr.add_const('CR_PROP_CASIGCERTCRLCHAIN',0x00000020)
		win_const_mgr.add_const('DDCAPS2_CANSHARERESOURCE',0x80000000)
		win_const_mgr.add_const('SIGNERSCORE_LOGO_PREMIUM',0x0D000001)
		win_const_mgr.add_const('WBF_WORDWRAP',0x00000010)
		win_const_mgr.add_const('RBBIM_CHILDSIZE',0x00000020)
		win_const_mgr.add_const('CREDUI_FLAGS_COMPLETE_USERNAME',0x00000800)
		win_const_mgr.add_const('VP_TV_STANDARD_NTSC_433',0x00010000)
		win_const_mgr.add_const('DISPID_SCROLLBARAPPEARANCE',0x0000000F)
		win_const_mgr.add_const('SYMSTOREOPT_COMPRESS',0x00000001)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_BROADCAST',0x00000008)
		win_const_mgr.add_const('D3D10_SHADER_DEBUG',0x00000001)
		win_const_mgr.add_const('LINETSPIOPTION_NONREENTRANT',0x00000001)
		win_const_mgr.add_const('USER_PAD_PW_COUNT_PARMNUM',0x00000015)
		win_const_mgr.add_const('DN_FILTERED',0x00000800)
		win_const_mgr.add_const('DB_DISP_QUEUE_MAX',0x00000009)
		win_const_mgr.add_const('SERVICE_ACCEPT_SHUTDOWN',0x00000004)
		win_const_mgr.add_const('POWER_ACTION_UI_ALLOWED',0x00000002)
		win_const_mgr.add_const('WIA_INTENT_IMAGE_TYPE_GRAYSCALE',0x00000002)
		win_const_mgr.add_const('FLG_ADDREG_TYPE_NONE',0x00020000)
		win_const_mgr.add_const('MDPROPVAL_MNF_VAR',0x00000002)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_PAGES_PRINTED',0x00000017)
		win_const_mgr.add_const('DT_INTERNAL',0x00001000)
		win_const_mgr.add_const('MDPROPVAL_MNF_DRILLDOWNLEVELTOP',0x00004000)
		win_const_mgr.add_const('ERROR_DISK_RESET_FAILED',0x00000468)
		win_const_mgr.add_const('PRIVACY_URLHASPOLICYREFHEADER',0x00200000)
		win_const_mgr.add_const('CR_PROP_EXITCOUNT',0x00000003)
		win_const_mgr.add_const('HHWIN_PARAM_EXSTYLES',0x00000001)
		win_const_mgr.add_const('ERROR_BAD_REM_ADAP',0x0000003C)
		win_const_mgr.add_const('ALLOWED_ABORT',0x00000002)
		win_const_mgr.add_const('IDM_SAVE',0x00000046)
		win_const_mgr.add_const('SQL_SG_SELECT_TABLE',0x00000400)
		win_const_mgr.add_const('MD_GLOBAL_EDIT_WHILE_RUNNING_MINOR_VERSION_NUMBER',0x00002709)
		win_const_mgr.add_const('DBPROPVAL_SQL_ANSI92_ENTRY',0x00000010)
		win_const_mgr.add_const('TLS1_ALERT_CERTIFICATE_REVOKED',0x0000002C)
		win_const_mgr.add_const('MPR_ENABLE_ROUTING_ON_DEVICE',0x00000002)
		win_const_mgr.add_const('DT_RASPRINTER',0x00000002)
		win_const_mgr.add_const('ERROR_CLUSTER_PARAMETER_MISMATCH',0x00001709)
		win_const_mgr.add_const('AM_AC3_SERVICE_VISUALLY_IMPAIRED',0x00000002)
		win_const_mgr.add_const('FILE_DEVICE_BEEP',0x00000001)
		win_const_mgr.add_const('APPLY_OPTION_TEST_ONLY',0x00000004)
		win_const_mgr.add_const('DXVA_PICTURE_RESAMPLE_BUFFER',0x0000000E)
		win_const_mgr.add_const('CERT_FIND_OR_ENHKEY_USAGE_FLAG',0x00000010)
		win_const_mgr.add_const('MARSHAL_S_FIRST',0x00040120)
		win_const_mgr.add_const('BL_32M',0x02000000)
		win_const_mgr.add_const('MCI_DGV_GETDEVCAPS_CAN_STR_IN',0x00004008)
		win_const_mgr.add_const('WIA_DEVINFO_ENUM_LOCAL',0x00000010)
		win_const_mgr.add_const('TVGN_NEXTSELECTED',0x0000000B)
		win_const_mgr.add_const('MCI_FREEZE',0x00000844)
		win_const_mgr.add_const('DNS_RTYPE_KX',0x00002400)
		win_const_mgr.add_const('DBPROPVAL_SQL_ODBC_EXTENDED',0x00000004)
		win_const_mgr.add_const('DMCOLLATE_TRUE',0x00000001)
		win_const_mgr.add_const('CONNECT_REFCOUNT',0x00000040)
		win_const_mgr.add_const('STGM_DIRECT',0x00000000)
		win_const_mgr.add_const('PSP_USEHEADERTITLE',0x00001000)
		win_const_mgr.add_const('PSPROTOCOL_BCP',0x00000001)
		win_const_mgr.add_const('ERROR_INVALID_LIST_FORMAT',0x00000099)
		win_const_mgr.add_const('_STRALIGN_USE_SECURE_CRT',0x00000000)
		win_const_mgr.add_const('WAVEOUT_MAPPER_STATUS_MAPPED',0x00000001)
		win_const_mgr.add_const('SCALINGFACTORX',0x00000072)
		win_const_mgr.add_const('SCALINGFACTORY',0x00000073)
		win_const_mgr.add_const('MCI_WAVE_STATUS_LEVEL',0x00004007)
		win_const_mgr.add_const('PD_RETURNIC',0x00000200)
		win_const_mgr.add_const('OID_GEN_MAXIMUM_TOTAL_SIZE',0x00010111)
		win_const_mgr.add_const('NCRYPT_DO_NOT_FINALIZE_FLAG',0x00000400)
		win_const_mgr.add_const('KSSTREAM_NONPAGED_DATA',0x00000100)
		win_const_mgr.add_const('IME_SMODE_NONE',0x00000000)
		win_const_mgr.add_const('ERROR_CANNOT_FIND_WND_CLASS',0x0000057F)
		win_const_mgr.add_const('DNS_RTYPE_ISDN',0x00001400)
		win_const_mgr.add_const('CRED_FLAGS_REQUIRE_CONFIRMATION',0x00000010)
		win_const_mgr.add_const('SHDID_NET_SHARE',0x0000000F)
		win_const_mgr.add_const('DBPROP_INIT_PROTOCOLPROVIDER',0x00000006)
		win_const_mgr.add_const('AUTO_PROXY_FLAG_CACHE_INIT_RUN',0x00000020)
		win_const_mgr.add_const('EAP_E_USER_ROOT_CERT_INVALID',0x80420301)
		win_const_mgr.add_const('PHONEBUTTONFUNCTION_NONE',0x0000002E)
		win_const_mgr.add_const('SYMSTOREOPT_ALT_INDEX',0x00000010)
		win_const_mgr.add_const('IDM_TRIED_INDENT',0x0000002A)
		win_const_mgr.add_const('STAT_REFRESH_INCOMPLETE',0x00000040)
		win_const_mgr.add_const('UIA_E_NOCLICKABLEPOINT',0x80040202)
		win_const_mgr.add_const('SES_SCROLLONKILLFOCUS',0x00002000)
		win_const_mgr.add_const('DEBUG_ECREATE_PROCESS_USE_VERIFIER_FLAGS',0x00000002)
		win_const_mgr.add_const('JOB_STATUS_DELETED',0x00000100)
		win_const_mgr.add_const('DEBUG_GET_PROC_DEFAULT',0x00000000)
		win_const_mgr.add_const('MCI_DGV_SETAUDIO_BITSPERSAMPLE',0x00004008)
		win_const_mgr.add_const('SS_PATHELLIPSIS',0x00008000)
		win_const_mgr.add_const('MD_DIMTYPE_MEASURE',0x00000002)
		win_const_mgr.add_const('SECURITY_CREATOR_OWNER_SERVER_RID',0x00000002)
		win_const_mgr.add_const('DOT11_FLAGS_80211B_PBCC',0x00000002)
		win_const_mgr.add_const('DEBUG_CSS_SCOPE',0x00000004)
		win_const_mgr.add_const('DISPID_HTMLDLGMODEL',0x00006590)
		win_const_mgr.add_const('DRVCNF_RESTART',0x00000002)
		win_const_mgr.add_const('IF_TYPE_USB',0x000000A0)
		win_const_mgr.add_const('IEIFLAG_REFRESH',0x00000400)
		win_const_mgr.add_const('SEF_DEFAULT_DESCRIPTOR_FOR_OBJECT',0x00000004)
		win_const_mgr.add_const('KS_DVD_CGMS_COPY_PROTECT_MASK',0x00000018)
		win_const_mgr.add_const('PST_RS232',0x00000001)
		win_const_mgr.add_const('SECURITY_PROTOCOL_NONE',0x00000000)
		win_const_mgr.add_const('PGB_BOTTOMORRIGHT',0x00000001)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_INVALID_GROUP',0x00003629)
		win_const_mgr.add_const('EVENT_HEADER_FLAG_NO_CPUTIME',0x00000010)
		win_const_mgr.add_const('BCRYPT_ECDH_PUBLIC_P384_MAGIC',0x334B4345)
		win_const_mgr.add_const('CC_CHORD',0x00000004)
		win_const_mgr.add_const('ERROR_CLASS_ALREADY_EXISTS',0x00000582)
		win_const_mgr.add_const('LINEADDRFEATURE_PICKUP',0x00000004)
		win_const_mgr.add_const('MDM_DIAGNOSTICS',0x00000800)
		win_const_mgr.add_const('RTM_NEXTHOP_FLAGS_DOWN',0x00000002)
		win_const_mgr.add_const('ELEMENT_STATUS_ID_VALID',0x00002000)
		win_const_mgr.add_const('AMVA_QUERYRENDERSTATUSF_READ',0x00000001)
		win_const_mgr.add_const('DDCAPS_BLTDEPTHFILL',0x10000000)
		win_const_mgr.add_const('DTT_TEXTCOLOR',0x00000001)
		win_const_mgr.add_const('DDGBS_CANBLT',0x00000001)
		win_const_mgr.add_const('TF_CONVERSIONMODE_SYMBOL',0x00000400)
		win_const_mgr.add_const('IDD_ACMFORMATCHOOSE_CMB_CUSTOM',0x00000064)
		win_const_mgr.add_const('IDM_ARRANGERIGHT',0x00000009)
		win_const_mgr.add_const('E_DELTA_PRINTTICKET_FORMAT',0x80040005)
		win_const_mgr.add_const('PROCESSOR_INTEL_486',0x000001E6)
		win_const_mgr.add_const('IMGBITS_PARTIAL',0x04000000)
		win_const_mgr.add_const('RPC_S_UUID_LOCAL_ONLY',0x00000720)
		win_const_mgr.add_const('ABM_ACTIVATE',0x00000006)
		win_const_mgr.add_const('SQL_SG_USAGE_ON_COLLATION',0x00000004)
		win_const_mgr.add_const('WIA_FINAL_SCAN',0x00000000)
		win_const_mgr.add_const('BS_VCENTER',0x00000C00)
		win_const_mgr.add_const('WH_CALLWNDPROCRET',0x0000000C)
		win_const_mgr.add_const('PRESENTED_TYPE_IS_ARRAY',0x00000010)
		win_const_mgr.add_const('PORT_QRH',0x000002F0)
		win_const_mgr.add_const('FLG_ADDREG_KEYONLY_COMMON',0x00002000)
		win_const_mgr.add_const('MIN_RPT',0x00000000)
		win_const_mgr.add_const('IMAGE_REL_ARM_GPREL7',0x00000007)
		win_const_mgr.add_const('NDIS_OFFLOAD_PARAMETERS_REVISION_1',0x00000001)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_CLR_TOKEN',0x0000006B)
		win_const_mgr.add_const('SECPKG_ATTR_TARGET_INFORMATION',0x00000011)
		win_const_mgr.add_const('NET_STRING_IPV6_ADDRESS',0x00000008)
		win_const_mgr.add_const('FILE_SET_ENCRYPTION',0x00000001)
		win_const_mgr.add_const('CM_ADD_RANGE_ADDIFCONFLICT',0x00000000)
		win_const_mgr.add_const('DDCKEYCAPS_SRCOVERLAYONEACTIVE',0x00010000)
		win_const_mgr.add_const('PSINJECT_PAGEBBOX',0x0000006A)
		win_const_mgr.add_const('ERROR_INVALID_DATA',0x0000000D)
		win_const_mgr.add_const('SDP_ATTRIB_DI_PRIMARY_RECORD',0x00000204)
		win_const_mgr.add_const('ERROR_INVALID_TRANSACTION',0x00001A2C)
		win_const_mgr.add_const('HTTP_QUERY_PRAGMA',0x00000011)
		win_const_mgr.add_const('DEBUG_PROC_DESC_NO_SESSION_ID',0x00000010)
		win_const_mgr.add_const('TC_NOTIFY_IFC_CLOSE',0x00000002)
		win_const_mgr.add_const('ERROR_DS_INIT_FAILURE_CONSOLE',0x00002171)
		win_const_mgr.add_const('APPCOMMAND_REDO',0x00000023)
		win_const_mgr.add_const('ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED',0x00000790)
		win_const_mgr.add_const('RPC_C_IMP_LEVEL_DEFAULT',0x00000000)
		win_const_mgr.add_const('ADS_SERVICE_START_PENDING',0x00000002)
		win_const_mgr.add_const('SEVERITY_ERROR',0x00000001)
		win_const_mgr.add_const('MF_ENABLED',0x00000000)
		win_const_mgr.add_const('MAXFILELEN',0x0000000D)
		win_const_mgr.add_const('SUBLANG_DUTCH',0x00000001)
		win_const_mgr.add_const('PAN_SERIF_BONE',0x00000008)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_THUMB',0x00000001)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY11',0x04000000)
		win_const_mgr.add_const('SQL_ATTR_READONLY',0x00000000)
		win_const_mgr.add_const('REDBOOK_DIGITAL_AUDIO_EXTRACTION_INFO_VERSION',0x00000001)
		win_const_mgr.add_const('PPP_LCP_MULTILINK_FRAMING',0x00000001)
		win_const_mgr.add_const('DISPID_IADCCTL_ONDOMAIN',0x00000105)
		win_const_mgr.add_const('LOCALE_INEGNUMBER',0x00001010)
		win_const_mgr.add_const('SQL_SSF_TRIM_BOTH',0x00000020)
		win_const_mgr.add_const('MCI_OPEN_SHAREABLE',0x00000100)
		win_const_mgr.add_const('COD_SERVICE_POSITIONING',0x00000008)
		win_const_mgr.add_const('ERROR_SERVICE_DATABASE_LOCKED',0x0000041F)
		win_const_mgr.add_const('SERVICE_ACCEPT_POWEREVENT',0x00000040)
		win_const_mgr.add_const('SPEAKER_FRONT_RIGHT_OF_CENTER',0x00000080)
		win_const_mgr.add_const('CM_DRP_REMOVAL_POLICY',0x00000020)
		win_const_mgr.add_const('ACS_AUTOPLAY',0x00000004)
		win_const_mgr.add_const('WGL_SWAP_UNDERLAY10',0x02000000)
		win_const_mgr.add_const('SHTDN_REASON_MINOR_SECURITY',0x00000013)
		win_const_mgr.add_const('WINHTTP_ENABLE_SSL_REVOCATION',0x00000001)
		win_const_mgr.add_const('DVB_NIT_PID',0x00000010)
		win_const_mgr.add_const('WMDM_STORAGE_ATTR_VIRTUAL',0x20000000)
		win_const_mgr.add_const('ERROR_NOT_READY',0x00000015)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_WRONGVALUE',0x0000000A)
		win_const_mgr.add_const('DMBIN_SMALLFMT',0x00000009)
		win_const_mgr.add_const('SDP_ATTRIB_IMAGING_SUPPORTED_FUNCTIONS',0x00000312)
		win_const_mgr.add_const('CFU_UNDERLINEHEAVYWAVE',0x0000000C)
		win_const_mgr.add_const('VT_STREAMED_PROPSET',0x00000049)
		win_const_mgr.add_const('SCARD_W_RESET_CARD',0x80100068)
		win_const_mgr.add_const('ERROR_INSTALL_PACKAGE_VERSION',0x0000064D)
		win_const_mgr.add_const('EMR_REALIZEPALETTE',0x00000034)
		win_const_mgr.add_const('DNS_QUERY_NO_MULTICAST',0x00000800)
		win_const_mgr.add_const('SM_NETWORK',0x0000003F)
		win_const_mgr.add_const('SMC_GETSFOBJECT',0x00000008)
		win_const_mgr.add_const('DOF_EXECUTABLE',0x00008001)
		win_const_mgr.add_const('LINECALLFEATURE_SETMEDIACONTROL',0x00400000)
		win_const_mgr.add_const('SV_SHARINGVIOLATIONRETRIES_PARMNUM',0x00000233)
		win_const_mgr.add_const('DEBUG_FORMAT_CAB_SECONDARY_FILES',0x40000000)
		win_const_mgr.add_const('PERF_ATTRIB_DISPLAY_AS_REAL',0x00000008)
		win_const_mgr.add_const('LOCALE_IDEFAULTCOUNTRY',0x0000000A)
		win_const_mgr.add_const('SND_RESOURCE',0x00040004)
		win_const_mgr.add_const('OBM_ZOOM',0x00007FEC)
		win_const_mgr.add_const('ERROR_TOO_MANY_TCBS',0x0000009B)
		win_const_mgr.add_const('LANG_POLISH',0x00000015)
		win_const_mgr.add_const('PS_ENDCAP_MASK',0x00000F00)
		win_const_mgr.add_const('CERT_OFFLINE_CRL_SIGN_KEY_USAGE',0x00000002)
		win_const_mgr.add_const('CREDP_FLAGS_USER_ENCRYPTED_PASSWORD',0x00000010)
		win_const_mgr.add_const('DIRID_COMMON_STARTUP',0x00004018)
		win_const_mgr.add_const('PORT_NSSROUTING',0x0000009F)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_304',0x80190130)
		win_const_mgr.add_const('SERVICE_FLUSH',0x00000003)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_302',0x8019012E)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_303',0x8019012F)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_300',0x8019012C)
		win_const_mgr.add_const('BG_E_HTTP_ERROR_301',0x8019012D)
		win_const_mgr.add_const('SUBLANG_RUSSIAN_RUSSIA',0x00000001)
		win_const_mgr.add_const('PP_CONTEXT_INFO',0x0000000B)
		win_const_mgr.add_const('SQL_SQL92_RELATIONAL_JOIN_OPERATORS',0x000000A1)
		win_const_mgr.add_const('ODT_COMBOBOX',0x00000003)
		win_const_mgr.add_const('RC_GDI20_STATE',0x00000020)
		win_const_mgr.add_const('MCI_SET_ON',0x00002000)
		win_const_mgr.add_const('SCARD_CLASS_MECHANICAL',0x00000006)
		win_const_mgr.add_const('LINEDISCONNECTMODE_UNKNOWN',0x00000002)
		win_const_mgr.add_const('SQL_INTERVAL_MINUTE_TO_SECOND',0x00000064)
		win_const_mgr.add_const('DISPID_EVENTHOOK_SENSITIVE_MAX',0x0044AA1F)
		win_const_mgr.add_const('SQL_DIAG_DROP_ASSERTION',0x00000018)
		win_const_mgr.add_const('CM_DISABLE_UI_NOT_OK',0x00000004)
		win_const_mgr.add_const('DISPID_IWRITEENGINE2EVENTARGS_LASTWRITTENLBA',0x00000103)
		win_const_mgr.add_const('D3DCREATE_ENABLE_PRESENTSTATS',0x00004000)
		win_const_mgr.add_const('WIA_COMPRESSION_PNG',0x00000008)
		win_const_mgr.add_const('ERROR_IS_JOINED',0x00000086)
		win_const_mgr.add_const('CPL_STARTWPARMSW',0x0000000A)
		win_const_mgr.add_const('EMR_COLORMATCHTOTARGETW',0x00000079)
		win_const_mgr.add_const('CRYPTUI_HIDE_HIERARCHYPAGE',0x00000001)
		win_const_mgr.add_const('MSV1_0_SUBAUTH_PASSWORD',0x00000002)
		win_const_mgr.add_const('IMAGE_REL_M32R_ADDR24',0x00000003)
		win_const_mgr.add_const('MMIO_CREATE',0x00001000)
		win_const_mgr.add_const('USER_MARSHAL_FC_WCHAR',0x00000005)
		win_const_mgr.add_const('EC_USER',0x00008000)
		win_const_mgr.add_const('CERT_ROOT_PROGRAM_CERT_POLICIES_PROP_ID',0x00000053)
		win_const_mgr.add_const('SPI_SETACTIVEWINDOWTRACKING',0x00001001)
		win_const_mgr.add_const('DNS_ERROR_DP_FSMO_ERROR',0x000026B2)
		win_const_mgr.add_const('INTERNET_SUPPRESS_RESET_ALL',0x00000000)
		win_const_mgr.add_const('DDEM_MODEFAILED',0x00000002)
		win_const_mgr.add_const('SQL_FETCH_BY_BOOKMARK',0x00000007)
		win_const_mgr.add_const('GMEM_NODISCARD',0x00000020)
		win_const_mgr.add_const('CERT_COMPARE_ANY',0x00000000)
		win_const_mgr.add_const('HTTP_QUERY_LAST_MODIFIED',0x0000000B)
		win_const_mgr.add_const('TMT_LIGHT3D',0x00000657)
		win_const_mgr.add_const('CERT_STORE_PROV_DELETE_CERT_FUNC',0x00000003)
		win_const_mgr.add_const('ERROR_DS_OBJ_CLASS_VIOLATION',0x00002014)
		win_const_mgr.add_const('CRM_PROTOCOL_DYNAMIC_MARSHAL_INFO',0x00000002)
		win_const_mgr.add_const('CBN_SELENDOK',0x00000009)
		win_const_mgr.add_const('EMR_SETMETARGN',0x0000001C)
		win_const_mgr.add_const('DT_METAFILE',0x00000005)
		win_const_mgr.add_const('WIA_ADVANCED_PREVIEW',0x00000000)
		win_const_mgr.add_const('MAX_DEVICE_ID_LEN',0x000000C8)
		win_const_mgr.add_const('BOE_CONTEXTALIGNMENT',0x00000010)
		win_const_mgr.add_const('DEX_IDS_NO_3D',0x00000585)
		win_const_mgr.add_const('VIDCF_TEMPORAL',0x00000004)
		win_const_mgr.add_const('PTRDIFF_T_MAX',0x7FFFFFFF)
		win_const_mgr.add_const('CMSG_CTRL_KEY_TRANS_DECRYPT',0x00000010)
		win_const_mgr.add_const('BTH_MFG_AVM_BERLIN',0x0000001F)
		win_const_mgr.add_const('SSPROP_INIT_USEPROCFORPREP',0x00000007)
		win_const_mgr.add_const('WMDRM_IMPORT_CONTENT_KEY_DEFINED',0x00000001)
		win_const_mgr.add_const('IP_INVERTED',0x00000002)
		win_const_mgr.add_const('CRYPT_REGISTER_LAST_INDEX',0xFFFFFFFF)
		win_const_mgr.add_const('SNMP_ERRORSTATUS_GENERR',0x00000005)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME7',0x0000004A)
		win_const_mgr.add_const('LVGGR_HEADER',0x00000001)
		win_const_mgr.add_const('AM_AC3_SERVICE_EMERGENCY_FLASH',0x00000006)
		win_const_mgr.add_const('REGDF_CONFLICTIO',0x00010000)
		win_const_mgr.add_const('CRESTRICTIONS_DBSCHEMA_TABLES_INFO',0x00000004)
		win_const_mgr.add_const('OBM_BTSIZE',0x00007FF9)
		win_const_mgr.add_const('KF_FLAG_SIMPLE_IDLIST',0x00000100)
		win_const_mgr.add_const('EMR_CREATEMONOBRUSH',0x0000005D)
		win_const_mgr.add_const('ACM_STREAMSIZEF_QUERYMASK',0x0000000F)
		win_const_mgr.add_const('DNS_MAX_IP6_REVERSE_NAME_LENGTH',0x0000004B)
		win_const_mgr.add_const('HH_SET_INCLUSIVE_FILTER',0x00000018)
		win_const_mgr.add_const('TXTLOG_SETUPAPI_CMDLINE',0x00000002)
		win_const_mgr.add_const('OBJECT_PUSH_FORMAT_VNOTE',0x00000005)
		win_const_mgr.add_const('ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE',0x000036C1)
		win_const_mgr.add_const('LDAP_OPT_API_INFO',0x00000000)
		win_const_mgr.add_const('URLPOLICY_AUTHENTICATE_CLEARTEXT_OK',0x00000000)
		win_const_mgr.add_const('SMC_CHEVRONEXPAND',0x00000019)
		win_const_mgr.add_const('SQL_API_SQLEXTENDEDFETCH',0x0000003B)
		win_const_mgr.add_const('SS_SUNKEN',0x00001000)
		win_const_mgr.add_const('DDSCAPS3_RESERVED1',0x00000100)
		win_const_mgr.add_const('DDSCAPS3_RESERVED2',0x00000200)
		win_const_mgr.add_const('ETW_SIZET_TYPE_VALUE',0x0000006A)
		win_const_mgr.add_const('CDERR_REGISTERMSGFAIL',0x0000000C)
		win_const_mgr.add_const('SUF_NETSETUP',0x00000020)
		win_const_mgr.add_const('SUBLANG_AMHARIC_ETHIOPIA',0x00000001)
		win_const_mgr.add_const('SECPKG_FLAG_LOGON',0x00002000)
		win_const_mgr.add_const('ISIOI_ICONFILE',0x00000001)
		win_const_mgr.add_const('FACILITY_MF',0x0000000D)
		win_const_mgr.add_const('OID_FDDI_IF_IN_OCTETS',0x03030281)
		win_const_mgr.add_const('EXP_PROPERTYSTORAGE_SIG',0xA0000009)
		win_const_mgr.add_const('LINETRANSLATERESULT_LONGDISTANCE',0x00000004)
		win_const_mgr.add_const('DS_REPADD_INTERSITE_MESSAGING',0x00000010)
		win_const_mgr.add_const('IN_CLASSB_HOST',0x00000000)
		win_const_mgr.add_const('DBT_MONITORCHANGE',0x0000001B)
		win_const_mgr.add_const('MCI_VCR_FREEZE_FRAME',0x00080000)
		win_const_mgr.add_const('MD_CPU_KILL_W3WP',0x00000001)
		win_const_mgr.add_const('LOCALE_SABBREVMONTHNAME8',0x0000004B)
		win_const_mgr.add_const('LOGFLAGS_BACKWARD',0x00000001)
		win_const_mgr.add_const('MSG_SERVICE_CREATE',0x00000002)
		win_const_mgr.add_const('FACILITY_HYPERVISOR',0x00000035)
		win_const_mgr.add_const('NIS_SHAREDICON',0x00000002)
		win_const_mgr.add_const('LVNI_ABOVE',0x00000100)
		win_const_mgr.add_const('TLS1_ALERT_DECRYPTION_FAILED',0x00000015)
		win_const_mgr.add_const('WIA_DPC_BURST_NUMBER',0x0000081C)
		win_const_mgr.add_const('ILLUMINANT_DEVICE_DEFAULT',0x00000000)
		win_const_mgr.add_const('LINEAGENTSTATE_BUSYACD',0x00000008)
		win_const_mgr.add_const('MCI_DGV_STATUS_VIDEO_SOURCE',0x00000401)
		win_const_mgr.add_const('MD_LOGFILE_PERIOD_NONE',0x00000000)
		win_const_mgr.add_const('VIFF_DONTDELETEOLD',0x00000002)
		win_const_mgr.add_const('ERROR_WORKING_SET_QUOTA',0x000005AD)
		win_const_mgr.add_const('MD_ERROR_SUB403_INSUFFICIENT_PRIVILEGE_FOR_CGI',0x00000013)
		win_const_mgr.add_const('PSCB_INITIALIZED',0x00000001)
		win_const_mgr.add_const('LINEDEVCAPFLAGS_DIALDIALTONE',0x00000100)
		win_const_mgr.add_const('LINETERMMODE_DISPLAY',0x00000004)
		win_const_mgr.add_const('PORT_RSH',0x00000202)
		win_const_mgr.add_const('STRM_STOPPED',0x00000010)
		win_const_mgr.add_const('SVTI2_SCOPED_NAME',0x00000004)
		win_const_mgr.add_const('D3D10_SRGB_TO_FLOAT_TOLERANCE_IN_ULP',0x00000000)
		win_const_mgr.add_const('WIA_DPC_FOCUS_METERING_MODE',0x00000825)
		win_const_mgr.add_const('PSH_WIZARDCONTEXTHELP',0x00001000)
		win_const_mgr.add_const('SET_CLIP_BOX',0x0000100C)
		win_const_mgr.add_const('DBPROPFLAGS_ADSISEARCH',0x0000C000)
		win_const_mgr.add_const('DBPROPVAL_UP_INSERT',0x00000004)
		win_const_mgr.add_const('SV_DISABLESTRICTNAMECHECKING_PARMNUM',0x0000025A)
		win_const_mgr.add_const('VS_FF_SPECIALBUILD',0x00000020)
		win_const_mgr.add_const('ERROR_INVALID_COLORINDEX',0x000007E6)
		win_const_mgr.add_const('TVGN_CARET',0x00000009)
		win_const_mgr.add_const('SUBLANG_SPANISH_PANAMA',0x00000006)
		win_const_mgr.add_const('ARCONTENT_MASK',0x00007FFE)
		win_const_mgr.add_const('SFVM_DIDDRAGDROP',0x00000024)
		win_const_mgr.add_const('CFM_ANIMATION',0x00040000)
		win_const_mgr.add_const('SP_BACKUP_BOOTFILE',0x00000008)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_FAILQUERYSSP',0x0000361E)
		win_const_mgr.add_const('ALG_SID_RSA_ANY',0x00000000)
		win_const_mgr.add_const('VDMEVENT_VERBOSE',0x00004000)
		win_const_mgr.add_const('DBPROP_FREETEXTANYTERM',0x0000000C)
		win_const_mgr.add_const('PPCF_ADDQUOTES',0x00000001)
		win_const_mgr.add_const('GESTURE_CIRCLE_CIRCLE',0x00000000)
		win_const_mgr.add_const('URLACTION_SCRIPT_JAVA_USE',0x00001402)
		win_const_mgr.add_const('OID_802_3_XMIT_LATE_COLLISIONS',0x01020207)
		win_const_mgr.add_const('WSS_OPERATION_IN_PROGRESS',0x00000103)
		win_const_mgr.add_const('JOB_NOTIFY_FIELD_DEVMODE',0x00000009)
		win_const_mgr.add_const('IMAGE_SYM_CLASS_UNDEFINED_LABEL',0x00000007)
		win_const_mgr.add_const('STAT_RELDOC_ACCESS_DENIED',0x00001000)
		win_const_mgr.add_const('ERROR_BAD_DRIVER',0x000007D1)
		win_const_mgr.add_const('LINECALLPRIVILEGE_MONITOR',0x00000002)
		win_const_mgr.add_const('DS_INSTANCETYPE_IS_NC_HEAD',0x00000001)
		win_const_mgr.add_const('TF_CONVERSIONMODE_CHARCODE',0x00000020)
		win_const_mgr.add_const('DEBUG_VALUE_VECTOR128',0x0000000B)
		win_const_mgr.add_const('LANG_UZBEK',0x00000043)
		win_const_mgr.add_const('DE_E_SECURITY_PROBLEM',0x800C000E)
		win_const_mgr.add_const('SCARD_STATE_CHANGED',0x00000002)
		win_const_mgr.add_const('WPF_USE_PROVIDER_PASSED',0x00000040)
		win_const_mgr.add_const('SESI1_NUM_ELEMENTS',0x00000008)
		win_const_mgr.add_const('OID_FDDI_MAC_DOWNSTREAM_PORT_TYPE',0x0303022B)
		win_const_mgr.add_const('CONSOLE_NO_SELECTION',0x00000000)
		win_const_mgr.add_const('CP_WINANSI',0x000003EC)
		win_const_mgr.add_const('INTERNET_IDENTITY_FLAG_CLEAR_HISTORY',0x00000010)
		win_const_mgr.add_const('LOCAL_D3DFMT_DEFINES',0x00000001)
		win_const_mgr.add_const('SC_MOVE',0x0000F010)
		win_const_mgr.add_const('PROTO_IP_MGM',0x00002719)
		win_const_mgr.add_const('NETLOGON_CONTROL_FORCE_DNS_REG',0x0000000B)
		win_const_mgr.add_const('SQL_SQL92_PREDICATES',0x000000A0)
		win_const_mgr.add_const('IPX_TRAFFIC_FILTER_ON_SRCNET',0x00000001)
		win_const_mgr.add_const('OID_ATM_CELLS_HEC_ERROR',0x08020202)
		win_const_mgr.add_const('PP_ADMIN_PIN',0x0000001F)
		win_const_mgr.add_const('DS_REPADD_DISABLE_PERIODIC',0x00000080)
		win_const_mgr.add_const('WORD_ERROR',0x00000000)
		win_const_mgr.add_const('OID_802_5_ABORT_DELIMETERS',0x02020203)
		win_const_mgr.add_const('ERROR_BUFFER_OVERFLOW',0x0000006F)
		win_const_mgr.add_const('FLASHW_TIMERNOFG',0x0000000C)
		win_const_mgr.add_const('SCRIPT_UNDEFINED',0x00000000)
		win_const_mgr.add_const('JOB_OBJECT_ASSIGN_PROCESS',0x00000001)
		win_const_mgr.add_const('DNF_BAD_DRIVER',0x00000800)
		win_const_mgr.add_const('EMR_POLYPOLYLINE',0x00000007)
		win_const_mgr.add_const('DC_TRUETYPE',0x0000000F)
		win_const_mgr.add_const('MD_AUTH_ANONYMOUS',0x00000001)
		win_const_mgr.add_const('DDWAITVB_BLOCKBEGINEVENT',0x00000002)
		win_const_mgr.add_const('ET_RESOLUTION',0x00000008)
		win_const_mgr.add_const('CTLCOLOR_MSGBOX',0x00000000)
		win_const_mgr.add_const('DEBUG_REQUEST_TARGET_EXCEPTION_CONTEXT',0x00000001)
		win_const_mgr.add_const('DNS_ERROR_BACKGROUND_LOADING',0x00002560)
		win_const_mgr.add_const('CFM_BACKCOLOR',0x04000000)
		win_const_mgr.add_const('ACM_METRIC_COUNT_LOCAL_CODECS',0x00000015)
		win_const_mgr.add_const('ICW_LAUNCHFULL',0x00000100)
		win_const_mgr.add_const('SNMP_GENERICTRAP_LINKDOWN',0x00000002)
		win_const_mgr.add_const('TTI_ERROR_LARGE',0x00000006)
		win_const_mgr.add_const('KERB_S4U_LOGON_FLAG_CHECK_LOGONHOURS',0x00000002)
		win_const_mgr.add_const('DEBUG_CES_PROCESS_OPTIONS',0x00000200)
		win_const_mgr.add_const('SQL_SG_REFERENCES_COLUMN',0x00000200)
		win_const_mgr.add_const('WINEVENT_CHANNEL_GLOBAL_SYSTEM',0x00000008)
		win_const_mgr.add_const('ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND',0x000013A8)
		win_const_mgr.add_const('DFS_STORAGE_STATES',0x0000000F)
		win_const_mgr.add_const('FLAG_DEPENDENTONDATA',0x00000002)
		win_const_mgr.add_const('VER_ERR_OPCODE',0x00000002)
		win_const_mgr.add_const('MIB_IF_TYPE_FDDI',0x0000000F)
		win_const_mgr.add_const('LVIR_LABEL',0x00000002)
		win_const_mgr.add_const('FS_ARABIC',0x00000040)
		win_const_mgr.add_const('TLS1_ALERT_CERTIFICATE_EXPIRED',0x0000002D)
		win_const_mgr.add_const('SESSION_PWLEN',0x00000018)
		win_const_mgr.add_const('ERROR_LOG_BLOCK_INCOMPLETE',0x000019CB)
		win_const_mgr.add_const('D3DFVF_POSITION_MASK',0x0000400E)
		win_const_mgr.add_const('RPC_S_NO_BINDINGS',0x000006B6)
		win_const_mgr.add_const('IMAGE_FILE_MACHINE_ALPHA',0x00000184)
		win_const_mgr.add_const('FWPS_CLASSIFY_OUT_FLAG_BUFFER_LIMIT_REACHED',0x00000002)
		win_const_mgr.add_const('NDIS_OFFLOAD_SET_NO_CHANGE',0x00000000)
		win_const_mgr.add_const('SHCNEE_MSI_CHANGE',0x00000004)
		win_const_mgr.add_const('ERROR_TOO_MANY_SIDS',0x0000056D)
		win_const_mgr.add_const('WMDM_POWER_CAP_EXTERNAL',0x00000002)
		win_const_mgr.add_const('SPFILENOTIFY_ENDQUEUE',0x00000002)
		win_const_mgr.add_const('RTCRF_REGISTER_INVITE_SESSIONS',0x00000001)
		win_const_mgr.add_const('SUF_CLEAN',0x00000008)
		win_const_mgr.add_const('TVS_EX_EXCLUSIONCHECKBOXES',0x00000100)
		win_const_mgr.add_const('CM_IN_GAMUT',0x00000000)
		win_const_mgr.add_const('DN_MAXOPTL',0x00000010)
		win_const_mgr.add_const('CHANNEL_RC_ZERO_LENGTH',0x00000011)
		win_const_mgr.add_const('INTERNET_COOKIE_P3P_ENABLED',0x00000100)
		win_const_mgr.add_const('DEBUG_OUTTYPE_DEFAULT',0x00000000)
		win_const_mgr.add_const('DIF_RESERVED1',0x00000025)
		win_const_mgr.add_const('OID_WAN_GET_BRIDGE_INFO',0x0401020A)
		win_const_mgr.add_const('DIF_RESERVED2',0x00000030)
		win_const_mgr.add_const('DS_REPSYNC_PREEMPTED',0x00800000)
		win_const_mgr.add_const('MCI_DGV_STATUS_DISKSPACE',0x00200000)
		win_const_mgr.add_const('APD_COPY_NEW_FILES',0x00000008)
		win_const_mgr.add_const('ERROR_EVALUATION_EXPIRATION',0x0000026E)
		win_const_mgr.add_const('OID_802_11_REMOVE_WEP',0x0D010114)
		win_const_mgr.add_const('ERROR_THREAD_MODE_NOT_BACKGROUND',0x00000191)
		win_const_mgr.add_const('IF_NOSNAPSHOTBACKUP',0x00000100)
		win_const_mgr.add_const('TMT_COLORIZATIONOPACITY',0x00000980)
		win_const_mgr.add_const('ERROR_CTX_WINSTATION_ALREADY_EXISTS',0x00001B6F)
		win_const_mgr.add_const('ERROR_DLL_INIT_FAILED',0x0000045A)
		win_const_mgr.add_const('STATE_SYSTEM_COLLAPSED',0x00000400)
		win_const_mgr.add_const('LINETRANSLATERESULT_DIALPROMPT',0x00000200)
		win_const_mgr.add_const('LINECALLFEATURE_RELEASEUSERUSERINFO',0x10000000)
		win_const_mgr.add_const('ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED',0x000002EA)
		win_const_mgr.add_const('PROTO_TYPE_UCAST',0x00000000)
		win_const_mgr.add_const('DEBUG_FILTER_INITIAL_MODULE_LOAD',0x00000008)
		win_const_mgr.add_const('PROGDLG_NOMINIMIZE',0x00000008)
		win_const_mgr.add_const('DLCTL_URL_ENCODING_DISABLE_UTF8',0x00020000)
		win_const_mgr.add_const('USER_DATA_DESCRIPTOR',0xCF3FFFFF00000000)
		win_const_mgr.add_const('MA_ACTIVATEANDEAT',0x00000002)
		win_const_mgr.add_const('SF_RTFVAL',0x00000700)
		win_const_mgr.add_const('SECPKG_FLAG_FRAGMENT',0x00008000)
		win_const_mgr.add_const('CR_PROP_EXITDESCRIPTION',0x00000004)
		win_const_mgr.add_const('DBG_SEGFREE',0x00000002)
		win_const_mgr.add_const('USN_REASON_NAMED_DATA_EXTEND',0x00000020)
		win_const_mgr.add_const('DNS_ERROR_ZONE_LOCKED',0x00002587)
		win_const_mgr.add_const('ERROR_DS_CANT_CACHE_CLASS',0x000020D2)
		win_const_mgr.add_const('SUBLANG_CHINESE_SINGAPORE',0x00000004)
		win_const_mgr.add_const('IPX_MAXSIZE',0x00004006)
		win_const_mgr.add_const('METHOD_RIP2_OUTBOUND_INTF',0x00000002)
		win_const_mgr.add_const('IMF_AUTOFONT',0x00000002)
		win_const_mgr.add_const('FE_FONTSMOOTHINGCLEARTYPE',0x00000002)
		win_const_mgr.add_const('ERROR_VOLUME_NOT_SUPPORT_EFS',0x0000177E)
		win_const_mgr.add_const('WIA_IPS_CUR_INTENT',0x00001802)
		win_const_mgr.add_const('PORT_ISOIP',0x00000093)
		win_const_mgr.add_const('CR_ALREADY_SUCH_DEVNODE',0x00000010)
		win_const_mgr.add_const('PIDVSI_TIMELENGTH',0x00000007)
		win_const_mgr.add_const('WINHTTP_QUERY_MESSAGE_ID',0x0000000C)
		win_const_mgr.add_const('NTDSCONN_KCC_REDUNDANT_SERVER_TOPOLOGY',0x00000001)
		win_const_mgr.add_const('HCBT_KEYSKIPPED',0x00000007)
		win_const_mgr.add_const('DCR_MBZ1_V',0x00000000)
		win_const_mgr.add_const('NTMS_OMIDLABELINFO_LENGTH',0x00000100)
		win_const_mgr.add_const('SQL_COLUMN_TYPE',0x00000002)
		win_const_mgr.add_const('MEVT_F_CALLBACK',0x40000000)
		win_const_mgr.add_const('CMSG_SIGNER_INFO_PARAM',0x00000006)
		win_const_mgr.add_const('SQL_API_ALL_FUNCTIONS',0x00000000)
		win_const_mgr.add_const('SQL_NO_DATA_FOUND',0x00000064)
		win_const_mgr.add_const('RPC_X_BYTE_COUNT_TOO_SMALL',0x000006F6)
		win_const_mgr.add_const('D3DDEVCAPS2_PRESAMPLEDDMAPNPATCH',0x00000020)
		win_const_mgr.add_const('INTERNET_REQFLAG_FROM_CACHE',0x00000001)
		win_const_mgr.add_const('EXTENSION_ORIGIN_SERVER',0x00040000)
		win_const_mgr.add_const('INADDR_NONE',0x00000000)
		win_const_mgr.add_const('OIC_BANG',0x00007F03)
		win_const_mgr.add_const('MODALS_MIN_PASSWD_AGE_PARMNUM',0x00000003)
		win_const_mgr.add_const('KS_BI_RGB',0x00000000)
		win_const_mgr.add_const('DT_PREFIXONLY',0x00200000)
		win_const_mgr.add_const('LANG_KONKANI',0x00000057)
		win_const_mgr.add_const('DDFXALPHACAPS_BLTALPHASURFACESNEG',0x00000010)
		win_const_mgr.add_const('PPP_LCP_SPAP',0x0000C027)
		win_const_mgr.add_const('FOF_NOCOPYSECURITYATTRIBS',0x00000800)
		win_const_mgr.add_const('CCS_BOTTOM',0x00000003)
		win_const_mgr.add_const('ISFBVIEWMODE_LARGEICONS',0x00000002)
		win_const_mgr.add_const('VECTOR_RANK_MIN',0x00000000)
		win_const_mgr.add_const('DEBUG_COMMAND_EXCEPTION_ID',0x00000000)
		win_const_mgr.add_const('OID_FDDI_MAC_DA_FLAG',0x0303024A)
		win_const_mgr.add_const('SERIAL_IOC_FCR_RCVR_TRIGGER_LSB',0x00000040)
		win_const_mgr.add_const('EMO_GETVIEWMODE',0x00000005)
		win_const_mgr.add_const('CHANNEL_CHUNK_LENGTH',0x00000640)
		win_const_mgr.add_const('TAPE_DRIVE_SET_CMP_BOP_ONLY',0x04000000)
		win_const_mgr.add_const('DDCAPS2_CANFLIPODDEVEN',0x00002000)
		win_const_mgr.add_const('DEBUG_EXECUTE_DEFAULT',0x00000000)
		win_const_mgr.add_const('PRINTER_NOTIFY_FIELD_PARAMETERS',0x0000000A)
		win_const_mgr.add_const('VK_DELETE',0x0000002E)
		win_const_mgr.add_const('IKEEXT_CERT_AUTH_FLAG_SSL_ONE_WAY',0x00000001)
		win_const_mgr.add_const('OLEMISC_IMEMODE',0x00040000)
		win_const_mgr.add_const('DISPID_SEARCHCOMMAND_PROGRESSTEXT',0x00000005)
		win_const_mgr.add_const('WINHTTP_CALLBACK_STATUS_CONNECTED_TO_SERVER',0x00000008)
		win_const_mgr.add_const('SET_REPAIR_ENABLED',0x00000001)
		win_const_mgr.add_const('RTCTR_UDP',0x00000001)
		win_const_mgr.add_const('DISPID_PICT_RENDER',0x00000006)
		win_const_mgr.add_const('TVIS_EXPANDEDONCE',0x00000040)
		win_const_mgr.add_const('NRB_FUNCTION_SPINDLE_STATUS',0x000000E5)
		win_const_mgr.add_const('ICMF_CONFIGURE_QUERY',0x00000001)
		win_const_mgr.add_const('REO_GETOBJ_NO_INTERFACES',0x00000000)
		win_const_mgr.add_const('AE_CLOSEFILE',0x00000009)
		win_const_mgr.add_const('CMSG_ENCRYPTED_FLAG',0x00000001)
		win_const_mgr.add_const('EC_VARIANT_TYPE_MASK',0x00000007)
		win_const_mgr.add_const('SQL_ATTR_IMP_ROW_DESC',0x0000271C)
		win_const_mgr.add_const('TMT_GLYPHFONTSIZINGTYPE',0x00000FAE)
		win_const_mgr.add_const('SIGNERSCORE_UNKNOWN',0xFF000000)
		win_const_mgr.add_const('WHITE_PEN',0x00000006)
		win_const_mgr.add_const('X3_IMM39_1_INST_WORD_POS_X',0x00000000)
		win_const_mgr.add_const('CM_GETIDLIST_FILTER_REMOVALRELATIONS',0x00000008)
		win_const_mgr.add_const('TCS_SCROLLOPPOSITE',0x00000001)
		win_const_mgr.add_const('SQL_SQL92_VALUE_EXPRESSIONS',0x000000A5)
		win_const_mgr.add_const('OID_FDDI_IF_IN_UNKNOWN_PROTOS',0x03030286)
		win_const_mgr.add_const('MCI_DGV_STATUS_INPUT',0x00400000)
		win_const_mgr.add_const('NCRYPTBUFFER_PKCS_OID',0x00000028)
		win_const_mgr.add_const('SO_BTH_AUTHENTICATE',0x80000001)
		win_const_mgr.add_const('DISPID_ONQUIT',0x000000FD)
		win_const_mgr.add_const('MIDIPROP_TEMPO',0x00000002)
		win_const_mgr.add_const('DDSVCAPS_RESERVED4',0x00000008)
		win_const_mgr.add_const('DDSVCAPS_RESERVED3',0x00000004)
		win_const_mgr.add_const('IAS_ATTRIB_STR',0x00000003)
		win_const_mgr.add_const('DDSVCAPS_RESERVED1',0x00000001)
		win_const_mgr.add_const('MCIWNDF_SHOWPOS',0x00000020)
		win_const_mgr.add_const('SSA_HOTKEY',0x00000400)
		win_const_mgr.add_const('ERROR_PRIVILEGE_NOT_HELD',0x00000522)
		win_const_mgr.add_const('DEBUG_MANSTR_LOADED_SUPPORT_DLL',0x00000001)
		win_const_mgr.add_const('DEBUG_ENGOPT_IGNORE_LOADER_EXCEPTIONS',0x00000010)
		win_const_mgr.add_const('NDIS_RING_HARD_ERROR',0x00004000)
		win_const_mgr.add_const('RASLCPAP_EAP',0x0000C227)
		win_const_mgr.add_const('AVIIF_LASTPART',0x00000040)
		win_const_mgr.add_const('CF_USESTYLE',0x00000080)
		win_const_mgr.add_const('KS_NABTS_GROUPID_SYNDICATED_SHOW_CONTENT_BASE',0x00000840)
		win_const_mgr.add_const('JOY_CAL_READXYONLY',0x00020000)
		win_const_mgr.add_const('OID_FDDI_PORT_LCT_FAIL_CT',0x0303026C)
		win_const_mgr.add_const('IDS_FROM',0x00011001)
		win_const_mgr.add_const('GCP_NUMERICSLOCAL',0x08000000)
		win_const_mgr.add_const('PIDMSI_PROJECT',0x00000006)
		win_const_mgr.add_const('IF_TYPE_DS1_FDL',0x000000AA)
		win_const_mgr.add_const('JOB_OBJECT_SECURITY_FILTER_TOKENS',0x00000008)
		win_const_mgr.add_const('MSG_SERVICE_PROVIDER_CREATE',0x00000006)
		win_const_mgr.add_const('DSBM_CHANGEIMAGESTATE',0x00000066)
		win_const_mgr.add_const('HTTP_STATUS_BAD_METHOD',0x00000195)
		win_const_mgr.add_const('BSF_RETURNHDESK',0x00000200)
		win_const_mgr.add_const('PRINTER_STATUS_USER_INTERVENTION',0x00100000)
		win_const_mgr.add_const('SDP_ATTRIB_DI_VENDOR_ID',0x00000201)
		win_const_mgr.add_const('IMAGE_COMDAT_SELECT_LARGEST',0x00000006)
		win_const_mgr.add_const('DISPID_IDISCFORMAT2TAO_TOTALSECTORSONMEDIA',0x00000104)
		win_const_mgr.add_const('SHERB_NOPROGRESSUI',0x00000002)
		win_const_mgr.add_const('_KS_NO_ANONYMOUS_STRUCTURES_',0x00000001)
		win_const_mgr.add_const('FILE_DEVICE_KEYBOARD',0x00000000)
		win_const_mgr.add_const('VK_DBE_NOCODEINPUT',0x00000000)
		win_const_mgr.add_const('SM_CYMENUCHECK',0x00000048)
		win_const_mgr.add_const('SQL_PT_FUNCTION',0x00000002)
		win_const_mgr.add_const('HTTP_LOGGING_FLAG_LOG_SUCCESS_ONLY',0x00000008)
		win_const_mgr.add_const('NTM_PS_OPENTYPE',0x00020000)
		win_const_mgr.add_const('SQL_DL_SQL92_INTERVAL_HOUR',0x00000040)
		win_const_mgr.add_const('LPD_TYPE_RGBA',0x00000000)
		win_const_mgr.add_const('FW_THIN',0x00000064)
		win_const_mgr.add_const('SPFILENOTIFY_CABINETINFO',0x00000010)
		win_const_mgr.add_const('SB_GRAD_RECT',0x00000010)
		win_const_mgr.add_const('CTRY_DEFAULT',0x00000000)
		win_const_mgr.add_const('DOT11_SSID_MAX_LENGTH',0x00000020)
		win_const_mgr.add_const('DBPROPVAL_SQL_ODBC_CORE',0x00000002)
		win_const_mgr.add_const('LDAP_UNBIND_CMD',0x00000042)
		win_const_mgr.add_const('GOPHER_TYPE_TELNET',0x00000100)
		win_const_mgr.add_const('ISC_REQ_PROMPT_FOR_CREDS',0x00000040)
		win_const_mgr.add_const('EM_GETMODIFY',0x000000B8)
		win_const_mgr.add_const('CB_INITSTORAGE',0x00000161)
		win_const_mgr.add_const('SQL_MAX_USER_NAME_LEN',0x0000006B)
		win_const_mgr.add_const('SERVICE_CONTROL_INTERROGATE',0x00000004)
		win_const_mgr.add_const('SIP_MAX_MAGIC_NUMBER',0x00000004)
		win_const_mgr.add_const('ERROR_SXS_KEY_NOT_FOUND',0x000036B7)
		win_const_mgr.add_const('MCI_DGV_SETVIDEO_SRC_SVIDEO',0x00004002)
		win_const_mgr.add_const('SQL_PROCEDURE_TERM',0x00000028)
		win_const_mgr.add_const('CBA_DEFERRED_SYMBOL_LOAD_FAILURE',0x00000003)
		win_const_mgr.add_const('SQL_TIMESTAMP',0x0000000B)
		win_const_mgr.add_const('DS_REPL_NBR_FULL_SYNC_IN_PROGRESS',0x00010000)
		win_const_mgr.add_const('SPINST_REGISTRY',0x00000004)
		win_const_mgr.add_const('LDAP_RES_SEARCH_RESULT',0x00000065)
		win_const_mgr.add_const('D3DSP_SWIZZLE_MASK',0x00FF0000)
		win_const_mgr.add_const('WIA_IPS_OPTICAL_YRES',0x00000C13)
		win_const_mgr.add_const('BFFM_SELCHANGED',0x00000002)
		win_const_mgr.add_const('OPF_SHOWHELP',0x00000004)
		win_const_mgr.add_const('IGP_UI',0x00000010)
		win_const_mgr.add_const('EPS_SIGNATURE',0x46535045)
		win_const_mgr.add_const('DISPID_DEFAULTSEARCHPROVIDER',0x0000001A)
		win_const_mgr.add_const('NCRYPTBUFFER_CERT_BLOB',0x0000002F)
		win_const_mgr.add_const('FILE_CURRENT',0x00000001)
		win_const_mgr.add_const('ISCSI_LOGIN_OPTIONS_USERNAME',0x00000020)
		win_const_mgr.add_const('FWPS_METADATA_FIELD_IP_HEADER_SIZE',0x00000004)
		win_const_mgr.add_const('DC_COPIES',0x00000012)
		win_const_mgr.add_const('SQL_DRIVER_HSTMT',0x00000005)
		win_const_mgr.add_const('DB_NULL_HACCESSOR',0x00000000)
		win_const_mgr.add_const('ERROR_PROFILING_AT_LIMIT',0x00000229)
		win_const_mgr.add_const('CSURL_ADDTOCRLCDP',0x00000008)
		win_const_mgr.add_const('IKEEXT_CERT_AUTH_FLAG_DISABLE_CRL_CHECK',0x00000002)
		win_const_mgr.add_const('MSG_OOB',0x00000001)
		win_const_mgr.add_const('ANSI_CHARSET',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_FORWARDER_ALREADY_EXISTS',0x00002593)
		win_const_mgr.add_const('EXTENSION_ORIGIN_PKCS7',0x00070000)
		win_const_mgr.add_const('MCW_DEFAULT',0x00000000)
		win_const_mgr.add_const('DEBUG_DUMP_SMALL',0x00000400)
		win_const_mgr.add_const('CRYPTUI_ENABLE_REVOCATION_CHECK_END_CERT',0x00004000)
		win_const_mgr.add_const('SERVICE_ACCEPT_SESSIONCHANGE',0x00000080)
		win_const_mgr.add_const('CTRY_PRCHINA',0x00000056)
		win_const_mgr.add_const('IN_CLASSC_NET',0x00000000)
		win_const_mgr.add_const('SQL_API_SQLPRIMARYKEYS',0x00000041)
		win_const_mgr.add_const('WRITE_RESTRICTED',0x00000008)
		win_const_mgr.add_const('CRYPT_MESSAGE_KEYID_RECIPIENT_FLAG',0x00000004)
		win_const_mgr.add_const('MIXERCONTROL_CONTROLF_UNIFORM',0x00000001)
		win_const_mgr.add_const('TBCDRF_NOMARK',0x00080000)
		win_const_mgr.add_const('URL_ESCAPE_SPACES_ONLY',0x04000000)
		win_const_mgr.add_const('GESTURE_DOWN_UP',0x00000000)
		win_const_mgr.add_const('IDM_TRIED_ACTIVATEACTIVEXCONTROLS',0x00000017)
		win_const_mgr.add_const('MFASFINDEXER_APPROX_SEEK_TIME_UNKNOWN',0x00000000)
		win_const_mgr.add_const('DSF_WIA_SCANNERS',0x00000004)
		win_const_mgr.add_const('GD_FONT',0x00000008)
		win_const_mgr.add_const('ERROR_CLUSTER_LAST_INTERNAL_NETWORK',0x000013CA)
		win_const_mgr.add_const('WS_EX_CONTROLPARENT',0x00010000)
		win_const_mgr.add_const('PST_UNSPECIFIED',0x00000000)
		win_const_mgr.add_const('DM_PANNINGWIDTH',0x08000000)
		win_const_mgr.add_const('RTCAU_KERBEROS',0x00000008)
		win_const_mgr.add_const('SM_SHOWSOUNDS',0x00000046)
		win_const_mgr.add_const('GW_OWNER',0x00000004)
		win_const_mgr.add_const('ERROR_INVALID_TASK_INDEX',0x0000060F)
		win_const_mgr.add_const('MD_ERROR_SUB404_SITE_NOT_FOUND',0x00000001)
		win_const_mgr.add_const('CE_FRAME',0x00000008)
		win_const_mgr.add_const('QS_ALLPOSTMESSAGE',0x00000100)
		win_const_mgr.add_const('PST_RC_REMOVABLE',0x80000000)
		win_const_mgr.add_const('DS_REPSYNCALL_NO_OPTIONS',0x00000000)
		win_const_mgr.add_const('WSB_PROP_VSTYLE',0x00000100)
		win_const_mgr.add_const('IME_ESC_SEQUENCE_TO_INTERNAL',0x00001001)
		win_const_mgr.add_const('SN_INFLAG_ADMIN_ACCESS',0x00000004)
		win_const_mgr.add_const('DRIVER_W9X_SUSPECT_HARDWAREID_RANK',0x0000CFFF)
		win_const_mgr.add_const('DNS_QUERY_RETURN_MESSAGE',0x00000200)
		win_const_mgr.add_const('GOPHER_TYPE_TN3270',0x00000800)
		win_const_mgr.add_const('SNMP_TRAP_ENTERPRISESPECIFIC',0x00000006)
		win_const_mgr.add_const('IDM_SHOWSCRIPTTAGS',0x00000912)
		win_const_mgr.add_const('NOTE_COLOR_YELLOW',0x00000003)
		win_const_mgr.add_const('LIFF_LOAD_DEFINED_FILTER',0x00000001)
		win_const_mgr.add_const('PID_APPNAME',0x00000012)
		win_const_mgr.add_const('CM_INSTALL_STATE_NEEDS_REINSTALL',0x00000001)
		win_const_mgr.add_const('LWS_TRANSPARENT',0x00000001)
		win_const_mgr.add_const('STI_ONLINESTATE_WARMING_UP',0x00000800)
		win_const_mgr.add_const('BOM_CONTEXTREADING',0x00000008)
		win_const_mgr.add_const('GESTURE_CLOSEUP',0x00000000)
		win_const_mgr.add_const('WLAN_CONNECTION_EAPOL_PASSTHROUGH',0x00000008)
		win_const_mgr.add_const('IEIFLAG_NOBORDER',0x00000100)
		win_const_mgr.add_const('DEBUG_DISASM_EFFECTIVE_ADDRESS',0x00000001)
		win_const_mgr.add_const('CERT_DISPWELL_TRUST_CA_CERT',0x00000002)
		win_const_mgr.add_const('IF_TYPE_NFAS',0x000000AF)
		win_const_mgr.add_const('DWORD_PTR_MAX',0x00000000)
		win_const_mgr.add_const('LVBKIF_SOURCE_MASK',0x00000003)
		win_const_mgr.add_const('RPC_X_SS_CHAR_TRANS_OPEN_FAIL',0x000006ED)
		win_const_mgr.add_const('ATM_E164',0x00000001)
		win_const_mgr.add_const('ERROR_SXS_ACTIVATION_CONTEXT_DISABLED',0x000036B6)
		win_const_mgr.add_const('REQDISP_DENY',0x00000002)
		win_const_mgr.add_const('NCRYPT_WRITE_KEY_TO_LEGACY_STORE_FLAG',0x00000200)
		win_const_mgr.add_const('D3DFVF_TEX3',0x00000300)
		win_const_mgr.add_const('ACM_FILTERDETAILSF_FILTER',0x00000001)
		win_const_mgr.add_const('LM20_SERVICE_PAUSED',0x0000000C)
		win_const_mgr.add_const('SCARD_E_INVALID_PARAMETER',0x80100004)
		win_const_mgr.add_const('NCBFINDNAME',0x00000078)
		win_const_mgr.add_const('IASSEMBLYCACHE_UNINSTALL_DISPOSITION_UNINSTALLED',0x00000001)
		win_const_mgr.add_const('LOGON_GRACE_LOGON',0x01000000)
		win_const_mgr.add_const('D3DFVF_TEX1',0x00000100)
		win_const_mgr.add_const('SQL_DESC_DATETIME_INTERVAL_PRECISION',0x0000001A)
		win_const_mgr.add_const('ISR_ILLEGAL_ISA',0x00000004)
		win_const_mgr.add_const('GESTURE_UP_DOWN',0x00000000)
		win_const_mgr.add_const('ERROR_WRONG_DISK',0x00000022)
		win_const_mgr.add_const('ERROR_DEPENDENCY_NOT_FOUND',0x0000138A)
		win_const_mgr.add_const('MM_WAVE_MAPPER',0x00000002)
		win_const_mgr.add_const('BATTERY_FLAG_HIGH',0x00000001)
		win_const_mgr.add_const('NDIS_PACKET_TYPE_ALL_FUNCTIONAL',0x00002000)
		win_const_mgr.add_const('TXTLOG_UTIL',0x00000200)
		win_const_mgr.add_const('DAV_DETECTION_REQUIRED',0x00008000)
		win_const_mgr.add_const('CFS_POINT',0x00000002)
		win_const_mgr.add_const('CRYPTUI_SELECT_INTENDEDUSE_COLUMN',0x00000004)
		win_const_mgr.add_const('EVENTLOG_PAIRED_EVENT_ACTIVE',0x00000008)
		win_const_mgr.add_const('NRB_FUNCTION_QUERY_HYBRID_DISK_STATUS',0x000000D1)
		win_const_mgr.add_const('NETERR_RING_STATUS_LOBE_WIRE_FAULT',0x00000800)
		win_const_mgr.add_const('PS_256K',0x00000012)
		win_const_mgr.add_const('TH32CS_SNAPPROCESS',0x00000002)
		win_const_mgr.add_const('LDAP_NO_LIMIT',0x00000000)
		win_const_mgr.add_const('EMR_SETVIEWPORTEXTEX',0x0000000B)
		win_const_mgr.add_const('SCH_CRED_CACHE_ONLY_URL_RETRIEVAL_ON_CREATE',0x00020000)
		win_const_mgr.add_const('LINEERR_INVALAPPHANDLE',0x80000014)
		win_const_mgr.add_const('ERROR_LOG_APPENDED_FLUSH_FAILED',0x000019F7)
		win_const_mgr.add_const('CERT_FILTER_LEAF_CERTS_ONLY',0x00000008)
		win_const_mgr.add_const('OS_SERVER',0x00000017)
		win_const_mgr.add_const('IOC_IN',0x80000000)
		win_const_mgr.add_const('MCI_GETDEVCAPS_CAN_PLAY',0x00000008)
		win_const_mgr.add_const('SQL_AT_ADD_CONSTRAINT',0x00000008)
		win_const_mgr.add_const('IDC_IO_CONTROLTYPELIST',0x00000844)
		win_const_mgr.add_const('TBIF_TEXT',0x00000002)
		win_const_mgr.add_const('ERROR_ALL_NODES_NOT_AVAILABLE',0x000013AD)
		win_const_mgr.add_const('EMR_CREATEBRUSHINDIRECT',0x00000027)
		win_const_mgr.add_const('SM_SECURE',0x0000002C)
		win_const_mgr.add_const('KS_BI_RLE8',0x00000001)
		win_const_mgr.add_const('HS_VERTICAL',0x00000001)
		win_const_mgr.add_const('INTERNET_OPTION_SECURITY_CONNECTION_INFO',0x00000042)
		win_const_mgr.add_const('SQL_API_SQLCOLUMNPRIVILEGES',0x00000038)
		win_const_mgr.add_const('FPF_VIRTUAL',0x00000004)
		win_const_mgr.add_const('SQL_TIME',0x0000000A)
		win_const_mgr.add_const('PDCAP_WAKE_FROM_D0_SUPPORTED',0x00000010)
		win_const_mgr.add_const('DRIVERSIGN_BLOCKING',0x00000002)
		win_const_mgr.add_const('ERROR_IPSEC_IKE_DOS_COOKIE_SENT',0x00003642)
		win_const_mgr.add_const('CAPTUREMODE_TIMELAPSE',0x00000003)
		win_const_mgr.add_const('KS_BI_RLE4',0x00000002)
		win_const_mgr.add_const('IDC_EL_COL1',0x000000DC)
		win_const_mgr.add_const('IDC_EL_COL2',0x000000DD)
		win_const_mgr.add_const('IDC_EL_COL3',0x000000DE)
		win_const_mgr.add_const('VNSPROTO_IPC',0x00000001)
		win_const_mgr.add_const('SFGAO_HIDDEN',0x00080000)
		win_const_mgr.add_const('ERROR_IPSEC_QM_POLICY_EXISTS',0x000032C8)
		win_const_mgr.add_const('META_SETBKMODE',0x00000102)
		win_const_mgr.add_const('URL_UNESCAPE_HIGH_ANSI_ONLY',0x00400000)
		win_const_mgr.add_const('KERB_ETYPE_DES_EDE3_CBC_ENV',0x0000000F)
		win_const_mgr.add_const('DISPID_IHTMLOPSPROFILE_SETATTRIBUTE',0x00000005)
		win_const_mgr.add_const('VER_SUITE_SINGLEUSERTS',0x00000100)
		win_const_mgr.add_const('POLLNVAL',0x00000004)
		win_const_mgr.add_const('WM_DWMNCRENDERINGCHANGED',0x0000031F)
		win_const_mgr.add_const('COMP_TYPE_HTMLDOC',0x00000000)
		win_const_mgr.add_const('CRYPT_DEFAULT_CONTEXT_PROCESS_FLAG',0x00000002)
		win_const_mgr.add_const('SQL_FN_TSI_FRAC_SECOND',0x00000001)
		win_const_mgr.add_const('IDM_PERSISTSTREAMSYNC',0x00000925)
		win_const_mgr.add_const('ITSAT_MAX_PRIORITY',0x00000007)
		win_const_mgr.add_const('FWPM_FILTER_FLAG_BOOTTIME',0x00000002)
		win_const_mgr.add_const('LDAP_FILTER_NOT',0x00000000)
		win_const_mgr.add_const('VFT2_DRV_PRINTER',0x00000001)
		win_const_mgr.add_const('PERF_AGGREGATE_UNDEFINED',0x00000000)
		win_const_mgr.add_const('MARSHAL_S_LAST',0x0004012F)
		win_const_mgr.add_const('MA_NOACTIVATEANDEAT',0x00000004)
		win_const_mgr.add_const('MD_LFHINT_NONE',0x00000000)
		win_const_mgr.add_const('IDM_REPLACEGLYPHCONTENTS',0x00000923)
		win_const_mgr.add_const('STIEDFL_ALLDEVICES',0x00000000)
		win_const_mgr.add_const('DNS_ERROR_NOT_UNIQUE',0x00002553)
		win_const_mgr.add_const('AM_VIDEO_FLAG_FIELD2',0x00000002)
		win_const_mgr.add_const('CR_INVALID_DEVNODE',0x00000005)
		win_const_mgr.add_const('CACHE_ENTRY_ACCTIME_FC',0x00000100)
		win_const_mgr.add_const('AM_VIDEO_FLAG_FIELD1',0x00000001)
		win_const_mgr.add_const('UF_ACCOUNTDISABLE',0x00000002)
		win_const_mgr.add_const('IMAGE_SYM_DTYPE_POINTER',0x00000001)
		win_const_mgr.add_const('IDM_GETUSERINITFLAGS',0x00003A9C)
		win_const_mgr.add_const('DB_BINDFLAGS_OUTPUT',0x00000008)
		win_const_mgr.add_const('DOMAIN_ALIAS_RID_EVENT_LOG_READERS_GROUP',0x0000023D)
		win_const_mgr.add_const('WH_GETMESSAGE',0x00000003)
		win_const_mgr.add_const('MSV1_0_ALLOW_FORCE_GUEST',0x00002000)
		win_const_mgr.add_const('WIA_IPS_XEXTENT',0x00001807)
		win_const_mgr.add_const('PROV_EC_ECDSA_SIG',0x0000000E)
		win_const_mgr.add_const('PRINTER_CHANGE_DELETE_PRINTER_DRIVER',0x40000000)
		win_const_mgr.add_const('SPQ_SCAN_ACTIVATE_DRP',0x00000400)
		win_const_mgr.add_const('IPN_FIRST',0x00000000)
		win_const_mgr.add_const('FMEVENT_USER_REFRESH',0x00000067)
		win_const_mgr.add_const('ASC_REQ_ALLOW_NON_USER_LOGONS',0x00200000)
		win_const_mgr.add_const('HINSTANCE_ERROR',0x00000020)
		win_const_mgr.add_const('EM_GETLIMITTEXT',0x000000D5)
		win_const_mgr.add_const('WAVE_FORMAT_1S16',0x00000008)
		win_const_mgr.add_const('KERB_CHECKSUM_KRB_DES_MAC',0x00000004)
		win_const_mgr.add_const('INDEX_GUID_FACTOID',0x00000007)
		win_const_mgr.add_const('PDH_FMT_NOCAP100',0x00008000)
		win_const_mgr.add_const('GESTURE_CHEVRON_RIGHT',0x00000000)
		win_const_mgr.add_const('SV_MAXWORKITEMS_PARMNUM',0x000001FA)
		win_const_mgr.add_const('IP_OPT_SID',0x00000088)
		win_const_mgr.add_const('LOG_CONF_BITS',0x00000007)
		win_const_mgr.add_const('TSF_MOVE_AS_COPY_DELETE',0x00000400)
		win_const_mgr.add_const('ERROR_DUPLICATE_TAG',0x000007DE)
		win_const_mgr.add_const('LDAP_UNICODE',0x00000000)
		win_const_mgr.add_const('WMS_CONTAINER_FILESIZE_LO',0x0000000B)
		win_const_mgr.add_const('MD_ERROR_SUB404_URL_TOO_LONG',0x0000000E)
		win_const_mgr.add_const('SYSFXUI_DONOTSHOW_BASSBOOST',0x00000008)
		win_const_mgr.add_const('INTERNET_FLAG_NO_CACHE_WRITE',0x04000000)
		win_const_mgr.add_const('CRLF_ALLOW_REQUEST_ATTRIBUTE_SUBJECT',0x00010000)
		win_const_mgr.add_const('IDM_CUSTOMIZEITEM',0x00000054)
		win_const_mgr.add_const('OID_802_11_RX_ANTENNA_SELECTED',0x0D01020C)
		win_const_mgr.add_const('ERR_FUTURE_VERSION',0xE000000D)
		win_const_mgr.add_const('MOUSEEVENTF_XDOWN',0x00000080)
		win_const_mgr.add_const('GESTURE_RECTANGLE',0x00000000)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_MARSHAL',0x00020000)
		win_const_mgr.add_const('REGSTR_VAL_FONT_SIZE_DEF',0x00000002)
		win_const_mgr.add_const('STGM_NOSNAPSHOT',0x00200000)
		win_const_mgr.add_const('CF_SCALABLEONLY',0x00020000)
		win_const_mgr.add_const('NI_NUMERICSERV',0x00000008)
		win_const_mgr.add_const('CLASSFACTORY_S_LAST',0x0004011F)
		win_const_mgr.add_const('CDDS_ITEM',0x00010000)
		win_const_mgr.add_const('SQL_INSENSITIVE',0x00000001)
		win_const_mgr.add_const('DO_NOT_ADVERTISE_ROUTE',0x00000002)
		win_const_mgr.add_const('ERROR_TAG_NOT_PRESENT',0x000007DD)
		win_const_mgr.add_const('DVB_EIT_PID',0x00000012)
		win_const_mgr.add_const('WIA_PREVIEW_SCAN',0x00000001)
		win_const_mgr.add_const('DIGCF_DEFAULT',0x00000001)
		win_const_mgr.add_const('DISPID_USEDIVONCR',0x0000001E)
		win_const_mgr.add_const('PHOTO_FLASH_FLASH',0x00000001)
		win_const_mgr.add_const('ERROR_DS_COMPARE_TRUE',0x00002026)
		win_const_mgr.add_const('LDAP_AUTH_OTHERKIND',0x00000086)
		win_const_mgr.add_const('CDO_E_PROP_CANNOT_DELETE',0x80040228)
		win_const_mgr.add_const('DEFAULT_SNMP_PORT_IPX',0x0000900F)
		win_const_mgr.add_const('TRANSACTION_NOTIFY_PROMOTE',0x08000000)
		win_const_mgr.add_const('FILE_DEVICE_VIDEO',0x00000023)
		win_const_mgr.add_const('DEV_PORT_USB',0x00000009)
		win_const_mgr.add_const('CERT_RDN_UTF8_STRING',0x0000000D)
		win_const_mgr.add_const('AIF_NOSKIP',0x00000002)
		win_const_mgr.add_const('URLACTION_LOOSE_XAML',0x00002402)
		win_const_mgr.add_const('DC_MEDIATYPENAMES',0x00000022)
		win_const_mgr.add_const('SM_FOCUS_TYPE_NT_SERVER',0x00000004)
		win_const_mgr.add_const('COD_SERVICE_TELEPHONY',0x00000200)
		win_const_mgr.add_const('ISC_RET_DELEGATE',0x00000001)
		win_const_mgr.add_const('SPI_GETNONCLIENTMETRICS',0x00000029)
		win_const_mgr.add_const('OID_GEN_TRANSMIT_QUEUE_LENGTH',0x0002020E)
		win_const_mgr.add_const('EAP_E_SERVER_CERT_EXPIRED',0x80420202)
		win_const_mgr.add_const('SQL_TXN_ISOLATION',0x0000006C)
		win_const_mgr.add_const('DEBUG_CMDEX_INVALID',0x00000000)
		win_const_mgr.add_const('LOCALE_IDAYLZERO',0x00000026)
		win_const_mgr.add_const('COLOR_RAINBOW',0x000002C6)
		win_const_mgr.add_const('DDCKEYCAPS_SRCBLTCLRSPACEYUV',0x00000800)
		win_const_mgr.add_const('IMAGE_REL_IA64_PCREL60M',0x00000019)
		win_const_mgr.add_const('IMAGE_REL_MIPS_SECRELHI',0x0000000D)
		win_const_mgr.add_const('MCHT_PREV',0x02000000)
		win_const_mgr.add_const('IDM_NOACTIVATEDESIGNTIMECONTROLS',0x0000091D)
		win_const_mgr.add_const('OID_GEN_MAC_ADDRESS',0x00010205)
		win_const_mgr.add_const('TIME_STAMP_CAPABLE',0x00000020)
		win_const_mgr.add_const('WIA_IPA_ITEM_CATEGORY',0x0000101D)
		win_const_mgr.add_const('DNS_UPDATE_SECURITY_OFF',0x00000010)
		win_const_mgr.add_const('SERVICE_KERNEL_DRIVER',0x00000001)
		win_const_mgr.add_const('HANDLE_PARAM_IS_IN',0x00000040)
		win_const_mgr.add_const('IF_CHECK_SEND',0x00000002)
		win_const_mgr.add_const('MSV1_0_ALLOW_WORKSTATION_TRUST_ACCOUNT',0x00000800)
		win_const_mgr.add_const('SPI_SETMOUSEBUTTONSWAP',0x00000021)
		win_const_mgr.add_const('IME_MODE_HANJACONVERT',0x00000004)
		win_const_mgr.add_const('BOM_CONTEXTALIGNMENT',0x00000010)
		win_const_mgr.add_const('LVHT_TOLEFT',0x00000040)
		win_const_mgr.add_const('ERROR_INVALID_CATEGORY',0x00000075)
		win_const_mgr.add_const('DN_WILL_BE_REMOVED',0x00040000)
		win_const_mgr.add_const('SQL_GB_COLLATE',0x00000004)
		win_const_mgr.add_const('DOT11_STATUS_XMIT_MSDU_TIMER_EXPIRED',0x00000040)
		win_const_mgr.add_const('PIDDSI_BYTECOUNT',0x00000004)
		win_const_mgr.add_const('DDLOCK_WAIT',0x00000001)
		win_const_mgr.add_const('SBS_VERT',0x00000001)
		win_const_mgr.add_const('SAC_MAC_LEN',0x00000008)
		win_const_mgr.add_const('MEVT_F_LONG',0x80000000)
		win_const_mgr.add_const('TH32CS_SNAPMODULE32',0x00000010)
		win_const_mgr.add_const('ROUTEBASE',0x00000384)
		win_const_mgr.add_const('TBIF_PREPEND',0x00000001)
		win_const_mgr.add_const('IMAGE_REL_BASED_IA64_PCREL60',0x0000000C)
		win_const_mgr.add_const('STATE_SYSTEM_VALID',0x3FFFFFFF)
		win_const_mgr.add_const('DDSCAPS2_STEREOSURFACELEFT',0x00080000)
		win_const_mgr.add_const('SPVERSION_MASK',0x0000FF00)
		win_const_mgr.add_const('DBPROPVAL_OO_ROWOBJECT',0x00000004)
		win_const_mgr.add_const('LINECALLINFOSTATE_QOS',0x20000000)
		win_const_mgr.add_const('PRIUSER',0x00000000)
		win_const_mgr.add_const('IDM_COLUMNSELECT',0x000008A0)
		win_const_mgr.add_const('KP_CMS_DH_KEY_INFO',0x00000026)
		win_const_mgr.add_const('LINETONEMODE_BUSY',0x00000004)
		win_const_mgr.add_const('MCI_DGV_MONITOR_METHOD',0x00010000)

	end

end

end; end; end; end; end; end
