package msfgui;

import java.awt.Color;
import java.util.Map;
import javax.swing.JColorChooser;
import javax.swing.UIManager;
import javax.swing.UIManager.LookAndFeelInfo;

/**
 * Preferences form to see/save preferences.
 *
 * @author scriptjunkie
 */
public class PreferencesFrame extends MsfFrame {
	private final Map prefs;
	private String[] lookNFeels;

    /** Creates new form viewPrefs */
    public PreferencesFrame() {
		LookAndFeelInfo[] infoArray = UIManager.getInstalledLookAndFeels();
		lookNFeels = new String[infoArray.length];
		for(int i = 0; i < infoArray.length; i++)
			lookNFeels[i] = infoArray[i].getClassName();
        initComponents();
		updateSizes(this);
		prefs = MsfguiApp.getPropertiesNode();
		setLnFBox.setSelectedItem(prefs.get("LnF"));
		tabWindowBox.setSelected(!"window".equals(prefs.get("tabWindowPreference")));
		tableLineBox.setSelected(Boolean.TRUE.equals(prefs.get("tableShowLines")));
		tableExpandBox.setSelected(!"off".equals(prefs.get("tableResize")));
		if(Boolean.TRUE.equals(prefs.get("overrideColors")))
			colorThemeBox.setSelected(true);
		if(prefs.containsKey("defaultTextSize"))
			fontSizeSlider.setValue(new Integer(prefs.get("defaultTextSize").toString()));
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        tabWindowBox = new javax.swing.JCheckBox();
        tableLineBox = new javax.swing.JCheckBox();
        tableExpandBox = new javax.swing.JCheckBox();
        headerLabel = new javax.swing.JLabel();
        okButton = new javax.swing.JButton();
        cancelButton = new javax.swing.JButton();
        restartLabel = new javax.swing.JLabel();
        setLnFBox = new javax.swing.JComboBox();
        lnFLabel = new javax.swing.JLabel();
        fontSizeSlider = new javax.swing.JSlider();
        textSizeLabel = new javax.swing.JLabel();
        colorThemeBox = new javax.swing.JCheckBox();
        foregroundButton = new javax.swing.JButton();
        background = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setName("Form"); // NOI18N

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(msfgui.MsfguiApp.class).getContext().getResourceMap(PreferencesFrame.class);
        tabWindowBox.setText(resourceMap.getString("tabWindowBox.text")); // NOI18N
        tabWindowBox.setName("tabWindowBox"); // NOI18N

        tableLineBox.setText(resourceMap.getString("tableLineBox.text")); // NOI18N
        tableLineBox.setName("tableLineBox"); // NOI18N

        tableExpandBox.setText(resourceMap.getString("tableExpandBox.text")); // NOI18N
        tableExpandBox.setName("tableExpandBox"); // NOI18N

        headerLabel.setText(resourceMap.getString("headerLabel.text")); // NOI18N
        headerLabel.setName("headerLabel"); // NOI18N

        okButton.setText(resourceMap.getString("okButton.text")); // NOI18N
        okButton.setName("okButton"); // NOI18N
        okButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okButtonActionPerformed(evt);
            }
        });

        cancelButton.setText(resourceMap.getString("cancelButton.text")); // NOI18N
        cancelButton.setName("cancelButton"); // NOI18N
        cancelButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelButtonActionPerformed(evt);
            }
        });

        restartLabel.setText(resourceMap.getString("restartLabel.text")); // NOI18N
        restartLabel.setName("restartLabel"); // NOI18N

        setLnFBox.setModel(new javax.swing.DefaultComboBoxModel(lookNFeels));
        setLnFBox.setName("setLnFBox"); // NOI18N
        setLnFBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                setLnFBoxActionPerformed(evt);
            }
        });

        lnFLabel.setText(resourceMap.getString("lnFLabel.text")); // NOI18N
        lnFLabel.setName("lnFLabel"); // NOI18N

        fontSizeSlider.setMaximum(20);
        fontSizeSlider.setMinimum(4);
        fontSizeSlider.setPaintLabels(true);
        fontSizeSlider.setPaintTicks(true);
        fontSizeSlider.setSnapToTicks(true);
        fontSizeSlider.setValue(10);
        fontSizeSlider.setName("fontSizeSlider"); // NOI18N
        fontSizeSlider.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                fontSizeSliderStateChanged(evt);
            }
        });

        textSizeLabel.setText(resourceMap.getString("textSizeLabel.text")); // NOI18N
        textSizeLabel.setName("textSizeLabel"); // NOI18N

        colorThemeBox.setText(resourceMap.getString("colorThemeBox.text")); // NOI18N
        colorThemeBox.setName("colorThemeBox"); // NOI18N

        foregroundButton.setText(resourceMap.getString("foregroundButton.text")); // NOI18N
        foregroundButton.setName("foregroundButton"); // NOI18N
        foregroundButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                foregroundButtonActionPerformed(evt);
            }
        });

        background.setText(resourceMap.getString("background.text")); // NOI18N
        background.setName("background"); // NOI18N
        background.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                backgroundActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(headerLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                                .addComponent(setLnFBox, 0, 704, Short.MAX_VALUE)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(lnFLabel)))
                        .addContainerGap())
                    .addGroup(layout.createSequentialGroup()
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addGroup(layout.createSequentialGroup()
                                .addComponent(tableLineBox)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 638, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addGroup(layout.createSequentialGroup()
                                .addComponent(tableExpandBox)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 476, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addGroup(layout.createSequentialGroup()
                                .addComponent(restartLabel, javax.swing.GroupLayout.DEFAULT_SIZE, 696, Short.MAX_VALUE)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(cancelButton)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(okButton)))
                        .addGap(18, 18, 18))
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(tabWindowBox)
                        .addContainerGap(635, Short.MAX_VALUE))
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(fontSizeSlider, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addGap(18, 18, 18)
                        .addComponent(textSizeLabel)
                        .addContainerGap(486, Short.MAX_VALUE))
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(colorThemeBox)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(foregroundButton)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(background)
                        .addContainerGap(445, Short.MAX_VALUE))))
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(headerLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(setLnFBox, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(lnFLabel))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(colorThemeBox)
                    .addComponent(foregroundButton)
                    .addComponent(background))
                .addGap(47, 47, 47)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(textSizeLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(fontSizeSlider, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(tabWindowBox)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(tableLineBox)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(tableExpandBox)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(restartLabel)
                    .addComponent(cancelButton)
                    .addComponent(okButton))
                .addContainerGap())
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

	private void cancelButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cancelButtonActionPerformed
		try{
			UIManager.setLookAndFeel(prefs.get("LnF").toString());
		}catch(Exception ex){
		}
		setVisible(false);
		dispose();
	}//GEN-LAST:event_cancelButtonActionPerformed

	private void okButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_okButtonActionPerformed
		prefs.put("LnF", setLnFBox.getSelectedItem().toString());
		prefs.put("tabWindowPreference", tabWindowBox.isSelected() ? "tab" : "window");
		prefs.put("tableShowLines", tableLineBox.isSelected());
		prefs.put("tableResize", tableExpandBox.isSelected() ? "on" : "off");
		prefs.put("overrideColors", colorThemeBox.isSelected());
		prefs.put("defaultTextSize", new Integer(fontSizeSlider.getValue()).toString());
		if(fontSizeSlider.getValue() >= 12)
			prefs.put("jComponentSizeVariant", "large");
		else if(fontSizeSlider.getValue() >= 10)
			prefs.put("jComponentSizeVariant", "regular");
		else if(fontSizeSlider.getValue() >= 8)
			prefs.put("jComponentSizeVariant", "small");
		else
			prefs.put("jComponentSizeVariant", "mini");
		setVisible(false);
		dispose();
		updateUIs();
	}//GEN-LAST:event_okButtonActionPerformed

	/**
	 * Recursively iterates through a container, updating the size to this local font slider size
	 * @param c Container to be resized
	 */
	public void updateSize(java.awt.Container c) {
		for(java.awt.Component com : c.getComponents()) {
			com.setFont(com.getFont().deriveFont((float)fontSizeSlider.getValue()));
			if (com instanceof java.awt.Container)
				updateSize((java.awt.Container) com);
		}
	}
	private void fontSizeSliderStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_fontSizeSliderStateChanged
		updateSize(this);
	}//GEN-LAST:event_fontSizeSliderStateChanged

	private void setLnFBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_setLnFBoxActionPerformed
		try{
			UIManager.setLookAndFeel(setLnFBox.getSelectedItem().toString());
			javax.swing.SwingUtilities.updateComponentTreeUI(this);
			pack();
		}catch(Exception ex){
		}
	}//GEN-LAST:event_setLnFBoxActionPerformed

	private void foregroundButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_foregroundButtonActionPerformed
		Color fgcol = JColorChooser.showDialog(this, null, lnFLabel.getForeground());
		prefs.put("foregroundColor",fgcol.getRGB());
		colorThemeBox.setSelected(true);
		prefs.put("overrideColors",true);
		updateSizes(this);
	}//GEN-LAST:event_foregroundButtonActionPerformed

	private void backgroundActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_backgroundActionPerformed
		Color bgcol = JColorChooser.showDialog(this, null, lnFLabel.getForeground());
		prefs.put("backgroundColor",bgcol.getRGB());
		colorThemeBox.setSelected(true);
		prefs.put("overrideColors",true);
		updateSizes(this);
	}//GEN-LAST:event_backgroundActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton background;
    private javax.swing.JButton cancelButton;
    private javax.swing.JCheckBox colorThemeBox;
    private javax.swing.JSlider fontSizeSlider;
    private javax.swing.JButton foregroundButton;
    private javax.swing.JLabel headerLabel;
    private javax.swing.JLabel lnFLabel;
    private javax.swing.JButton okButton;
    private javax.swing.JLabel restartLabel;
    private javax.swing.JComboBox setLnFBox;
    private javax.swing.JCheckBox tabWindowBox;
    private javax.swing.JCheckBox tableExpandBox;
    private javax.swing.JCheckBox tableLineBox;
    private javax.swing.JLabel textSizeLabel;
    // End of variables declaration//GEN-END:variables

}
